/* Generated by Cython 3.0.11 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/_core/include/numpy/arrayobject.h",
            "/private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/_core/include/numpy/arrayscalars.h",
            "/private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/_core/include/numpy/ndarrayobject.h",
            "/private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/_core/include/numpy/ndarraytypes.h",
            "/private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/_core/include/numpy/ufuncobject.h",
            "class-sz/include/class.h"
        ],
        "extra_link_args": [
            "-lomp",
            "-lgsl",
            "-lfftw3",
            "-lgslcblas"
        ],
        "include_dirs": [
            "/private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/_core/include",
            "class-sz/include"
        ],
        "libraries": [
            "class"
        ],
        "library_dirs": [
            "class-sz",
            "/Applications/Xcode_15.4.app/Contents/Developer/Toolchains/XcodeDefault.xctoolchain/usr/lib/clang/15.0.0/lib/darwin"
        ],
        "name": "classy_sz",
        "sources": [
            "class-sz/python/classy.pyx"
        ]
    },
    "module_name": "classy_sz"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_11" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x03000BF0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 0
  #endif
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__;  (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__classy_sz
#define __PYX_HAVE_API__classy_sz
/* Early includes */
#include <string.h>
#include <stdio.h>

    /* Using NumPy API declarations from "numpy/__init__.cython-30.pxd" */
    
#include "numpy/arrayobject.h"
#include "numpy/ndarrayobject.h"
#include "numpy/ndarraytypes.h"
#include "numpy/arrayscalars.h"
#include "numpy/ufuncobject.h"
#include <stdlib.h>
#include <math.h>
#include "class.h"
#include "pythread.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif (defined(_Complex_I) && !defined(_MSC_VER)) || ((defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) && !defined(__STDC_NO_COMPLEX__) && !defined(_MSC_VER))
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "class-sz/python/classy.pyx",
  "<stringsource>",
  "__init__.cython-30.pxd",
  "type.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* BufferFormatStructs.proto */
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;

/* Atomics.proto */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_incr_aligned(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_decr_aligned(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_incr_aligned(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_decr_aligned(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_incr_aligned(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_aligned(value) __sync_fetch_and_sub(value, 1)
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #pragma intrinsic (_InterlockedExchangeAdd)
    #define __pyx_atomic_incr_aligned(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_aligned(value) _InterlockedExchangeAdd(value, -1)
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif
#if CYTHON_ATOMICS
    #define __pyx_add_acquisition_count(memview)\
             __pyx_atomic_incr_aligned(__pyx_get_slice_count_pointer(memview))
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_atomic_decr_aligned(__pyx_get_slice_count_pointer(memview))
#else
    #define __pyx_add_acquisition_count(memview)\
            __pyx_add_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_sub_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
#endif

/* MemviewSliceStruct.proto */
struct __pyx_memoryview_obj;
typedef struct {
  struct __pyx_memoryview_obj *memview;
  char *data;
  Py_ssize_t shape[8];
  Py_ssize_t strides[8];
  Py_ssize_t suboffsets[8];
} __Pyx_memviewslice;
#define __Pyx_MemoryView_Len(m)  (m.shape[0])

/* #### Code section: numeric_typedefs ### */

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":770
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":771
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":772
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":773
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":777
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":778
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":779
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":780
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":784
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":785
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":792
 * ctypedef double complex complex128_t
 * 
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":793
 * 
 * ctypedef npy_longlong   longlong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":795
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":796
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":798
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":799
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":800
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef float complex       cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;

/* "class-sz/python/classy.pyx":163
 *         return d.viewitems()
 * 
 * ctypedef np.float_t DTYPE_t             # <<<<<<<<<<<<<<
 * ctypedef np.int64_t DTYPE_i
 * 
 */
typedef __pyx_t_5numpy_float_t __pyx_t_9classy_sz_DTYPE_t;

/* "class-sz/python/classy.pyx":164
 * 
 * ctypedef np.float_t DTYPE_t
 * ctypedef np.int64_t DTYPE_i             # <<<<<<<<<<<<<<
 * 
 * # Import the .pxd containing definitions
 */
typedef __pyx_t_5numpy_int64_t __pyx_t_9classy_sz_DTYPE_i;
/* #### Code section: complex_type_declarations ### */
/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< long double > __pyx_t_long_double_complex;
  #else
    typedef long double _Complex __pyx_t_long_double_complex;
  #endif
#else
    typedef struct { long double real, imag; } __pyx_t_long_double_complex;
#endif
static CYTHON_INLINE __pyx_t_long_double_complex __pyx_t_long_double_complex_from_parts(long double, long double);

/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_9classy_sz_Class;
struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings;
struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast;
struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr;
struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl;
struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl;
struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw;
struct __pyx_array_obj;
struct __pyx_MemviewEnum_obj;
struct __pyx_memoryview_obj;
struct __pyx_memoryviewslice_obj;

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1096
 * 
 * # Iterator API added in v1.6
 * ctypedef int (*NpyIter_IterNextFunc)(NpyIter* it) noexcept nogil             # <<<<<<<<<<<<<<
 * ctypedef void (*NpyIter_GetMultiIndexFunc)(NpyIter* it, npy_intp* outcoords) noexcept nogil
 * 
 */
typedef int (*__pyx_t_5numpy_NpyIter_IterNextFunc)(NpyIter *);

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1097
 * # Iterator API added in v1.6
 * ctypedef int (*NpyIter_IterNextFunc)(NpyIter* it) noexcept nogil
 * ctypedef void (*NpyIter_GetMultiIndexFunc)(NpyIter* it, npy_intp* outcoords) noexcept nogil             # <<<<<<<<<<<<<<
 * 
 * cdef extern from "numpy/arrayobject.h":
 */
typedef void (*__pyx_t_5numpy_NpyIter_GetMultiIndexFunc)(NpyIter *, npy_intp *);
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;
struct __pyx_defaults1;
typedef struct __pyx_defaults1 __pyx_defaults1;
struct __pyx_defaults {
  PyObject *__pyx_arg_level;
};
struct __pyx_defaults1 {
  PyObject *__pyx_arg_specific_keys;
};

/* "class-sz/python/classy.pyx":208
 * 
 * 
 * cdef class Class:             # <<<<<<<<<<<<<<
 *     """
 *     Class wrapping, creates the glue between C and python
 */
struct __pyx_obj_9classy_sz_Class {
  PyObject_HEAD
  struct __pyx_vtabstruct_9classy_sz_Class *__pyx_vtab;
  struct precision pr;
  struct background ba;
  struct thermo th;
  struct perturbs pt;
  struct primordial pm;
  struct nonlinear nl;
  struct transfers tr;
  struct spectra sp;
  struct output op;
  struct lensing le;
  struct class_sz_structure tsz;
  struct szcount csz;
  struct file_content fc;
  int computed;
  int allocated;
  PyObject *_pars;
  PyObject *ncp;
  PyObject *logger;
  double sigma8_fast;
  double A_s_fast;
  double logA_fast;
  double Neff_fast;
  PyObject *class_szfast;
  int likelihood_mode;
};


/* "class-sz/python/classy.pyx":52
 *     configure_logging(level)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def suppress_warnings():
 *     warnings.filterwarnings("ignore")
 */
struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings {
  PyObject_HEAD
};


/* "class-sz/python/classy.pyx":727
 *     # @cython.wraparound(False)
 *     # the likelihood_mode parameter is used to identify whether we run within cobaya
 *     def compute_class_szfast(self,likelihood_mode=False):             # <<<<<<<<<<<<<<
 * 
 * 
 */
struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast {
  PyObject_HEAD
  struct __pyx_obj_9classy_sz_Class *__pyx_v_self;
};


/* "class-sz/python/classy.pyx":856
 *                 pknl_in_output = re.compile(r'^hf$').match(self._pars['output'])
 * 
 *                 pknl_key_value_checks = any(self._pars.get(key) == 1 for key in ['use_pknl_in_2hterms_IA_only', 'use_pknl_in_2hterms'])             # <<<<<<<<<<<<<<
 * 
 *                 non_linear_check = 'non_linear' in self._pars
 */
struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr {
  PyObject_HEAD
  struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *__pyx_outer_scope;
  PyObject *__pyx_v_key;
};


/* "class-sz/python/classy.pyx":4234
 * 
 * 
 *     def get_pkl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the linear power spectrum at given wavenumbers and redshifts.
 */
struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl {
  PyObject_HEAD
  PyObject *__pyx_v_compute_pkl;
  struct __pyx_obj_9classy_sz_Class *__pyx_v_self;
};


/* "class-sz/python/classy.pyx":4279
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pknl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the non-linear power spectrum at given wavenumbers and redshifts.
 */
struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl {
  PyObject_HEAD
  PyObject *__pyx_v_compute_pknl;
  struct __pyx_obj_9classy_sz_Class *__pyx_v_self;
};


/* "class-sz/python/classy.pyx":4533
 * 
 *     # Define the vectorized method
 *     def get_uk_nfw(self, z_input, k_input, m_input, double xout=1):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the truncated NFW profile at given redshifts, wavenumbers, and masses.
 */
struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw {
  PyObject_HEAD
  PyObject *__pyx_v_compute_profile;
  struct __pyx_obj_9classy_sz_Class *__pyx_v_self;
  double __pyx_v_xout;
};


/* "View.MemoryView":114
 * @cython.collection_type("sequence")
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
struct __pyx_array_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_array *__pyx_vtab;
  char *data;
  Py_ssize_t len;
  char *format;
  int ndim;
  Py_ssize_t *_shape;
  Py_ssize_t *_strides;
  Py_ssize_t itemsize;
  PyObject *mode;
  PyObject *_format;
  void (*callback_free_data)(void *);
  int free_data;
  int dtype_is_object;
};


/* "View.MemoryView":302
 * 
 * @cname('__pyx_MemviewEnum')
 * cdef class Enum(object):             # <<<<<<<<<<<<<<
 *     cdef object name
 *     def __init__(self, name):
 */
struct __pyx_MemviewEnum_obj {
  PyObject_HEAD
  PyObject *name;
};


/* "View.MemoryView":337
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview:             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */
struct __pyx_memoryview_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_memoryview *__pyx_vtab;
  PyObject *obj;
  PyObject *_size;
  PyObject *_array_interface;
  PyThread_type_lock lock;
  __pyx_atomic_int_type acquisition_count;
  Py_buffer view;
  int flags;
  int dtype_is_object;
  __Pyx_TypeInfo *typeinfo;
};


/* "View.MemoryView":952
 * @cython.collection_type("sequence")
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */
struct __pyx_memoryviewslice_obj {
  struct __pyx_memoryview_obj __pyx_base;
  __Pyx_memviewslice from_slice;
  PyObject *from_object;
  PyObject *(*to_object_func)(char *);
  int (*to_dtype_func)(char *, PyObject *);
};



/* "class-sz/python/classy.pyx":208
 * 
 * 
 * cdef class Class:             # <<<<<<<<<<<<<<
 *     """
 *     Class wrapping, creates the glue between C and python
 */

struct __pyx_vtabstruct_9classy_sz_Class {
  PyObject *(*get_perturbations)(struct __pyx_obj_9classy_sz_Class *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9classy_sz_Class *__pyx_vtabptr_9classy_sz_Class;


/* "View.MemoryView":114
 * @cython.collection_type("sequence")
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */

struct __pyx_vtabstruct_array {
  PyObject *(*get_memview)(struct __pyx_array_obj *);
};
static struct __pyx_vtabstruct_array *__pyx_vtabptr_array;


/* "View.MemoryView":337
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview:             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */

struct __pyx_vtabstruct_memoryview {
  char *(*get_item_pointer)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*is_slice)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_slice_assignment)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*setitem_slice_assign_scalar)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_indexed)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*convert_item_to_object)(struct __pyx_memoryview_obj *, char *);
  PyObject *(*assign_item_from_object)(struct __pyx_memoryview_obj *, char *, PyObject *);
  PyObject *(*_get_base)(struct __pyx_memoryview_obj *);
};
static struct __pyx_vtabstruct_memoryview *__pyx_vtabptr_memoryview;


/* "View.MemoryView":952
 * @cython.collection_type("sequence")
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */

struct __pyx_vtabstruct__memoryviewslice {
  struct __pyx_vtabstruct_memoryview __pyx_base;
};
static struct __pyx_vtabstruct__memoryviewslice *__pyx_vtabptr__memoryviewslice;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *); /*proto*/
/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* DivInt[Py_ssize_t].proto */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t, Py_ssize_t);

/* UnaryNegOverflows.proto */
#define __Pyx_UNARY_NEG_WOULD_OVERFLOW(x)\
        (((x) < 0) & ((unsigned long)(x) == 0-(unsigned long)(x)))

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (1)
#elif CYTHON_COMPILING_IN_LIMITED_API  ||  (CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030C0000)
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PySequenceMultiply.proto */
#define __Pyx_PySequence_Multiply_Left(mul, seq)  __Pyx_PySequence_Multiply(seq, mul)
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* DivInt[long].proto */
static CYTHON_INLINE long __Pyx_div_long(long, long);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_size_t(size_t value, Py_ssize_t width, char padding_char, char format_char);

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* set_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set);
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set);

/* pyfrozenset_new.proto */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* PySetContains.proto */
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyObject_Unicode.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))
#else
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Unicode(obj))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* decode_c_string_utf16.proto */
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 0;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16LE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = -1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16BE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* MergeKeywords.proto */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping);

/* RaiseClosureNameError.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_TrueDivideObjC(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_SubtractObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_SubtractObjC(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* SliceObject.proto */
#define __Pyx_PyObject_DelSlice(obj, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)\
    __Pyx_PyObject_SetSlice(obj, (PyObject*)NULL, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(
        PyObject* obj, PyObject* value, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right)
    #endif
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_ConcatInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_ConcatInPlaceSafe(left, right) ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_ConcatInPlace(left, right))

/* PyIntFromDouble.proto */
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE PyObject* __Pyx_PyInt_FromDouble(double value);
#else
#define __Pyx_PyInt_FromDouble(value) PyLong_FromDouble(value)
#endif

/* IsLittleEndian.proto */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void);

/* BufferFormatCheck.proto */
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts);
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type);

/* BufferGetAndValidate.proto */
#define __Pyx_GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack)\
    ((obj == Py_None || obj == NULL) ?\
    (__Pyx_ZeroBuffer(buf), 0) :\
    __Pyx__GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack))
static int  __Pyx__GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static void __Pyx_ZeroBuffer(Py_buffer* buf);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);
static Py_ssize_t __Pyx_minusones[] = { -1, -1, -1, -1, -1, -1, -1, -1 };
static Py_ssize_t __Pyx_zeros[] = { 0, 0, 0, 0, 0, 0, 0, 0 };

/* BufferIndexError.proto */
static void __Pyx_RaiseBufferIndexError(int axis);

#define __Pyx_BufPtrStrided3d(type, buf, i0, s0, i1, s1, i2, s2) (type)((char*)buf + i0 * s0 + i1 * s1 + i2 * s2)
#define __Pyx_BufPtrStrided1d(type, buf, i0, s0) (type)((char*)buf + i0 * s0)
#define __Pyx_BufPtrStrided2d(type, buf, i0, s0, i1, s1) (type)((char*)buf + i0 * s0 + i1 * s1)
/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddCObj(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_TrueDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_TrueDivideObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_TrueDivideCObj(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_AddCObj(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyFloatBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyFloat_AddObjC(op1, op2, floatval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_MultiplyCObj(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type);
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_0_11
#define __PYX_HAVE_RT_ImportType_proto_3_0_11
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_11(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_11(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_0_11 {
   __Pyx_ImportType_CheckSize_Error_3_0_11 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_0_11 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_0_11 = 2
};
static PyTypeObject *__Pyx_ImportType_3_0_11(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_11 check_size);
#endif

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


/* BufferStructDeclare.proto */
typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

/* MemviewSliceIsContig.proto */
static int __pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim);

/* OverlappingSlices.proto */
static int __pyx_slices_overlap(__Pyx_memviewslice *slice1,
                                __Pyx_memviewslice *slice2,
                                int ndim, size_t itemsize);

/* TypeInfoCompare.proto */
static int __pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b);

/* MemviewSliceValidateAndInit.proto */
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_d_dc_double(PyObject *, int writable_flag);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_double(const char *itemp);
static CYTHON_INLINE int __pyx_memview_set_double(const char *itemp, PyObject *obj);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_long__double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_long__double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_long__double(a, b) ((a)-(b))
    #define __Pyx_c_prod_long__double(a, b) ((a)*(b))
    #define __Pyx_c_quot_long__double(a, b) ((a)/(b))
    #define __Pyx_c_neg_long__double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_long__double(z) ((z)==(long double)0)
    #define __Pyx_c_conj_long__double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_long__double(z)     (::std::abs(z))
        #define __Pyx_c_pow_long__double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_long__double(z) ((z)==0)
    #define __Pyx_c_conj_long__double(z)    (conjl(z))
    #if 1
        #define __Pyx_c_abs_long__double(z)     (cabsl(z))
        #define __Pyx_c_pow_long__double(a, b)  (cpowl(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_long__double(__pyx_t_long_double_complex, __pyx_t_long_double_complex);
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_sum_long__double(__pyx_t_long_double_complex, __pyx_t_long_double_complex);
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_diff_long__double(__pyx_t_long_double_complex, __pyx_t_long_double_complex);
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_prod_long__double(__pyx_t_long_double_complex, __pyx_t_long_double_complex);
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_quot_long__double(__pyx_t_long_double_complex, __pyx_t_long_double_complex);
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_neg_long__double(__pyx_t_long_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_long__double(__pyx_t_long_double_complex);
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_conj_long__double(__pyx_t_long_double_complex);
    #if 1
        static CYTHON_INLINE long double __Pyx_c_abs_long__double(__pyx_t_long_double_complex);
        static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_pow_long__double(__pyx_t_long_double_complex, __pyx_t_long_double_complex);
    #endif
#endif

/* MemviewSliceCopyTemplate.proto */
static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object);

/* MemviewSliceInit.proto */
#define __Pyx_BUF_MAX_NDIMS %(BUF_MAX_NDIMS)d
#define __Pyx_MEMVIEW_DIRECT   1
#define __Pyx_MEMVIEW_PTR      2
#define __Pyx_MEMVIEW_FULL     4
#define __Pyx_MEMVIEW_CONTIG   8
#define __Pyx_MEMVIEW_STRIDED  16
#define __Pyx_MEMVIEW_FOLLOW   32
#define __Pyx_IS_C_CONTIG 1
#define __Pyx_IS_F_CONTIG 2
static int __Pyx_init_memviewslice(
                struct __pyx_memoryview_obj *memview,
                int ndim,
                __Pyx_memviewslice *memviewslice,
                int memview_is_new_reference);
static CYTHON_INLINE int __pyx_add_acquisition_count_locked(
    __pyx_atomic_int_type *acquisition_count, PyThread_type_lock lock);
static CYTHON_INLINE int __pyx_sub_acquisition_count_locked(
    __pyx_atomic_int_type *acquisition_count, PyThread_type_lock lock);
#define __pyx_get_slice_count_pointer(memview) (&memview->acquisition_count)
#define __PYX_INC_MEMVIEW(slice, have_gil) __Pyx_INC_MEMVIEW(slice, have_gil, __LINE__)
#define __PYX_XCLEAR_MEMVIEW(slice, have_gil) __Pyx_XCLEAR_MEMVIEW(slice, have_gil, __LINE__)
static CYTHON_INLINE void __Pyx_INC_MEMVIEW(__Pyx_memviewslice *, int, int);
static CYTHON_INLINE void __Pyx_XCLEAR_MEMVIEW(__Pyx_memviewslice *, int, int);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* TypeInfoToFormat.proto */
struct __pyx_typeinfo_string {
    char string[3];
};
static struct __pyx_typeinfo_string __Pyx_TypeInfoToFormat(__Pyx_TypeInfo *type);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_intp __Pyx_PyInt_As_npy_intp(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_intp(npy_intp value);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_short(short value);

/* CIntFromPy.proto */
static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CoroutineBase.proto */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */
static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self); /* proto*/
static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto*/
static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview__get_base(struct __pyx_memoryview_obj *__pyx_v_self); /* proto*/
static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryviewslice__get_base(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_5dtype_8itemsize_itemsize(PyArray_Descr *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_5dtype_9alignment_alignment(PyArray_Descr *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_5numpy_5dtype_6fields_fields(PyArray_Descr *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_5numpy_5dtype_5names_names(PyArray_Descr *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyArray_ArrayDescr *__pyx_f_5numpy_5dtype_8subarray_subarray(PyArray_Descr *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_uint64 __pyx_f_5numpy_5dtype_5flags_flags(PyArray_Descr *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_5numpy_9broadcast_7numiter_numiter(PyArrayMultiIterObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_9broadcast_4size_size(PyArrayMultiIterObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_9broadcast_5index_index(PyArrayMultiIterObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_5numpy_9broadcast_2nd_nd(PyArrayMultiIterObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_9broadcast_10dimensions_dimensions(PyArrayMultiIterObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE void **__pyx_f_5numpy_9broadcast_5iters_iters(PyArrayMultiIterObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_9classy_sz_5Class_get_perturbations(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "numpy" */

/* Module declarations from "numpy" */

/* Module declarations from "libc.stdlib" */

/* Module declarations from "cython.view" */
static struct __pyx_array_obj *__pyx_array_new(PyObject *, Py_ssize_t, char *, char *, char *); /*proto*/

/* Module declarations from "cython.dataclasses" */

/* Module declarations from "cython" */

/* Module declarations from "libc.math" */

/* Module declarations from "cclassy" */

/* Module declarations from "classy_sz" */
static PyObject *__pyx_collections_abc_Sequence = 0;
static PyObject *generic = 0;
static PyObject *strided = 0;
static PyObject *indirect = 0;
static PyObject *contiguous = 0;
static PyObject *indirect_contiguous = 0;
static int __pyx_memoryview_thread_locks_used;
static PyThread_type_lock __pyx_memoryview_thread_locks[8];
static int __pyx_array_allocate_buffer(struct __pyx_array_obj *); /*proto*/
static struct __pyx_array_obj *__pyx_array_new(PyObject *, Py_ssize_t, char *, char *, char *); /*proto*/
static PyObject *__pyx_memoryview_new(PyObject *, int, int, __Pyx_TypeInfo *); /*proto*/
static CYTHON_INLINE int __pyx_memoryview_check(PyObject *); /*proto*/
static PyObject *_unellipsify(PyObject *, int); /*proto*/
static int assert_direct_dimensions(Py_ssize_t *, int); /*proto*/
static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *, PyObject *); /*proto*/
static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int, int); /*proto*/
static char *__pyx_pybuffer_index(Py_buffer *, char *, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memslice_transpose(__Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice, int, PyObject *(*)(char *), int (*)(char *, PyObject *), int); /*proto*/
static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *); /*proto*/
static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static Py_ssize_t abs_py_ssize_t(Py_ssize_t); /*proto*/
static char __pyx_get_best_slice_order(__Pyx_memviewslice *, int); /*proto*/
static void _copy_strided_to_strided(char *, Py_ssize_t *, char *, Py_ssize_t *, Py_ssize_t *, Py_ssize_t *, int, size_t); /*proto*/
static void copy_strided_to_strided(__Pyx_memviewslice *, __Pyx_memviewslice *, int, size_t); /*proto*/
static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *, int); /*proto*/
static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *, Py_ssize_t *, Py_ssize_t, int, char); /*proto*/
static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *, __Pyx_memviewslice *, char, int); /*proto*/
static int __pyx_memoryview_err_extents(int, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memoryview_err_dim(PyObject *, PyObject *, int); /*proto*/
static int __pyx_memoryview_err(PyObject *, PyObject *); /*proto*/
static int __pyx_memoryview_err_no_memory(void); /*proto*/
static int __pyx_memoryview_copy_contents(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int); /*proto*/
static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *, int, int); /*proto*/
static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *, int, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *, int, size_t, void *, int); /*proto*/
static void __pyx_memoryview__slice_assign_scalar(char *, Py_ssize_t *, Py_ssize_t *, int, size_t, void *); /*proto*/
static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *, PyObject *); /*proto*/
static PyObject *__pyx_format_from_typeinfo(__Pyx_TypeInfo *); /*proto*/
/* #### Code section: typeinfo ### */
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t = { "DTYPE_t", NULL, sizeof(__pyx_t_9classy_sz_DTYPE_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_double = { "double", NULL, sizeof(double), { 0 }, 0, 'R', 0, 0 };
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "classy_sz"
extern int __pyx_module_is_main_classy_sz;
int __pyx_module_is_main_classy_sz = 0;

/* Implementation of "classy_sz" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_AssertionError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_xrange;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_NotImplementedError;
static PyObject *__pyx_builtin___import__;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_Ellipsis;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_ImportError;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = ": ";
static const char __pyx_k_A[] = "A";
static const char __pyx_k_B[] = "B";
static const char __pyx_k_D[] = "D";
static const char __pyx_k_F[] = "F";
static const char __pyx_k_G[] = "G";
static const char __pyx_k_H[] = "H";
static const char __pyx_k_M[] = "M";
static const char __pyx_k_N[] = "N";
static const char __pyx_k_O[] = "O";
static const char __pyx_k_P[] = "P";
static const char __pyx_k_R[] = "R";
static const char __pyx_k_T[] = "T{";
static const char __pyx_k_X[] = "X";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_h[] = "h";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_j[] = "j";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_l[] = "l";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_p[] = "p";
static const char __pyx_k_q[] = "q";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "[,\\s]+";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_y[] = "y";
static const char __pyx_k_z[] = "z";
static const char __pyx_k_1h[] = "1h";
static const char __pyx_k_2h[] = "2h";
static const char __pyx_k_3h[] = "3h";
static const char __pyx_k_As[] = "As";
static const char __pyx_k_Dz[] = "Dz";
static const char __pyx_k_Eh[] = "Eh";
static const char __pyx_k_Ez[] = "Ez";
static const char __pyx_k_H0[] = "H0";
static const char __pyx_k_I0[] = "I0";
static const char __pyx_k_Nc[] = "Nc";
static const char __pyx_k_Ns[] = "Ns";
static const char __pyx_k_Nz[] = "Nz";
static const char __pyx_k_Pz[] = "Pz";
static const char __pyx_k_QF[] = "QF";
static const char __pyx_k_Tb[] = "Tb";
static const char __pyx_k_Wg[] = "Wg";
static const char __pyx_k_Y0[] = "Y0";
static const char __pyx_k_Y1[] = "Y1";
static const char __pyx_k_Y2[] = "Y2";
static const char __pyx_k_Y3[] = "Y3";
static const char __pyx_k_Y4[] = "Y4";
static const char __pyx_k__2[] = ".";
static const char __pyx_k__3[] = "*";
static const char __pyx_k__6[] = "'";
static const char __pyx_k__7[] = ")";
static const char __pyx_k__9[] = "^";
static const char __pyx_k_bb[] = "bb";
static const char __pyx_k_bh[] = "bh";
static const char __pyx_k_cl[] = "cl";
static const char __pyx_k_dd[] = "dd";
static const char __pyx_k_dl[] = "dl";
static const char __pyx_k_dx[] = "dx";
static const char __pyx_k_ee[] = "ee";
static const char __pyx_k_fc[] = "fc";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_hf[] = "^hf$";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_k1[] = "k1";
static const char __pyx_k_k2[] = "k2";
static const char __pyx_k_k3[] = "k3";
static const char __pyx_k_kB[] = "kB";
static const char __pyx_k_kh[] = "kh";
static const char __pyx_k_kk[] = "kk";
static const char __pyx_k_ll[] = "ll";
static const char __pyx_k_me[] = "me";
static const char __pyx_k_mm[] = "mm";
static const char __pyx_k_nl[] = "nl";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_nq[] = "nq";
static const char __pyx_k_ns[] = "ns";
static const char __pyx_k_nu[] = "nu";
static const char __pyx_k_nz[] = "nz";
static const char __pyx_k_pi[] = "pi";
static const char __pyx_k_pk[] = "pk";
static const char __pyx_k_pp[] = "pp";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_rv[] = "rv";
static const char __pyx_k_td[] = "td";
static const char __pyx_k_te[] = "te";
static const char __pyx_k_tl[] = "tl";
static const char __pyx_k_tp[] = "tp";
static const char __pyx_k_tt[] = "tt";
static const char __pyx_k_xc[] = "xc";
static const char __pyx_k_xe[] = "xe";
static const char __pyx_k_xi[] = "xi";
static const char __pyx_k_y0[] = "y0";
static const char __pyx_k_yp[] = "yp";
static const char __pyx_k_z1[] = "z1";
static const char __pyx_k_z2[] = "z2";
static const char __pyx_k_zi[] = "zi";
static const char __pyx_k_zp[] = "zp";
static const char __pyx_k_A_s[] = "A_s";
static const char __pyx_k_D_A[] = "D_A";
static const char __pyx_k_Stw[] = "Stw";
static const char __pyx_k_V_0[] = "V_0";
static const char __pyx_k_V_1[] = "V_1";
static const char __pyx_k_V_2[] = "V_2";
static const char __pyx_k_V_3[] = "V_3";
static const char __pyx_k_V_4[] = "V_4";
static const char __pyx_k_Xtw[] = "Xtw";
static const char __pyx_k_YHe[] = "YHe";
static const char __pyx_k__10[] = "";
static const char __pyx_k__11[] = ":";
static const char __pyx_k__12[] = "}";
static const char __pyx_k__13[] = "(";
static const char __pyx_k__14[] = ",";
static const char __pyx_k__20[] = " ";
static const char __pyx_k__22[] = ", ";
static const char __pyx_k__46[] = "\t";
static const char __pyx_k_abc[] = "abc";
static const char __pyx_k_add[] = "add";
static const char __pyx_k_age[] = "age";
static const char __pyx_k_and[] = " and ";
static const char __pyx_k_chi[] = "chi";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_ctx[] = "ctx";
static const char __pyx_k_dcl[] = "dcl";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_ell[] = "ell";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_exp[] = "exp";
static const char __pyx_k_fNL[] = "fNL";
static const char __pyx_k_f_b[] = "f_b";
static const char __pyx_k_fac[] = "fac";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_got[] = " (got ";
static const char __pyx_k_h_P[] = "_h_P_";
static const char __pyx_k_hmf[] = "hmf";
static const char __pyx_k_hsv[] = "hsv";
static const char __pyx_k_imp[] = "imp";
static const char __pyx_k_k_B[] = "_k_B_";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_lCl[] = "lCl";
static const char __pyx_k_lcl[] = "lcl";
static const char __pyx_k_lcp[] = "lcp";
static const char __pyx_k_lin[] = "lin";
static const char __pyx_k_lna[] = "lna";
static const char __pyx_k_log[] = "log";
static const char __pyx_k_mPk[] = "mPk";
static const char __pyx_k_max[] = "max";
static const char __pyx_k_min[] = "min";
static const char __pyx_k_mnu[] = "mnu";
static const char __pyx_k_n5k[] = "n5k";
static const char __pyx_k_nCl[] = "nCl";
static const char __pyx_k_n_e[] = "n_e";
static const char __pyx_k_n_s[] = "n_s";
static const char __pyx_k_n_t[] = "n_t";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_nfw[] = "nfw";
static const char __pyx_k_nu1[] = "nu1";
static const char __pyx_k_nu2[] = "nu2";
static const char __pyx_k_num[] = "num";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_pCl[] = "pCl";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_rcl[] = "rcl";
static const char __pyx_k_sep[] = "sep";
static const char __pyx_k_set[] = "set";
static const char __pyx_k_str[] = "__str__";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_tCl[] = "tCl";
static const char __pyx_k_tau[] = "tau";
static const char __pyx_k_tmp[] = "tmp";
static const char __pyx_k_val[] = "val";
static const char __pyx_k_z_d[] = "z_d";
static const char __pyx_k_zpk[] = "zpk";
static const char __pyx_k_A_IA[] = "A_IA";
static const char __pyx_k_A_P0[] = "A_P0";
static const char __pyx_k_A_cn[] = "A_cn";
static const char __pyx_k_A_ir[] = "A_ir";
static const char __pyx_k_A_rs[] = "A_rs";
static const char __pyx_k_A_sn[] = "A_sn";
static const char __pyx_k_A_xc[] = "A_xc";
static const char __pyx_k_B_sz[] = "B_sz";
static const char __pyx_k_INFO[] = "INFO";
static const char __pyx_k_M1SZ[] = "M1SZ";
static const char __pyx_k_M500[] = "M500";
static const char __pyx_k_N_dg[] = "N_dg";
static const char __pyx_k_N_ur[] = "N_ur";
static const char __pyx_k_Neff[] = "Neff";
static const char __pyx_k_Ntot[] = "Ntot";
static const char __pyx_k_Om_m[] = "Om_m";
static const char __pyx_k_P200[] = "P200";
static const char __pyx_k_PArr[] = "PArr";
static const char __pyx_k_TCMB[] = "TCMB";
static const char __pyx_k_Tcmb[] = "Tcmb";
static const char __pyx_k_TkeV[] = "TkeV";
static const char __pyx_k_Type[] = "Type '";
static const char __pyx_k__554[] = "?";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_axis[] = "axis";
static const char __pyx_k_base[] = "base";
static const char __pyx_k_c500[] = "c500";
static const char __pyx_k_camb[] = "camb";
static const char __pyx_k_cnew[] = "cnew";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_cosh[] = "cosh";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_dndM[] = "dndM";
static const char __pyx_k_dndm[] = "dndm";
static const char __pyx_k_ds_d[] = "ds_d";
static const char __pyx_k_dumc[] = "dumc";
static const char __pyx_k_dydz[] = "dydz";
static const char __pyx_k_dzdr[] = "dzdr";
static const char __pyx_k_elem[] = "elem";
static const char __pyx_k_eps1[] = "eps1";
static const char __pyx_k_eps2[] = "eps2";
static const char __pyx_k_even[] = "even";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_fRel[] = "fRel";
static const char __pyx_k_flag[] = "flag";
static const char __pyx_k_hf_2[] = "hf";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_k_eq[] = "k_eq";
static const char __pyx_k_k_nl[] = "k_nl";
static const char __pyx_k_kars[] = "kars";
static const char __pyx_k_kind[] = "kind";
static const char __pyx_k_lmax[] = "lmax";
static const char __pyx_k_logA[] = "logA";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_math[] = "math";
static const char __pyx_k_mcut[] = "mcut";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_ndim[] = "ndim";
static const char __pyx_k_ngtm[] = "ngtm";
static const char __pyx_k_none[] = "none";
static const char __pyx_k_ntot[] = "ntot";
static const char __pyx_k_outf[] = "outf";
static const char __pyx_k_pack[] = "pack";
static const char __pyx_k_pars[] = "_pars";
static const char __pyx_k_qmax[] = "qmax";
static const char __pyx_k_rhoc[] = "rhoc";
static const char __pyx_k_rs_d[] = "rs_d";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_sinh[] = "sinh";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_sqrt[] = "sqrt";
static const char __pyx_k_step[] = "step";
static const char __pyx_k_stop[] = "stop";
static const char __pyx_k_tanh[] = "tanh";
static const char __pyx_k_tckP[] = "tckP";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_teyy[] = "teyy";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_xout[] = "xout";
static const char __pyx_k_zmax[] = "zmax";
static const char __pyx_k_zmin[] = "zmin";
static const char __pyx_k_ASCII[] = "ASCII";
static const char __pyx_k_A_cib[] = "A_cib";
static const char __pyx_k_Class[] = "Class";
static const char __pyx_k_DEBUG[] = "DEBUG";
static const char __pyx_k_Dzmax[] = "Dzmax";
static const char __pyx_k_M_max[] = "M_max";
static const char __pyx_k_M_min[] = "M_min";
static const char __pyx_k_T_cmb[] = "T_cmb";
static const char __pyx_k_alpha[] = "alpha";
static const char __pyx_k_arr_0[] = "arr_0";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_b_tty[] = "b_tty";
static const char __pyx_k_b_yyy[] = "b_yyy";
static const char __pyx_k_c_B12[] = "c_B12";
static const char __pyx_k_c_B16[] = "c_B16";
static const char __pyx_k_cl_ee[] = "cl_ee";
static const char __pyx_k_cl_eg[] = "cl_eg";
static const char __pyx_k_cl_gg[] = "cl_gg";
static const char __pyx_k_cl_gk[] = "cl_gk";
static const char __pyx_k_cl_gm[] = "cl_gm";
static const char __pyx_k_cl_gy[] = "cl_gy";
static const char __pyx_k_cl_kg[] = "cl_kg";
static const char __pyx_k_cl_kk[] = "cl_kk";
static const char __pyx_k_cl_km[] = "cl_km";
static const char __pyx_k_cl_md[] = "cl_md";
static const char __pyx_k_cl_mm[] = "cl_mm";
static const char __pyx_k_cl_my[] = "cl_my";
static const char __pyx_k_cl_sz[] = "cl_sz";
static const char __pyx_k_cl_yg[] = "cl_yg";
static const char __pyx_k_cl_ym[] = "cl_ym";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_cltot[] = "cltot";
static const char __pyx_k_cosmo[] = "cosmo";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_cubic[] = "cubic";
static const char __pyx_k_d_ell[] = "d_ell";
static const char __pyx_k_delta[] = "delta";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_dumcp[] = "dumcp";
static const char __pyx_k_empty[] = "empty";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_eps23[] = "eps23";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_eta_V[] = "eta_V";
static const char __pyx_k_f_rel[] = "f_rel";
static const char __pyx_k_fineP[] = "fineP";
static const char __pyx_k_first[] = "first";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_gamma[] = "gamma";
static const char __pyx_k_get_H[] = "get_H";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_input[] = "input";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_k_len[] = "k_len";
static const char __pyx_k_level[] = "level";
static const char __pyx_k_lmaxR[] = "lmaxR";
static const char __pyx_k_log10[] = "log10";
static const char __pyx_k_m_len[] = "m_len";
static const char __pyx_k_match[] = "match";
static const char __pyx_k_mcfit[] = "mcfit";
static const char __pyx_k_names[] = "names";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_ombh2[] = "ombh2";
static const char __pyx_k_omch2[] = "omch2";
static const char __pyx_k_omega[] = "omega";
static const char __pyx_k_pk_cb[] = "pk_cb";
static const char __pyx_k_power[] = "power";
static const char __pyx_k_q_arr[] = "q_arr";
static const char __pyx_k_q_max[] = "q_max";
static const char __pyx_k_r200c[] = "r200c";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_rates[] = "rates";
static const char __pyx_k_scale[] = "scale";
static const char __pyx_k_scipy[] = "scipy";
static const char __pyx_k_shape[] = "shape";
static const char __pyx_k_sigma[] = "sigma";
static const char __pyx_k_simps[] = "simps";
static const char __pyx_k_splev[] = "splev";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_t2t2f[] = "t2t2f";
static const char __pyx_k_tau_d[] = "tau_d";
static const char __pyx_k_theta[] = "theta";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_trapz[] = "trapz";
static const char __pyx_k_units[] = "units";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_vrms2[] = "vrms2";
static const char __pyx_k_y0Err[] = "y0Err";
static const char __pyx_k_ystar[] = "ystar";
static const char __pyx_k_z_arr[] = "z_arr";
static const char __pyx_k_z_len[] = "z_len";
static const char __pyx_k_z_max[] = "z_max";
static const char __pyx_k_z_min[] = "z_min";
static const char __pyx_k_z_rec[] = "z_rec";
static const char __pyx_k_zeros[] = "zeros";
static const char __pyx_k_A_beta[] = "A_beta";
static const char __pyx_k_A_rho0[] = "A_rho0";
static const char __pyx_k_Hankel[] = "Hankel";
static const char __pyx_k_Hubble[] = "Hubble";
static const char __pyx_k_MUpper[] = "MUpper";
static const char __pyx_k_M_halo[] = "M_halo";
static const char __pyx_k_N_ncdm[] = "N_ncdm";
static const char __pyx_k_N_ngal[] = "N_ngal";
static const char __pyx_k_Nmcfit[] = "Nmcfit";
static const char __pyx_k_P0GNFW[] = "P0GNFW";
static const char __pyx_k_P0_B12[] = "P0_B12";
static const char __pyx_k_a_dark[] = "a_dark";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_arange[] = "arange";
static const char __pyx_k_argmax[] = "argmax";
static const char __pyx_k_beta_s[] = "beta_s";
static const char __pyx_k_cl_cib[] = "cl_cib";
static const char __pyx_k_cl_gIA[] = "cl_gIA";
static const char __pyx_k_cl_gkg[] = "cl_gkg";
static const char __pyx_k_cl_ksz[] = "cl_ksz";
static const char __pyx_k_cl_mkg[] = "cl_mkg";
static const char __pyx_k_cl_ykg[] = "cl_ykg";
static const char __pyx_k_covmat[] = "covmat";
static const char __pyx_k_cp_B12[] = "cp_B12";
static const char __pyx_k_cp_B16[] = "cp_B16";
static const char __pyx_k_da_rec[] = "da_rec";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_dndlnM[] = "dndlnM";
static const char __pyx_k_dndlnm[] = "dndlnm";
static const char __pyx_k_dndzdy[] = "dndzdy";
static const char __pyx_k_double[] = "double";
static const char __pyx_k_ds_d_h[] = "ds_d_h";
static const char __pyx_k_ds_rec[] = "ds_rec";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_errmsg[] = "errmsg";
static const char __pyx_k_extrap[] = "extrap";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_get_Ez[] = "get_Ez";
static const char __pyx_k_get_dA[] = "get_dA";
static const char __pyx_k_get_pk[] = "get_pk";
static const char __pyx_k_get_uk[] = "get_uk";
static const char __pyx_k_ic_key[] = "ic_key";
static const char __pyx_k_ic_num[] = "ic_num";
static const char __pyx_k_id_nu1[] = "id_nu1";
static const char __pyx_k_id_nu2[] = "id_nu2";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_k_size[] = "k_size";
static const char __pyx_k_k_vals[] = "k_vals";
static const char __pyx_k_kh_len[] = "kh_len";
static const char __pyx_k_levels[] = "levels";
static const char __pyx_k_ln1pzc[] = "ln1pzc";
static const char __pyx_k_log10M[] = "log10M";
static const char __pyx_k_log_y0[] = "log_y0";
static const char __pyx_k_m_ncdm[] = "m_ncdm";
static const char __pyx_k_m_vals[] = "m_vals";
static const char __pyx_k_mcfitx[] = "mcfitx";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_nofail[] = "nofail";
static const char __pyx_k_nonlin[] = "nonlin";
static const char __pyx_k_output[] = "output";
static const char __pyx_k_pars_2[] = "pars";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_pk_lin[] = "pk_lin";
static const char __pyx_k_r_0002[] = "r_0002";
static const char __pyx_k_ra_rec[] = "ra_rec";
static const char __pyx_k_raw_cl[] = "raw_cl";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_rho0_m[] = "rho0_m";
static const char __pyx_k_rs_d_h[] = "rs_d_h";
static const char __pyx_k_rs_rec[] = "rs_rec";
static const char __pyx_k_scalar[] = "scalar";
static const char __pyx_k_sigma8[] = "sigma8";
static const char __pyx_k_sigmaM[] = "sigmaM";
static const char __pyx_k_sigmaT[] = "sigmaT";
static const char __pyx_k_spline[] = "_spline";
static const char __pyx_k_splrep[] = "splrep";
static const char __pyx_k_struct[] = "struct";
static const char __pyx_k_te_y_y[] = "te_y_y";
static const char __pyx_k_tensor[] = "tensor";
static const char __pyx_k_thetae[] = "thetae";
static const char __pyx_k_thetas[] = "thetas";
static const char __pyx_k_titles[] = "titles";
static const char __pyx_k_unpack[] = "unpack";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_vector[] = "vector";
static const char __pyx_k_xc_B12[] = "xc_B12";
static const char __pyx_k_xc_B16[] = "xc_B16";
static const char __pyx_k_xi_idr[] = "xi_idr";
static const char __pyx_k_xrange[] = "xrange";
static const char __pyx_k_z_of_r[] = "z_of_r";
static const char __pyx_k_z_reio[] = "z_reio";
static const char __pyx_k_z_size[] = "z_size";
static const char __pyx_k_z_star[] = "z_star";
static const char __pyx_k_z_step[] = "z_step";
static const char __pyx_k_z_vals[] = "z_vals";
static const char __pyx_k_1h_slow[] = "1h (slow)";
static const char __pyx_k_2h_slow[] = "2h (slow)";
static const char __pyx_k_3h_slow[] = "3h (slow)";
static const char __pyx_k_A_alpha[] = "A_alpha";
static const char __pyx_k_Class_h[] = "Class.h";
static const char __pyx_k_Delta_c[] = "Delta_c";
static const char __pyx_k_H_array[] = "H_array";
static const char __pyx_k_MF_extr[] = "MF_extr";
static const char __pyx_k_Nc_mean[] = "Nc_mean";
static const char __pyx_k_Omega_b[] = "Omega_b";
static const char __pyx_k_Omega_c[] = "Omega_c";
static const char __pyx_k_Omega_g[] = "Omega_g";
static const char __pyx_k_Omega_m[] = "Omega_m";
static const char __pyx_k_Omega_r[] = "Omega_r";
static const char __pyx_k_PLog10M[] = "PLog10M";
static const char __pyx_k_Profile[] = "Profile '";
static const char __pyx_k_TKelvin[] = "TKelvin";
static const char __pyx_k_alpha_s[] = "alpha_s";
static const char __pyx_k_alpha_t[] = "alpha_t";
static const char __pyx_k_asarray[] = "asarray";
static const char __pyx_k_c_asked[] = "c_asked";
static const char __pyx_k_c_delta[] = "c_delta";
static const char __pyx_k_cl_IA_g[] = "cl_IA_g";
static const char __pyx_k_cl_c1c1[] = "cl_c1c1";
static const char __pyx_k_cl_kg_k[] = "cl_kg_k";
static const char __pyx_k_cl_kg_m[] = "cl_kg_m";
static const char __pyx_k_class_2[] = "class";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_compute[] = "compute";
static const char __pyx_k_cov_N_N[] = "cov(N,N)";
static const char __pyx_k_cszfast[] = "cszfast";
static const char __pyx_k_current[] = "current";
static const char __pyx_k_da_star[] = "da_star";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_derived[] = "derived";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_ds_star[] = "ds_star";
static const char __pyx_k_find_As[] = "find_As";
static const char __pyx_k_flatten[] = "flatten";
static const char __pyx_k_float64[] = "float64";
static const char __pyx_k_fortran[] = "fortran";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_getData[] = "getData";
static const char __pyx_k_get_chi[] = "get_chi";
static const char __pyx_k_get_f_b[] = "get_f_b";
static const char __pyx_k_get_pkl[] = "get_pkl";
static const char __pyx_k_h_units[] = "h_units";
static const char __pyx_k_hplanck[] = "hplanck";
static const char __pyx_k_ic_info[] = "ic_info";
static const char __pyx_k_index_g[] = "index_g";
static const char __pyx_k_index_k[] = "index_k";
static const char __pyx_k_index_l[] = "index_l";
static const char __pyx_k_index_m[] = "index_m";
static const char __pyx_k_index_r[] = "index_r";
static const char __pyx_k_index_x[] = "index_x";
static const char __pyx_k_index_y[] = "index_y";
static const char __pyx_k_index_z[] = "index_z";
static const char __pyx_k_initial[] = "initial";
static const char __pyx_k_isw_tsz[] = "isw_tsz";
static const char __pyx_k_k_array[] = "k_array";
static const char __pyx_k_k_asked[] = "k_asked";
static const char __pyx_k_k_input[] = "k_input";
static const char __pyx_k_k_nl_cb[] = "k_nl_cb";
static const char __pyx_k_kh_vals[] = "kh_vals";
static const char __pyx_k_ksi_V_2[] = "ksi_V^2";
static const char __pyx_k_l_asked[] = "l_asked";
static const char __pyx_k_lensing[] = "lensing";
static const char __pyx_k_loadtxt[] = "loadtxt";
static const char __pyx_k_log10Ms[] = "log10Ms";
static const char __pyx_k_logging[] = "logging";
static const char __pyx_k_loglike[] = "loglike";
static const char __pyx_k_lowring[] = "lowring";
static const char __pyx_k_m_asked[] = "m_asked";
static const char __pyx_k_m_delta[] = "m_delta";
static const char __pyx_k_m_input[] = "m_input";
static const char __pyx_k_memview[] = "memview";
static const char __pyx_k_message[] = "message";
static const char __pyx_k_minimal[] = "minimal";
static const char __pyx_k_mu_size[] = "mu_size";
static const char __pyx_k_newaxis[] = "newaxis";
static const char __pyx_k_oldpars[] = "oldpars";
static const char __pyx_k_omega_b[] = "omega_b";
static const char __pyx_k_omega_c[] = "omega_c";
static const char __pyx_k_perturb[] = "perturb";
static const char __pyx_k_phi_max[] = "phi_max";
static const char __pyx_k_phi_min[] = "phi_min";
static const char __pyx_k_pk_tilt[] = "pk_tilt";
static const char __pyx_k_poisson[] = "poisson";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_profile[] = "profile";
static const char __pyx_k_r_asked[] = "r_asked";
static const char __pyx_k_r_delta[] = "r_delta";
static const char __pyx_k_ra_star[] = "ra_star";
static const char __pyx_k_rd_star[] = "rd_star";
static const char __pyx_k_reshape[] = "reshape";
static const char __pyx_k_rho0_cb[] = "rho0_cb";
static const char __pyx_k_rs_drag[] = "rs_drag";
static const char __pyx_k_rs_star[] = "rs_star";
static const char __pyx_k_sigma_8[] = "sigma_8";
static const char __pyx_k_spectra[] = "spectra";
static const char __pyx_k_szcat_z[] = "szcat_z";
static const char __pyx_k_szcount[] = "szcount";
static const char __pyx_k_tau_rec[] = "tau_rec";
static const char __pyx_k_tmpdict[] = "tmpdict";
static const char __pyx_k_version[] = "__version__";
static const char __pyx_k_want_ee[] = "want_ee";
static const char __pyx_k_want_pp[] = "want_pp";
static const char __pyx_k_want_te[] = "want_te";
static const char __pyx_k_want_tt[] = "want_tt";
static const char __pyx_k_x_asked[] = "x_asked";
static const char __pyx_k_x_outSZ[] = "x_outSZ";
static const char __pyx_k_z_array[] = "z_array";
static const char __pyx_k_z_asked[] = "z_asked";
static const char __pyx_k_z_edges[] = "z_edges";
static const char __pyx_k_z_input[] = "z_input";
static const char __pyx_k_1h_2h_3h[] = "^\\((1h|2h|3h)\\)$";
static const char __pyx_k_A10_file[] = "A10_file";
static const char __pyx_k_A_s_fast[] = "A_s_fast";
static const char __pyx_k_CRITICAL[] = "CRITICAL";
static const char __pyx_k_Class_pk[] = "Class.pk";
static const char __pyx_k_Ellipsis[] = "Ellipsis";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_M1_prime[] = "M1_prime";
static const char __pyx_k_M500c_zk[] = "M500c_zk";
static const char __pyx_k_Omega0_b[] = "Omega0_b";
static const char __pyx_k_Omega0_k[] = "Omega0_k";
static const char __pyx_k_Omega0_m[] = "Omega0_m";
static const char __pyx_k_P13_file[] = "P13_file";
static const char __pyx_k_Sequence[] = "Sequence";
static const char __pyx_k_T_ll_arr[] = "T_ll_arr";
static const char __pyx_k_Tcmb_gNU[] = "Tcmb_gNU";
static const char __pyx_k_bad_call[] = "bad call";
static const char __pyx_k_betaGNFW[] = "betaGNFW";
static const char __pyx_k_beta_B12[] = "beta_B12";
static const char __pyx_k_boundary[] = "boundary";
static const char __pyx_k_calcFRel[] = "calcFRel";
static const char __pyx_k_chi_star[] = "chi_star";
static const char __pyx_k_cl_g_cib[] = "cl_g_cib";
static const char __pyx_k_cl_kg_kg[] = "cl_kg_kg";
static const char __pyx_k_cl_md_ic[] = "cl_md_ic";
static const char __pyx_k_cl_t2t2f[] = "cl_t2t2f";
static const char __pyx_k_cl_y_cib[] = "cl_y_cib";
static const char __pyx_k_contains[] = "contains";
static const char __pyx_k_cumtrapz[] = "cumtrapz";
static const char __pyx_k_da_rec_h[] = "da_rec_h";
static const char __pyx_k_deg_ncdm[] = "deg_ncdm";
static const char __pyx_k_deltaSZE[] = "deltaSZE";
static const char __pyx_k_ds_rec_h[] = "ds_rec_h";
static const char __pyx_k_endpoint[] = "endpoint";
static const char __pyx_k_get_mu_e[] = "get_mu_e";
static const char __pyx_k_get_pknl[] = "get_pknl";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_index_ic[] = "index_ic";
static const char __pyx_k_index_md[] = "index_md";
static const char __pyx_k_index_mu[] = "index_mu";
static const char __pyx_k_index_pk[] = "index_pk";
static const char __pyx_k_intUpper[] = "intUpper";
static const char __pyx_k_interp1d[] = "interp1d";
static const char __pyx_k_isscalar[] = "isscalar";
static const char __pyx_k_isw_auto[] = "isw_auto";
static const char __pyx_k_isw_lens[] = "isw_lens";
static const char __pyx_k_itemsize[] = "itemsize";
static const char __pyx_k_kh_input[] = "kh_input";
static const char __pyx_k_linspace[] = "linspace";
static const char __pyx_k_logspace[] = "logspace";
static const char __pyx_k_maxIndex[] = "maxIndex";
static const char __pyx_k_mcut_B12[] = "mcut_B12";
static const char __pyx_k_minIndex[] = "minIndex";
static const char __pyx_k_pattern1[] = "pattern1";
static const char __pyx_k_pattern2[] = "pattern2";
static const char __pyx_k_pattern3[] = "pattern3";
static const char __pyx_k_pk_array[] = "pk_array";
static const char __pyx_k_pvecback[] = "pvecback";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_ra_rec_h[] = "ra_rec_h";
static const char __pyx_k_redshift[] = "redshift";
static const char __pyx_k_register[] = "register";
static const char __pyx_k_rs_rec_h[] = "rs_rec_h";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_sigma_cb[] = "sigma_cb";
static const char __pyx_k_skip_chi[] = "skip_chi";
static const char __pyx_k_skip_cmb[] = "skip_cmb";
static const char __pyx_k_skip_pkl[] = "skip_pkl";
static const char __pyx_k_tau_reio[] = "tau_reio";
static const char __pyx_k_tau_star[] = "tau_star";
static const char __pyx_k_theta500[] = "theta500";
static const char __pyx_k_transfer[] = "transfer";
static const char __pyx_k_warnings[] = "warnings";
static const char __pyx_k_xi_mcfit[] = "xi_mcfit";
static const char __pyx_k_z_center[] = "z_center";
static const char __pyx_k_z_of_tau[] = "z_of_tau";
static const char __pyx_k_Class_age[] = "Class.age";
static const char __pyx_k_Class_n_s[] = "Class.n_s";
static const char __pyx_k_Class_set[] = "Class.set";
static const char __pyx_k_M_min_HOD[] = "M_min_HOD";
static const char __pyx_k_Omega_cdm[] = "Omega_cdm";
static const char __pyx_k_Py0GivenM[] = "Py0GivenM";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_alphaGNFW[] = "alphaGNFW";
static const char __pyx_k_alpha_B12[] = "alpha_B12";
static const char __pyx_k_cl_c1_gal[] = "cl_c1_gal";
static const char __pyx_k_cl_c1_tSZ[] = "cl_c1_tSZ";
static const char __pyx_k_cl_ggamma[] = "cl_ggamma";
static const char __pyx_k_cl_kg_cib[] = "cl_kg_cib";
static const char __pyx_k_cl_te_y_y[] = "cl_te_y_y";
static const char __pyx_k_cl_y_kcmb[] = "cl_y_kcmb";
static const char __pyx_k_classy_sz[] = "classy_sz";
static const char __pyx_k_cltotfunc[] = "cltotfunc";
static const char __pyx_k_custom1_W[] = "custom1_W";
static const char __pyx_k_custom1_b[] = "custom1_b";
static const char __pyx_k_delta_def[] = "delta_def";
static const char __pyx_k_dl_isw_sz[] = "dl_isw_sz";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_epsilon_V[] = "epsilon_V";
static const char __pyx_k_extensive[] = "extensive";
static const char __pyx_k_gammaGNFW[] = "gammaGNFW";
static const char __pyx_k_gamma_B12[] = "gamma_B12";
static const char __pyx_k_gamma_B16[] = "gamma_B16";
static const char __pyx_k_geomspace[] = "geomspace";
static const char __pyx_k_getLogger[] = "getLogger";
static const char __pyx_k_get_m_nfw[] = "get_m_nfw";
static const char __pyx_k_get_pk_cb[] = "get_pk_cb";
static const char __pyx_k_has_flags[] = "has_flags";
static const char __pyx_k_ic_suffix[] = "ic_suffix";
static const char __pyx_k_index_m_z[] = "index_m_z";
static const char __pyx_k_index_tau[] = "index_tau";
static const char __pyx_k_index_z_r[] = "index_z_r";
static const char __pyx_k_integrate[] = "integrate";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_l_max_lss[] = "l_max_lss";
static const char __pyx_k_lensed_cl[] = "lensed_cl";
static const char __pyx_k_logA_fast[] = "logA_fast";
static const char __pyx_k_log_y0Err[] = "log_y0Err";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_nonlinear[] = "nonlinear";
static const char __pyx_k_normalize[] = "normalize";
static const char __pyx_k_nu_in_GHz[] = "nu_in_GHz";
static const char __pyx_k_nu_in_ghz[] = "nu_in_ghz";
static const char __pyx_k_omega_cdm[] = "omega_cdm";
static const char __pyx_k_omega_mh2[] = "omega_mh2";
static const char __pyx_k_pk_at_k_z[] = "pk_at_k_z";
static const char __pyx_k_pk_cb_lin[] = "pk_cb_lin";
static const char __pyx_k_pk_nonlin[] = "pk_nonlin";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_rho0_crit[] = "rho0_crit";
static const char __pyx_k_sBBN_file[] = "sBBN file";
static const char __pyx_k_sample_id[] = "sample_id";
static const char __pyx_k_shotnoise[] = "shotnoise";
static const char __pyx_k_sigma8_cb[] = "sigma8_cb";
static const char __pyx_k_sigma_int[] = "sigma_int";
static const char __pyx_k_skip_pknl[] = "skip_pknl";
static const char __pyx_k_szcat_snr[] = "szcat_snr";
static const char __pyx_k_theta_500[] = "theta_500";
static const char __pyx_k_theta_rad[] = "theta_rad";
static const char __pyx_k_timesteps[] = "timesteps";
static const char __pyx_k_transfers[] = "transfers";
static const char __pyx_k_use_pklin[] = "use_pklin";
static const char __pyx_k_vec_theta[] = "vec_theta";
static const char __pyx_k_vectorize[] = "vectorize";
static const char __pyx_k_verbosity[] = "verbosity";
static const char __pyx_k_viewitems[] = "viewitems";
static const char __pyx_k_Class_A_cn[] = "Class.A_cn";
static const char __pyx_k_Class_A_ir[] = "Class.A_ir";
static const char __pyx_k_Class_A_rs[] = "Class.A_rs";
static const char __pyx_k_Class_A_sn[] = "Class.A_sn";
static const char __pyx_k_Class_B_sz[] = "Class.B_sz";
static const char __pyx_k_Class_M1SZ[] = "Class.M1SZ";
static const char __pyx_k_Class_Neff[] = "Class.Neff";
static const char __pyx_k_Class_Om_m[] = "Class.Om_m";
static const char __pyx_k_Class_k_eq[] = "Class.k_eq";
static const char __pyx_k_CosmoError[] = "CosmoError";
static const char __pyx_k_Deprecated[] = "Deprecated";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_Omega0_cdm[] = "Omega0_cdm";
static const char __pyx_k_Omega0_fld[] = "Omega0_fld";
static const char __pyx_k_Rho_crit_0[] = "Rho_crit_0";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_alpha_c_P0[] = "alpha_c_P0";
static const char __pyx_k_alpha_c_xc[] = "alpha_c_xc";
static const char __pyx_k_alpha_m_P0[] = "alpha_m_P0";
static const char __pyx_k_alpha_m_xc[] = "alpha_m_xc";
static const char __pyx_k_alpha_z_P0[] = "alpha_z_P0";
static const char __pyx_k_alpha_z_xc[] = "alpha_z_xc";
static const char __pyx_k_atleast_1d[] = "atleast_1d";
static const char __pyx_k_background[] = "background";
static const char __pyx_k_bk_at_z_hm[] = "bk_at_z_hm";
static const char __pyx_k_calcErrors[] = "calcErrors";
static const char __pyx_k_cl_c1_lens[] = "cl_c1_lens";
static const char __pyx_k_cl_cib_cib[] = "cl_cib_cib";
static const char __pyx_k_cl_gal_cib[] = "cl_gal_cib";
static const char __pyx_k_cl_galn_IA[] = "cl_galn_IA";
static const char __pyx_k_cl_phi_cib[] = "cl_phi_cib";
static const char __pyx_k_cl_tSZ_cib[] = "cl_tSZ_cib";
static const char __pyx_k_contextlib[] = "contextlib";
static const char __pyx_k_custom1_ux[] = "custom1_ux";
static const char __pyx_k_delta_crit[] = "delta_crit";
static const char __pyx_k_density_cl[] = "density_cl";
static const char __pyx_k_empty_like[] = "empty_like";
static const char __pyx_k_fill_value[] = "fill_value";
static const char __pyx_k_fineLog10M[] = "fineLog10M";
static const char __pyx_k_getPLog10M[] = "getPLog10M";
static const char __pyx_k_get_dndlnm[] = "get_dndlnm";
static const char __pyx_k_get_dndzdq[] = "get_dndzdq";
static const char __pyx_k_get_f_free[] = "get_f_free";
static const char __pyx_k_get_hubble[] = "get_hubble";
static const char __pyx_k_get_mean_y[] = "get_mean_y";
static const char __pyx_k_get_pk_lin[] = "get_pk_lin";
static const char __pyx_k_get_uk_nfw[] = "get_uk_nfw";
static const char __pyx_k_issuperset[] = "issuperset";
static const char __pyx_k_l_max_flag[] = "l_max_flag";
static const char __pyx_k_last_index[] = "last_index";
static const char __pyx_k_log10x_num[] = "log10x_num";
static const char __pyx_k_log_y0pred[] = "log_y0pred";
static const char __pyx_k_m_ncdm_tot[] = "m_ncdm_tot";
static const char __pyx_k_non_linear[] = "non_linear";
static const char __pyx_k_obsFreqGHz[] = "obsFreqGHz";
static const char __pyx_k_pars_check[] = "_pars_check";
static const char __pyx_k_pk_at_z_hm[] = "pk_at_z_hm";
static const char __pyx_k_pk_linzmax[] = "pk_linzmax";
static const char __pyx_k_primordial[] = "primordial";
static const char __pyx_k_pvecthermo[] = "pvecthermo";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_qobs_asked[] = "qobs_asked";
static const char __pyx_k_sigma8_Pcb[] = "sigma8_Pcb";
static const char __pyx_k_sigma_8_cb[] = "sigma_8_cb";
static const char __pyx_k_sigma_disp[] = "sigma_disp";
static const char __pyx_k_skip_input[] = "skip_input";
static const char __pyx_k_transforms[] = "transforms";
static const char __pyx_k_window_nfw[] = "window_nfw";
static const char __pyx_k_100_theta_s[] = "100*theta_s";
static const char __pyx_k_Class_A_cib[] = "Class.A_cib";
static const char __pyx_k_Class_T_cmb[] = "Class.T_cmb";
static const char __pyx_k_Class_alpha[] = "Class.alpha";
static const char __pyx_k_Class_b_tty[] = "Class.b_tty";
static const char __pyx_k_Class_b_yyy[] = "Class.b_yyy";
static const char __pyx_k_Class_cl_ee[] = "Class.cl_ee";
static const char __pyx_k_Class_cl_eg[] = "Class.cl_eg";
static const char __pyx_k_Class_cl_gg[] = "Class.cl_gg";
static const char __pyx_k_Class_cl_gm[] = "Class.cl_gm";
static const char __pyx_k_Class_cl_kg[] = "Class.cl_kg";
static const char __pyx_k_Class_cl_kk[] = "Class.cl_kk";
static const char __pyx_k_Class_cl_km[] = "Class.cl_km";
static const char __pyx_k_Class_cl_mm[] = "Class.cl_mm";
static const char __pyx_k_Class_cl_sz[] = "Class.cl_sz";
static const char __pyx_k_Class_cl_yg[] = "Class.cl_yg";
static const char __pyx_k_Class_cl_ym[] = "Class.cl_ym";
static const char __pyx_k_Class_empty[] = "Class.empty";
static const char __pyx_k_Class_get_H[] = "Class.get_H";
static const char __pyx_k_Class_pk_cb[] = "Class.pk_cb";
static const char __pyx_k_Class_sigma[] = "Class.sigma";
static const char __pyx_k_Class_ystar[] = "Class.ystar";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_M0_HOD_ngal[] = "M0_HOD_ngal_";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_SZ_cat_file[] = "SZ_cat_file";
static const char __pyx_k_alpha_s_HOD[] = "alpha_s_HOD";
static const char __pyx_k_alphap_m_P0[] = "alphap_m_P0";
static const char __pyx_k_alphap_m_xc[] = "alphap_m_xc";
static const char __pyx_k_basicConfig[] = "basicConfig";
static const char __pyx_k_cl_galn_tsz[] = "cl_galn_tsz";
static const char __pyx_k_cl_lens_cib[] = "cl_lens_cib";
static const char __pyx_k_clusterM500[] = "clusterM500";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_compute_pkl[] = "compute_pkl";
static const char __pyx_k_cosmo_model[] = "cosmo_model";
static const char __pyx_k_defaultdict[] = "defaultdict";
static const char __pyx_k_extrapolate[] = "extrapolate";
static const char __pyx_k_fillparfile[] = "_fillparfile";
static const char __pyx_k_get_IA_of_z[] = "get_IA_of_z";
static const char __pyx_k_get_cov_N_N[] = "get_cov_N_N";
static const char __pyx_k_get_dA_z1z2[] = "get_dA_z1z2";
static const char __pyx_k_interpolate[] = "interpolate";
static const char __pyx_k_ln10_10_A_s[] = "ln10^{10}A_s";
static const char __pyx_k_m_flattened[] = "m_flattened";
static const char __pyx_k_mro_entries[] = "__mro_entries__";
static const char __pyx_k_ndim_masses[] = "ndim_masses";
static const char __pyx_k_output_keys[] = "output_keys";
static const char __pyx_k_q_threshold[] = "q_threshold";
static const char __pyx_k_set_default[] = "set_default";
static const char __pyx_k_sigma_prime[] = "sigma_prime";
static const char __pyx_k_skip_hubble[] = "skip_hubble";
static const char __pyx_k_theta_mcfit[] = "theta_mcfit";
static const char __pyx_k_theta_s_100[] = "theta_s_100";
static const char __pyx_k_tllprime_sz[] = "tllprime_sz";
static const char __pyx_k_z_flattened[] = "z_flattened";
static const char __pyx_k_z_for_pk_hm[] = "z_for_pk_hm";
static const char __pyx_k_Class_Hubble[] = "Class.Hubble";
static const char __pyx_k_Class_cl_ksz[] = "Class.cl_ksz";
static const char __pyx_k_Class_cl_ykg[] = "Class.cl_ykg";
static const char __pyx_k_Class_get_Ez[] = "Class.get_Ez";
static const char __pyx_k_Class_get_dA[] = "Class.get_dA";
static const char __pyx_k_Class_get_pk[] = "Class.get_pk";
static const char __pyx_k_Class_get_uk[] = "Class.get_uk";
static const char __pyx_k_Class_pk_lin[] = "Class.pk_lin";
static const char __pyx_k_Class_raw_cl[] = "Class.raw_cl";
static const char __pyx_k_Class_rho0_m[] = "Class.rho0_m";
static const char __pyx_k_Class_sigma8[] = "Class.sigma8";
static const char __pyx_k_Class_sigmaM[] = "Class.sigmaM";
static const char __pyx_k_Class_szfast[] = "Class_szfast";
static const char __pyx_k_Class_z_of_r[] = "Class.z_of_r";
static const char __pyx_k_Class_z_reio[] = "Class.z_reio";
static const char __pyx_k_Gamma_0_nadm[] = "Gamma_0_nadm";
static const char __pyx_k_M1_prime_HOD[] = "M1_prime_HOD";
static const char __pyx_k_Omega_Lambda[] = "Omega_Lambda";
static const char __pyx_k_PLog10M_full[] = "PLog10M_full";
static const char __pyx_k_alpha_c_beta[] = "alpha_c_beta";
static const char __pyx_k_alpha_c_rho0[] = "alpha_c_rho0";
static const char __pyx_k_alpha_m_beta[] = "alpha_m_beta";
static const char __pyx_k_alpha_m_rho0[] = "alpha_m_rho0";
static const char __pyx_k_alpha_z_beta[] = "alpha_z_beta";
static const char __pyx_k_alpha_z_rho0[] = "alpha_z_rho0";
static const char __pyx_k_bounds_error[] = "bounds_error";
static const char __pyx_k_cib_monopole[] = "cib_monopole";
static const char __pyx_k_cl_galn_galn[] = "cl_galn_galn";
static const char __pyx_k_cl_galn_lens[] = "cl_galn_lens";
static const char __pyx_k_cl_kSZ_kSZ_g[] = "cl_kSZ_kSZ_g";
static const char __pyx_k_compute_pknl[] = "compute_pknl";
static const char __pyx_k_extrapolator[] = "extrapolator";
static const char __pyx_k_gamma_ggamma[] = "gamma_ggamma";
static const char __pyx_k_get_pk_array[] = "get_pk_array";
static const char __pyx_k_get_pkl_at_z[] = "get_pkl_at_z";
static const char __pyx_k_get_transfer[] = "get_transfer";
static const char __pyx_k_get_z_of_chi[] = "get_z_of_chi";
static const char __pyx_k_index_M_bins[] = "index_M_bins";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_lensing_term[] = "lensing term";
static const char __pyx_k_log10y_edges[] = "log10y_edges";
static const char __pyx_k_lum_distance[] = "lum_distance";
static const char __pyx_k_m_ncdm_in_eV[] = "m_ncdm_in_eV";
static const char __pyx_k_pk_b_at_z_2h[] = "pk_b_at_z_2h";
static const char __pyx_k_pk_lin_array[] = "pk_lin_array";
static const char __pyx_k_problem_flag[] = "problem_flag";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_sigma_log10M[] = "sigma_log10M";
static const char __pyx_k_size_ic_data[] = "size_ic_data";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_theta_arcmin[] = "theta_arcmin";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_Class_Omega_b[] = "Class.Omega_b";
static const char __pyx_k_Class_Omega_g[] = "Class.Omega_g";
static const char __pyx_k_Class_Omega_m[] = "Class.Omega_m";
static const char __pyx_k_Class_Omega_r[] = "Class.Omega_r";
static const char __pyx_k_Class_cl_IA_g[] = "Class.cl_IA_g";
static const char __pyx_k_Class_cl_c1c1[] = "Class.cl_c1c1";
static const char __pyx_k_Class_cl_kg_k[] = "Class.cl_kg_k";
static const char __pyx_k_Class_cl_kg_m[] = "Class.cl_kg_m";
static const char __pyx_k_Class_compute[] = "Class.compute";
static const char __pyx_k_Class_get_chi[] = "Class.get_chi";
static const char __pyx_k_Class_get_f_b[] = "Class.get_f_b";
static const char __pyx_k_Class_get_pkl[] = "Class.get_pkl";
static const char __pyx_k_Class_omega_b[] = "Class.omega_b";
static const char __pyx_k_Class_pk_tilt[] = "Class.pk_tilt";
static const char __pyx_k_Class_rho0_cb[] = "Class.rho0_cb";
static const char __pyx_k_Class_rs_drag[] = "Class.rs_drag";
static const char __pyx_k_Omega0_lambda[] = "Omega0_lambda";
static const char __pyx_k_alpha_c_alpha[] = "alpha_c_alpha";
static const char __pyx_k_alpha_m_alpha[] = "alpha_m_alpha";
static const char __pyx_k_alpha_z_alpha[] = "alpha_z_alpha";
static const char __pyx_k_alphap_m_beta[] = "alphap_m_beta";
static const char __pyx_k_alphap_m_rho0[] = "alphap_m_rho0";
static const char __pyx_k_assume_sorted[] = "assume_sorted";
static const char __pyx_k_calculate_chi[] = "calculate_chi";
static const char __pyx_k_calculate_cmb[] = "calculate_cmb";
static const char __pyx_k_calculate_pkl[] = "calculate_pkl";
static const char __pyx_k_cib_shotnoise[] = "cib_shotnoise";
static const char __pyx_k_cl_c1_gallens[] = "cl_c1_gallens";
static const char __pyx_k_cl_g_gamma_1h[] = "cl_g_gamma_1h";
static const char __pyx_k_cl_g_gamma_2h[] = "cl_g_gamma_2h";
static const char __pyx_k_cl_kSZ_kSZ_kg[] = "cl_kSZ_kSZ_kg";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_classy_szfast[] = "classy_szfast";
static const char __pyx_k_conformal_age[] = "conformal_age";
static const char __pyx_k_get_Omega_m_0[] = "get_Omega_m_0";
static const char __pyx_k_get_Omega_r_0[] = "get_Omega_r_0";
static const char __pyx_k_get_dydz_at_z[] = "get_dydz_at_z";
static const char __pyx_k_get_params_sz[] = "get_params_sz";
static const char __pyx_k_get_pk_cb_lin[] = "get_pk_cb_lin";
static const char __pyx_k_get_pknl_at_z[] = "get_pknl_at_z";
static const char __pyx_k_index_l_prime[] = "index_l_prime";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_l_max_scalars[] = "l_max_scalars";
static const char __pyx_k_log10M500c_zk[] = "log10M500c_zk";
static const char __pyx_k_log10y_center[] = "log10y_center";
static const char __pyx_k_m_broadcasted[] = "m_broadcasted";
static const char __pyx_k_mass_function[] = "mass_function";
static const char __pyx_k_numberDensity[] = "numberDensity";
static const char __pyx_k_output_format[] = "output_format";
static const char __pyx_k_output_string[] = "output_string";
static const char __pyx_k_pk_bb_at_z_hm[] = "pk_bb_at_z_hm";
static const char __pyx_k_pk_em_at_z_hm[] = "pk_em_at_z_hm";
static const char __pyx_k_pk_gg_at_z_hm[] = "pk_gg_at_z_hm";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_resetwarnings[] = "resetwarnings";
static const char __pyx_k_set_verbosity[] = "set_verbosity";
static const char __pyx_k_sigma_disp_cb[] = "sigma_disp_cb";
static const char __pyx_k_skip_class_sz[] = "skip_class_sz";
static const char __pyx_k_specific_keys[] = "specific_keys";
static const char __pyx_k_szcounts_ntot[] = "szcounts_ntot";
static const char __pyx_k_viewdictitems[] = "viewdictitems";
static const char __pyx_k_x_out_custom1[] = "x_out_custom1";
static const char __pyx_k_z_broadcasted[] = "z_broadcasted";
static const char __pyx_k_100_theta_star[] = "100*theta_star";
static const char __pyx_k_AssertionError[] = "AssertionError";
static const char __pyx_k_Class_Omega0_b[] = "Class.Omega0_b";
static const char __pyx_k_Class_Omega0_k[] = "Class.Omega0_k";
static const char __pyx_k_Class_Omega0_m[] = "Class.Omega0_m";
static const char __pyx_k_Class_calcFRel[] = "Class.calcFRel";
static const char __pyx_k_Class_chi_star[] = "Class.chi_star";
static const char __pyx_k_Class_cl_kg_kg[] = "Class.cl_kg_kg";
static const char __pyx_k_Class_cl_t2t2f[] = "Class.cl_t2t2f";
static const char __pyx_k_Class_get_mu_e[] = "Class.get_mu_e";
static const char __pyx_k_Class_get_pknl[] = "Class.get_pknl";
static const char __pyx_k_Class_sigma_cb[] = "Class.sigma_cb";
static const char __pyx_k_Class_tau_reio[] = "Class.tau_reio";
static const char __pyx_k_Class_z_of_tau[] = "Class.z_of_tau";
static const char __pyx_k_Error_in_Class[] = "\n\nError in Class: ";
static const char __pyx_k_M_min_HOD_ngal[] = "M_min_HOD_ngal_";
static const char __pyx_k_No_Cl_computed[] = "No Cl computed";
static const char __pyx_k_alpha_c_P0_B12[] = "alpha_c_P0_B12";
static const char __pyx_k_alpha_c_xc_B12[] = "alpha_c_xc_B12";
static const char __pyx_k_alpha_m_P0_B12[] = "alpha_m_P0_B12";
static const char __pyx_k_alpha_m_xc_B12[] = "alpha_m_xc_B12";
static const char __pyx_k_alpha_z_P0_B12[] = "alpha_z_P0_B12";
static const char __pyx_k_alpha_z_xc_B12[] = "alpha_z_xc_B12";
static const char __pyx_k_alphap_m_alpha[] = "alphap_m_alpha";
static const char __pyx_k_bk_ttg_at_z_hm[] = "bk_ttg_at_z_hm";
static const char __pyx_k_calculate_pknl[] = "calculate_pknl";
static const char __pyx_k_cib_Snu_file_z[] = "cib_Snu_file_z";
static const char __pyx_k_cl_custom1_cib[] = "cl_custom1_cib";
static const char __pyx_k_cl_g_gamma_ell[] = "cl_g_gamma_ell";
static const char __pyx_k_class_sz_cosmo[] = "class_sz_cosmo";
static const char __pyx_k_clusterLogM500[] = "clusterLogM500";
static const char __pyx_k_contextmanager[] = "contextmanager";
static const char __pyx_k_dndz_shift_gal[] = "dndz_shift_gal";
static const char __pyx_k_dndzdy_index_z[] = "dndzdy_index_z";
static const char __pyx_k_exp_m_2_tau_As[] = "exp_m_2_tau_As";
static const char __pyx_k_filterwarnings[] = "filterwarnings";
static const char __pyx_k_get_N_centrals[] = "get_N_centrals";
static const char __pyx_k_get_background[] = "get_background";
static const char __pyx_k_get_primordial[] = "get_primordial";
static const char __pyx_k_get_vrms2_at_z[] = "get_vrms2_at_z";
static const char __pyx_k_integrate_only[] = "integrate_only";
static const char __pyx_k_load_n5k_cl_K1[] = "load_n5k_cl_K1";
static const char __pyx_k_load_n5k_pk_zk[] = "load_n5k_pk_zk";
static const char __pyx_k_mass_bin_edges[] = "mass_bin_edges";
static const char __pyx_k_ndim_redshifts[] = "ndim_redshifts";
static const char __pyx_k_pknl_in_output[] = "pknl_in_output";
static const char __pyx_k_sigma_disp_100[] = "sigma_disp_100";
static const char __pyx_k_sigma_prime_cb[] = "sigma_prime_cb";
static const char __pyx_k_struct_cleanup[] = "struct_cleanup";
static const char __pyx_k_thermodynamics[] = "thermodynamics";
static const char __pyx_k_theta_star_100[] = "theta_star_100";
static const char __pyx_k_Class_cl_c1_gal[] = "Class.cl_c1_gal";
static const char __pyx_k_Class_cl_c1_tSZ[] = "Class.cl_c1_tSZ";
static const char __pyx_k_Class_cl_ggamma[] = "Class.cl_ggamma";
static const char __pyx_k_Class_cl_kg_cib[] = "Class.cl_kg_cib";
static const char __pyx_k_Class_cl_te_y_y[] = "Class.cl_te_y_y";
static const char __pyx_k_Class_cl_y_kcmb[] = "Class.cl_y_kcmb";
static const char __pyx_k_Class_dl_isw_sz[] = "Class.dl_isw_sz";
static const char __pyx_k_Class_get_m_nfw[] = "Class.get_m_nfw";
static const char __pyx_k_Class_get_pk_cb[] = "Class.get_pk_cb";
static const char __pyx_k_Class_lensed_cl[] = "Class.lensed_cl";
static const char __pyx_k_Class_omega_cdm[] = "Class.omega_cdm";
static const char __pyx_k_Class_pk_cb_lin[] = "Class.pk_cb_lin";
static const char __pyx_k_Class_pk_nonlin[] = "Class.pk_nonlin";
static const char __pyx_k_Class_rho0_crit[] = "Class.rho0_crit";
static const char __pyx_k_Class_sigma8_cb[] = "Class.sigma8_cb";
static const char __pyx_k_View_MemoryView[] = "View.MemoryView";
static const char __pyx_k_allocate_buffer[] = "allocate_buffer";
static const char __pyx_k_alphap_m_P0_B12[] = "alphap_m_P0_B12";
static const char __pyx_k_alphap_m_xc_B12[] = "alphap_m_xc_B12";
static const char __pyx_k_calculate_sigma[] = "calculate_sigma";
static const char __pyx_k_cib_Snu_file_nu[] = "cib_Snu_file_nu";
static const char __pyx_k_cl_gal_gal_kcmb[] = "cl_gal_gal_kcmb";
static const char __pyx_k_cl_galn_gallens[] = "cl_galn_gallens";
static const char __pyx_k_cl_kSZ_kSZ_kcmb[] = "cl_kSZ_kSZ_kcmb";
static const char __pyx_k_cl_lensmagn_tsz[] = "cl_lensmagn_tsz";
static const char __pyx_k_collections_abc[] = "collections.abc";
static const char __pyx_k_compute_profile[] = "compute_profile";
static const char __pyx_k_cosmo_arguments[] = "cosmo_arguments";
static const char __pyx_k_dndz_shift_ngal[] = "dndz_shift_ngal_";
static const char __pyx_k_dtype_is_object[] = "dtype_is_object";
static const char __pyx_k_frequency_in_Hz[] = "frequency_in_Hz";
static const char __pyx_k_get_ng_bar_at_z[] = "get_ng_bar_at_z";
static const char __pyx_k_get_pk_cb_array[] = "get_pk_cb_array";
static const char __pyx_k_get_sigma8_at_z[] = "get_sigma8_at_z";
static const char __pyx_k_likelihood_mode[] = "likelihood_mode";
static const char __pyx_k_log10xmax_mcfit[] = "log10xmax_mcfit";
static const char __pyx_k_log10xmin_mcfit[] = "log10xmin_mcfit";
static const char __pyx_k_mass_function_2[] = "mass function";
static const char __pyx_k_mcmc_parameters[] = "mcmc_parameters";
static const char __pyx_k_nonlinear_scale[] = "nonlinear_scale";
static const char __pyx_k_params_settings[] = "params_settings";
static const char __pyx_k_pdict_to_update[] = "pdict_to_update";
static const char __pyx_k_pk_unvectorized[] = "pk_unvectorized";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_z_max_nonlinear[] = "z_max_nonlinear";
static const char __pyx_k_z_max_requested[] = "z_max_requested";
static const char __pyx_k_Class_Omega0_cdm[] = "Class.Omega0_cdm";
static const char __pyx_k_Class_Rho_crit_0[] = "Class.Rho_crit_0";
static const char __pyx_k_Class_bk_at_z_hm[] = "Class.bk_at_z_hm";
static const char __pyx_k_Class_cl_c1_lens[] = "Class.cl_c1_lens";
static const char __pyx_k_Class_cl_cib_cib[] = "Class.cl_cib_cib";
static const char __pyx_k_Class_cl_gal_cib[] = "Class.cl_gal_cib";
static const char __pyx_k_Class_cl_galn_IA[] = "Class.cl_galn_IA";
static const char __pyx_k_Class_cl_tSZ_cib[] = "Class.cl_tSZ_cib";
static const char __pyx_k_Class_density_cl[] = "Class.density_cl";
static const char __pyx_k_Class_getPLog10M[] = "Class.getPLog10M";
static const char __pyx_k_Class_get_dndlnm[] = "Class.get_dndlnm";
static const char __pyx_k_Class_get_f_free[] = "Class.get_f_free";
static const char __pyx_k_Class_get_mean_y[] = "Class.get_mean_y";
static const char __pyx_k_Class_get_pk_lin[] = "Class.get_pk_lin";
static const char __pyx_k_Class_get_uk_nfw[] = "Class.get_uk_nfw";
static const char __pyx_k_Class_pk_at_z_hm[] = "Class.pk_at_z_hm";
static const char __pyx_k_Class_sigma8_Pcb[] = "Class.sigma8_Pcb";
static const char __pyx_k_CosmoError___str[] = "CosmoError.__str__";
static const char __pyx_k_CosmoSevereError[] = "CosmoSevereError";
static const char __pyx_k_alpha_c_beta_B12[] = "alpha_c_beta_B12";
static const char __pyx_k_alpha_m_beta_B12[] = "alpha_m_beta_B12";
static const char __pyx_k_alpha_s_HOD_ngal[] = "alpha_s_HOD_ngal_";
static const char __pyx_k_alpha_z_beta_B12[] = "alpha_z_beta_B12";
static const char __pyx_k_angular_distance[] = "angular_distance";
static const char __pyx_k_broadcast_arrays[] = "broadcast_arrays";
static const char __pyx_k_calculate_hubble[] = "calculate_hubble";
static const char __pyx_k_cib_Snu_file_snu[] = "cib_Snu_file_snu";
static const char __pyx_k_compute_class_sz[] = "compute_class_sz";
static const char __pyx_k_dndz_stretch_gal[] = "dndz_stretch_gal";
static const char __pyx_k_get_N_satellites[] = "get_N_satellites";
static const char __pyx_k_get_Omega_m_at_z[] = "get_Omega_m_at_z";
static const char __pyx_k_get_n5k_z_of_chi[] = "get_n5k_z_of_chi";
static const char __pyx_k_get_y_at_m_and_z[] = "get_y_at_m_and_z";
static const char __pyx_k_k1_in_h_over_Mpc[] = "k1_in_h_over_Mpc";
static const char __pyx_k_k2_in_h_over_Mpc[] = "k2_in_h_over_Mpc";
static const char __pyx_k_k3_in_h_over_Mpc[] = "k3_in_h_over_Mpc";
static const char __pyx_k_non_linear_check[] = "non_linear_check";
static const char __pyx_k_number_of_titles[] = "number_of_titles";
static const char __pyx_k_pressure_profile[] = "pressure_profile";
static const char __pyx_k_sigma_log10M_HOD[] = "sigma_log10M_HOD";
static const char __pyx_k_skip_sigma8_at_z[] = "skip_sigma8_at_z";
static const char __pyx_k_Class__pars_check[] = "Class._pars_check";
static const char __pyx_k_Class_cl_galn_tsz[] = "Class.cl_galn_tsz";
static const char __pyx_k_Class_cl_lens_cib[] = "Class.cl_lens_cib";
static const char __pyx_k_Class_get_IA_of_z[] = "Class.get_IA_of_z";
static const char __pyx_k_Class_get_cov_N_N[] = "Class.get_cov_N_N";
static const char __pyx_k_Class_get_dA_z1z2[] = "Class.get_dA_z1z2";
static const char __pyx_k_Class_set_default[] = "Class.set_default";
static const char __pyx_k_Class_theta_s_100[] = "Class.theta_s_100";
static const char __pyx_k_Class_tllprime_sz[] = "Class.tllprime_sz";
static const char __pyx_k_CosmoError___init[] = "CosmoError.__init__";
static const char __pyx_k_M1_prime_HOD_ngal[] = "M1_prime_HOD_ngal_";
static const char __pyx_k_alphap_m_beta_B12[] = "alphap_m_beta_B12";
static const char __pyx_k_class_sz_class_sz[] = "/class_sz/class-sz/";
static const char __pyx_k_class_sz_tabulate[] = "class_sz_tabulate";
static const char __pyx_k_classy_sz_verbose[] = "classy_sz_verbose";
static const char __pyx_k_clusterLogM500Max[] = "clusterLogM500Max";
static const char __pyx_k_clusterLogM500Min[] = "clusterLogM500Min";
static const char __pyx_k_configure_logging[] = "configure_logging";
static const char __pyx_k_cszfast_pk_grid_k[] = "cszfast_pk_grid_k";
static const char __pyx_k_cszfast_pk_grid_z[] = "cszfast_pk_grid_z";
static const char __pyx_k_delta_def_custom1[] = "delta_def_custom1";
static const char __pyx_k_dndz_stretch_ngal[] = "dndz_stretch_ngal_";
static const char __pyx_k_get_Q_of_theta500[] = "get_Q_of_theta500";
static const char __pyx_k_get_arcmin_to_rad[] = "get_arcmin_to_rad";
static const char __pyx_k_get_nu_at_z_and_m[] = "get_nu_at_z_and_m";
static const char __pyx_k_get_perturbations[] = "get_perturbations";
static const char __pyx_k_get_rad_to_arcmin[] = "get_rad_to_arcmin";
static const char __pyx_k_get_rho_crit_at_z[] = "get_rho_crit_at_z";
static const char __pyx_k_load_n5k_z_of_chi[] = "load_n5k_z_of_chi";
static const char __pyx_k_non_class_sz_keys[] = "non_class_sz_keys";
static const char __pyx_k_pyx_unpickle_Enum[] = "__pyx_unpickle_Enum";
static const char __pyx_k_scipy_interpolate[] = "scipy.interpolate";
static const char __pyx_k_sigma_disp_100_cb[] = "sigma_disp_100_cb";
static const char __pyx_k_suppress_warnings[] = "suppress_warnings";
static const char __pyx_k_sz_cluster_counts[] = "sz_cluster_counts";
static const char __pyx_k_Class_Omega_Lambda[] = "Class.Omega_Lambda";
static const char __pyx_k_Class__fillparfile[] = "Class._fillparfile";
static const char __pyx_k_Class_cib_monopole[] = "Class.cib_monopole";
static const char __pyx_k_Class_cl_galn_galn[] = "Class.cl_galn_galn";
static const char __pyx_k_Class_cl_galn_lens[] = "Class.cl_galn_lens";
static const char __pyx_k_Class_cl_kSZ_kSZ_g[] = "Class.cl_kSZ_kSZ_g";
static const char __pyx_k_Class_gamma_ggamma[] = "Class.gamma_ggamma";
static const char __pyx_k_Class_get_pk_array[] = "Class.get_pk_array";
static const char __pyx_k_Class_get_pkl_at_z[] = "Class.get_pkl_at_z";
static const char __pyx_k_Class_get_transfer[] = "Class.get_transfer";
static const char __pyx_k_Class_get_z_of_chi[] = "Class.get_z_of_chi";
static const char __pyx_k_Class_pk_b_at_z_2h[] = "Class.pk_b_at_z_2h";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_baryon_temperature[] = "baryon_temperature";
static const char __pyx_k_calculate_pkl_at_z[] = "calculate_pkl_at_z";
static const char __pyx_k_class_sz_integrate[] = "class_sz_integrate";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_clusterM500PlusErr[] = "clusterM500PlusErr";
static const char __pyx_k_dndzdy_theoretical[] = "dndzdy_theoretical";
static const char __pyx_k_effective_f_sigma8[] = "effective_f_sigma8";
static const char __pyx_k_get_H0_from_thetas[] = "get_H0_from_thetas";
static const char __pyx_k_get_T10_alpha_at_z[] = "get_T10_alpha_at_z";
static const char __pyx_k_get_pk_and_k_and_z[] = "get_pk_and_k_and_z";
static const char __pyx_k_get_pkl_at_k_and_z[] = "get_pkl_at_k_and_z";
static const char __pyx_k_get_thermodynamics[] = "get_thermodynamics";
static const char __pyx_k_index_M_bins_prime[] = "index_M_bins_prime";
static const char __pyx_k_nonlinear_scale_cb[] = "nonlinear_scale_cb";
static const char __pyx_k_params_values_dict[] = "params_values_dict";
static const char __pyx_k_pressure_profile_2[] = "pressure profile";
static const char __pyx_k_strided_and_direct[] = "<strided and direct>";
static const char __pyx_k_szunbinned_loglike[] = "szunbinned_loglike";
static const char __pyx_k_Class_cib_shotnoise[] = "Class.cib_shotnoise";
static const char __pyx_k_Class_cl_c1_gallens[] = "Class.cl_c1_gallens";
static const char __pyx_k_Class_cl_kSZ_kSZ_kg[] = "Class.cl_kSZ_kSZ_kg";
static const char __pyx_k_Class_get_Omega_m_0[] = "Class.get_Omega_m_0";
static const char __pyx_k_Class_get_Omega_r_0[] = "Class.get_Omega_r_0";
static const char __pyx_k_Class_get_dydz_at_z[] = "Class.get_dydz_at_z";
static const char __pyx_k_Class_get_params_sz[] = "Class.get_params_sz";
static const char __pyx_k_Class_get_pk_cb_lin[] = "Class.get_pk_cb_lin";
static const char __pyx_k_Class_get_pknl_at_z[] = "Class.get_pknl_at_z";
static const char __pyx_k_Class_pk_bb_at_z_hm[] = "Class.pk_bb_at_z_hm";
static const char __pyx_k_Class_pk_em_at_z_hm[] = "Class.pk_em_at_z_hm";
static const char __pyx_k_Class_pk_gg_at_z_hm[] = "Class.pk_gg_at_z_hm";
static const char __pyx_k_Class_szcounts_ntot[] = "Class.szcounts_ntot";
static const char __pyx_k_Class_x_out_custom1[] = "Class.x_out_custom1";
static const char __pyx_k_NotImplementedError[] = "NotImplementedError";
static const char __pyx_k_but_you_asked_a_l_i[] = "but you asked a l=%i";
static const char __pyx_k_calculate_pknl_at_z[] = "calculate_pknl_at_z";
static const char __pyx_k_cl_lensmagn_gallens[] = "cl_lensmagn_gallens";
static const char __pyx_k_clusterM500MinusErr[] = "clusterM500MinusErr";
static const char __pyx_k_cszfast_pk_grid_lnk[] = "cszfast_pk_grid_lnk";
static const char __pyx_k_cszfast_pk_grid_lnr[] = "cszfast_pk_grid_lnr";
static const char __pyx_k_getM500_from_y0_H13[] = "getM500_from_y0_H13";
static const char __pyx_k_get_comoving_volume[] = "get_comoving_volume";
static const char __pyx_k_get_fstar_of_m_at_z[] = "get_fstar_of_m_at_z";
static const char __pyx_k_get_mcmc_parameters[] = "get_mcmc_parameters";
static const char __pyx_k_get_pknl_at_k_and_z[] = "get_pknl_at_k_and_z";
static const char __pyx_k_handle_combinations[] = "handle_combinations";
static const char __pyx_k_ionization_fraction[] = "ionization_fraction";
static const char __pyx_k_luminosity_distance[] = "luminosity_distance";
static const char __pyx_k_other_class_sz_keys[] = "other_class_sz_keys";
static const char __pyx_k_pk_lin_unvectorized[] = "pk_lin_unvectorized";
static const char __pyx_k_shear_calibration_m[] = "shear_calibration_m";
static const char __pyx_k_skip_sigma8_and_der[] = "skip_sigma8_and_der";
static const char __pyx_k_use_pknl_in_2hterms[] = "use_pknl_in_2hterms";
static const char __pyx_k_Class_bk_ttg_at_z_hm[] = "Class.bk_ttg_at_z_hm";
static const char __pyx_k_Class_cl_custom1_cib[] = "Class.cl_custom1_cib";
static const char __pyx_k_Class_get_N_centrals[] = "Class.get_N_centrals";
static const char __pyx_k_Class_get_background[] = "Class.get_background";
static const char __pyx_k_Class_get_primordial[] = "Class.get_primordial";
static const char __pyx_k_Class_get_vrms2_at_z[] = "Class.get_vrms2_at_z";
static const char __pyx_k_Class_load_n5k_cl_K1[] = "Class.load_n5k_cl_K1";
static const char __pyx_k_Class_load_n5k_pk_zk[] = "Class.load_n5k_pk_zk";
static const char __pyx_k_Class_struct_cleanup[] = "Class.struct_cleanup";
static const char __pyx_k_Class_theta_star_100[] = "Class.theta_star_100";
static const char __pyx_k_compute_class_szfast[] = "compute_class_szfast";
static const char __pyx_k_cszfast_pk_grid_pknl[] = "cszfast_pk_grid_pknl";
static const char __pyx_k_cszfast_pk_grid_zmax[] = "cszfast_pk_grid_zmax";
static const char __pyx_k_get_c200c_at_m_and_z[] = "get_c200c_at_m_and_z";
static const char __pyx_k_get_c200m_at_m_and_z[] = "get_c200m_at_m_and_z";
static const char __pyx_k_get_c500c_at_m_and_z[] = "get_c500c_at_m_and_z";
static const char __pyx_k_get_cib_Snu_z_and_nu[] = "get_cib_Snu_z_and_nu";
static const char __pyx_k_get_n5k_cl_K1_at_chi[] = "get_n5k_cl_K1_at_chi";
static const char __pyx_k_get_pkl_unvectorized[] = "get_pkl_unvectorized";
static const char __pyx_k_get_sigma_at_r_and_z[] = "get_sigma_at_r_and_z";
static const char __pyx_k_get_sigma_at_z_and_m[] = "get_sigma_at_z_and_m";
static const char __pyx_k_get_theta_at_m_and_z[] = "get_theta_at_m_and_z";
static const char __pyx_k_params_for_emulators[] = "params_for_emulators";
static const char __pyx_k_scale_dependent_bias[] = "scale_dependent_bias";
static const char __pyx_k_strided_and_indirect[] = "<strided and indirect>";
static const char __pyx_k_Class___reduce_cython[] = "Class.__reduce_cython__";
static const char __pyx_k_Class_cl_gal_gal_kcmb[] = "Class.cl_gal_gal_kcmb";
static const char __pyx_k_Class_cl_galn_gallens[] = "Class.cl_galn_gallens";
static const char __pyx_k_Class_cl_kSZ_kSZ_kcmb[] = "Class.cl_kSZ_kSZ_kcmb";
static const char __pyx_k_Class_cl_lensmagn_tsz[] = "Class.cl_lensmagn_tsz";
static const char __pyx_k_Class_get_ng_bar_at_z[] = "Class.get_ng_bar_at_z";
static const char __pyx_k_Class_get_pk_cb_array[] = "Class.get_pk_cb_array";
static const char __pyx_k_Class_get_sigma8_at_z[] = "Class.get_sigma8_at_z";
static const char __pyx_k_Class_nonlinear_scale[] = "Class.nonlinear_scale";
static const char __pyx_k_Class_pk_unvectorized[] = "Class.pk_unvectorized";
static const char __pyx_k_CosmoComputationError[] = "CosmoComputationError";
static const char __pyx_k_Invalid_shape_in_axis[] = "Invalid shape in axis ";
static const char __pyx_k_No_lensed_Cl_computed[] = "No lensed Cl computed";
static const char __pyx_k_PATH_TO_CLASS_SZ_DATA[] = "PATH_TO_CLASS_SZ_DATA";
static const char __pyx_k_calculate_sigma8_at_z[] = "calculate_sigma8_at_z";
static const char __pyx_k_check_task_dependency[] = "_check_task_dependency";
static const char __pyx_k_contiguous_and_direct[] = "<contiguous and direct>";
static const char __pyx_k_cszfast_pk_grid_ln1pz[] = "cszfast_pk_grid_ln1pz";
static const char __pyx_k_dndz_shift_source_gal[] = "dndz_shift_source_gal";
static const char __pyx_k_effective_galaxy_bias[] = "effective_galaxy_bias";
static const char __pyx_k_full_path_to_dndz_gal[] = "full_path_to_dndz_gal";
static const char __pyx_k_get_custom1_bias_at_z[] = "get_custom1_bias_at_z";
static const char __pyx_k_get_cvir_of_mvir_at_z[] = "get_cvir_of_mvir_at_z";
static const char __pyx_k_get_dndlnM_at_z_and_M[] = "get_dndlnM_at_z_and_M";
static const char __pyx_k_get_n5k_pk_at_z_and_k[] = "get_n5k_pk_at_z_and_k";
static const char __pyx_k_get_pk_lin_at_k_and_z[] = "get_pk_lin_at_k_and_z";
static const char __pyx_k_get_pknl_unvectorized[] = "get_pknl_unvectorized";
static const char __pyx_k_get_rvir_of_mvir_at_z[] = "get_rvir_of_mvir_at_z";
static const char __pyx_k_get_yc_at_m_and_z_H13[] = "get_yc_at_m_and_z_H13";
static const char __pyx_k_levelname_s_message_s[] = "%(levelname)s - %(message)s";
static const char __pyx_k_pknl_key_value_checks[] = "pknl_key_value_checks";
static const char __pyx_k_sigma_log10M_HOD_ngal[] = "sigma_log10M_HOD_ngal_";
static const char __pyx_k_sz_cluster_counts_fft[] = "sz_cluster_counts_fft";
static const char __pyx_k_Cannot_index_with_type[] = "Cannot index with type '";
static const char __pyx_k_Class_angular_distance[] = "Class.angular_distance";
static const char __pyx_k_Class_compute_class_sz[] = "Class.compute_class_sz";
static const char __pyx_k_Class_get_N_satellites[] = "Class.get_N_satellites";
static const char __pyx_k_Class_get_Omega_m_at_z[] = "Class.get_Omega_m_at_z";
static const char __pyx_k_Class_get_n5k_z_of_chi[] = "Class.get_n5k_z_of_chi";
static const char __pyx_k_Class_get_y_at_m_and_z[] = "Class.get_y_at_m_and_z";
static const char __pyx_k_MemoryView_of_r_object[] = "<MemoryView of %r object>";
static const char __pyx_k_No_density_Cl_computed[] = "No density Cl computed";
static const char __pyx_k_contains_specific_keys[] = "contains_specific_keys";
static const char __pyx_k_get_Delta_c_of_Omega_m[] = "get_Delta_c_of_Omega_m";
static const char __pyx_k_get_c_delta_at_m_and_z[] = "get_c_delta_at_m_and_z";
static const char __pyx_k_get_effective_f_sigma8[] = "get_effective_f_sigma8";
static const char __pyx_k_get_rvir_of_m200c_at_z[] = "get_rvir_of_m200c_at_z";
static const char __pyx_k_is_not_implemented_yet[] = "' is not implemented yet.";
static const char __pyx_k_problematic_parameters[] = "problematic_parameters";
static const char __pyx_k_Class___setstate_cython[] = "Class.__setstate_cython__";
static const char __pyx_k_Class_delta_def_custom1[] = "Class.delta_def_custom1";
static const char __pyx_k_Class_get_arcmin_to_rad[] = "Class.get_arcmin_to_rad";
static const char __pyx_k_Class_get_nu_at_z_and_m[] = "Class.get_nu_at_z_and_m";
static const char __pyx_k_Class_get_perturbations[] = "Class.get_perturbations";
static const char __pyx_k_Class_get_rad_to_arcmin[] = "Class.get_rad_to_arcmin";
static const char __pyx_k_Class_get_rho_crit_at_z[] = "Class.get_rho_crit_at_z";
static const char __pyx_k_Class_load_n5k_z_of_chi[] = "Class.load_n5k_z_of_chi";
static const char __pyx_k_Emissivity_index_of_sed[] = "Emissivity_index_of_sed";
static const char __pyx_k_MemoryView_of_r_at_0x_x[] = "<MemoryView of %r at 0x%x>";
static const char __pyx_k_applyMFDebiasCorrection[] = "applyMFDebiasCorrection";
static const char __pyx_k_class_sz_in_dict_output[] = "class_sz_in_dict_output";
static const char __pyx_k_concentration_parameter[] = "concentration_parameter";
static const char __pyx_k_contiguous_and_indirect[] = "<contiguous and indirect>";
static const char __pyx_k_cumulativeNumberDensity[] = "_cumulativeNumberDensity";
static const char __pyx_k_dndz_stretch_source_gal[] = "dndz_stretch_source_gal";
static const char __pyx_k_galaxy_samples_list_num[] = "galaxy_samples_list_num";
static const char __pyx_k_get_dcib0dz_at_z_and_nu[] = "get_dcib0dz_at_z_and_nu";
static const char __pyx_k_get_dydzdlnm_at_z_and_m[] = "get_dydzdlnm_at_z_and_m";
static const char __pyx_k_get_nl_index_at_z_and_k[] = "get_nl_index_at_z_and_k";
static const char __pyx_k_nonlinear_hmcode_sigma8[] = "nonlinear_hmcode_sigma8";
static const char __pyx_k_only_clustering_species[] = "only_clustering_species";
static const char __pyx_k_Class_baryon_temperature[] = "Class.baryon_temperature";
static const char __pyx_k_Class_dndzdy_theoretical[] = "Class.dndzdy_theoretical";
static const char __pyx_k_Class_effective_f_sigma8[] = "Class.effective_f_sigma8";
static const char __pyx_k_Class_get_T10_alpha_at_z[] = "Class.get_T10_alpha_at_z";
static const char __pyx_k_Class_get_pk_and_k_and_z[] = "Class.get_pk_and_k_and_z";
static const char __pyx_k_Class_get_thermodynamics[] = "Class.get_thermodynamics";
static const char __pyx_k_Class_nonlinear_scale_cb[] = "Class.nonlinear_scale_cb";
static const char __pyx_k_Class_szunbinned_loglike[] = "Class.szunbinned_loglike";
static const char __pyx_k_calculate_sigma8_and_der[] = "calculate_sigma8_and_der";
static const char __pyx_k_cp_pkl_fftlog_alphas_nus[] = "cp_pkl_fftlog_alphas_nus";
static const char __pyx_k_cp_predicted_ee_spectrum[] = "cp_predicted_ee_spectrum";
static const char __pyx_k_cp_predicted_pp_spectrum[] = "cp_predicted_pp_spectrum";
static const char __pyx_k_cp_predicted_te_spectrum[] = "cp_predicted_te_spectrum";
static const char __pyx_k_cp_predicted_tt_spectrum[] = "cp_predicted_tt_spectrum";
static const char __pyx_k_cszfast_pk_grid_pkl_flat[] = "cszfast_pk_grid_pkl_flat";
static const char __pyx_k_get_bispectrum_f2_kernel[] = "get_bispectrum_f2_kernel";
static const char __pyx_k_get_c200c_at_m_and_z_B13[] = "get_c200c_at_m_and_z_B13";
static const char __pyx_k_get_c200c_at_m_and_z_D08[] = "get_c200c_at_m_and_z_D08";
static const char __pyx_k_get_c200m_at_m_and_z_D08[] = "get_c200m_at_m_and_z_D08";
static const char __pyx_k_get_galaxy_number_counts[] = "get_galaxy_number_counts";
static const char __pyx_k_get_gnu_tsz_of_nu_in_ghz[] = "get_gnu_tsz_of_nu_in_ghz";
static const char __pyx_k_get_lensing_noise_at_ell[] = "get_lensing_noise_at_ell";
static const char __pyx_k_get_m_to_xout_at_z_and_m[] = "get_m_to_xout_at_z_and_m";
static const char __pyx_k_get_pk_nonlin_at_k_and_z[] = "get_pk_nonlin_at_k_and_z";
static const char __pyx_k_get_te_of_m500c_at_z_lee[] = "get_te_of_m500c_at_z_lee";
static const char __pyx_k_Class_cl_lensmagn_gallens[] = "Class.cl_lensmagn_gallens";
static const char __pyx_k_Class_getM500_from_y0_H13[] = "Class.getM500_from_y0_H13";
static const char __pyx_k_Class_get_comoving_volume[] = "Class.get_comoving_volume";
static const char __pyx_k_Class_get_fstar_of_m_at_z[] = "Class.get_fstar_of_m_at_z";
static const char __pyx_k_Class_ionization_fraction[] = "Class.ionization_fraction";
static const char __pyx_k_Class_luminosity_distance[] = "Class.luminosity_distance";
static const char __pyx_k_Class_pk_lin_unvectorized[] = "Class.pk_lin_unvectorized";
static const char __pyx_k_Dimension_d_is_not_direct[] = "Dimension %d is not direct";
static const char __pyx_k_concentration_parameter_2[] = "concentration parameter";
static const char __pyx_k_cszfast_pk_grid_pknl_flat[] = "cszfast_pk_grid_pknl_flat";
static const char __pyx_k_get_f_of_sigma_at_m_and_z[] = "get_f_of_sigma_at_m_and_z";
static const char __pyx_k_get_mean_galaxy_bias_at_z[] = "get_mean_galaxy_bias_at_z";
static const char __pyx_k_get_unwise_m_min_cut_at_z[] = "get_unwise_m_min_cut_at_z";
static const char __pyx_k_get_z_of_chi_unvectorized[] = "get_z_of_chi_unvectorized";
static const char __pyx_k_m_d_a_zA_Z__to_m_d_a_zA_Z[] = "^m\\d+[a-zA-Z]*_to_m\\d+[a-zA-Z]*$";
static const char __pyx_k_Class_compute_class_szfast[] = "Class.compute_class_szfast";
static const char __pyx_k_Class_get_c200c_at_m_and_z[] = "Class.get_c200c_at_m_and_z";
static const char __pyx_k_Class_get_c200m_at_m_and_z[] = "Class.get_c200m_at_m_and_z";
static const char __pyx_k_Class_get_c500c_at_m_and_z[] = "Class.get_c500c_at_m_and_z";
static const char __pyx_k_Class_get_cib_Snu_z_and_nu[] = "Class.get_cib_Snu_z_and_nu";
static const char __pyx_k_Class_get_n5k_cl_K1_at_chi[] = "Class.get_n5k_cl_K1_at_chi";
static const char __pyx_k_Class_get_pkl_unvectorized[] = "Class.get_pkl_unvectorized";
static const char __pyx_k_Class_get_sigma_at_z_and_m[] = "Class.get_sigma_at_z_and_m";
static const char __pyx_k_Class_get_theta_at_m_and_z[] = "Class.get_theta_at_m_and_z";
static const char __pyx_k_Index_out_of_bounds_axis_d[] = "Index out of bounds (axis %d)";
static const char __pyx_k_class_sz_python_classy_pyx[] = "class-sz/python/classy.pyx";
static const char __pyx_k_get_P_delta_at_m_and_z_b12[] = "get_P_delta_at_m_and_z_b12";
static const char __pyx_k_get_dkappacmbdz_at_l_and_z[] = "get_dkappacmbdz_at_l_and_z";
static const char __pyx_k_get_f_tinker08_at_nu_and_z[] = "get_f_tinker08_at_nu_and_z";
static const char __pyx_k_get_f_tinker10_at_nu_and_z[] = "get_f_tinker10_at_nu_and_z";
static const char __pyx_k_get_fftlog_ComputeXiLMsloz[] = "get_fftlog_ComputeXiLMsloz";
static const char __pyx_k_get_pk_lin_at_k_and_z_fast[] = "get_pk_lin_at_k_and_z_fast";
static const char __pyx_k_get_pkl_locals_compute_pkl[] = "get_pkl.<locals>.compute_pkl";
static const char __pyx_k_get_szcounts_dndzdq_at_z_q[] = "get_szcounts_dndzdq_at_z_q";
static const char __pyx_k_get_volume_dVdzdOmega_at_z[] = "get_volume_dVdzdOmega_at_z";
static const char __pyx_k_nonlinear_hmcode_sigma8_cb[] = "nonlinear_hmcode_sigma8_cb";
static const char __pyx_k_nonlinear_hmcode_sigmadisp[] = "nonlinear_hmcode_sigmadisp";
static const char __pyx_k_skip_background_and_thermo[] = "skip_background_and_thermo";
static const char __pyx_k_sz_unbinned_cluster_counts[] = "sz_unbinned_cluster_counts";
static const char __pyx_k_Class_effective_galaxy_bias[] = "Class.effective_galaxy_bias";
static const char __pyx_k_Class_get_custom1_bias_at_z[] = "Class.get_custom1_bias_at_z";
static const char __pyx_k_Class_get_cvir_of_mvir_at_z[] = "Class.get_cvir_of_mvir_at_z";
static const char __pyx_k_Class_get_dndlnM_at_z_and_M[] = "Class.get_dndlnM_at_z_and_M";
static const char __pyx_k_Class_get_n5k_pk_at_z_and_k[] = "Class.get_n5k_pk_at_z_and_k";
static const char __pyx_k_Class_get_pk_lin_at_k_and_z[] = "Class.get_pk_lin_at_k_and_z";
static const char __pyx_k_Class_get_pknl_unvectorized[] = "Class.get_pknl_unvectorized";
static const char __pyx_k_Class_get_rvir_of_mvir_at_z[] = "Class.get_rvir_of_mvir_at_z";
static const char __pyx_k_Class_get_yc_at_m_and_z_H13[] = "Class.get_yc_at_m_and_z_H13";
static const char __pyx_k_Step_may_not_be_zero_axis_d[] = "Step may not be zero (axis %d)";
static const char __pyx_k_calculate_pkl_fftlog_alphas[] = "calculate_pkl_fftlog_alphas";
static const char __pyx_k_get_r_delta_of_m_delta_at_z[] = "get_r_delta_of_m_delta_at_z";
static const char __pyx_k_get_rho_2h_at_r_and_m_and_z[] = "get_rho_2h_at_r_and_m_and_z";
static const char __pyx_k_get_te_of_m500c_at_z_arnaud[] = "get_te_of_m500c_at_z_arnaud";
static const char __pyx_k_itemsize_0_for_cython_array[] = "itemsize <= 0 for cython.array";
static const char __pyx_k_nonlinear_hmcode_sigmaprime[] = "nonlinear_hmcode_sigmaprime";
static const char __pyx_k_nonlinear_hmcode_window_nfw[] = "nonlinear_hmcode_window_nfw";
static const char __pyx_k_szcounts_ntot_rates_loglike[] = "szcounts_ntot_rates_loglike";
static const char __pyx_k_use_pknl_in_2hterms_IA_only[] = "use_pknl_in_2hterms_IA_only";
static const char __pyx_k_Class__check_task_dependency[] = "Class._check_task_dependency";
static const char __pyx_k_Class_get_Delta_c_of_Omega_m[] = "Class.get_Delta_c_of_Omega_m";
static const char __pyx_k_Class_get_c_delta_at_m_and_z[] = "Class.get_c_delta_at_m_and_z";
static const char __pyx_k_Class_get_effective_f_sigma8[] = "Class.get_effective_f_sigma8";
static const char __pyx_k_Class_get_rvir_of_m200c_at_z[] = "Class.get_rvir_of_m200c_at_z";
static const char __pyx_k_H_over_c_in_h_over_Mpc_array[] = "H_over_c_in_h_over_Mpc_array";
static const char __pyx_k_InterpolatedUnivariateSpline[] = "InterpolatedUnivariateSpline";
static const char __pyx_k_cszfast_pk_grid_dsigma2_flat[] = "cszfast_pk_grid_dsigma2_flat";
static const char __pyx_k_full_path_to_source_dndz_gal[] = "full_path_to_source_dndz_gal";
static const char __pyx_k_get_custom1_profile_at_k_m_z[] = "get_custom1_profile_at_k_m_z";
static const char __pyx_k_get_custom1_profile_at_x_m_z[] = "get_custom1_profile_at_x_m_z";
static const char __pyx_k_get_dlnsigma_dlnR_at_z_and_m[] = "get_dlnsigma_dlnR_at_z_and_m";
static const char __pyx_k_get_pknl_locals_compute_pknl[] = "get_pknl.<locals>.compute_pknl";
static const char __pyx_k_get_planck_sigma_at_theta500[] = "get_planck_sigma_at_theta500";
static const char __pyx_k_1h_2h_hf_3h_covmat_lensing_te[] = "^[^,]+_(1h|2h|hf|3h|covmat|lensing_term|hsv)$";
static const char __pyx_k_Can_only_compute_up_to_lmax_d[] = "Can only compute up to lmax=%d";
static const char __pyx_k_Class_get_dcib0dz_at_z_and_nu[] = "Class.get_dcib0dz_at_z_and_nu";
static const char __pyx_k_Class_get_dydzdlnm_at_z_and_m[] = "Class.get_dydzdlnm_at_z_and_m";
static const char __pyx_k_Class_get_nl_index_at_z_and_k[] = "Class.get_nl_index_at_z_and_k";
static const char __pyx_k_Class_nonlinear_hmcode_sigma8[] = "Class.nonlinear_hmcode_sigma8";
static const char __pyx_k_bbn_PRIMAT21_class_format_dat[] = "/bbn/PRIMAT21_class_format.dat";
static const char __pyx_k_cl_sz_at_nu_in_GHz_in_microK2[] = "cl_sz_at_nu_in_GHz_in_microK2";
static const char __pyx_k_cszfast_pk_grid_lnsigma2_flat[] = "cszfast_pk_grid_lnsigma2_flat";
static const char __pyx_k_get_delta_from_delta_def_at_z[] = "get_delta_from_delta_def_at_z";
static const char __pyx_k_get_m200c_to_m200m_at_z_and_M[] = "get_m200c_to_m200m_at_z_and_M";
static const char __pyx_k_get_m200c_to_m500c_at_z_and_M[] = "get_m200c_to_m500c_at_z_and_M";
static const char __pyx_k_get_m200m_to_m200c_at_z_and_M[] = "get_m200m_to_m200c_at_z_and_M";
static const char __pyx_k_get_m200m_to_m500c_at_z_and_M[] = "get_m200m_to_m500c_at_z_and_M";
static const char __pyx_k_get_m500c_to_m200c_at_z_and_M[] = "get_m500c_to_m200c_at_z_and_M";
static const char __pyx_k_get_m500c_to_m200m_at_z_and_M[] = "get_m500c_to_m200m_at_z_and_M";
static const char __pyx_k_get_pk_nonlin_at_k_and_z_fast[] = "get_pk_nonlin_at_k_and_z_fast";
static const char __pyx_k_nonlinear_hmcode_sigmadisp100[] = "nonlinear_hmcode_sigmadisp100";
static const char __pyx_k_nonlinear_hmcode_sigmadisp_cb[] = "nonlinear_hmcode_sigmadisp_cb";
static const char __pyx_k_tabulate_rhob_xout_at_m_and_z[] = "tabulate_rhob_xout_at_m_and_z";
static const char __pyx_k_unable_to_allocate_array_data[] = "unable to allocate array data.";
static const char __pyx_k_Class__cumulativeNumberDensity[] = "Class._cumulativeNumberDensity";
static const char __pyx_k_Class_get_bispectrum_f2_kernel[] = "Class.get_bispectrum_f2_kernel";
static const char __pyx_k_Class_get_c200c_at_m_and_z_B13[] = "Class.get_c200c_at_m_and_z_B13";
static const char __pyx_k_Class_get_c200c_at_m_and_z_D08[] = "Class.get_c200c_at_m_and_z_D08";
static const char __pyx_k_Class_get_c200m_at_m_and_z_D08[] = "Class.get_c200m_at_m_and_z_D08";
static const char __pyx_k_Class_get_galaxy_number_counts[] = "Class.get_galaxy_number_counts";
static const char __pyx_k_Class_get_gnu_tsz_of_nu_in_ghz[] = "Class.get_gnu_tsz_of_nu_in_ghz";
static const char __pyx_k_Class_get_lensing_noise_at_ell[] = "Class.get_lensing_noise_at_ell";
static const char __pyx_k_Class_get_m_to_xout_at_z_and_m[] = "Class.get_m_to_xout_at_z_and_m";
static const char __pyx_k_Class_get_pk_nonlin_at_k_and_z[] = "Class.get_pk_nonlin_at_k_and_z";
static const char __pyx_k_Class_get_te_of_m500c_at_z_lee[] = "Class.get_te_of_m500c_at_z_lee";
static const char __pyx_k_get_current_derived_parameters[] = "get_current_derived_parameters";
static const char __pyx_k_get_hmf_counter_term_nmin_at_z[] = "get_hmf_counter_term_nmin_at_z";
static const char __pyx_k_nonlinear_hmcode_sigmaprime_cb[] = "nonlinear_hmcode_sigmaprime_cb";
static const char __pyx_k_strided_and_direct_or_indirect[] = "<strided and direct or indirect>";
static const char __pyx_k_Class_get_1e6xdy_from_battaglia[] = "Class.get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c";
static const char __pyx_k_Class_get_delta_mean_from_delta[] = "Class.get_delta_mean_from_delta_crit_at_z";
static const char __pyx_k_Class_get_f_of_sigma_at_m_and_z[] = "Class.get_f_of_sigma_at_m_and_z";
static const char __pyx_k_Class_get_first_order_bias_at_z[] = "Class.get_first_order_bias_at_z_and_nu";
static const char __pyx_k_Class_get_hmf_counter_term_nmin[] = "Class.get_hmf_counter_term_nmin_at_z";
static const char __pyx_k_Class_get_mass_profile_at_x_M_z[] = "Class.get_mass_profile_at_x_M_z_nfw_200m";
static const char __pyx_k_Class_get_mean_galaxy_bias_at_z[] = "Class.get_mean_galaxy_bias_at_z";
static const char __pyx_k_Class_get_r_delta_of_m_delta_at[] = "Class.get_r_delta_of_m_delta_at_z";
static const char __pyx_k_Class_get_rho_2h_at_r_and_m_and[] = "Class.get_rho_2h_at_r_and_m_and_z";
static const char __pyx_k_Class_get_truncated_nfw_profile[] = "Class.get_truncated_nfw_profile_at_z_k_rd_cd_xout";
static const char __pyx_k_Class_get_unwise_m_min_cut_at_z[] = "Class.get_unwise_m_min_cut_at_z";
static const char __pyx_k_Class_get_z_of_chi_unvectorized[] = "Class.get_z_of_chi_unvectorized";
static const char __pyx_k_Input_should_be_a_float_or_a_1D[] = "Input should be a float or a 1D NumPy array of type float64.";
static const char __pyx_k_Normalisation_of_L___M_relation[] = "Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]";
static const char __pyx_k_Raised_when_Class_could_not_com[] = "\n    Raised when Class could not compute the cosmology at this point.\n\n    This will be caught by the parameter extraction code to give an extremely\n    unlikely value to this point\n    ";
static const char __pyx_k_Raised_when_Class_failed_to_und[] = "\n    Raised when Class failed to understand one or more input parameters.\n\n    This case would not raise any problem in Class default behaviour. However,\n    for parameter extraction, one has to be sure that all input parameters were\n    understood, otherwise the wrong cosmological model would be selected.\n    ";
static const char __pyx_k_Users_boris_Work_CLASS_SZ_SO_SZ[] = "/Users/boris/Work/CLASS-SZ/SO-SZ/class_sz/sz_auxiliary_files/so_3freqs_020621_theta500arcmin_Q.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ[] = "/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_A10.txt";
static const char __pyx_k_get_first_order_bias_at_z_and_m[] = "get_first_order_bias_at_z_and_m_unvectorized";
static const char __pyx_k_get_hmf_counter_term_b1min_at_z[] = "get_hmf_counter_term_b1min_at_z";
static const char __pyx_k_get_hmf_counter_term_b2min_at_z[] = "get_hmf_counter_term_b2min_at_z";
static const char __pyx_k_get_matter_bispectrum_at_z_tree[] = "get_matter_bispectrum_at_z_tree_level_PT";
static const char __pyx_k_get_radial_kernel_W_galaxy_ngal[] = "get_radial_kernel_W_galaxy_ngal_at_z";
static const char __pyx_k_get_source_galaxy_number_counts[] = "get_source_galaxy_number_counts";
static const char __pyx_k_get_szcountsz_sigma_at_theta_in[] = "get_szcountsz_sigma_at_theta_in_patch";
static const char __pyx_k_get_upp_from_gnfw_pressure_at_x[] = "get_upp_from_gnfw_pressure_at_x_z_and_m500c";
static const char __pyx_k_is_not_implemented_yet_Availabl[] = "' is not implemented yet. Available types are 'lin' and 'nonlin'.";
static const char __pyx_k_module_classy_sz_synopsis_Pytho[] = "\n.. module:: classy_sz\n    :synopsis: Python wrapper around CLASS_SZ\n.. moduleauthor:: Boris Bolliet <bb667@cam.ac.uk>\n\n\nThis module is a Python wrapper around the CLASS_SZ code. \nAll CLASS specific functions were written by Karim Benabed <benabed@iap.fr>,\nBenjamin Audren <benjamin.audren@epfl.ch>, and Julien Lesgourgues <lesgourg@cern.ch>. \n\n\n";
static const char __pyx_k_path_to_cosmopower_organization[] = "path_to_cosmopower_organization";
static const char __pyx_k_s_was_not_recognized_as_a_deriv[] = "%s was not recognized as a derived parameter";
static const char __pyx_k_scale_independent_growth_factor[] = "scale_independent_growth_factor";
static const char __pyx_k_All_dimensions_preceding_dimensi[] = "All dimensions preceding dimension %d must be indexed and not sliced";
static const char __pyx_k_All_inputs_should_be_floats_or_1[] = "All inputs should be floats or 1D NumPy arrays of type float64.";
static const char __pyx_k_Buffer_view_does_not_expose_stri[] = "Buffer view does not expose strides";
static const char __pyx_k_Can_only_create_a_buffer_that_is[] = "Can only create a buffer that is contiguous in memory.";
static const char __pyx_k_Cannot_assign_to_read_only_memor[] = "Cannot assign to read-only memoryview";
static const char __pyx_k_Cannot_create_writable_memory_vi[] = "Cannot create writable memory view from read-only memoryview";
static const char __pyx_k_Cannot_transpose_memoryview_with[] = "Cannot transpose memoryview with indirect dimensions";
static const char __pyx_k_Class_calculate_pkl_fftlog_alpha[] = "Class.calculate_pkl_fftlog_alphas";
static const char __pyx_k_Class_cl_sz_at_nu_in_GHz_in_micr[] = "Class.cl_sz_at_nu_in_GHz_in_microK2";
static const char __pyx_k_Class_did_not_read_input_paramet[] = "Class did not read input parameter(s): %s\n";
static const char __pyx_k_Class_get_1e6xdy_from_gnfw_press[] = "Class.get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c";
static const char __pyx_k_Class_get_P_delta_at_m_and_z_b12[] = "Class.get_P_delta_at_m_and_z_b12";
static const char __pyx_k_Class_get_current_derived_parame[] = "Class.get_current_derived_parameters";
static const char __pyx_k_Class_get_custom1_profile_at_k_m[] = "Class.get_custom1_profile_at_k_m_z";
static const char __pyx_k_Class_get_custom1_profile_at_x_m[] = "Class.get_custom1_profile_at_x_m_z";
static const char __pyx_k_Class_get_delta_from_delta_def_a[] = "Class.get_delta_from_delta_def_at_z";
static const char __pyx_k_Class_get_dkappacmbdz_at_l_and_z[] = "Class.get_dkappacmbdz_at_l_and_z";
static const char __pyx_k_Class_get_dlnsigma_dlnR_at_z_and[] = "Class.get_dlnsigma_dlnR_at_z_and_m";
static const char __pyx_k_Class_get_f_tinker08_at_nu_and_z[] = "Class.get_f_tinker08_at_nu_and_z";
static const char __pyx_k_Class_get_f_tinker10_at_nu_and_z[] = "Class.get_f_tinker10_at_nu_and_z";
static const char __pyx_k_Class_get_fftlog_ComputeXiLMsloz[] = "Class.get_fftlog_ComputeXiLMsloz";
static const char __pyx_k_Class_get_gas_density_profile_at[] = "Class.get_gas_density_profile_at_k_M_z";
static const char __pyx_k_Class_get_gas_pressure_2h_at_r_a[] = "Class.get_gas_pressure_2h_at_r_and_m_and_z";
static const char __pyx_k_Class_get_gas_profile_at_x_M_z_b[] = "Class.get_gas_profile_at_x_M_z_b16_200c";
static const char __pyx_k_Class_get_gas_profile_at_x_M_z_n[] = "Class.get_gas_profile_at_x_M_z_nfw_200m";
static const char __pyx_k_Class_get_hmf_counter_term_b1min[] = "Class.get_hmf_counter_term_b1min_at_z";
static const char __pyx_k_Class_get_hmf_counter_term_b2min[] = "Class.get_hmf_counter_term_b2min_at_z";
static const char __pyx_k_Class_get_m200c_to_m200m_at_z_an[] = "Class.get_m200c_to_m200m_at_z_and_M";
static const char __pyx_k_Class_get_m200c_to_m500c_at_z_an[] = "Class.get_m200c_to_m500c_at_z_and_M";
static const char __pyx_k_Class_get_m200m_to_m200c_at_z_an[] = "Class.get_m200m_to_m200c_at_z_and_M";
static const char __pyx_k_Class_get_m200m_to_m500c_at_z_an[] = "Class.get_m200m_to_m500c_at_z_and_M";
static const char __pyx_k_Class_get_m500c_to_m200c_at_z_an[] = "Class.get_m500c_to_m200c_at_z_and_M";
static const char __pyx_k_Class_get_m500c_to_m200m_at_z_an[] = "Class.get_m500c_to_m200m_at_z_and_M";
static const char __pyx_k_Class_get_matter_bispectrum_at_z[] = "Class.get_matter_bispectrum_at_z_effective_approach_smoothed";
static const char __pyx_k_Class_get_nl_index_at_z_and_k_no[] = "Class.get_nl_index_at_z_and_k_no_wiggles";
static const char __pyx_k_Class_get_normalization_gas_dens[] = "Class.get_normalization_gas_density_profile";
static const char __pyx_k_Class_get_pk_lin_at_k_and_z_fast[] = "Class.get_pk_lin_at_k_and_z_fast";
static const char __pyx_k_Class_get_pk_nonlin_at_k_and_z_f[] = "Class.get_pk_nonlin_at_k_and_z_fast";
static const char __pyx_k_Class_get_pkl_reconstructed_from[] = "Class.get_pkl_reconstructed_from_fftlog";
static const char __pyx_k_Class_get_planck_sigma_at_theta5[] = "Class.get_planck_sigma_at_theta500";
static const char __pyx_k_Class_get_pressure_P_over_P_delt[] = "Class.get_pressure_P_over_P_delta_at_x_M_z_b12_200c";
static const char __pyx_k_Class_get_radial_kernel_W_custom[] = "Class.get_radial_kernel_W_custom1_at_z";
static const char __pyx_k_Class_get_radial_kernel_W_galaxy[] = "Class.get_radial_kernel_W_galaxy_ngal_at_z";
static const char __pyx_k_Class_get_scale_dependent_bias_a[] = "Class.get_scale_dependent_bias_at_z_and_k";
static const char __pyx_k_Class_get_second_order_bias_at_z[] = "Class.get_second_order_bias_at_z_and_nu";
static const char __pyx_k_Class_get_source_galaxy_number_c[] = "Class.get_source_galaxy_number_counts";
static const char __pyx_k_Class_get_szcounts_dndzdq_at_z_q[] = "Class.get_szcounts_dndzdq_at_z_q";
static const char __pyx_k_Class_get_szcountsz_sigma_at_the[] = "Class.get_szcountsz_sigma_at_theta_in_patch";
static const char __pyx_k_Class_get_te_of_m500c_at_z_arnau[] = "Class.get_te_of_m500c_at_z_arnaud";
static const char __pyx_k_Class_get_ttg_bispectrum_at_z_ef[] = "Class.get_ttg_bispectrum_at_z_effective_approach";
static const char __pyx_k_Class_get_ttg_bispectrum_at_z_tr[] = "Class.get_ttg_bispectrum_at_z_tree_level_PT";
static const char __pyx_k_Class_get_upp_from_gnfw_pressure[] = "Class.get_upp_from_gnfw_pressure_at_x_z_and_m500c";
static const char __pyx_k_Class_get_volume_dVdzdOmega_at_z[] = "Class.get_volume_dVdzdOmega_at_z";
static const char __pyx_k_Class_nonlinear_hmcode_sigma8_cb[] = "Class.nonlinear_hmcode_sigma8_cb";
static const char __pyx_k_Class_nonlinear_hmcode_sigmadisp[] = "Class.nonlinear_hmcode_sigmadisp";
static const char __pyx_k_Class_nonlinear_hmcode_sigmaprim[] = "Class.nonlinear_hmcode_sigmaprime";
static const char __pyx_k_Class_nonlinear_hmcode_window_nf[] = "Class.nonlinear_hmcode_window_nfw";
static const char __pyx_k_Class_scale_independent_growth_f[] = "Class.scale_independent_growth_factor";
static const char __pyx_k_Class_szcounts_ntot_rates_loglik[] = "Class.szcounts_ntot_rates_loglike";
static const char __pyx_k_Dust_temperature_today_in_Kelvin[] = "Dust_temperature_today_in_Kelvins";
static const char __pyx_k_Empty_shape_tuple_for_cython_arr[] = "Empty shape tuple for cython.array";
static const char __pyx_k_In_order_to_get_pk_tilt_at_k_e_1[] = "In order to get pk_tilt at k=%e 1/Mpc, you should compute P(k,z) in a wider range of k's";
static const char __pyx_k_In_order_to_get_sigma_R_z_you_mu[] = "In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))";
static const char __pyx_k_Indirect_dimensions_not_supporte[] = "Indirect dimensions not supported";
static const char __pyx_k_Invalid_mode_expected_c_or_fortr[] = "Invalid mode, expected 'c' or 'fortran', got ";
static const char __pyx_k_Most_efficient_halo_mass_in_Msun[] = "Most_efficient_halo_mass_in_Msun";
static const char __pyx_k_No_massive_neutrinos_You_must_us[] = "No massive neutrinos. You must use pk, rather than pk_cb.";
static const char __pyx_k_No_power_spectrum_computed_In_or[] = "No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.";
static const char __pyx_k_No_power_spectrum_computed_You_m[] = "No power spectrum computed. You must add mPk to the list of outputs.";
static const char __pyx_k_Out_of_bounds_on_buffer_access_a[] = "Out of bounds on buffer access (axis ";
static const char __pyx_k_P_cb_not_computed_by_CLASS_proba[] = "P_cb not computed by CLASS (probably because there are no massive neutrinos)";
static const char __pyx_k_P_cb_not_computed_probably_becau[] = "P_cb not computed (probably because there are no massive neutrinos) so you cannot ask for it";
static const char __pyx_k_Power_law_index_of_SED_at_high_f[] = "Power_law_index_of_SED_at_high_frequency";
static const char __pyx_k_Redshift_evolution_of_L___M_norm[] = "Redshift_evolution_of_L_-_M_normalisation";
static const char __pyx_k_Redshift_evolution_of_dust_tempe[] = "Redshift_evolution_of_dust_temperature";
static const char __pyx_k_Size_of_halo_masses_sourcing_CIB[] = "Size_of_halo_masses_sourcing_CIB_emission";
static const char __pyx_k_Tinker_et_al_10_alpha_consistenc[] = "Tinker_et_al_10_alpha_consistency_msyriac_file";
static const char __pyx_k_Unable_to_convert_item_to_object[] = "Unable to convert item to object";
static const char __pyx_k_You_ask_classy_to_return_an_arra[] = "You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations; add 'mPk' in 'output'";
static const char __pyx_k_compute_class_szfast_locals_gene[] = "compute_class_szfast.<locals>.genexpr";
static const char __pyx_k_contains_specific_pattern_or_key[] = "contains_specific_pattern_or_keys";
static const char __pyx_k_full_path_and_prefix_to_dndz_nga[] = "full_path_and_prefix_to_dndz_ngal";
static const char __pyx_k_get_1e6xdy_from_battaglia_pressu[] = "get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c";
static const char __pyx_k_get_1e6xdy_from_gnfw_pressure_at[] = "get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c";
static const char __pyx_k_get_delta_mean_from_delta_crit_a[] = "get_delta_mean_from_delta_crit_at_z";
static const char __pyx_k_get_first_order_bias_at_z_and_nu[] = "get_first_order_bias_at_z_and_nu";
static const char __pyx_k_get_gas_density_profile_at_k_M_z[] = "get_gas_density_profile_at_k_M_z";
static const char __pyx_k_get_gas_pressure_2h_at_r_and_m_a[] = "get_gas_pressure_2h_at_r_and_m_and_z";
static const char __pyx_k_get_gas_profile_at_x_M_z_b16_200[] = "get_gas_profile_at_x_M_z_b16_200c";
static const char __pyx_k_get_gas_profile_at_x_M_z_bcm_200[] = "get_gas_profile_at_x_M_z_bcm_200c";
static const char __pyx_k_get_gas_profile_at_x_M_z_nfw_200[] = "get_gas_profile_at_x_M_z_nfw_200m";
static const char __pyx_k_get_mass_profile_at_x_M_z_nfw_20[] = "get_mass_profile_at_x_M_z_nfw_200m";
static const char __pyx_k_get_matter_bispectrum_at_z_effec[] = "get_matter_bispectrum_at_z_effective_approach_smoothed";
static const char __pyx_k_get_nl_index_at_z_and_k_no_wiggl[] = "get_nl_index_at_z_and_k_no_wiggles";
static const char __pyx_k_get_normalization_gas_density_pr[] = "get_normalization_gas_density_profile";
static const char __pyx_k_get_pkl_locals_handle_combinatio[] = "get_pkl.<locals>.handle_combinations";
static const char __pyx_k_get_pkl_reconstructed_from_fftlo[] = "get_pkl_reconstructed_from_fftlog";
static const char __pyx_k_get_pknl_locals_handle_combinati[] = "get_pknl.<locals>.handle_combinations";
static const char __pyx_k_get_pressure_P_over_P_delta_at_x[] = "get_pressure_P_over_P_delta_at_x_M_z_b12_200c";
static const char __pyx_k_get_radial_kernel_W_custom1_at_z[] = "get_radial_kernel_W_custom1_at_z";
static const char __pyx_k_get_radial_kernel_W_galaxy_lensi[] = "get_radial_kernel_W_galaxy_lensing_at_z";
static const char __pyx_k_get_scale_dependent_bias_at_z_an[] = "get_scale_dependent_bias_at_z_and_k";
static const char __pyx_k_get_second_order_bias_at_z_and_n[] = "get_second_order_bias_at_z_and_nu";
static const char __pyx_k_get_truncated_nfw_profile_at_z_k[] = "get_truncated_nfw_profile_at_z_k_rd_cd_xout";
static const char __pyx_k_get_ttg_bispectrum_at_z_effectiv[] = "get_ttg_bispectrum_at_z_effective_approach";
static const char __pyx_k_get_ttg_bispectrum_at_z_tree_lev[] = "get_ttg_bispectrum_at_z_tree_level_PT";
static const char __pyx_k_get_uk_nfw_locals_compute_profil[] = "get_uk_nfw.<locals>.compute_profile";
static const char __pyx_k_get_uk_nfw_locals_handle_combina[] = "get_uk_nfw.<locals>.handle_combinations";
static const char __pyx_k_got_differing_extents_in_dimensi[] = "got differing extents in dimension ";
static const char __pyx_k_k_and_z_must_be_broadcastable_to[] = "k and z must be broadcastable to the same shape.";
static const char __pyx_k_m_input_should_be_a_float_or_a_1[] = "m_input should be a float or a 1D NumPy array of type float64";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_nonlinear_hmcode_sigmadisp100_cb[] = "nonlinear_hmcode_sigmadisp100_cb";
static const char __pyx_k_numpy__core_multiarray_failed_to[] = "numpy._core.multiarray failed to import";
static const char __pyx_k_numpy__core_umath_failed_to_impo[] = "numpy._core.umath failed to import";
static const char __pyx_k_sigma_cb_not_computed_by_CLASS_p[] = "sigma_cb not computed by CLASS (probably because there are no massive neutrinos)";
static const char __pyx_k_sz_selection_function_skyfracs_f[] = "sz_selection_function_skyfracs_file";
static const char __pyx_k_sz_selection_function_thetas_fil[] = "sz_selection_function_thetas_file";
static const char __pyx_k_sz_selection_function_ylims_file[] = "sz_selection_function_ylims_file";
static const char __pyx_k_the_s_spectrum_was_computed_unti[] = "the %s spectrum was computed until l=%i ";
static const char __pyx_k_unable_to_allocate_shape_and_str[] = "unable to allocate shape and strides.";
static const char __pyx_k_z_input_should_be_a_float_or_a_1[] = "z_input should be a float or a 1D NumPy array of type float64";
static const char __pyx_k_Class_get_first_order_bias_at_z_2[] = "Class.get_first_order_bias_at_z_and_m_unvectorized";
static const char __pyx_k_Class_get_first_order_bias_at_z_3[] = "Class.get_first_order_bias_at_z_and_m";
static const char __pyx_k_Class_get_truncated_nfw_profile_2[] = "Class.get_truncated_nfw_profile_at_z_k_m_xout";
static const char __pyx_k_class_sz_auxiliary_files_includ_2[] = "/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_P13.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_3[] = "/class_sz_auxiliary_files/includes/Tinker_et_al_10_alpha_consistency_msyriac.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_4[] = "/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example1.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_5[] = "/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example";
static const char __pyx_k_class_sz_auxiliary_files_includ_6[] = "/class_sz_auxiliary_files/includes/WISC_bin3.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_7[] = "/class_sz_auxiliary_files/includes/filtered_snu_planck_fine.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_8[] = "/class_sz_auxiliary_files/includes/filtered_snu_planck_z_fine.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_9[] = "/class_sz_auxiliary_files/includes/filtered_snu_planck_nu_fine.txt";
static const char __pyx_k_get_first_order_bias_at_z_and_m_2[] = "get_first_order_bias_at_z_and_m";
static const char __pyx_k_scale_independent_growth_factor_2[] = "scale_independent_growth_factor_f";
static const char __pyx_k_Class_get_gas_profile_at_x_M_z_b_2[] = "Class.get_gas_profile_at_x_M_z_bcm_200c";
static const char __pyx_k_Class_get_gas_profile_at_x_M_z_n_2[] = "Class.get_gas_profile_at_x_M_z_nfw_200c";
static const char __pyx_k_Class_get_matter_bispectrum_at_z_2[] = "Class.get_matter_bispectrum_at_z_effective_approach";
static const char __pyx_k_Class_get_matter_bispectrum_at_z_3[] = "Class.get_matter_bispectrum_at_z_effective_approach_SC";
static const char __pyx_k_Class_get_matter_bispectrum_at_z_4[] = "Class.get_matter_bispectrum_at_z_tree_level_PT";
static const char __pyx_k_Class_get_pressure_P_over_P_delt_2[] = "Class.get_pressure_P_over_P_delta_at_x_gnfw_500c";
static const char __pyx_k_Class_get_radial_kernel_W_galaxy_2[] = "Class.get_radial_kernel_W_galaxy_lensing_at_z";
static const char __pyx_k_Class_nonlinear_hmcode_sigmadisp_2[] = "Class.nonlinear_hmcode_sigmadisp_cb";
static const char __pyx_k_Class_nonlinear_hmcode_sigmadisp_3[] = "Class.nonlinear_hmcode_sigmadisp100";
static const char __pyx_k_Class_nonlinear_hmcode_sigmadisp_4[] = "Class.nonlinear_hmcode_sigmadisp100_cb";
static const char __pyx_k_Class_nonlinear_hmcode_sigmaprim_2[] = "Class.nonlinear_hmcode_sigmaprime_cb";
static const char __pyx_k_Class_scale_independent_growth_f_2[] = "Class.scale_independent_growth_factor_f";
static const char __pyx_k_No_power_spectrum_computed_In_or_2[] = "No power spectrum computed. In order to get pk_tilt(k,z) you must add mPk to the list of outputs.";
static const char __pyx_k_You_ask_classy_to_return_an_arra_2[] = "You ask classy to return an array of nonlinear P(k,z) values, but the input parameters sent to CLASS did not require any non-linear P(k,z) calculations; add e.g. 'halofit' or 'HMcode' in 'nonlinear'";
static const char __pyx_k_You_ask_classy_to_return_an_arra_3[] = "You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations for z>0; pass either a list of z in 'z_pk' or one non-zero value in 'z_max_pk'";
static const char __pyx_k_class_sz_auxiliary_files_includ_10[] = "/class_sz_auxiliary_files/includes/SZ_cat.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_11[] = "/class_sz_auxiliary_files/includes/SZ_thetas.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_12[] = "/class_sz_auxiliary_files/includes/SZ_skyfracs.txt";
static const char __pyx_k_class_sz_auxiliary_files_includ_13[] = "/class_sz_auxiliary_files/includes/SZ_ylims.txt";
static const char __pyx_k_get_gas_profile_at_x_M_z_nfw_200_2[] = "get_gas_profile_at_x_M_z_nfw_200c";
static const char __pyx_k_get_matter_bispectrum_at_z_effec_2[] = "get_matter_bispectrum_at_z_effective_approach";
static const char __pyx_k_get_matter_bispectrum_at_z_effec_3[] = "get_matter_bispectrum_at_z_effective_approach_SC";
static const char __pyx_k_get_pressure_P_over_P_delta_at_x_2[] = "get_pressure_P_over_P_delta_at_x_gnfw_500c";
static const char __pyx_k_get_truncated_nfw_profile_at_z_k_2[] = "get_truncated_nfw_profile_at_z_k_m_xout";
/* #### Code section: decls ### */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object); /* proto */
static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9classy_sz_15__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_configure_logging(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_level); /* proto */
static PyObject *__pyx_pf_9classy_sz_2set_verbosity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_verbosity); /* proto */
static PyObject *__pyx_pf_9classy_sz_4suppress_warnings(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_7class_sz_in_dict_output(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d); /* proto */
static PyObject *__pyx_pf_9classy_sz_17__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_9contains_specific_keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d, PyObject *__pyx_v_specific_keys); /* proto */
static PyObject *__pyx_pf_9classy_sz_11contains_specific_pattern_or_keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d); /* proto */
static PyObject *__pyx_pf_9classy_sz_13viewdictitems(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d); /* proto */
static PyObject *__pyx_pf_9classy_sz_10CosmoError___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_message); /* proto */
static PyObject *__pyx_pf_9classy_sz_10CosmoError_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_4pars___get__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_5state___get__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_8Omega_nu___get__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_16nonlinear_method___get__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_21PATH_TO_CLASS_SZ_DATA___get__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_set_default(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static int __pyx_pf_9classy_sz_5Class_2__cinit__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_default); /* proto */
static void __pyx_pf_9classy_sz_5Class_4__dealloc__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_6set(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_pars, PyObject *__pyx_v_kars); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_8empty(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_10_fillparfile(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_12struct_cleanup(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_14_check_task_dependency(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_level); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_16_pars_check(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value, PyObject *__pyx_v_contains, PyObject *__pyx_v_add); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_18compute(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_level); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_20calculate_pkl_fftlog_alphas(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_zpk); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_22get_pkl_reconstructed_from_fftlog(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_zpk); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_20compute_class_szfast_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_24compute_class_szfast(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_likelihood_mode); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_26compute_class_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_pdict_to_update); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_28raw_cl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_lmax, PyObject *__pyx_v_nofail); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_30lensed_cl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_lmax, PyObject *__pyx_v_nofail); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_32density_cl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_lmax, PyObject *__pyx_v_nofail); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_34z_of_r(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_array); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_36luminosity_distance(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_38get_pkl_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_params_values_dict); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_40get_pknl_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_params_values_dict); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_42pk_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_44pk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_46pk_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_48pk_lin_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_50pk_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_52pk_nonlin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_54pk_cb_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_56get_pk_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, int __pyx_v_mu_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_58get_pk_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, int __pyx_v_mu_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_60get_pk_cb_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, int __pyx_v_mu_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_62get_pk_and_k_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nonlinear, PyObject *__pyx_v_only_clustering_species, PyObject *__pyx_v_h_units); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_64sigma(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_R, double __pyx_v_z, CYTHON_UNUSED PyObject *__pyx_v_h_units); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_66sigma_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_R, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_68pk_tilt(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_70nonlinear_hmcode_window_nfw(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_rv, double __pyx_v_c); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_72effective_f_sigma8(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_z_step); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_74age(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_76h(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_78n_s(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_80tau_reio(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_82Omega_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_84Omega_r(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_86theta_s_100(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_88theta_star_100(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_90Omega_Lambda(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_92Omega_g(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_94Omega_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_96omega_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_98omega_cdm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_100Neff(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_102k_eq(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_104sigma8(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_106get_sigma8_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_108get_effective_f_sigma8(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_110get_fstar_of_m_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_112sigma8_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_114rs_drag(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_116z_reio(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_118get_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_120angular_distance(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_122get_radial_kernel_W_galaxy_ngal_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_index_g); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_124scale_independent_growth_factor(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_126scale_independent_growth_factor_f(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_128z_of_tau(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_tau); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_130get_Ez(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_132Hubble(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_134get_H(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_136Om_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_138ionization_fraction(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_140baryon_temperature(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_142T_cmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_144Omega0_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_146cl_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_148dl_isw_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_150cl_sz_at_nu_in_GHz_in_microK2(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nu_in_GHz); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_152get_volume_dVdzdOmega_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_154get_z_of_chi_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_chi); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_156get_z_of_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_chi); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_158get_comoving_volume(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_160get_IA_of_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_162get_f_of_sigma_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_164get_delta_mean_from_delta_crit_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_delta_crit, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_166get_galaxy_number_counts(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_168get_cov_N_N(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_170cl_kg_kg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_172cl_kg_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_174cl_yg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_176cl_IA_g(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_178cl_kg_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_180cl_ykg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_Nmcfit, PyObject *__pyx_v_log10xmin_mcfit, PyObject *__pyx_v_log10xmax_mcfit, PyObject *__pyx_v_log10x_num); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_182cl_kSZ_kSZ_g(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_184cl_kSZ_kSZ_kg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_186cl_kSZ_kSZ_kcmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_188cl_gal_gal_kcmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_190cl_te_y_y(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_192cl_ym(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_194cl_y_kcmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_196cl_t2t2f(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_198cl_gg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_200cl_ksz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_202cl_ggamma(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_Nmcfit, PyObject *__pyx_v_log10xmin_mcfit, PyObject *__pyx_v_log10xmax_mcfit, PyObject *__pyx_v_log10x_num); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_204gamma_ggamma(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_206cl_ee(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_208cl_eg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_210cl_kg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_212pk_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_214bk_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_216bk_ttg_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_218b_yyy(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_220b_tty(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_222pk_gg_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_224pk_b_at_z_2h(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_226pk_bb_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_228pk_em_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_230cl_kk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_232cl_c1c1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_234cl_c1_lens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_236cl_c1_tSZ(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_238cl_c1_gal(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_240cl_c1_gallens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_242cib_monopole(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_244cib_shotnoise(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_246cl_cib_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_248cl_galn_galn(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_250cl_galn_lens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_252cl_galn_gallens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_254cl_galn_tsz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_256cl_galn_IA(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_258cl_lensmagn_gallens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_260cl_lensmagn_tsz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_262cl_kg_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_264cl_custom1_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_266cl_tSZ_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_268cl_gal_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_270cl_lens_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_272cl_km(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_274cl_mm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_276cl_gm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_278get_scale_dependent_bias_at_z_and_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_k_asked, PyObject *__pyx_v_bh); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_280get_szcounts_dndzdq_at_z_q(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_qobs_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_282get_params_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_284tllprime_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_286A_rs(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_288B_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_290Rho_crit_0(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_292rho0_crit(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_294rho0_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_296rho0_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_298chi_star(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_300delta_def_custom1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_302effective_galaxy_bias(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_304x_out_custom1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_306M1SZ(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_308ystar(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_310alpha(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_312sigmaM(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_314sigma8_Pcb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_316A_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_318A_sn(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_320A_ir(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_322A_cn(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_324get_te_of_m500c_at_z_arnaud(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_326get_lensing_noise_at_ell(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_l); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_328get_te_of_m500c_at_z_lee(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_330get_f_tinker10_at_nu_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nu, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_332get_f_tinker08_at_nu_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nu, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_334get_T10_alpha_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_336get_dndlnM_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_338get_dndlnm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_m_input); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_340get_dcib0dz_at_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_342get_dydz_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_344get_mean_y(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_346get_mean_galaxy_bias_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_348get_gnu_tsz_of_nu_in_ghz(struct __pyx_obj_9classy_sz_Class *__pyx_v_nu_in_ghz, PyObject *__pyx_v_Tcmb); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_350get_hmf_counter_term_nmin_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_352get_hmf_counter_term_b1min_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_354get_hmf_counter_term_b2min_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_356get_gas_density_profile_at_k_M_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_l_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_normalize); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_358get_rho_2h_at_r_and_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_360get_P_delta_at_m_and_z_b12(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_362get_gas_pressure_2h_at_r_and_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_364get_dkappacmbdz_at_l_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_z, PyObject *__pyx_v_use_pklin); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_366get_dydzdlnm_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_l); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_368get_c_delta_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z, PyObject *__pyx_v_delta_def); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_370get_delta_from_delta_def_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_delta_def, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_372get_r_delta_of_m_delta_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_delta, PyObject *__pyx_v_m_delta, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_374get_m200m_to_m200c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_m_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_376get_normalization_gas_density_profile(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_m_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_378get_m_to_xout_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_m_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_380get_c200m_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_382get_c200c_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_384get_c500c_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_386get_c200m_at_m_and_z_D08(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_M, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_388get_c200c_at_m_and_z_D08(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_M, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_390get_c200c_at_m_and_z_B13(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_M, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_392get_f_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_394get_f_free(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_396get_mu_e(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_398get_Omega_m_0(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_400get_Omega_r_0(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_402get_m_nfw(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_404get_rho_crit_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_406get_pkl_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_408get_pknl_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_7get_pkl_compute_pkl(PyObject *__pyx_self, double __pyx_v_kh, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_7get_pkl_2handle_combinations(PyObject *__pyx_self, PyObject *__pyx_v_kh_vals, PyObject *__pyx_v_z_vals); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_410get_pkl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh_input, PyObject *__pyx_v_z_input); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_8get_pknl_compute_pknl(PyObject *__pyx_self, double __pyx_v_kh, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_8get_pknl_2handle_combinations(PyObject *__pyx_self, PyObject *__pyx_v_kh_vals, PyObject *__pyx_v_z_vals); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_412get_pknl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh_input, PyObject *__pyx_v_z_input); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_414get_pk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh_input, PyObject *__pyx_v_z_input, PyObject *__pyx_v_type); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_416get_pk_nonlin_at_k_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_418get_pk_lin_at_k_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_420get_pk_nonlin_at_k_and_z_fast(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_422get_pk_lin_at_k_and_z_fast(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_424get_gas_profile_at_x_M_z_b16_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_c_asked, PyObject *__pyx_v_A_rho0, PyObject *__pyx_v_A_alpha, PyObject *__pyx_v_A_beta, PyObject *__pyx_v_alpha_m_rho0, PyObject *__pyx_v_alpha_m_alpha, PyObject *__pyx_v_alpha_m_beta, PyObject *__pyx_v_alpha_z_rho0, PyObject *__pyx_v_alpha_z_alpha, PyObject *__pyx_v_alpha_z_beta, PyObject *__pyx_v_mcut, PyObject *__pyx_v_alphap_m_rho0, PyObject *__pyx_v_alphap_m_alpha, PyObject *__pyx_v_alphap_m_beta, PyObject *__pyx_v_alpha_c_rho0, PyObject *__pyx_v_alpha_c_alpha, PyObject *__pyx_v_alpha_c_beta, PyObject *__pyx_v_gamma, PyObject *__pyx_v_xc); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_426get_pressure_P_over_P_delta_at_x_M_z_b12_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_c_asked, PyObject *__pyx_v_A_P0, PyObject *__pyx_v_A_xc, PyObject *__pyx_v_A_beta, PyObject *__pyx_v_alpha_m_P0, PyObject *__pyx_v_alpha_m_xc, PyObject *__pyx_v_alpha_m_beta, PyObject *__pyx_v_alpha_z_P0, PyObject *__pyx_v_alpha_z_xc, PyObject *__pyx_v_alpha_z_beta, PyObject *__pyx_v_mcut, PyObject *__pyx_v_alphap_m_P0, PyObject *__pyx_v_alphap_m_xc, PyObject *__pyx_v_alphap_m_beta, PyObject *__pyx_v_alpha_c_P0, PyObject *__pyx_v_alpha_c_xc, PyObject *__pyx_v_alpha_c_beta, PyObject *__pyx_v_alpha, PyObject *__pyx_v_gamma); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_428get_pressure_P_over_P_delta_at_x_gnfw_500c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x_asked, PyObject *__pyx_v_P0GNFW, PyObject *__pyx_v_alphaGNFW, PyObject *__pyx_v_betaGNFW, PyObject *__pyx_v_gammaGNFW, PyObject *__pyx_v_c500); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_430get_dA_z1z2(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z1, PyObject *__pyx_v_z2); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_432get_dA(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_434get_rad_to_arcmin(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_theta_rad); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_436get_truncated_nfw_profile_at_z_k_rd_cd_xout(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_k, double __pyx_v_r_delta, double __pyx_v_c_delta, double __pyx_v_xout); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_438get_truncated_nfw_profile_at_z_k_m_xout(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_k, double __pyx_v_m, double __pyx_v_xout); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_10get_uk_nfw_compute_profile(PyObject *__pyx_self, double __pyx_v_z, double __pyx_v_k, double __pyx_v_m, double __pyx_v_xout); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_10get_uk_nfw_2handle_combinations(PyObject *__pyx_self, PyObject *__pyx_v_z_vals, PyObject *__pyx_v_k_vals, PyObject *__pyx_v_m_vals); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_440get_uk_nfw(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_k_input, PyObject *__pyx_v_m_input, double __pyx_v_xout); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_442get_uk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_k_input, PyObject *__pyx_v_m_input, double __pyx_v_xout, PyObject *__pyx_v_profile); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_444get_arcmin_to_rad(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_theta_arcmin); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_446get_gas_profile_at_x_M_z_nfw_200m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_448get_gas_profile_at_x_M_z_bcm_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_450get_rvir_of_m200c_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_452get_Delta_c_of_Omega_m(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_Omega_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_454get_cvir_of_mvir_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_456get_Omega_m_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_458get_rvir_of_mvir_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_460get_gas_profile_at_x_M_z_nfw_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_462get_mass_profile_at_x_M_z_nfw_200m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_464get_planck_sigma_at_theta500(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_theta500); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_466get_szcountsz_sigma_at_theta_in_patch(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_theta500); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_468get_second_order_bias_at_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_470get_first_order_bias_at_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_472get_first_order_bias_at_z_and_m_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_474get_first_order_bias_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_m_input); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_476get_cib_Snu_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_478get_sigma_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_480get_dlnsigma_dlnR_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_482get_sigma8_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_484get_y_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_486get_theta_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_488get_m200m_to_m500c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_490get_m200c_to_m500c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_492get_m200c_to_m200m_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_494get_m200m_to_m200c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_496get_m500c_to_m200c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_498get_m500c_to_m200m_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_500calcFRel(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_M500, PyObject *__pyx_v_obsFreqGHz); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_502get_radial_kernel_W_galaxy_lensing_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_504get_custom1_bias_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_506get_radial_kernel_W_custom1_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_508get_custom1_profile_at_x_m_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_x, double __pyx_v_m, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_510get_custom1_profile_at_k_m_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_m, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_512get_ng_bar_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_514get_source_galaxy_number_counts(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_516get_N_satellites(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_M_halo, double __pyx_v_Nc_mean, double __pyx_v_M_min, double __pyx_v_alpha_s, double __pyx_v_M1_prime); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_518get_N_centrals(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_M_halo, double __pyx_v_M_min, double __pyx_v_sigma_log10M, double __pyx_v_fc); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_520get_unwise_m_min_cut_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, int __pyx_v_sample_id); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_522get_yc_at_m_and_z_H13(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z, PyObject *__pyx_v_A, PyObject *__pyx_v_B); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_524_cumulativeNumberDensity(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_526getPLog10M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_528getM500_from_y0_H13(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_y0, PyObject *__pyx_v_y0Err, PyObject *__pyx_v_A, PyObject *__pyx_v_B, PyObject *__pyx_v_sigma_int, PyObject *__pyx_v_z, PyObject *__pyx_v_applyMFDebiasCorrection); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_530get_bispectrum_f2_kernel(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k1, double __pyx_v_k2, double __pyx_v_k3); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_532get_nu_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_534get_matter_bispectrum_at_z_effective_approach_smoothed(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_536get_ttg_bispectrum_at_z_effective_approach(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_538get_ttg_bispectrum_at_z_tree_level_PT(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_540get_matter_bispectrum_at_z_effective_approach(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_542get_matter_bispectrum_at_z_effective_approach_SC(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_544get_matter_bispectrum_at_z_tree_level_PT(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_546get_nl_index_at_z_and_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_k1_in_h_over_Mpc); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_548get_nl_index_at_z_and_k_no_wiggles(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_k1_in_h_over_Mpc); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_550get_vrms2_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_552get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_x); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_554get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_x, PyObject *__pyx_v_d); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_556get_upp_from_gnfw_pressure_at_x_z_and_m500c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_x, PyObject *__pyx_v_d); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_558szunbinned_loglike(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_560szcounts_ntot(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_562szcounts_ntot_rates_loglike(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, int __pyx_v_nq, double __pyx_v_qmax); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_564dndzdy_theoretical(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_566get_background(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_568get_thermodynamics(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_570get_primordial(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_572get_perturbations(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_574get_transfer(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_output_format); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_576get_current_derived_parameters(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_names); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_578nonlinear_scale(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_580nonlinear_scale_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_582nonlinear_hmcode_sigma8(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_584nonlinear_hmcode_sigma8_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_586nonlinear_hmcode_sigmadisp(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_588nonlinear_hmcode_sigmadisp_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_590nonlinear_hmcode_sigmadisp100(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_592nonlinear_hmcode_sigmadisp100_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_594nonlinear_hmcode_sigmaprime(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_596nonlinear_hmcode_sigmaprime_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_598__call__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_ctx); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_600get_pk_array(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, PyObject *__pyx_v_nonlinear); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_602get_pk_cb_array(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, PyObject *__pyx_v_nonlinear); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_604get_fftlog_ComputeXiLMsloz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, int __pyx_v_l, int __pyx_v_m, int __pyx_v_N, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_pk, PyArrayObject *__pyx_v_r, PyArrayObject *__pyx_v_xi); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_606get_n5k_z_of_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_chi); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_608get_n5k_pk_at_z_and_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z_asked, double __pyx_v_k_asked); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_610get_n5k_cl_K1_at_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_chi); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_612load_n5k_cl_K1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_614load_n5k_pk_zk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_616load_n5k_z_of_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_618Omega0_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_620Omega0_cdm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_622Omega0_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_624__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9classy_sz_5Class_626__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_9classy_sz_Class(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct__suppress_warnings(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_1_compute_class_szfast(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_2_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_3_get_pkl(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_4_get_pknl(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_5_get_uk_nfw(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_5numpy_dtype;
  PyTypeObject *__pyx_ptype_5numpy_flatiter;
  PyTypeObject *__pyx_ptype_5numpy_broadcast;
  PyTypeObject *__pyx_ptype_5numpy_ndarray;
  PyTypeObject *__pyx_ptype_5numpy_generic;
  PyTypeObject *__pyx_ptype_5numpy_number;
  PyTypeObject *__pyx_ptype_5numpy_integer;
  PyTypeObject *__pyx_ptype_5numpy_signedinteger;
  PyTypeObject *__pyx_ptype_5numpy_unsignedinteger;
  PyTypeObject *__pyx_ptype_5numpy_inexact;
  PyTypeObject *__pyx_ptype_5numpy_floating;
  PyTypeObject *__pyx_ptype_5numpy_complexfloating;
  PyTypeObject *__pyx_ptype_5numpy_flexible;
  PyTypeObject *__pyx_ptype_5numpy_character;
  PyTypeObject *__pyx_ptype_5numpy_ufunc;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_9classy_sz_Class;
  PyObject *__pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings;
  PyObject *__pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast;
  PyObject *__pyx_type_9classy_sz___pyx_scope_struct_2_genexpr;
  PyObject *__pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl;
  PyObject *__pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl;
  PyObject *__pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw;
  PyObject *__pyx_type___pyx_array;
  PyObject *__pyx_type___pyx_MemviewEnum;
  PyObject *__pyx_type___pyx_memoryview;
  PyObject *__pyx_type___pyx_memoryviewslice;
  #endif
  PyTypeObject *__pyx_ptype_9classy_sz_Class;
  PyTypeObject *__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings;
  PyTypeObject *__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast;
  PyTypeObject *__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr;
  PyTypeObject *__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl;
  PyTypeObject *__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl;
  PyTypeObject *__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw;
  PyTypeObject *__pyx_array_type;
  PyTypeObject *__pyx_MemviewEnum_type;
  PyTypeObject *__pyx_memoryview_type;
  PyTypeObject *__pyx_memoryviewslice_type;
  PyObject *__pyx_kp_u_;
  PyObject *__pyx_kp_u_100_theta_s;
  PyObject *__pyx_kp_u_100_theta_star;
  PyObject *__pyx_kp_u_1h;
  PyObject *__pyx_kp_u_1h_2h_3h;
  PyObject *__pyx_kp_u_1h_2h_hf_3h_covmat_lensing_te;
  PyObject *__pyx_kp_u_1h_slow;
  PyObject *__pyx_kp_u_2h;
  PyObject *__pyx_kp_u_2h_slow;
  PyObject *__pyx_kp_u_3h;
  PyObject *__pyx_kp_u_3h_slow;
  PyObject *__pyx_n_s_A;
  PyObject *__pyx_n_u_A10_file;
  PyObject *__pyx_n_s_ASCII;
  PyObject *__pyx_n_u_A_IA;
  PyObject *__pyx_n_s_A_P0;
  PyObject *__pyx_n_s_A_alpha;
  PyObject *__pyx_n_u_A_alpha;
  PyObject *__pyx_n_s_A_beta;
  PyObject *__pyx_n_u_A_beta;
  PyObject *__pyx_n_s_A_cib;
  PyObject *__pyx_n_s_A_cn;
  PyObject *__pyx_n_s_A_ir;
  PyObject *__pyx_n_s_A_rho0;
  PyObject *__pyx_n_u_A_rho0;
  PyObject *__pyx_n_s_A_rs;
  PyObject *__pyx_n_u_A_s;
  PyObject *__pyx_n_s_A_s_fast;
  PyObject *__pyx_n_s_A_sn;
  PyObject *__pyx_n_s_A_xc;
  PyObject *__pyx_kp_s_All_dimensions_preceding_dimensi;
  PyObject *__pyx_kp_u_All_inputs_should_be_floats_or_1;
  PyObject *__pyx_n_u_As;
  PyObject *__pyx_n_s_AssertionError;
  PyObject *__pyx_n_s_B;
  PyObject *__pyx_n_s_B_sz;
  PyObject *__pyx_kp_s_Buffer_view_does_not_expose_stri;
  PyObject *__pyx_n_s_CRITICAL;
  PyObject *__pyx_kp_u_Can_only_compute_up_to_lmax_d;
  PyObject *__pyx_kp_s_Can_only_create_a_buffer_that_is;
  PyObject *__pyx_kp_s_Cannot_assign_to_read_only_memor;
  PyObject *__pyx_kp_s_Cannot_create_writable_memory_vi;
  PyObject *__pyx_kp_u_Cannot_index_with_type;
  PyObject *__pyx_kp_s_Cannot_transpose_memoryview_with;
  PyObject *__pyx_n_s_Class;
  PyObject *__pyx_n_s_Class_A_cib;
  PyObject *__pyx_n_s_Class_A_cn;
  PyObject *__pyx_n_s_Class_A_ir;
  PyObject *__pyx_n_s_Class_A_rs;
  PyObject *__pyx_n_s_Class_A_sn;
  PyObject *__pyx_n_s_Class_B_sz;
  PyObject *__pyx_n_s_Class_Hubble;
  PyObject *__pyx_n_s_Class_M1SZ;
  PyObject *__pyx_n_s_Class_Neff;
  PyObject *__pyx_n_s_Class_Om_m;
  PyObject *__pyx_n_s_Class_Omega0_b;
  PyObject *__pyx_n_s_Class_Omega0_cdm;
  PyObject *__pyx_n_s_Class_Omega0_k;
  PyObject *__pyx_n_s_Class_Omega0_m;
  PyObject *__pyx_n_s_Class_Omega_Lambda;
  PyObject *__pyx_n_s_Class_Omega_b;
  PyObject *__pyx_n_s_Class_Omega_g;
  PyObject *__pyx_n_s_Class_Omega_m;
  PyObject *__pyx_n_s_Class_Omega_r;
  PyObject *__pyx_n_s_Class_Rho_crit_0;
  PyObject *__pyx_n_s_Class_T_cmb;
  PyObject *__pyx_n_s_Class___reduce_cython;
  PyObject *__pyx_n_s_Class___setstate_cython;
  PyObject *__pyx_n_s_Class__check_task_dependency;
  PyObject *__pyx_n_s_Class__cumulativeNumberDensity;
  PyObject *__pyx_n_s_Class__fillparfile;
  PyObject *__pyx_n_s_Class__pars_check;
  PyObject *__pyx_n_s_Class_age;
  PyObject *__pyx_n_s_Class_alpha;
  PyObject *__pyx_n_s_Class_angular_distance;
  PyObject *__pyx_n_s_Class_b_tty;
  PyObject *__pyx_n_s_Class_b_yyy;
  PyObject *__pyx_n_s_Class_baryon_temperature;
  PyObject *__pyx_n_s_Class_bk_at_z_hm;
  PyObject *__pyx_n_s_Class_bk_ttg_at_z_hm;
  PyObject *__pyx_n_s_Class_calcFRel;
  PyObject *__pyx_n_s_Class_calculate_pkl_fftlog_alpha;
  PyObject *__pyx_n_s_Class_chi_star;
  PyObject *__pyx_n_s_Class_cib_monopole;
  PyObject *__pyx_n_s_Class_cib_shotnoise;
  PyObject *__pyx_n_s_Class_cl_IA_g;
  PyObject *__pyx_n_s_Class_cl_c1_gal;
  PyObject *__pyx_n_s_Class_cl_c1_gallens;
  PyObject *__pyx_n_s_Class_cl_c1_lens;
  PyObject *__pyx_n_s_Class_cl_c1_tSZ;
  PyObject *__pyx_n_s_Class_cl_c1c1;
  PyObject *__pyx_n_s_Class_cl_cib_cib;
  PyObject *__pyx_n_s_Class_cl_custom1_cib;
  PyObject *__pyx_n_s_Class_cl_ee;
  PyObject *__pyx_n_s_Class_cl_eg;
  PyObject *__pyx_n_s_Class_cl_gal_cib;
  PyObject *__pyx_n_s_Class_cl_gal_gal_kcmb;
  PyObject *__pyx_n_s_Class_cl_galn_IA;
  PyObject *__pyx_n_s_Class_cl_galn_gallens;
  PyObject *__pyx_n_s_Class_cl_galn_galn;
  PyObject *__pyx_n_s_Class_cl_galn_lens;
  PyObject *__pyx_n_s_Class_cl_galn_tsz;
  PyObject *__pyx_n_s_Class_cl_gg;
  PyObject *__pyx_n_s_Class_cl_ggamma;
  PyObject *__pyx_n_s_Class_cl_gm;
  PyObject *__pyx_n_s_Class_cl_kSZ_kSZ_g;
  PyObject *__pyx_n_s_Class_cl_kSZ_kSZ_kcmb;
  PyObject *__pyx_n_s_Class_cl_kSZ_kSZ_kg;
  PyObject *__pyx_n_s_Class_cl_kg;
  PyObject *__pyx_n_s_Class_cl_kg_cib;
  PyObject *__pyx_n_s_Class_cl_kg_k;
  PyObject *__pyx_n_s_Class_cl_kg_kg;
  PyObject *__pyx_n_s_Class_cl_kg_m;
  PyObject *__pyx_n_s_Class_cl_kk;
  PyObject *__pyx_n_s_Class_cl_km;
  PyObject *__pyx_n_s_Class_cl_ksz;
  PyObject *__pyx_n_s_Class_cl_lens_cib;
  PyObject *__pyx_n_s_Class_cl_lensmagn_gallens;
  PyObject *__pyx_n_s_Class_cl_lensmagn_tsz;
  PyObject *__pyx_n_s_Class_cl_mm;
  PyObject *__pyx_n_s_Class_cl_sz;
  PyObject *__pyx_n_s_Class_cl_sz_at_nu_in_GHz_in_micr;
  PyObject *__pyx_n_s_Class_cl_t2t2f;
  PyObject *__pyx_n_s_Class_cl_tSZ_cib;
  PyObject *__pyx_n_s_Class_cl_te_y_y;
  PyObject *__pyx_n_s_Class_cl_y_kcmb;
  PyObject *__pyx_n_s_Class_cl_yg;
  PyObject *__pyx_n_s_Class_cl_ykg;
  PyObject *__pyx_n_s_Class_cl_ym;
  PyObject *__pyx_n_s_Class_compute;
  PyObject *__pyx_n_s_Class_compute_class_sz;
  PyObject *__pyx_n_s_Class_compute_class_szfast;
  PyObject *__pyx_n_s_Class_delta_def_custom1;
  PyObject *__pyx_n_s_Class_density_cl;
  PyObject *__pyx_kp_u_Class_did_not_read_input_paramet;
  PyObject *__pyx_n_s_Class_dl_isw_sz;
  PyObject *__pyx_n_s_Class_dndzdy_theoretical;
  PyObject *__pyx_n_s_Class_effective_f_sigma8;
  PyObject *__pyx_n_s_Class_effective_galaxy_bias;
  PyObject *__pyx_n_s_Class_empty;
  PyObject *__pyx_n_s_Class_gamma_ggamma;
  PyObject *__pyx_n_s_Class_getM500_from_y0_H13;
  PyObject *__pyx_n_s_Class_getPLog10M;
  PyObject *__pyx_n_s_Class_get_1e6xdy_from_battaglia;
  PyObject *__pyx_n_s_Class_get_1e6xdy_from_gnfw_press;
  PyObject *__pyx_n_s_Class_get_Delta_c_of_Omega_m;
  PyObject *__pyx_n_s_Class_get_Ez;
  PyObject *__pyx_n_s_Class_get_H;
  PyObject *__pyx_n_s_Class_get_IA_of_z;
  PyObject *__pyx_n_s_Class_get_N_centrals;
  PyObject *__pyx_n_s_Class_get_N_satellites;
  PyObject *__pyx_n_s_Class_get_Omega_m_0;
  PyObject *__pyx_n_s_Class_get_Omega_m_at_z;
  PyObject *__pyx_n_s_Class_get_Omega_r_0;
  PyObject *__pyx_n_s_Class_get_P_delta_at_m_and_z_b12;
  PyObject *__pyx_n_s_Class_get_T10_alpha_at_z;
  PyObject *__pyx_n_s_Class_get_arcmin_to_rad;
  PyObject *__pyx_n_s_Class_get_background;
  PyObject *__pyx_n_s_Class_get_bispectrum_f2_kernel;
  PyObject *__pyx_n_s_Class_get_c200c_at_m_and_z;
  PyObject *__pyx_n_s_Class_get_c200c_at_m_and_z_B13;
  PyObject *__pyx_n_s_Class_get_c200c_at_m_and_z_D08;
  PyObject *__pyx_n_s_Class_get_c200m_at_m_and_z;
  PyObject *__pyx_n_s_Class_get_c200m_at_m_and_z_D08;
  PyObject *__pyx_n_s_Class_get_c500c_at_m_and_z;
  PyObject *__pyx_n_s_Class_get_c_delta_at_m_and_z;
  PyObject *__pyx_n_s_Class_get_chi;
  PyObject *__pyx_n_s_Class_get_cib_Snu_z_and_nu;
  PyObject *__pyx_n_s_Class_get_comoving_volume;
  PyObject *__pyx_n_s_Class_get_cov_N_N;
  PyObject *__pyx_n_s_Class_get_current_derived_parame;
  PyObject *__pyx_n_s_Class_get_custom1_bias_at_z;
  PyObject *__pyx_n_s_Class_get_custom1_profile_at_k_m;
  PyObject *__pyx_n_s_Class_get_custom1_profile_at_x_m;
  PyObject *__pyx_n_s_Class_get_cvir_of_mvir_at_z;
  PyObject *__pyx_n_s_Class_get_dA;
  PyObject *__pyx_n_s_Class_get_dA_z1z2;
  PyObject *__pyx_n_s_Class_get_dcib0dz_at_z_and_nu;
  PyObject *__pyx_n_s_Class_get_delta_from_delta_def_a;
  PyObject *__pyx_n_s_Class_get_delta_mean_from_delta;
  PyObject *__pyx_n_s_Class_get_dkappacmbdz_at_l_and_z;
  PyObject *__pyx_n_s_Class_get_dlnsigma_dlnR_at_z_and;
  PyObject *__pyx_n_s_Class_get_dndlnM_at_z_and_M;
  PyObject *__pyx_n_s_Class_get_dndlnm;
  PyObject *__pyx_n_s_Class_get_dydz_at_z;
  PyObject *__pyx_n_s_Class_get_dydzdlnm_at_z_and_m;
  PyObject *__pyx_n_s_Class_get_effective_f_sigma8;
  PyObject *__pyx_n_s_Class_get_f_b;
  PyObject *__pyx_n_s_Class_get_f_free;
  PyObject *__pyx_n_s_Class_get_f_of_sigma_at_m_and_z;
  PyObject *__pyx_n_s_Class_get_f_tinker08_at_nu_and_z;
  PyObject *__pyx_n_s_Class_get_f_tinker10_at_nu_and_z;
  PyObject *__pyx_n_s_Class_get_fftlog_ComputeXiLMsloz;
  PyObject *__pyx_n_s_Class_get_first_order_bias_at_z;
  PyObject *__pyx_n_s_Class_get_first_order_bias_at_z_2;
  PyObject *__pyx_n_s_Class_get_first_order_bias_at_z_3;
  PyObject *__pyx_n_s_Class_get_fstar_of_m_at_z;
  PyObject *__pyx_n_s_Class_get_galaxy_number_counts;
  PyObject *__pyx_n_s_Class_get_gas_density_profile_at;
  PyObject *__pyx_n_s_Class_get_gas_pressure_2h_at_r_a;
  PyObject *__pyx_n_s_Class_get_gas_profile_at_x_M_z_b;
  PyObject *__pyx_n_s_Class_get_gas_profile_at_x_M_z_b_2;
  PyObject *__pyx_n_s_Class_get_gas_profile_at_x_M_z_n;
  PyObject *__pyx_n_s_Class_get_gas_profile_at_x_M_z_n_2;
  PyObject *__pyx_n_s_Class_get_gnu_tsz_of_nu_in_ghz;
  PyObject *__pyx_n_s_Class_get_hmf_counter_term_b1min;
  PyObject *__pyx_n_s_Class_get_hmf_counter_term_b2min;
  PyObject *__pyx_n_s_Class_get_hmf_counter_term_nmin;
  PyObject *__pyx_n_s_Class_get_lensing_noise_at_ell;
  PyObject *__pyx_n_s_Class_get_m200c_to_m200m_at_z_an;
  PyObject *__pyx_n_s_Class_get_m200c_to_m500c_at_z_an;
  PyObject *__pyx_n_s_Class_get_m200m_to_m200c_at_z_an;
  PyObject *__pyx_n_s_Class_get_m200m_to_m500c_at_z_an;
  PyObject *__pyx_n_s_Class_get_m500c_to_m200c_at_z_an;
  PyObject *__pyx_n_s_Class_get_m500c_to_m200m_at_z_an;
  PyObject *__pyx_n_s_Class_get_m_nfw;
  PyObject *__pyx_n_s_Class_get_m_to_xout_at_z_and_m;
  PyObject *__pyx_n_s_Class_get_mass_profile_at_x_M_z;
  PyObject *__pyx_n_s_Class_get_matter_bispectrum_at_z;
  PyObject *__pyx_n_s_Class_get_matter_bispectrum_at_z_2;
  PyObject *__pyx_n_s_Class_get_matter_bispectrum_at_z_3;
  PyObject *__pyx_n_s_Class_get_matter_bispectrum_at_z_4;
  PyObject *__pyx_n_s_Class_get_mean_galaxy_bias_at_z;
  PyObject *__pyx_n_s_Class_get_mean_y;
  PyObject *__pyx_n_s_Class_get_mu_e;
  PyObject *__pyx_n_s_Class_get_n5k_cl_K1_at_chi;
  PyObject *__pyx_n_s_Class_get_n5k_pk_at_z_and_k;
  PyObject *__pyx_n_s_Class_get_n5k_z_of_chi;
  PyObject *__pyx_n_s_Class_get_ng_bar_at_z;
  PyObject *__pyx_n_s_Class_get_nl_index_at_z_and_k;
  PyObject *__pyx_n_s_Class_get_nl_index_at_z_and_k_no;
  PyObject *__pyx_n_s_Class_get_normalization_gas_dens;
  PyObject *__pyx_n_s_Class_get_nu_at_z_and_m;
  PyObject *__pyx_n_s_Class_get_params_sz;
  PyObject *__pyx_n_s_Class_get_perturbations;
  PyObject *__pyx_n_s_Class_get_pk;
  PyObject *__pyx_n_s_Class_get_pk_and_k_and_z;
  PyObject *__pyx_n_s_Class_get_pk_array;
  PyObject *__pyx_n_s_Class_get_pk_cb;
  PyObject *__pyx_n_s_Class_get_pk_cb_array;
  PyObject *__pyx_n_s_Class_get_pk_cb_lin;
  PyObject *__pyx_n_s_Class_get_pk_lin;
  PyObject *__pyx_n_s_Class_get_pk_lin_at_k_and_z;
  PyObject *__pyx_n_s_Class_get_pk_lin_at_k_and_z_fast;
  PyObject *__pyx_n_s_Class_get_pk_nonlin_at_k_and_z;
  PyObject *__pyx_n_s_Class_get_pk_nonlin_at_k_and_z_f;
  PyObject *__pyx_n_s_Class_get_pkl;
  PyObject *__pyx_n_s_Class_get_pkl_at_z;
  PyObject *__pyx_n_s_Class_get_pkl_reconstructed_from;
  PyObject *__pyx_n_s_Class_get_pkl_unvectorized;
  PyObject *__pyx_n_s_Class_get_pknl;
  PyObject *__pyx_n_s_Class_get_pknl_at_z;
  PyObject *__pyx_n_s_Class_get_pknl_unvectorized;
  PyObject *__pyx_n_s_Class_get_planck_sigma_at_theta5;
  PyObject *__pyx_n_s_Class_get_pressure_P_over_P_delt;
  PyObject *__pyx_n_s_Class_get_pressure_P_over_P_delt_2;
  PyObject *__pyx_n_s_Class_get_primordial;
  PyObject *__pyx_n_s_Class_get_r_delta_of_m_delta_at;
  PyObject *__pyx_n_s_Class_get_rad_to_arcmin;
  PyObject *__pyx_n_s_Class_get_radial_kernel_W_custom;
  PyObject *__pyx_n_s_Class_get_radial_kernel_W_galaxy;
  PyObject *__pyx_n_s_Class_get_radial_kernel_W_galaxy_2;
  PyObject *__pyx_n_s_Class_get_rho_2h_at_r_and_m_and;
  PyObject *__pyx_n_s_Class_get_rho_crit_at_z;
  PyObject *__pyx_n_s_Class_get_rvir_of_m200c_at_z;
  PyObject *__pyx_n_s_Class_get_rvir_of_mvir_at_z;
  PyObject *__pyx_n_s_Class_get_scale_dependent_bias_a;
  PyObject *__pyx_n_s_Class_get_second_order_bias_at_z;
  PyObject *__pyx_n_s_Class_get_sigma8_at_z;
  PyObject *__pyx_n_s_Class_get_sigma_at_z_and_m;
  PyObject *__pyx_n_s_Class_get_source_galaxy_number_c;
  PyObject *__pyx_n_s_Class_get_szcounts_dndzdq_at_z_q;
  PyObject *__pyx_n_s_Class_get_szcountsz_sigma_at_the;
  PyObject *__pyx_n_s_Class_get_te_of_m500c_at_z_arnau;
  PyObject *__pyx_n_s_Class_get_te_of_m500c_at_z_lee;
  PyObject *__pyx_n_s_Class_get_thermodynamics;
  PyObject *__pyx_n_s_Class_get_theta_at_m_and_z;
  PyObject *__pyx_n_s_Class_get_transfer;
  PyObject *__pyx_n_s_Class_get_truncated_nfw_profile;
  PyObject *__pyx_n_s_Class_get_truncated_nfw_profile_2;
  PyObject *__pyx_n_s_Class_get_ttg_bispectrum_at_z_ef;
  PyObject *__pyx_n_s_Class_get_ttg_bispectrum_at_z_tr;
  PyObject *__pyx_n_s_Class_get_uk;
  PyObject *__pyx_n_s_Class_get_uk_nfw;
  PyObject *__pyx_n_s_Class_get_unwise_m_min_cut_at_z;
  PyObject *__pyx_n_s_Class_get_upp_from_gnfw_pressure;
  PyObject *__pyx_n_s_Class_get_volume_dVdzdOmega_at_z;
  PyObject *__pyx_n_s_Class_get_vrms2_at_z;
  PyObject *__pyx_n_s_Class_get_y_at_m_and_z;
  PyObject *__pyx_n_s_Class_get_yc_at_m_and_z_H13;
  PyObject *__pyx_n_s_Class_get_z_of_chi;
  PyObject *__pyx_n_s_Class_get_z_of_chi_unvectorized;
  PyObject *__pyx_n_s_Class_h;
  PyObject *__pyx_n_s_Class_ionization_fraction;
  PyObject *__pyx_n_s_Class_k_eq;
  PyObject *__pyx_n_s_Class_lensed_cl;
  PyObject *__pyx_n_s_Class_load_n5k_cl_K1;
  PyObject *__pyx_n_s_Class_load_n5k_pk_zk;
  PyObject *__pyx_n_s_Class_load_n5k_z_of_chi;
  PyObject *__pyx_n_s_Class_luminosity_distance;
  PyObject *__pyx_n_s_Class_n_s;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigma8;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigma8_cb;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigmadisp;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_2;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_3;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_4;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigmaprim;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_sigmaprim_2;
  PyObject *__pyx_n_s_Class_nonlinear_hmcode_window_nf;
  PyObject *__pyx_n_s_Class_nonlinear_scale;
  PyObject *__pyx_n_s_Class_nonlinear_scale_cb;
  PyObject *__pyx_n_s_Class_omega_b;
  PyObject *__pyx_n_s_Class_omega_cdm;
  PyObject *__pyx_n_s_Class_pk;
  PyObject *__pyx_n_s_Class_pk_at_z_hm;
  PyObject *__pyx_n_s_Class_pk_b_at_z_2h;
  PyObject *__pyx_n_s_Class_pk_bb_at_z_hm;
  PyObject *__pyx_n_s_Class_pk_cb;
  PyObject *__pyx_n_s_Class_pk_cb_lin;
  PyObject *__pyx_n_s_Class_pk_em_at_z_hm;
  PyObject *__pyx_n_s_Class_pk_gg_at_z_hm;
  PyObject *__pyx_n_s_Class_pk_lin;
  PyObject *__pyx_n_s_Class_pk_lin_unvectorized;
  PyObject *__pyx_n_s_Class_pk_nonlin;
  PyObject *__pyx_n_s_Class_pk_tilt;
  PyObject *__pyx_n_s_Class_pk_unvectorized;
  PyObject *__pyx_n_s_Class_raw_cl;
  PyObject *__pyx_n_s_Class_rho0_cb;
  PyObject *__pyx_n_s_Class_rho0_crit;
  PyObject *__pyx_n_s_Class_rho0_m;
  PyObject *__pyx_n_s_Class_rs_drag;
  PyObject *__pyx_n_s_Class_scale_independent_growth_f;
  PyObject *__pyx_n_s_Class_scale_independent_growth_f_2;
  PyObject *__pyx_n_s_Class_set;
  PyObject *__pyx_n_s_Class_set_default;
  PyObject *__pyx_n_s_Class_sigma;
  PyObject *__pyx_n_s_Class_sigma8;
  PyObject *__pyx_n_s_Class_sigma8_Pcb;
  PyObject *__pyx_n_s_Class_sigma8_cb;
  PyObject *__pyx_n_s_Class_sigmaM;
  PyObject *__pyx_n_s_Class_sigma_cb;
  PyObject *__pyx_n_s_Class_struct_cleanup;
  PyObject *__pyx_n_s_Class_szcounts_ntot;
  PyObject *__pyx_n_s_Class_szcounts_ntot_rates_loglik;
  PyObject *__pyx_n_s_Class_szfast;
  PyObject *__pyx_n_s_Class_szunbinned_loglike;
  PyObject *__pyx_n_s_Class_tau_reio;
  PyObject *__pyx_n_s_Class_theta_s_100;
  PyObject *__pyx_n_s_Class_theta_star_100;
  PyObject *__pyx_n_s_Class_tllprime_sz;
  PyObject *__pyx_n_s_Class_x_out_custom1;
  PyObject *__pyx_n_s_Class_ystar;
  PyObject *__pyx_n_s_Class_z_of_r;
  PyObject *__pyx_n_s_Class_z_of_tau;
  PyObject *__pyx_n_s_Class_z_reio;
  PyObject *__pyx_n_s_CosmoComputationError;
  PyObject *__pyx_n_s_CosmoError;
  PyObject *__pyx_n_s_CosmoError___init;
  PyObject *__pyx_n_s_CosmoError___str;
  PyObject *__pyx_n_s_CosmoSevereError;
  PyObject *__pyx_n_s_D;
  PyObject *__pyx_n_s_DEBUG;
  PyObject *__pyx_n_s_D_A;
  PyObject *__pyx_n_s_Delta_c;
  PyObject *__pyx_n_u_Deprecated;
  PyObject *__pyx_kp_s_Dimension_d_is_not_direct;
  PyObject *__pyx_n_u_Dust_temperature_today_in_Kelvin;
  PyObject *__pyx_n_s_Dz;
  PyObject *__pyx_n_s_Dzmax;
  PyObject *__pyx_n_s_Eh;
  PyObject *__pyx_n_s_Ellipsis;
  PyObject *__pyx_n_u_Emissivity_index_of_sed;
  PyObject *__pyx_kp_s_Empty_shape_tuple_for_cython_arr;
  PyObject *__pyx_kp_u_Error_in_Class;
  PyObject *__pyx_n_s_Ez;
  PyObject *__pyx_n_s_F;
  PyObject *__pyx_n_s_G;
  PyObject *__pyx_n_u_Gamma_0_nadm;
  PyObject *__pyx_n_s_H;
  PyObject *__pyx_n_u_H0;
  PyObject *__pyx_n_s_H_array;
  PyObject *__pyx_n_s_H_over_c_in_h_over_Mpc_array;
  PyObject *__pyx_n_s_Hankel;
  PyObject *__pyx_n_s_Hubble;
  PyObject *__pyx_n_u_I0;
  PyObject *__pyx_n_s_INFO;
  PyObject *__pyx_n_s_ImportError;
  PyObject *__pyx_kp_u_In_order_to_get_pk_tilt_at_k_e_1;
  PyObject *__pyx_kp_u_In_order_to_get_sigma_R_z_you_mu;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_n_s_IndexError;
  PyObject *__pyx_kp_s_Index_out_of_bounds_axis_d;
  PyObject *__pyx_kp_s_Indirect_dimensions_not_supporte;
  PyObject *__pyx_kp_u_Input_should_be_a_float_or_a_1D;
  PyObject *__pyx_n_s_InterpolatedUnivariateSpline;
  PyObject *__pyx_kp_u_Invalid_mode_expected_c_or_fortr;
  PyObject *__pyx_kp_u_Invalid_shape_in_axis;
  PyObject *__pyx_n_s_KeyError;
  PyObject *__pyx_n_s_M;
  PyObject *__pyx_n_u_M0_HOD_ngal;
  PyObject *__pyx_n_s_M1SZ;
  PyObject *__pyx_n_s_M1_prime;
  PyObject *__pyx_n_u_M1_prime_HOD;
  PyObject *__pyx_n_u_M1_prime_HOD_ngal;
  PyObject *__pyx_n_s_M500;
  PyObject *__pyx_n_s_M500c_zk;
  PyObject *__pyx_n_s_MF_extr;
  PyObject *__pyx_n_s_MUpper;
  PyObject *__pyx_n_s_M_halo;
  PyObject *__pyx_n_u_M_max;
  PyObject *__pyx_n_s_M_min;
  PyObject *__pyx_n_u_M_min;
  PyObject *__pyx_n_u_M_min_HOD;
  PyObject *__pyx_n_u_M_min_HOD_ngal;
  PyObject *__pyx_n_s_MemoryError;
  PyObject *__pyx_kp_s_MemoryView_of_r_at_0x_x;
  PyObject *__pyx_kp_s_MemoryView_of_r_object;
  PyObject *__pyx_n_u_Most_efficient_halo_mass_in_Msun;
  PyObject *__pyx_n_s_N;
  PyObject *__pyx_n_u_N_dg;
  PyObject *__pyx_n_u_N_ncdm;
  PyObject *__pyx_n_s_N_ngal;
  PyObject *__pyx_n_u_N_ur;
  PyObject *__pyx_n_s_Nc;
  PyObject *__pyx_n_s_Nc_mean;
  PyObject *__pyx_n_s_Neff;
  PyObject *__pyx_n_u_Neff;
  PyObject *__pyx_n_s_Nmcfit;
  PyObject *__pyx_kp_u_No_Cl_computed;
  PyObject *__pyx_kp_u_No_density_Cl_computed;
  PyObject *__pyx_kp_u_No_lensed_Cl_computed;
  PyObject *__pyx_kp_u_No_massive_neutrinos_You_must_us;
  PyObject *__pyx_kp_u_No_power_spectrum_computed_In_or;
  PyObject *__pyx_kp_u_No_power_spectrum_computed_In_or_2;
  PyObject *__pyx_kp_u_No_power_spectrum_computed_You_m;
  PyObject *__pyx_kp_u_Normalisation_of_L___M_relation;
  PyObject *__pyx_n_s_NotImplementedError;
  PyObject *__pyx_n_s_Ns;
  PyObject *__pyx_n_s_Ntot;
  PyObject *__pyx_n_s_Nz;
  PyObject *__pyx_n_b_O;
  PyObject *__pyx_n_s_Om_m;
  PyObject *__pyx_n_s_Omega0_b;
  PyObject *__pyx_n_s_Omega0_cdm;
  PyObject *__pyx_n_u_Omega0_fld;
  PyObject *__pyx_n_s_Omega0_k;
  PyObject *__pyx_n_u_Omega0_lambda;
  PyObject *__pyx_n_s_Omega0_m;
  PyObject *__pyx_n_s_Omega_Lambda;
  PyObject *__pyx_n_u_Omega_Lambda;
  PyObject *__pyx_n_s_Omega_b;
  PyObject *__pyx_n_u_Omega_b;
  PyObject *__pyx_n_u_Omega_c;
  PyObject *__pyx_n_u_Omega_cdm;
  PyObject *__pyx_n_s_Omega_g;
  PyObject *__pyx_n_s_Omega_m;
  PyObject *__pyx_n_u_Omega_m;
  PyObject *__pyx_n_s_Omega_r;
  PyObject *__pyx_kp_u_Out_of_bounds_on_buffer_access_a;
  PyObject *__pyx_n_s_P;
  PyObject *__pyx_n_s_P0GNFW;
  PyObject *__pyx_n_u_P0GNFW;
  PyObject *__pyx_n_u_P0_B12;
  PyObject *__pyx_n_u_P13_file;
  PyObject *__pyx_n_s_P200;
  PyObject *__pyx_n_s_PATH_TO_CLASS_SZ_DATA;
  PyObject *__pyx_n_s_PArr;
  PyObject *__pyx_n_s_PLog10M;
  PyObject *__pyx_n_s_PLog10M_full;
  PyObject *__pyx_kp_u_P_cb_not_computed_by_CLASS_proba;
  PyObject *__pyx_kp_u_P_cb_not_computed_probably_becau;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_n_u_Power_law_index_of_SED_at_high_f;
  PyObject *__pyx_kp_u_Profile;
  PyObject *__pyx_n_s_Py0GivenM;
  PyObject *__pyx_n_s_Pz;
  PyObject *__pyx_n_s_QF;
  PyObject *__pyx_n_s_R;
  PyObject *__pyx_kp_s_Raised_when_Class_could_not_com;
  PyObject *__pyx_kp_s_Raised_when_Class_failed_to_und;
  PyObject *__pyx_kp_u_Redshift_evolution_of_L___M_norm;
  PyObject *__pyx_n_u_Redshift_evolution_of_dust_tempe;
  PyObject *__pyx_n_s_Rho_crit_0;
  PyObject *__pyx_n_u_SZ_cat_file;
  PyObject *__pyx_n_s_Sequence;
  PyObject *__pyx_n_u_Size_of_halo_masses_sourcing_CIB;
  PyObject *__pyx_kp_s_Step_may_not_be_zero_axis_d;
  PyObject *__pyx_n_s_Stw;
  PyObject *__pyx_kp_b_T;
  PyObject *__pyx_n_s_TCMB;
  PyObject *__pyx_n_s_TKelvin;
  PyObject *__pyx_n_s_T_cmb;
  PyObject *__pyx_n_s_T_ll_arr;
  PyObject *__pyx_n_s_Tb;
  PyObject *__pyx_n_s_Tcmb;
  PyObject *__pyx_n_s_Tcmb_gNU;
  PyObject *__pyx_n_u_Tinker_et_al_10_alpha_consistenc;
  PyObject *__pyx_n_s_TkeV;
  PyObject *__pyx_kp_u_Type;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_kp_s_Unable_to_convert_item_to_object;
  PyObject *__pyx_kp_u_Users_boris_Work_CLASS_SZ_SO_SZ;
  PyObject *__pyx_n_u_V_0;
  PyObject *__pyx_n_u_V_1;
  PyObject *__pyx_n_u_V_2;
  PyObject *__pyx_n_u_V_3;
  PyObject *__pyx_n_u_V_4;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s_View_MemoryView;
  PyObject *__pyx_n_s_Wg;
  PyObject *__pyx_n_s_X;
  PyObject *__pyx_n_s_Xtw;
  PyObject *__pyx_n_s_Y0;
  PyObject *__pyx_n_s_Y1;
  PyObject *__pyx_n_s_Y2;
  PyObject *__pyx_n_s_Y3;
  PyObject *__pyx_n_s_Y4;
  PyObject *__pyx_n_u_YHe;
  PyObject *__pyx_kp_u_You_ask_classy_to_return_an_arra;
  PyObject *__pyx_kp_u_You_ask_classy_to_return_an_arra_2;
  PyObject *__pyx_kp_u_You_ask_classy_to_return_an_arra_3;
  PyObject *__pyx_kp_b__10;
  PyObject *__pyx_kp_u__10;
  PyObject *__pyx_kp_b__11;
  PyObject *__pyx_kp_b__12;
  PyObject *__pyx_kp_u__13;
  PyObject *__pyx_kp_u__14;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_kp_u__20;
  PyObject *__pyx_kp_u__22;
  PyObject *__pyx_n_s__3;
  PyObject *__pyx_kp_u__46;
  PyObject *__pyx_n_s__554;
  PyObject *__pyx_kp_u__6;
  PyObject *__pyx_kp_u__7;
  PyObject *__pyx_kp_b__9;
  PyObject *__pyx_n_u_a_dark;
  PyObject *__pyx_n_s_abc;
  PyObject *__pyx_n_s_add;
  PyObject *__pyx_n_s_age;
  PyObject *__pyx_n_u_age;
  PyObject *__pyx_n_s_allocate_buffer;
  PyObject *__pyx_n_s_alpha;
  PyObject *__pyx_n_s_alphaGNFW;
  PyObject *__pyx_n_u_alpha_B12;
  PyObject *__pyx_n_s_alpha_c_P0;
  PyObject *__pyx_n_u_alpha_c_P0_B12;
  PyObject *__pyx_n_s_alpha_c_alpha;
  PyObject *__pyx_n_u_alpha_c_alpha;
  PyObject *__pyx_n_s_alpha_c_beta;
  PyObject *__pyx_n_u_alpha_c_beta;
  PyObject *__pyx_n_u_alpha_c_beta_B12;
  PyObject *__pyx_n_s_alpha_c_rho0;
  PyObject *__pyx_n_u_alpha_c_rho0;
  PyObject *__pyx_n_s_alpha_c_xc;
  PyObject *__pyx_n_u_alpha_c_xc_B12;
  PyObject *__pyx_n_s_alpha_m_P0;
  PyObject *__pyx_n_u_alpha_m_P0_B12;
  PyObject *__pyx_n_s_alpha_m_alpha;
  PyObject *__pyx_n_u_alpha_m_alpha;
  PyObject *__pyx_n_s_alpha_m_beta;
  PyObject *__pyx_n_u_alpha_m_beta;
  PyObject *__pyx_n_u_alpha_m_beta_B12;
  PyObject *__pyx_n_s_alpha_m_rho0;
  PyObject *__pyx_n_u_alpha_m_rho0;
  PyObject *__pyx_n_s_alpha_m_xc;
  PyObject *__pyx_n_u_alpha_m_xc_B12;
  PyObject *__pyx_n_s_alpha_s;
  PyObject *__pyx_n_u_alpha_s;
  PyObject *__pyx_n_u_alpha_s_HOD;
  PyObject *__pyx_n_u_alpha_s_HOD_ngal;
  PyObject *__pyx_n_u_alpha_t;
  PyObject *__pyx_n_s_alpha_z_P0;
  PyObject *__pyx_n_u_alpha_z_P0_B12;
  PyObject *__pyx_n_s_alpha_z_alpha;
  PyObject *__pyx_n_u_alpha_z_alpha;
  PyObject *__pyx_n_s_alpha_z_beta;
  PyObject *__pyx_n_u_alpha_z_beta;
  PyObject *__pyx_n_u_alpha_z_beta_B12;
  PyObject *__pyx_n_s_alpha_z_rho0;
  PyObject *__pyx_n_u_alpha_z_rho0;
  PyObject *__pyx_n_s_alpha_z_xc;
  PyObject *__pyx_n_u_alpha_z_xc_B12;
  PyObject *__pyx_n_s_alphap_m_P0;
  PyObject *__pyx_n_u_alphap_m_P0_B12;
  PyObject *__pyx_n_s_alphap_m_alpha;
  PyObject *__pyx_n_u_alphap_m_alpha;
  PyObject *__pyx_n_s_alphap_m_beta;
  PyObject *__pyx_n_u_alphap_m_beta;
  PyObject *__pyx_n_u_alphap_m_beta_B12;
  PyObject *__pyx_n_s_alphap_m_rho0;
  PyObject *__pyx_n_u_alphap_m_rho0;
  PyObject *__pyx_n_s_alphap_m_xc;
  PyObject *__pyx_n_u_alphap_m_xc_B12;
  PyObject *__pyx_kp_u_and;
  PyObject *__pyx_n_s_angular_distance;
  PyObject *__pyx_n_s_append;
  PyObject *__pyx_n_s_applyMFDebiasCorrection;
  PyObject *__pyx_n_s_arange;
  PyObject *__pyx_n_s_argmax;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_u_arr_0;
  PyObject *__pyx_n_s_array;
  PyObject *__pyx_n_s_asarray;
  PyObject *__pyx_n_s_assume_sorted;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_atleast_1d;
  PyObject *__pyx_n_s_axis;
  PyObject *__pyx_n_s_b_tty;
  PyObject *__pyx_n_s_b_yyy;
  PyObject *__pyx_n_s_background;
  PyObject *__pyx_n_u_background;
  PyObject *__pyx_kp_u_bad_call;
  PyObject *__pyx_n_s_baryon_temperature;
  PyObject *__pyx_n_s_base;
  PyObject *__pyx_n_s_basicConfig;
  PyObject *__pyx_n_u_bb;
  PyObject *__pyx_kp_u_bbn_PRIMAT21_class_format_dat;
  PyObject *__pyx_n_s_betaGNFW;
  PyObject *__pyx_n_u_betaGNFW;
  PyObject *__pyx_n_u_beta_B12;
  PyObject *__pyx_n_u_beta_s;
  PyObject *__pyx_n_s_bh;
  PyObject *__pyx_n_s_bk_at_z_hm;
  PyObject *__pyx_n_s_bk_ttg_at_z_hm;
  PyObject *__pyx_n_u_boundary;
  PyObject *__pyx_n_s_bounds_error;
  PyObject *__pyx_n_s_broadcast_arrays;
  PyObject *__pyx_kp_u_but_you_asked_a_l_i;
  PyObject *__pyx_n_s_c;
  PyObject *__pyx_n_u_c;
  PyObject *__pyx_n_s_c500;
  PyObject *__pyx_n_u_c500;
  PyObject *__pyx_n_u_c_B12;
  PyObject *__pyx_n_u_c_B16;
  PyObject *__pyx_n_s_c_asked;
  PyObject *__pyx_n_s_c_delta;
  PyObject *__pyx_n_s_calcErrors;
  PyObject *__pyx_n_s_calcFRel;
  PyObject *__pyx_n_s_calculate_chi;
  PyObject *__pyx_n_s_calculate_cmb;
  PyObject *__pyx_n_s_calculate_hubble;
  PyObject *__pyx_n_s_calculate_pkl;
  PyObject *__pyx_n_s_calculate_pkl_at_z;
  PyObject *__pyx_n_s_calculate_pkl_fftlog_alphas;
  PyObject *__pyx_n_s_calculate_pknl;
  PyObject *__pyx_n_s_calculate_pknl_at_z;
  PyObject *__pyx_n_s_calculate_sigma;
  PyObject *__pyx_n_s_calculate_sigma8_and_der;
  PyObject *__pyx_n_s_calculate_sigma8_at_z;
  PyObject *__pyx_n_u_camb;
  PyObject *__pyx_n_s_check_task_dependency;
  PyObject *__pyx_n_s_chi;
  PyObject *__pyx_n_s_chi_star;
  PyObject *__pyx_n_u_cib_Snu_file_nu;
  PyObject *__pyx_n_u_cib_Snu_file_snu;
  PyObject *__pyx_n_u_cib_Snu_file_z;
  PyObject *__pyx_n_s_cib_monopole;
  PyObject *__pyx_n_s_cib_shotnoise;
  PyObject *__pyx_n_s_cl;
  PyObject *__pyx_n_s_cl_IA_g;
  PyObject *__pyx_n_s_cl_c1_gal;
  PyObject *__pyx_n_s_cl_c1_gallens;
  PyObject *__pyx_n_s_cl_c1_lens;
  PyObject *__pyx_n_s_cl_c1_tSZ;
  PyObject *__pyx_n_s_cl_c1c1;
  PyObject *__pyx_n_s_cl_cib;
  PyObject *__pyx_n_s_cl_cib_cib;
  PyObject *__pyx_n_s_cl_custom1_cib;
  PyObject *__pyx_n_s_cl_ee;
  PyObject *__pyx_n_s_cl_eg;
  PyObject *__pyx_n_s_cl_gIA;
  PyObject *__pyx_n_s_cl_g_cib;
  PyObject *__pyx_n_s_cl_g_gamma_1h;
  PyObject *__pyx_n_s_cl_g_gamma_2h;
  PyObject *__pyx_n_s_cl_g_gamma_ell;
  PyObject *__pyx_n_s_cl_gal_cib;
  PyObject *__pyx_n_s_cl_gal_gal_kcmb;
  PyObject *__pyx_n_s_cl_galn_IA;
  PyObject *__pyx_n_s_cl_galn_gallens;
  PyObject *__pyx_n_s_cl_galn_galn;
  PyObject *__pyx_n_s_cl_galn_lens;
  PyObject *__pyx_n_s_cl_galn_tsz;
  PyObject *__pyx_n_s_cl_gg;
  PyObject *__pyx_n_s_cl_ggamma;
  PyObject *__pyx_n_s_cl_gk;
  PyObject *__pyx_n_s_cl_gkg;
  PyObject *__pyx_n_s_cl_gm;
  PyObject *__pyx_n_s_cl_gy;
  PyObject *__pyx_n_s_cl_kSZ_kSZ_g;
  PyObject *__pyx_n_s_cl_kSZ_kSZ_kcmb;
  PyObject *__pyx_n_s_cl_kSZ_kSZ_kg;
  PyObject *__pyx_n_s_cl_kg;
  PyObject *__pyx_n_s_cl_kg_cib;
  PyObject *__pyx_n_s_cl_kg_k;
  PyObject *__pyx_n_s_cl_kg_kg;
  PyObject *__pyx_n_s_cl_kg_m;
  PyObject *__pyx_n_s_cl_kk;
  PyObject *__pyx_n_s_cl_km;
  PyObject *__pyx_n_s_cl_ksz;
  PyObject *__pyx_n_s_cl_lens_cib;
  PyObject *__pyx_n_s_cl_lensmagn_gallens;
  PyObject *__pyx_n_s_cl_lensmagn_tsz;
  PyObject *__pyx_n_s_cl_md;
  PyObject *__pyx_n_s_cl_md_ic;
  PyObject *__pyx_n_s_cl_mkg;
  PyObject *__pyx_n_s_cl_mm;
  PyObject *__pyx_n_s_cl_my;
  PyObject *__pyx_n_s_cl_phi_cib;
  PyObject *__pyx_n_s_cl_sz;
  PyObject *__pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2;
  PyObject *__pyx_n_s_cl_t2t2f;
  PyObject *__pyx_n_s_cl_tSZ_cib;
  PyObject *__pyx_n_s_cl_te_y_y;
  PyObject *__pyx_n_s_cl_y_cib;
  PyObject *__pyx_n_s_cl_y_kcmb;
  PyObject *__pyx_n_s_cl_yg;
  PyObject *__pyx_n_s_cl_ykg;
  PyObject *__pyx_n_s_cl_ym;
  PyObject *__pyx_n_s_class;
  PyObject *__pyx_n_u_class_2;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_10;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_11;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_12;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_13;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_2;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_3;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_4;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_5;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_6;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_7;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_8;
  PyObject *__pyx_kp_u_class_sz_auxiliary_files_includ_9;
  PyObject *__pyx_kp_u_class_sz_class_sz;
  PyObject *__pyx_n_u_class_sz_cosmo;
  PyObject *__pyx_n_s_class_sz_in_dict_output;
  PyObject *__pyx_n_u_class_sz_integrate;
  PyObject *__pyx_kp_s_class_sz_python_classy_pyx;
  PyObject *__pyx_n_u_class_sz_tabulate;
  PyObject *__pyx_n_s_classy_sz;
  PyObject *__pyx_n_u_classy_sz_verbose;
  PyObject *__pyx_n_s_classy_szfast;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_cls;
  PyObject *__pyx_n_s_cltot;
  PyObject *__pyx_n_s_cltotfunc;
  PyObject *__pyx_n_s_clusterLogM500;
  PyObject *__pyx_n_s_clusterLogM500Max;
  PyObject *__pyx_n_s_clusterLogM500Min;
  PyObject *__pyx_n_s_clusterM500;
  PyObject *__pyx_n_s_clusterM500MinusErr;
  PyObject *__pyx_n_s_clusterM500PlusErr;
  PyObject *__pyx_n_s_cnew;
  PyObject *__pyx_n_s_collections;
  PyObject *__pyx_kp_s_collections_abc;
  PyObject *__pyx_n_s_compile;
  PyObject *__pyx_n_s_compute;
  PyObject *__pyx_n_s_compute_class_sz;
  PyObject *__pyx_n_s_compute_class_szfast;
  PyObject *__pyx_n_s_compute_class_szfast_locals_gene;
  PyObject *__pyx_n_s_compute_pkl;
  PyObject *__pyx_n_s_compute_pknl;
  PyObject *__pyx_n_s_compute_profile;
  PyObject *__pyx_n_u_concentration_parameter;
  PyObject *__pyx_kp_u_concentration_parameter_2;
  PyObject *__pyx_n_s_configure_logging;
  PyObject *__pyx_n_u_conformal_age;
  PyObject *__pyx_n_s_contains;
  PyObject *__pyx_n_s_contains_specific_keys;
  PyObject *__pyx_n_s_contains_specific_pattern_or_key;
  PyObject *__pyx_n_s_contextlib;
  PyObject *__pyx_n_s_contextmanager;
  PyObject *__pyx_kp_s_contiguous_and_direct;
  PyObject *__pyx_kp_s_contiguous_and_indirect;
  PyObject *__pyx_n_s_copy;
  PyObject *__pyx_n_s_cosh;
  PyObject *__pyx_n_u_cosmo;
  PyObject *__pyx_n_s_cosmo_arguments;
  PyObject *__pyx_n_s_cosmo_model;
  PyObject *__pyx_n_u_cosmo_model;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_kp_u_cov_N_N;
  PyObject *__pyx_n_u_covmat;
  PyObject *__pyx_n_u_cp_B12;
  PyObject *__pyx_n_u_cp_B16;
  PyObject *__pyx_n_s_cp_pkl_fftlog_alphas_nus;
  PyObject *__pyx_n_s_cp_predicted_ee_spectrum;
  PyObject *__pyx_n_s_cp_predicted_pp_spectrum;
  PyObject *__pyx_n_s_cp_predicted_te_spectrum;
  PyObject *__pyx_n_s_cp_predicted_tt_spectrum;
  PyObject *__pyx_n_s_cszfast;
  PyObject *__pyx_n_s_cszfast_pk_grid_dsigma2_flat;
  PyObject *__pyx_n_s_cszfast_pk_grid_k;
  PyObject *__pyx_n_s_cszfast_pk_grid_ln1pz;
  PyObject *__pyx_n_s_cszfast_pk_grid_lnk;
  PyObject *__pyx_n_s_cszfast_pk_grid_lnr;
  PyObject *__pyx_n_s_cszfast_pk_grid_lnsigma2_flat;
  PyObject *__pyx_n_s_cszfast_pk_grid_pkl_flat;
  PyObject *__pyx_n_s_cszfast_pk_grid_pknl;
  PyObject *__pyx_n_s_cszfast_pk_grid_pknl_flat;
  PyObject *__pyx_n_s_cszfast_pk_grid_z;
  PyObject *__pyx_n_s_cszfast_pk_grid_zmax;
  PyObject *__pyx_n_s_ctx;
  PyObject *__pyx_n_u_cubic;
  PyObject *__pyx_n_s_cumtrapz;
  PyObject *__pyx_n_s_cumulativeNumberDensity;
  PyObject *__pyx_n_u_current;
  PyObject *__pyx_n_s_custom1_W;
  PyObject *__pyx_n_s_custom1_b;
  PyObject *__pyx_n_s_custom1_ux;
  PyObject *__pyx_n_s_d;
  PyObject *__pyx_n_u_d_ell;
  PyObject *__pyx_n_u_da_rec;
  PyObject *__pyx_n_u_da_rec_h;
  PyObject *__pyx_n_u_da_star;
  PyObject *__pyx_n_s_data;
  PyObject *__pyx_n_u_data;
  PyObject *__pyx_n_s_dcl;
  PyObject *__pyx_n_u_dd;
  PyObject *__pyx_n_s_decode;
  PyObject *__pyx_n_s_default;
  PyObject *__pyx_n_s_defaultdict;
  PyObject *__pyx_n_u_deg_ncdm;
  PyObject *__pyx_n_s_delta;
  PyObject *__pyx_n_s_deltaSZE;
  PyObject *__pyx_n_s_delta_crit;
  PyObject *__pyx_n_s_delta_def;
  PyObject *__pyx_n_s_delta_def_custom1;
  PyObject *__pyx_n_s_density_cl;
  PyObject *__pyx_n_s_derived;
  PyObject *__pyx_n_u_derived;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_dl;
  PyObject *__pyx_n_u_dl;
  PyObject *__pyx_n_s_dl_isw_sz;
  PyObject *__pyx_n_s_dndM;
  PyObject *__pyx_n_u_dndM;
  PyObject *__pyx_n_s_dndlnM;
  PyObject *__pyx_n_u_dndlnM;
  PyObject *__pyx_n_u_dndlnm;
  PyObject *__pyx_n_u_dndm;
  PyObject *__pyx_n_u_dndz_shift_gal;
  PyObject *__pyx_n_u_dndz_shift_ngal;
  PyObject *__pyx_n_u_dndz_shift_source_gal;
  PyObject *__pyx_n_u_dndz_stretch_gal;
  PyObject *__pyx_n_u_dndz_stretch_ngal;
  PyObject *__pyx_n_u_dndz_stretch_source_gal;
  PyObject *__pyx_n_s_dndzdy;
  PyObject *__pyx_n_u_dndzdy;
  PyObject *__pyx_n_s_dndzdy_index_z;
  PyObject *__pyx_n_s_dndzdy_theoretical;
  PyObject *__pyx_n_s_doc;
  PyObject *__pyx_n_s_double;
  PyObject *__pyx_n_u_ds_d;
  PyObject *__pyx_n_u_ds_d_h;
  PyObject *__pyx_n_u_ds_rec;
  PyObject *__pyx_n_u_ds_rec_h;
  PyObject *__pyx_n_u_ds_star;
  PyObject *__pyx_n_s_dtype;
  PyObject *__pyx_n_s_dtype_is_object;
  PyObject *__pyx_n_s_dumc;
  PyObject *__pyx_n_s_dumcp;
  PyObject *__pyx_n_s_dx;
  PyObject *__pyx_n_u_dydz;
  PyObject *__pyx_n_s_dzdr;
  PyObject *__pyx_n_s_e;
  PyObject *__pyx_n_u_ee;
  PyObject *__pyx_n_s_effective_f_sigma8;
  PyObject *__pyx_n_s_effective_galaxy_bias;
  PyObject *__pyx_n_s_elem;
  PyObject *__pyx_n_s_ell;
  PyObject *__pyx_n_u_ell;
  PyObject *__pyx_n_s_empty;
  PyObject *__pyx_n_s_empty_like;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_encode;
  PyObject *__pyx_n_s_end;
  PyObject *__pyx_n_s_endpoint;
  PyObject *__pyx_n_s_enter;
  PyObject *__pyx_n_s_enumerate;
  PyObject *__pyx_n_s_eps1;
  PyObject *__pyx_n_s_eps2;
  PyObject *__pyx_n_s_eps23;
  PyObject *__pyx_n_u_epsilon_V;
  PyObject *__pyx_n_s_errmsg;
  PyObject *__pyx_n_s_error;
  PyObject *__pyx_n_u_eta_V;
  PyObject *__pyx_n_s_even;
  PyObject *__pyx_n_s_exit;
  PyObject *__pyx_n_s_exp;
  PyObject *__pyx_n_u_exp_m_2_tau_As;
  PyObject *__pyx_n_u_extensive;
  PyObject *__pyx_n_s_extrap;
  PyObject *__pyx_n_u_extrapolate;
  PyObject *__pyx_n_s_extrapolator;
  PyObject *__pyx_n_s_f;
  PyObject *__pyx_n_u_fNL;
  PyObject *__pyx_n_s_fRel;
  PyObject *__pyx_n_s_f_b;
  PyObject *__pyx_n_s_f_rel;
  PyObject *__pyx_n_s_fac;
  PyObject *__pyx_n_s_fc;
  PyObject *__pyx_n_s_fill_value;
  PyObject *__pyx_n_s_fillparfile;
  PyObject *__pyx_n_s_filterwarnings;
  PyObject *__pyx_n_s_find_As;
  PyObject *__pyx_n_s_fineLog10M;
  PyObject *__pyx_n_s_fineP;
  PyObject *__pyx_n_u_first;
  PyObject *__pyx_n_s_flag;
  PyObject *__pyx_n_s_flags;
  PyObject *__pyx_n_s_flatten;
  PyObject *__pyx_n_s_float64;
  PyObject *__pyx_n_u_float64;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_s_fortran;
  PyObject *__pyx_n_u_fortran;
  PyObject *__pyx_n_s_frequency_in_Hz;
  PyObject *__pyx_n_u_full_path_and_prefix_to_dndz_nga;
  PyObject *__pyx_n_u_full_path_to_dndz_gal;
  PyObject *__pyx_n_u_full_path_to_source_dndz_gal;
  PyObject *__pyx_n_u_galaxy_samples_list_num;
  PyObject *__pyx_n_s_gamma;
  PyObject *__pyx_n_s_gammaGNFW;
  PyObject *__pyx_n_u_gamma_B12;
  PyObject *__pyx_n_u_gamma_B16;
  PyObject *__pyx_n_s_gamma_ggamma;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_genexpr;
  PyObject *__pyx_n_s_geomspace;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_getData;
  PyObject *__pyx_n_s_getLogger;
  PyObject *__pyx_n_s_getM500_from_y0_H13;
  PyObject *__pyx_n_s_getPLog10M;
  PyObject *__pyx_n_s_get_1e6xdy_from_battaglia_pressu;
  PyObject *__pyx_n_s_get_1e6xdy_from_gnfw_pressure_at;
  PyObject *__pyx_n_s_get_Delta_c_of_Omega_m;
  PyObject *__pyx_n_s_get_Ez;
  PyObject *__pyx_n_s_get_H;
  PyObject *__pyx_n_s_get_H0_from_thetas;
  PyObject *__pyx_n_s_get_IA_of_z;
  PyObject *__pyx_n_s_get_N_centrals;
  PyObject *__pyx_n_s_get_N_satellites;
  PyObject *__pyx_n_s_get_Omega_m_0;
  PyObject *__pyx_n_s_get_Omega_m_at_z;
  PyObject *__pyx_n_s_get_Omega_r_0;
  PyObject *__pyx_n_s_get_P_delta_at_m_and_z_b12;
  PyObject *__pyx_n_s_get_Q_of_theta500;
  PyObject *__pyx_n_s_get_T10_alpha_at_z;
  PyObject *__pyx_n_s_get_arcmin_to_rad;
  PyObject *__pyx_n_s_get_background;
  PyObject *__pyx_n_s_get_bispectrum_f2_kernel;
  PyObject *__pyx_n_s_get_c200c_at_m_and_z;
  PyObject *__pyx_n_s_get_c200c_at_m_and_z_B13;
  PyObject *__pyx_n_s_get_c200c_at_m_and_z_D08;
  PyObject *__pyx_n_s_get_c200m_at_m_and_z;
  PyObject *__pyx_n_s_get_c200m_at_m_and_z_D08;
  PyObject *__pyx_n_s_get_c500c_at_m_and_z;
  PyObject *__pyx_n_s_get_c_delta_at_m_and_z;
  PyObject *__pyx_n_s_get_chi;
  PyObject *__pyx_n_s_get_cib_Snu_z_and_nu;
  PyObject *__pyx_n_s_get_comoving_volume;
  PyObject *__pyx_n_s_get_cov_N_N;
  PyObject *__pyx_n_s_get_current_derived_parameters;
  PyObject *__pyx_n_s_get_custom1_bias_at_z;
  PyObject *__pyx_n_s_get_custom1_profile_at_k_m_z;
  PyObject *__pyx_n_s_get_custom1_profile_at_x_m_z;
  PyObject *__pyx_n_s_get_cvir_of_mvir_at_z;
  PyObject *__pyx_n_s_get_dA;
  PyObject *__pyx_n_s_get_dA_z1z2;
  PyObject *__pyx_n_s_get_dcib0dz_at_z_and_nu;
  PyObject *__pyx_n_s_get_delta_from_delta_def_at_z;
  PyObject *__pyx_n_s_get_delta_mean_from_delta_crit_a;
  PyObject *__pyx_n_s_get_dkappacmbdz_at_l_and_z;
  PyObject *__pyx_n_s_get_dlnsigma_dlnR_at_z_and_m;
  PyObject *__pyx_n_s_get_dndlnM_at_z_and_M;
  PyObject *__pyx_n_s_get_dndlnm;
  PyObject *__pyx_n_s_get_dndzdq;
  PyObject *__pyx_n_s_get_dydz_at_z;
  PyObject *__pyx_n_s_get_dydzdlnm_at_z_and_m;
  PyObject *__pyx_n_s_get_effective_f_sigma8;
  PyObject *__pyx_n_s_get_f_b;
  PyObject *__pyx_n_s_get_f_free;
  PyObject *__pyx_n_s_get_f_of_sigma_at_m_and_z;
  PyObject *__pyx_n_s_get_f_tinker08_at_nu_and_z;
  PyObject *__pyx_n_s_get_f_tinker10_at_nu_and_z;
  PyObject *__pyx_n_s_get_fftlog_ComputeXiLMsloz;
  PyObject *__pyx_n_s_get_first_order_bias_at_z_and_m;
  PyObject *__pyx_n_s_get_first_order_bias_at_z_and_m_2;
  PyObject *__pyx_n_s_get_first_order_bias_at_z_and_nu;
  PyObject *__pyx_n_s_get_fstar_of_m_at_z;
  PyObject *__pyx_n_s_get_galaxy_number_counts;
  PyObject *__pyx_n_s_get_gas_density_profile_at_k_M_z;
  PyObject *__pyx_n_s_get_gas_pressure_2h_at_r_and_m_a;
  PyObject *__pyx_n_s_get_gas_profile_at_x_M_z_b16_200;
  PyObject *__pyx_n_s_get_gas_profile_at_x_M_z_bcm_200;
  PyObject *__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200;
  PyObject *__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2;
  PyObject *__pyx_n_s_get_gnu_tsz_of_nu_in_ghz;
  PyObject *__pyx_n_s_get_hmf_counter_term_b1min_at_z;
  PyObject *__pyx_n_s_get_hmf_counter_term_b2min_at_z;
  PyObject *__pyx_n_s_get_hmf_counter_term_nmin_at_z;
  PyObject *__pyx_n_s_get_hubble;
  PyObject *__pyx_n_s_get_lensing_noise_at_ell;
  PyObject *__pyx_n_s_get_m200c_to_m200m_at_z_and_M;
  PyObject *__pyx_n_s_get_m200c_to_m500c_at_z_and_M;
  PyObject *__pyx_n_s_get_m200m_to_m200c_at_z_and_M;
  PyObject *__pyx_n_s_get_m200m_to_m500c_at_z_and_M;
  PyObject *__pyx_n_s_get_m500c_to_m200c_at_z_and_M;
  PyObject *__pyx_n_s_get_m500c_to_m200m_at_z_and_M;
  PyObject *__pyx_n_s_get_m_nfw;
  PyObject *__pyx_n_s_get_m_to_xout_at_z_and_m;
  PyObject *__pyx_n_s_get_mass_profile_at_x_M_z_nfw_20;
  PyObject *__pyx_n_s_get_matter_bispectrum_at_z_effec;
  PyObject *__pyx_n_s_get_matter_bispectrum_at_z_effec_2;
  PyObject *__pyx_n_s_get_matter_bispectrum_at_z_effec_3;
  PyObject *__pyx_n_s_get_matter_bispectrum_at_z_tree;
  PyObject *__pyx_n_s_get_mcmc_parameters;
  PyObject *__pyx_n_s_get_mean_galaxy_bias_at_z;
  PyObject *__pyx_n_s_get_mean_y;
  PyObject *__pyx_n_s_get_mu_e;
  PyObject *__pyx_n_s_get_n5k_cl_K1_at_chi;
  PyObject *__pyx_n_s_get_n5k_pk_at_z_and_k;
  PyObject *__pyx_n_s_get_n5k_z_of_chi;
  PyObject *__pyx_n_s_get_ng_bar_at_z;
  PyObject *__pyx_n_s_get_nl_index_at_z_and_k;
  PyObject *__pyx_n_s_get_nl_index_at_z_and_k_no_wiggl;
  PyObject *__pyx_n_s_get_normalization_gas_density_pr;
  PyObject *__pyx_n_s_get_nu_at_z_and_m;
  PyObject *__pyx_n_s_get_params_sz;
  PyObject *__pyx_n_s_get_perturbations;
  PyObject *__pyx_n_s_get_pk;
  PyObject *__pyx_n_s_get_pk_and_k_and_z;
  PyObject *__pyx_n_s_get_pk_array;
  PyObject *__pyx_n_s_get_pk_cb;
  PyObject *__pyx_n_s_get_pk_cb_array;
  PyObject *__pyx_n_s_get_pk_cb_lin;
  PyObject *__pyx_n_s_get_pk_lin;
  PyObject *__pyx_n_s_get_pk_lin_at_k_and_z;
  PyObject *__pyx_n_s_get_pk_lin_at_k_and_z_fast;
  PyObject *__pyx_n_s_get_pk_nonlin_at_k_and_z;
  PyObject *__pyx_n_s_get_pk_nonlin_at_k_and_z_fast;
  PyObject *__pyx_n_s_get_pkl;
  PyObject *__pyx_n_s_get_pkl_at_k_and_z;
  PyObject *__pyx_n_s_get_pkl_at_z;
  PyObject *__pyx_n_s_get_pkl_locals_compute_pkl;
  PyObject *__pyx_n_s_get_pkl_locals_handle_combinatio;
  PyObject *__pyx_n_s_get_pkl_reconstructed_from_fftlo;
  PyObject *__pyx_n_s_get_pkl_unvectorized;
  PyObject *__pyx_n_s_get_pknl;
  PyObject *__pyx_n_s_get_pknl_at_k_and_z;
  PyObject *__pyx_n_s_get_pknl_at_z;
  PyObject *__pyx_n_s_get_pknl_locals_compute_pknl;
  PyObject *__pyx_n_s_get_pknl_locals_handle_combinati;
  PyObject *__pyx_n_s_get_pknl_unvectorized;
  PyObject *__pyx_n_s_get_planck_sigma_at_theta500;
  PyObject *__pyx_n_s_get_pressure_P_over_P_delta_at_x;
  PyObject *__pyx_n_s_get_pressure_P_over_P_delta_at_x_2;
  PyObject *__pyx_n_s_get_primordial;
  PyObject *__pyx_n_s_get_r_delta_of_m_delta_at_z;
  PyObject *__pyx_n_s_get_rad_to_arcmin;
  PyObject *__pyx_n_s_get_radial_kernel_W_custom1_at_z;
  PyObject *__pyx_n_s_get_radial_kernel_W_galaxy_lensi;
  PyObject *__pyx_n_s_get_radial_kernel_W_galaxy_ngal;
  PyObject *__pyx_n_s_get_rho_2h_at_r_and_m_and_z;
  PyObject *__pyx_n_s_get_rho_crit_at_z;
  PyObject *__pyx_n_s_get_rvir_of_m200c_at_z;
  PyObject *__pyx_n_s_get_rvir_of_mvir_at_z;
  PyObject *__pyx_n_s_get_scale_dependent_bias_at_z_an;
  PyObject *__pyx_n_s_get_second_order_bias_at_z_and_n;
  PyObject *__pyx_n_s_get_sigma8_at_z;
  PyObject *__pyx_n_s_get_sigma_at_r_and_z;
  PyObject *__pyx_n_s_get_sigma_at_z_and_m;
  PyObject *__pyx_n_s_get_source_galaxy_number_counts;
  PyObject *__pyx_n_s_get_szcounts_dndzdq_at_z_q;
  PyObject *__pyx_n_s_get_szcountsz_sigma_at_theta_in;
  PyObject *__pyx_n_s_get_te_of_m500c_at_z_arnaud;
  PyObject *__pyx_n_s_get_te_of_m500c_at_z_lee;
  PyObject *__pyx_n_s_get_thermodynamics;
  PyObject *__pyx_n_s_get_theta_at_m_and_z;
  PyObject *__pyx_n_s_get_transfer;
  PyObject *__pyx_n_s_get_truncated_nfw_profile_at_z_k;
  PyObject *__pyx_n_s_get_truncated_nfw_profile_at_z_k_2;
  PyObject *__pyx_n_s_get_ttg_bispectrum_at_z_effectiv;
  PyObject *__pyx_n_s_get_ttg_bispectrum_at_z_tree_lev;
  PyObject *__pyx_n_s_get_uk;
  PyObject *__pyx_n_s_get_uk_nfw;
  PyObject *__pyx_n_s_get_uk_nfw_locals_compute_profil;
  PyObject *__pyx_n_s_get_uk_nfw_locals_handle_combina;
  PyObject *__pyx_n_s_get_unwise_m_min_cut_at_z;
  PyObject *__pyx_n_s_get_upp_from_gnfw_pressure_at_x;
  PyObject *__pyx_n_s_get_volume_dVdzdOmega_at_z;
  PyObject *__pyx_n_s_get_vrms2_at_z;
  PyObject *__pyx_n_s_get_y_at_m_and_z;
  PyObject *__pyx_n_s_get_yc_at_m_and_z_H13;
  PyObject *__pyx_n_s_get_z_of_chi;
  PyObject *__pyx_n_s_get_z_of_chi_unvectorized;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_kp_u_got;
  PyObject *__pyx_kp_u_got_differing_extents_in_dimensi;
  PyObject *__pyx_n_s_h;
  PyObject *__pyx_n_u_h;
  PyObject *__pyx_n_s_h_P;
  PyObject *__pyx_n_s_h_units;
  PyObject *__pyx_n_s_handle_combinations;
  PyObject *__pyx_n_s_has_flags;
  PyObject *__pyx_kp_u_hf;
  PyObject *__pyx_n_u_hf_2;
  PyObject *__pyx_n_u_hmf;
  PyObject *__pyx_n_s_hplanck;
  PyObject *__pyx_n_u_hsv;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_s_ic_info;
  PyObject *__pyx_n_s_ic_key;
  PyObject *__pyx_n_s_ic_num;
  PyObject *__pyx_n_s_ic_suffix;
  PyObject *__pyx_n_s_id;
  PyObject *__pyx_n_s_id_nu1;
  PyObject *__pyx_n_s_id_nu2;
  PyObject *__pyx_n_u_ignore;
  PyObject *__pyx_n_s_imp;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_n_s_index_M_bins;
  PyObject *__pyx_n_s_index_M_bins_prime;
  PyObject *__pyx_n_s_index_g;
  PyObject *__pyx_n_s_index_ic;
  PyObject *__pyx_n_s_index_k;
  PyObject *__pyx_n_s_index_l;
  PyObject *__pyx_n_s_index_l_prime;
  PyObject *__pyx_n_s_index_m;
  PyObject *__pyx_n_s_index_m_z;
  PyObject *__pyx_n_s_index_md;
  PyObject *__pyx_n_s_index_mu;
  PyObject *__pyx_n_s_index_pk;
  PyObject *__pyx_n_s_index_r;
  PyObject *__pyx_n_s_index_tau;
  PyObject *__pyx_n_s_index_x;
  PyObject *__pyx_n_s_index_y;
  PyObject *__pyx_n_s_index_z;
  PyObject *__pyx_n_s_index_z_r;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initial;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_u_input;
  PyObject *__pyx_n_s_intUpper;
  PyObject *__pyx_n_s_integrate;
  PyObject *__pyx_n_s_integrate_only;
  PyObject *__pyx_n_s_interp1d;
  PyObject *__pyx_n_s_interpolate;
  PyObject *__pyx_n_s_ionization_fraction;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_kp_u_is_not_implemented_yet;
  PyObject *__pyx_kp_u_is_not_implemented_yet_Availabl;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_isscalar;
  PyObject *__pyx_n_s_issuperset;
  PyObject *__pyx_n_u_isw_auto;
  PyObject *__pyx_n_u_isw_lens;
  PyObject *__pyx_n_u_isw_tsz;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_itemsize;
  PyObject *__pyx_kp_s_itemsize_0_for_cython_array;
  PyObject *__pyx_n_s_j;
  PyObject *__pyx_n_s_join;
  PyObject *__pyx_n_s_k;
  PyObject *__pyx_n_u_k;
  PyObject *__pyx_n_s_k1;
  PyObject *__pyx_n_s_k1_in_h_over_Mpc;
  PyObject *__pyx_n_s_k2;
  PyObject *__pyx_n_s_k2_in_h_over_Mpc;
  PyObject *__pyx_n_s_k3;
  PyObject *__pyx_n_s_k3_in_h_over_Mpc;
  PyObject *__pyx_n_s_kB;
  PyObject *__pyx_n_s_k_B;
  PyObject *__pyx_kp_u_k_and_z_must_be_broadcastable_to;
  PyObject *__pyx_n_s_k_array;
  PyObject *__pyx_n_s_k_asked;
  PyObject *__pyx_n_s_k_eq;
  PyObject *__pyx_n_u_k_eq;
  PyObject *__pyx_n_s_k_input;
  PyObject *__pyx_n_s_k_len;
  PyObject *__pyx_n_s_k_nl;
  PyObject *__pyx_n_s_k_nl_cb;
  PyObject *__pyx_n_s_k_size;
  PyObject *__pyx_n_s_k_vals;
  PyObject *__pyx_n_s_kars;
  PyObject *__pyx_n_s_key;
  PyObject *__pyx_n_s_kh;
  PyObject *__pyx_n_s_kh_input;
  PyObject *__pyx_n_s_kh_len;
  PyObject *__pyx_n_s_kh_vals;
  PyObject *__pyx_n_s_kind;
  PyObject *__pyx_n_s_kk;
  PyObject *__pyx_kp_u_ksi_V_2;
  PyObject *__pyx_n_s_l;
  PyObject *__pyx_n_u_lCl;
  PyObject *__pyx_n_s_l_asked;
  PyObject *__pyx_n_s_l_max_flag;
  PyObject *__pyx_n_u_l_max_lss;
  PyObject *__pyx_n_u_l_max_scalars;
  PyObject *__pyx_n_s_last_index;
  PyObject *__pyx_n_s_lcl;
  PyObject *__pyx_n_s_lcp;
  PyObject *__pyx_n_s_lensed_cl;
  PyObject *__pyx_n_u_lensing;
  PyObject *__pyx_kp_u_lensing_term;
  PyObject *__pyx_n_s_level;
  PyObject *__pyx_kp_u_levelname_s_message_s;
  PyObject *__pyx_n_s_levels;
  PyObject *__pyx_n_s_likelihood_mode;
  PyObject *__pyx_n_u_lin;
  PyObject *__pyx_n_s_linspace;
  PyObject *__pyx_n_u_ll;
  PyObject *__pyx_n_s_lmax;
  PyObject *__pyx_n_s_lmaxR;
  PyObject *__pyx_kp_u_ln10_10_A_s;
  PyObject *__pyx_n_s_ln1pzc;
  PyObject *__pyx_n_s_lna;
  PyObject *__pyx_n_s_load_n5k_cl_K1;
  PyObject *__pyx_n_s_load_n5k_pk_zk;
  PyObject *__pyx_n_s_load_n5k_z_of_chi;
  PyObject *__pyx_n_s_loadtxt;
  PyObject *__pyx_n_s_log;
  PyObject *__pyx_n_s_log10;
  PyObject *__pyx_n_s_log10M;
  PyObject *__pyx_n_s_log10M500c_zk;
  PyObject *__pyx_n_s_log10Ms;
  PyObject *__pyx_n_s_log10x_num;
  PyObject *__pyx_n_s_log10xmax_mcfit;
  PyObject *__pyx_n_s_log10xmin_mcfit;
  PyObject *__pyx_n_s_log10y_center;
  PyObject *__pyx_n_u_log10y_center;
  PyObject *__pyx_n_s_log10y_edges;
  PyObject *__pyx_n_u_log10y_edges;
  PyObject *__pyx_n_u_logA;
  PyObject *__pyx_n_s_logA_fast;
  PyObject *__pyx_n_s_log_y0;
  PyObject *__pyx_n_s_log_y0Err;
  PyObject *__pyx_n_s_log_y0pred;
  PyObject *__pyx_n_s_logging;
  PyObject *__pyx_n_s_loglike;
  PyObject *__pyx_n_u_loglike;
  PyObject *__pyx_n_s_logspace;
  PyObject *__pyx_n_s_lowring;
  PyObject *__pyx_n_s_lum_distance;
  PyObject *__pyx_n_s_luminosity_distance;
  PyObject *__pyx_n_s_m;
  PyObject *__pyx_n_u_mPk;
  PyObject *__pyx_n_s_m_asked;
  PyObject *__pyx_n_s_m_broadcasted;
  PyObject *__pyx_kp_u_m_d_a_zA_Z__to_m_d_a_zA_Z;
  PyObject *__pyx_n_s_m_delta;
  PyObject *__pyx_n_s_m_flattened;
  PyObject *__pyx_n_s_m_input;
  PyObject *__pyx_kp_u_m_input_should_be_a_float_or_a_1;
  PyObject *__pyx_n_s_m_len;
  PyObject *__pyx_n_u_m_ncdm;
  PyObject *__pyx_n_u_m_ncdm_in_eV;
  PyObject *__pyx_n_u_m_ncdm_tot;
  PyObject *__pyx_n_s_m_vals;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_u_mass_bin_edges;
  PyObject *__pyx_n_u_mass_function;
  PyObject *__pyx_kp_u_mass_function_2;
  PyObject *__pyx_n_s_match;
  PyObject *__pyx_n_s_math;
  PyObject *__pyx_n_s_max;
  PyObject *__pyx_n_s_maxIndex;
  PyObject *__pyx_n_s_mcfit;
  PyObject *__pyx_n_s_mcfitx;
  PyObject *__pyx_n_s_mcmc_parameters;
  PyObject *__pyx_n_s_mcut;
  PyObject *__pyx_n_u_mcut;
  PyObject *__pyx_n_u_mcut_B12;
  PyObject *__pyx_n_s_me;
  PyObject *__pyx_n_s_memview;
  PyObject *__pyx_n_s_message;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_n_s_min;
  PyObject *__pyx_n_s_minIndex;
  PyObject *__pyx_n_u_minimal;
  PyObject *__pyx_n_s_mm;
  PyObject *__pyx_n_u_mnu;
  PyObject *__pyx_n_s_mode;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_n_s_mro_entries;
  PyObject *__pyx_n_s_mu_size;
  PyObject *__pyx_n_s_n;
  PyObject *__pyx_n_u_n5k;
  PyObject *__pyx_n_u_nCl;
  PyObject *__pyx_n_u_n_e;
  PyObject *__pyx_n_s_n_s;
  PyObject *__pyx_n_u_n_s;
  PyObject *__pyx_n_u_n_t;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_names;
  PyObject *__pyx_n_s_ndim;
  PyObject *__pyx_n_u_ndim_masses;
  PyObject *__pyx_n_u_ndim_redshifts;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_newaxis;
  PyObject *__pyx_n_u_nfw;
  PyObject *__pyx_n_s_ngtm;
  PyObject *__pyx_n_s_nl;
  PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
  PyObject *__pyx_n_s_nofail;
  PyObject *__pyx_n_s_non_class_sz_keys;
  PyObject *__pyx_n_u_non_linear;
  PyObject *__pyx_n_s_non_linear_check;
  PyObject *__pyx_n_u_none;
  PyObject *__pyx_n_u_nonlin;
  PyObject *__pyx_n_s_nonlinear;
  PyObject *__pyx_n_u_nonlinear;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigma8;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigma8_cb;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigmadisp;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigmadisp100;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigmadisp100_cb;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigmadisp_cb;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigmaprime;
  PyObject *__pyx_n_s_nonlinear_hmcode_sigmaprime_cb;
  PyObject *__pyx_n_s_nonlinear_hmcode_window_nfw;
  PyObject *__pyx_n_s_nonlinear_scale;
  PyObject *__pyx_n_s_nonlinear_scale_cb;
  PyObject *__pyx_n_s_normalize;
  PyObject *__pyx_n_s_np;
  PyObject *__pyx_n_s_nq;
  PyObject *__pyx_n_u_ns;
  PyObject *__pyx_n_u_ntot;
  PyObject *__pyx_n_s_nu;
  PyObject *__pyx_n_u_nu;
  PyObject *__pyx_n_s_nu1;
  PyObject *__pyx_n_s_nu2;
  PyObject *__pyx_n_s_nu_in_GHz;
  PyObject *__pyx_n_s_nu_in_ghz;
  PyObject *__pyx_n_s_num;
  PyObject *__pyx_n_s_numberDensity;
  PyObject *__pyx_n_s_number_of_titles;
  PyObject *__pyx_n_s_numpy;
  PyObject *__pyx_kp_u_numpy__core_multiarray_failed_to;
  PyObject *__pyx_kp_u_numpy__core_umath_failed_to_impo;
  PyObject *__pyx_n_s_nz;
  PyObject *__pyx_n_s_obj;
  PyObject *__pyx_n_s_obsFreqGHz;
  PyObject *__pyx_n_s_oldpars;
  PyObject *__pyx_n_u_ombh2;
  PyObject *__pyx_n_u_omch2;
  PyObject *__pyx_n_s_omega;
  PyObject *__pyx_n_s_omega_b;
  PyObject *__pyx_n_u_omega_b;
  PyObject *__pyx_n_u_omega_c;
  PyObject *__pyx_n_s_omega_cdm;
  PyObject *__pyx_n_u_omega_cdm;
  PyObject *__pyx_n_u_omega_mh2;
  PyObject *__pyx_n_s_only_clustering_species;
  PyObject *__pyx_n_s_other_class_sz_keys;
  PyObject *__pyx_n_s_outf;
  PyObject *__pyx_n_u_output;
  PyObject *__pyx_n_s_output_format;
  PyObject *__pyx_n_s_output_keys;
  PyObject *__pyx_n_s_output_string;
  PyObject *__pyx_n_s_p;
  PyObject *__pyx_n_u_pCl;
  PyObject *__pyx_n_s_pack;
  PyObject *__pyx_n_s_params_for_emulators;
  PyObject *__pyx_n_s_params_settings;
  PyObject *__pyx_n_s_params_values_dict;
  PyObject *__pyx_n_s_pars;
  PyObject *__pyx_n_s_pars_2;
  PyObject *__pyx_n_s_pars_check;
  PyObject *__pyx_n_s_path_to_cosmopower_organization;
  PyObject *__pyx_n_s_pattern1;
  PyObject *__pyx_n_s_pattern2;
  PyObject *__pyx_n_s_pattern3;
  PyObject *__pyx_n_s_pdict_to_update;
  PyObject *__pyx_n_u_perturb;
  PyObject *__pyx_n_u_phi_max;
  PyObject *__pyx_n_u_phi_min;
  PyObject *__pyx_n_s_pi;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_pk;
  PyObject *__pyx_n_s_pk_array;
  PyObject *__pyx_n_s_pk_at_k_z;
  PyObject *__pyx_n_s_pk_at_z_hm;
  PyObject *__pyx_n_s_pk_b_at_z_2h;
  PyObject *__pyx_n_s_pk_bb_at_z_hm;
  PyObject *__pyx_n_s_pk_cb;
  PyObject *__pyx_n_s_pk_cb_lin;
  PyObject *__pyx_n_s_pk_em_at_z_hm;
  PyObject *__pyx_n_s_pk_gg_at_z_hm;
  PyObject *__pyx_n_s_pk_lin;
  PyObject *__pyx_n_s_pk_lin_array;
  PyObject *__pyx_n_s_pk_lin_unvectorized;
  PyObject *__pyx_n_s_pk_linzmax;
  PyObject *__pyx_n_s_pk_nonlin;
  PyObject *__pyx_n_s_pk_tilt;
  PyObject *__pyx_n_s_pk_unvectorized;
  PyObject *__pyx_n_s_pknl_in_output;
  PyObject *__pyx_n_s_pknl_key_value_checks;
  PyObject *__pyx_n_u_poisson;
  PyObject *__pyx_n_s_pop;
  PyObject *__pyx_n_s_power;
  PyObject *__pyx_n_u_pp;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_u_pressure_profile;
  PyObject *__pyx_kp_u_pressure_profile_2;
  PyObject *__pyx_n_s_primordial;
  PyObject *__pyx_n_u_primordial;
  PyObject *__pyx_n_s_problem_flag;
  PyObject *__pyx_n_s_problematic_parameters;
  PyObject *__pyx_n_s_profile;
  PyObject *__pyx_n_s_pvecback;
  PyObject *__pyx_n_s_pvecthermo;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_Enum;
  PyObject *__pyx_n_s_pyx_vtable;
  PyObject *__pyx_n_s_q;
  PyObject *__pyx_n_s_q_arr;
  PyObject *__pyx_n_s_q_max;
  PyObject *__pyx_n_s_q_threshold;
  PyObject *__pyx_n_s_qmax;
  PyObject *__pyx_n_s_qobs_asked;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_r;
  PyObject *__pyx_n_u_r;
  PyObject *__pyx_n_s_r200c;
  PyObject *__pyx_n_u_r_0002;
  PyObject *__pyx_n_s_r_asked;
  PyObject *__pyx_n_s_r_delta;
  PyObject *__pyx_n_u_ra_rec;
  PyObject *__pyx_n_u_ra_rec_h;
  PyObject *__pyx_n_u_ra_star;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_rates;
  PyObject *__pyx_n_u_rates;
  PyObject *__pyx_n_s_raw_cl;
  PyObject *__pyx_n_s_rcl;
  PyObject *__pyx_n_u_rd_star;
  PyObject *__pyx_n_s_re;
  PyObject *__pyx_n_s_redshift;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_register;
  PyObject *__pyx_n_s_resetwarnings;
  PyObject *__pyx_n_s_reshape;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_rho0_cb;
  PyObject *__pyx_n_s_rho0_crit;
  PyObject *__pyx_n_s_rho0_m;
  PyObject *__pyx_n_s_rhoc;
  PyObject *__pyx_n_u_rs_d;
  PyObject *__pyx_n_u_rs_d_h;
  PyObject *__pyx_n_s_rs_drag;
  PyObject *__pyx_n_u_rs_rec;
  PyObject *__pyx_n_u_rs_rec_h;
  PyObject *__pyx_n_u_rs_star;
  PyObject *__pyx_n_s_rv;
  PyObject *__pyx_kp_u_s;
  PyObject *__pyx_kp_u_sBBN_file;
  PyObject *__pyx_kp_u_s_was_not_recognized_as_a_deriv;
  PyObject *__pyx_n_s_sample_id;
  PyObject *__pyx_n_u_scalar;
  PyObject *__pyx_n_u_scale;
  PyObject *__pyx_n_u_scale_dependent_bias;
  PyObject *__pyx_n_s_scale_independent_growth_factor;
  PyObject *__pyx_n_s_scale_independent_growth_factor_2;
  PyObject *__pyx_n_s_scipy;
  PyObject *__pyx_n_s_scipy_interpolate;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_n_s_send;
  PyObject *__pyx_n_s_sep;
  PyObject *__pyx_n_s_set;
  PyObject *__pyx_n_s_set_default;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_set_verbosity;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_shape;
  PyObject *__pyx_n_u_shear_calibration_m;
  PyObject *__pyx_n_u_shotnoise;
  PyObject *__pyx_n_s_sigma;
  PyObject *__pyx_n_s_sigma8;
  PyObject *__pyx_n_u_sigma8;
  PyObject *__pyx_n_s_sigma8_Pcb;
  PyObject *__pyx_n_s_sigma8_cb;
  PyObject *__pyx_n_u_sigma8_cb;
  PyObject *__pyx_n_s_sigmaM;
  PyObject *__pyx_n_s_sigmaT;
  PyObject *__pyx_n_s_sigma_8;
  PyObject *__pyx_n_u_sigma_8;
  PyObject *__pyx_n_s_sigma_8_cb;
  PyObject *__pyx_n_s_sigma_cb;
  PyObject *__pyx_kp_u_sigma_cb_not_computed_by_CLASS_p;
  PyObject *__pyx_n_s_sigma_disp;
  PyObject *__pyx_n_s_sigma_disp_100;
  PyObject *__pyx_n_s_sigma_disp_100_cb;
  PyObject *__pyx_n_s_sigma_disp_cb;
  PyObject *__pyx_n_s_sigma_int;
  PyObject *__pyx_n_s_sigma_log10M;
  PyObject *__pyx_n_u_sigma_log10M_HOD;
  PyObject *__pyx_n_u_sigma_log10M_HOD_ngal;
  PyObject *__pyx_n_s_sigma_prime;
  PyObject *__pyx_n_s_sigma_prime_cb;
  PyObject *__pyx_n_s_simps;
  PyObject *__pyx_n_s_sinh;
  PyObject *__pyx_n_s_size;
  PyObject *__pyx_n_s_size_ic_data;
  PyObject *__pyx_n_s_skip_background_and_thermo;
  PyObject *__pyx_n_u_skip_background_and_thermo;
  PyObject *__pyx_n_u_skip_chi;
  PyObject *__pyx_n_u_skip_class_sz;
  PyObject *__pyx_n_u_skip_cmb;
  PyObject *__pyx_n_u_skip_hubble;
  PyObject *__pyx_n_u_skip_input;
  PyObject *__pyx_n_u_skip_pkl;
  PyObject *__pyx_n_u_skip_pknl;
  PyObject *__pyx_n_u_skip_sigma8_and_der;
  PyObject *__pyx_n_u_skip_sigma8_at_z;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_specific_keys;
  PyObject *__pyx_n_s_spectra;
  PyObject *__pyx_n_u_spectra;
  PyObject *__pyx_n_s_splev;
  PyObject *__pyx_n_s_spline;
  PyObject *__pyx_n_s_split;
  PyObject *__pyx_n_s_splrep;
  PyObject *__pyx_n_s_sqrt;
  PyObject *__pyx_n_s_start;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_step;
  PyObject *__pyx_n_s_stop;
  PyObject *__pyx_n_s_str;
  PyObject *__pyx_kp_s_strided_and_direct;
  PyObject *__pyx_kp_s_strided_and_direct_or_indirect;
  PyObject *__pyx_kp_s_strided_and_indirect;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_strip;
  PyObject *__pyx_n_s_struct;
  PyObject *__pyx_n_s_struct_cleanup;
  PyObject *__pyx_n_s_sum;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_suppress_warnings;
  PyObject *__pyx_n_s_sys;
  PyObject *__pyx_n_u_sz_cluster_counts;
  PyObject *__pyx_n_u_sz_cluster_counts_fft;
  PyObject *__pyx_n_u_sz_selection_function_skyfracs_f;
  PyObject *__pyx_n_u_sz_selection_function_thetas_fil;
  PyObject *__pyx_n_u_sz_selection_function_ylims_file;
  PyObject *__pyx_n_u_sz_unbinned_cluster_counts;
  PyObject *__pyx_n_s_szcat_snr;
  PyObject *__pyx_n_u_szcat_snr;
  PyObject *__pyx_n_s_szcat_z;
  PyObject *__pyx_n_u_szcat_z;
  PyObject *__pyx_n_u_szcount;
  PyObject *__pyx_n_s_szcounts_ntot;
  PyObject *__pyx_n_s_szcounts_ntot_rates_loglike;
  PyObject *__pyx_n_s_szunbinned_loglike;
  PyObject *__pyx_n_u_t2t2f;
  PyObject *__pyx_n_u_tCl;
  PyObject *__pyx_n_u_tabulate_rhob_xout_at_m_and_z;
  PyObject *__pyx_n_s_tanh;
  PyObject *__pyx_n_s_tau;
  PyObject *__pyx_n_u_tau;
  PyObject *__pyx_n_u_tau_d;
  PyObject *__pyx_n_u_tau_rec;
  PyObject *__pyx_n_s_tau_reio;
  PyObject *__pyx_n_u_tau_reio;
  PyObject *__pyx_n_u_tau_star;
  PyObject *__pyx_n_s_tckP;
  PyObject *__pyx_n_u_td;
  PyObject *__pyx_n_u_te;
  PyObject *__pyx_n_u_te_y_y;
  PyObject *__pyx_n_u_tensor;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_u_teyy;
  PyObject *__pyx_kp_u_the_s_spectrum_was_computed_unti;
  PyObject *__pyx_n_s_thermodynamics;
  PyObject *__pyx_n_u_thermodynamics;
  PyObject *__pyx_n_u_theta;
  PyObject *__pyx_n_s_theta500;
  PyObject *__pyx_n_s_theta_500;
  PyObject *__pyx_n_s_theta_arcmin;
  PyObject *__pyx_n_s_theta_mcfit;
  PyObject *__pyx_n_s_theta_rad;
  PyObject *__pyx_n_s_theta_s_100;
  PyObject *__pyx_n_s_theta_star_100;
  PyObject *__pyx_n_s_thetae;
  PyObject *__pyx_n_u_thetas;
  PyObject *__pyx_n_s_throw;
  PyObject *__pyx_n_s_time;
  PyObject *__pyx_n_s_timesteps;
  PyObject *__pyx_n_s_titles;
  PyObject *__pyx_n_u_tl;
  PyObject *__pyx_n_s_tllprime_sz;
  PyObject *__pyx_n_s_tmp;
  PyObject *__pyx_n_s_tmpdict;
  PyObject *__pyx_n_u_tp;
  PyObject *__pyx_n_u_transfer;
  PyObject *__pyx_n_s_transfers;
  PyObject *__pyx_n_s_transforms;
  PyObject *__pyx_n_s_trapz;
  PyObject *__pyx_n_u_tt;
  PyObject *__pyx_n_s_type;
  PyObject *__pyx_kp_s_unable_to_allocate_array_data;
  PyObject *__pyx_kp_s_unable_to_allocate_shape_and_str;
  PyObject *__pyx_n_s_units;
  PyObject *__pyx_n_s_unpack;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_upper;
  PyObject *__pyx_n_s_use_pklin;
  PyObject *__pyx_n_u_use_pknl_in_2hterms;
  PyObject *__pyx_n_u_use_pknl_in_2hterms_IA_only;
  PyObject *__pyx_n_s_v;
  PyObject *__pyx_n_s_val;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_n_s_vec_theta;
  PyObject *__pyx_n_u_vector;
  PyObject *__pyx_n_s_vectorize;
  PyObject *__pyx_n_s_verbosity;
  PyObject *__pyx_n_s_version;
  PyObject *__pyx_n_s_version_info;
  PyObject *__pyx_n_s_viewdictitems;
  PyObject *__pyx_n_s_viewitems;
  PyObject *__pyx_n_u_vrms2;
  PyObject *__pyx_n_s_want_ee;
  PyObject *__pyx_n_s_want_pp;
  PyObject *__pyx_n_s_want_te;
  PyObject *__pyx_n_s_want_tt;
  PyObject *__pyx_n_s_warnings;
  PyObject *__pyx_n_s_window_nfw;
  PyObject *__pyx_n_s_x;
  PyObject *__pyx_n_u_x;
  PyObject *__pyx_n_s_x_asked;
  PyObject *__pyx_n_u_x_outSZ;
  PyObject *__pyx_n_s_x_out_custom1;
  PyObject *__pyx_n_s_xc;
  PyObject *__pyx_n_u_xc_B12;
  PyObject *__pyx_n_u_xc_B16;
  PyObject *__pyx_n_s_xe;
  PyObject *__pyx_n_s_xi;
  PyObject *__pyx_n_u_xi;
  PyObject *__pyx_n_u_xi_idr;
  PyObject *__pyx_n_s_xi_mcfit;
  PyObject *__pyx_n_s_xout;
  PyObject *__pyx_n_s_xrange;
  PyObject *__pyx_n_s_y;
  PyObject *__pyx_n_s_y0;
  PyObject *__pyx_n_s_y0Err;
  PyObject *__pyx_n_s_yp;
  PyObject *__pyx_n_s_ystar;
  PyObject *__pyx_n_s_z;
  PyObject *__pyx_n_s_z1;
  PyObject *__pyx_n_s_z2;
  PyObject *__pyx_n_s_z_arr;
  PyObject *__pyx_n_s_z_array;
  PyObject *__pyx_n_s_z_asked;
  PyObject *__pyx_n_s_z_broadcasted;
  PyObject *__pyx_n_s_z_center;
  PyObject *__pyx_n_u_z_center;
  PyObject *__pyx_n_u_z_d;
  PyObject *__pyx_n_s_z_edges;
  PyObject *__pyx_n_u_z_edges;
  PyObject *__pyx_n_s_z_flattened;
  PyObject *__pyx_n_u_z_for_pk_hm;
  PyObject *__pyx_n_s_z_input;
  PyObject *__pyx_kp_u_z_input_should_be_a_float_or_a_1;
  PyObject *__pyx_n_s_z_len;
  PyObject *__pyx_n_u_z_max;
  PyObject *__pyx_n_s_z_max_nonlinear;
  PyObject *__pyx_n_s_z_max_requested;
  PyObject *__pyx_n_u_z_min;
  PyObject *__pyx_n_s_z_of_r;
  PyObject *__pyx_n_s_z_of_tau;
  PyObject *__pyx_n_u_z_rec;
  PyObject *__pyx_n_s_z_reio;
  PyObject *__pyx_n_u_z_reio;
  PyObject *__pyx_n_s_z_size;
  PyObject *__pyx_n_u_z_star;
  PyObject *__pyx_n_s_z_step;
  PyObject *__pyx_n_s_z_vals;
  PyObject *__pyx_n_s_zeros;
  PyObject *__pyx_n_s_zi;
  PyObject *__pyx_n_s_zmax;
  PyObject *__pyx_n_s_zmin;
  PyObject *__pyx_n_s_zp;
  PyObject *__pyx_n_s_zpk;
  PyObject *__pyx_float_0_;
  PyObject *__pyx_float_1_;
  PyObject *__pyx_float_2_;
  PyObject *__pyx_float_3_;
  PyObject *__pyx_float_4_;
  PyObject *__pyx_float_5_;
  PyObject *__pyx_float_0_0;
  PyObject *__pyx_float_0_1;
  PyObject *__pyx_float_0_5;
  PyObject *__pyx_float_1_0;
  PyObject *__pyx_float_10_;
  PyObject *__pyx_float_1e9;
  PyObject *__pyx_float_0_02;
  PyObject *__pyx_float_0_04;
  PyObject *__pyx_float_0_19;
  PyObject *__pyx_float_0_29;
  PyObject *__pyx_float_0_88;
  PyObject *__pyx_float_100_;
  PyObject *__pyx_float_18_1;
  PyObject *__pyx_float_1e14;
  PyObject *__pyx_float_1e16;
  PyObject *__pyx_float_200_;
  PyObject *__pyx_float_3_83;
  PyObject *__pyx_float_4_35;
  PyObject *__pyx_float_4_e3;
  PyObject *__pyx_float_500_;
  PyObject *__pyx_float_0_154;
  PyObject *__pyx_float_0_415;
  PyObject *__pyx_float_0_497;
  PyObject *__pyx_float_0_731;
  PyObject *__pyx_float_1_156;
  PyObject *__pyx_float_148_0;
  PyObject *__pyx_float_1eneg_10;
  PyObject *__pyx_float_8_130;
  PyObject *__pyx_float_0_0393;
  PyObject *__pyx_float_0_3292;
  PyObject *__pyx_float_0_6827;
  PyObject *__pyx_float_0_9665;
  PyObject *__pyx_float_1_0620;
  PyObject *__pyx_float_1eneg_100;
  PyObject *__pyx_float_5_4807;
  PyObject *__pyx_float_0_00441;
  PyObject *__pyx_float_0_022383;
  PyObject *__pyx_float_2_61051eneg_18;
  PyObject *__pyx_float_1_00000000e_12;
  PyObject *__pyx_float_neg_2_;
  PyObject *__pyx_float_neg_0_2;
  PyObject *__pyx_float_neg_0_3;
  PyObject *__pyx_float_neg_1_0;
  PyObject *__pyx_float_neg_10_;
  PyObject *__pyx_float_neg_0_03;
  PyObject *__pyx_float_neg_0_66;
  PyObject *__pyx_float_neg_0_025;
  PyObject *__pyx_float_neg_0_758;
  PyObject *__pyx_float_neg_0_00865;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_4;
  PyObject *__pyx_int_5;
  PyObject *__pyx_int_6;
  PyObject *__pyx_int_7;
  PyObject *__pyx_int_8;
  PyObject *__pyx_int_9;
  PyObject *__pyx_int_10;
  PyObject *__pyx_int_100;
  PyObject *__pyx_int_200;
  PyObject *__pyx_int_300;
  PyObject *__pyx_int_500;
  PyObject *__pyx_int_600;
  PyObject *__pyx_int_1024;
  PyObject *__pyx_int_10000;
  PyObject *__pyx_int_20000;
  PyObject *__pyx_int_112105877;
  PyObject *__pyx_int_136983863;
  PyObject *__pyx_int_184977713;
  PyObject *__pyx_int_10000000000;
  PyObject *__pyx_int_0xde0b6b3a7640000;
  PyObject *__pyx_int_neg_1;
  PyObject *__pyx_int_neg_4;
  PyObject *__pyx_int_neg_6;
  PyObject *__pyx_k__21;
  PyObject *__pyx_slice__5;
  PyObject *__pyx_tuple__4;
  PyObject *__pyx_tuple__8;
  PyObject *__pyx_slice__44;
  PyObject *__pyx_slice__47;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__16;
  PyObject *__pyx_tuple__18;
  PyObject *__pyx_tuple__19;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_tuple__25;
  PyObject *__pyx_tuple__26;
  PyObject *__pyx_tuple__27;
  PyObject *__pyx_tuple__28;
  PyObject *__pyx_tuple__29;
  PyObject *__pyx_tuple__30;
  PyObject *__pyx_tuple__31;
  PyObject *__pyx_tuple__33;
  PyObject *__pyx_tuple__34;
  PyObject *__pyx_tuple__38;
  PyObject *__pyx_tuple__40;
  PyObject *__pyx_tuple__42;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__45;
  PyObject *__pyx_tuple__48;
  PyObject *__pyx_tuple__49;
  PyObject *__pyx_tuple__50;
  PyObject *__pyx_tuple__51;
  PyObject *__pyx_tuple__52;
  PyObject *__pyx_tuple__53;
  PyObject *__pyx_tuple__54;
  PyObject *__pyx_tuple__55;
  PyObject *__pyx_tuple__56;
  PyObject *__pyx_tuple__57;
  PyObject *__pyx_tuple__58;
  PyObject *__pyx_tuple__59;
  PyObject *__pyx_tuple__60;
  PyObject *__pyx_tuple__62;
  PyObject *__pyx_tuple__64;
  PyObject *__pyx_tuple__66;
  PyObject *__pyx_tuple__67;
  PyObject *__pyx_tuple__69;
  PyObject *__pyx_tuple__71;
  PyObject *__pyx_tuple__73;
  PyObject *__pyx_tuple__75;
  PyObject *__pyx_tuple__77;
  PyObject *__pyx_tuple__78;
  PyObject *__pyx_tuple__80;
  PyObject *__pyx_tuple__82;
  PyObject *__pyx_tuple__85;
  PyObject *__pyx_tuple__88;
  PyObject *__pyx_tuple__90;
  PyObject *__pyx_tuple__92;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_tuple__95;
  PyObject *__pyx_tuple__97;
  PyObject *__pyx_tuple__99;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__102;
  PyObject *__pyx_tuple__104;
  PyObject *__pyx_tuple__106;
  PyObject *__pyx_tuple__107;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_tuple__111;
  PyObject *__pyx_tuple__113;
  PyObject *__pyx_tuple__115;
  PyObject *__pyx_tuple__117;
  PyObject *__pyx_tuple__119;
  PyObject *__pyx_tuple__121;
  PyObject *__pyx_tuple__123;
  PyObject *__pyx_tuple__125;
  PyObject *__pyx_tuple__127;
  PyObject *__pyx_tuple__129;
  PyObject *__pyx_tuple__131;
  PyObject *__pyx_tuple__133;
  PyObject *__pyx_tuple__135;
  PyObject *__pyx_tuple__138;
  PyObject *__pyx_tuple__140;
  PyObject *__pyx_tuple__141;
  PyObject *__pyx_tuple__143;
  PyObject *__pyx_tuple__145;
  PyObject *__pyx_tuple__147;
  PyObject *__pyx_tuple__149;
  PyObject *__pyx_tuple__151;
  PyObject *__pyx_tuple__156;
  PyObject *__pyx_tuple__169;
  PyObject *__pyx_tuple__172;
  PyObject *__pyx_tuple__177;
  PyObject *__pyx_tuple__179;
  PyObject *__pyx_tuple__181;
  PyObject *__pyx_tuple__183;
  PyObject *__pyx_tuple__185;
  PyObject *__pyx_tuple__187;
  PyObject *__pyx_tuple__190;
  PyObject *__pyx_tuple__192;
  PyObject *__pyx_tuple__194;
  PyObject *__pyx_tuple__196;
  PyObject *__pyx_tuple__198;
  PyObject *__pyx_tuple__202;
  PyObject *__pyx_tuple__204;
  PyObject *__pyx_tuple__206;
  PyObject *__pyx_tuple__209;
  PyObject *__pyx_tuple__211;
  PyObject *__pyx_tuple__213;
  PyObject *__pyx_tuple__217;
  PyObject *__pyx_tuple__220;
  PyObject *__pyx_tuple__227;
  PyObject *__pyx_tuple__229;
  PyObject *__pyx_tuple__261;
  PyObject *__pyx_tuple__263;
  PyObject *__pyx_tuple__265;
  PyObject *__pyx_tuple__267;
  PyObject *__pyx_tuple__269;
  PyObject *__pyx_tuple__271;
  PyObject *__pyx_tuple__273;
  PyObject *__pyx_tuple__275;
  PyObject *__pyx_tuple__277;
  PyObject *__pyx_tuple__279;
  PyObject *__pyx_tuple__283;
  PyObject *__pyx_tuple__285;
  PyObject *__pyx_tuple__290;
  PyObject *__pyx_tuple__292;
  PyObject *__pyx_tuple__295;
  PyObject *__pyx_tuple__317;
  PyObject *__pyx_tuple__320;
  PyObject *__pyx_tuple__324;
  PyObject *__pyx_tuple__326;
  PyObject *__pyx_tuple__328;
  PyObject *__pyx_tuple__330;
  PyObject *__pyx_tuple__332;
  PyObject *__pyx_tuple__335;
  PyObject *__pyx_tuple__340;
  PyObject *__pyx_tuple__342;
  PyObject *__pyx_tuple__343;
  PyObject *__pyx_tuple__345;
  PyObject *__pyx_tuple__348;
  PyObject *__pyx_tuple__350;
  PyObject *__pyx_tuple__352;
  PyObject *__pyx_tuple__354;
  PyObject *__pyx_tuple__356;
  PyObject *__pyx_tuple__358;
  PyObject *__pyx_tuple__365;
  PyObject *__pyx_tuple__374;
  PyObject *__pyx_tuple__376;
  PyObject *__pyx_tuple__378;
  PyObject *__pyx_tuple__381;
  PyObject *__pyx_tuple__383;
  PyObject *__pyx_tuple__385;
  PyObject *__pyx_tuple__387;
  PyObject *__pyx_tuple__388;
  PyObject *__pyx_tuple__393;
  PyObject *__pyx_tuple__395;
  PyObject *__pyx_tuple__396;
  PyObject *__pyx_tuple__398;
  PyObject *__pyx_tuple__399;
  PyObject *__pyx_tuple__401;
  PyObject *__pyx_tuple__402;
  PyObject *__pyx_tuple__405;
  PyObject *__pyx_tuple__407;
  PyObject *__pyx_tuple__409;
  PyObject *__pyx_tuple__410;
  PyObject *__pyx_tuple__412;
  PyObject *__pyx_tuple__414;
  PyObject *__pyx_tuple__416;
  PyObject *__pyx_tuple__417;
  PyObject *__pyx_tuple__420;
  PyObject *__pyx_tuple__422;
  PyObject *__pyx_tuple__424;
  PyObject *__pyx_tuple__427;
  PyObject *__pyx_tuple__429;
  PyObject *__pyx_tuple__433;
  PyObject *__pyx_tuple__435;
  PyObject *__pyx_tuple__437;
  PyObject *__pyx_tuple__440;
  PyObject *__pyx_tuple__444;
  PyObject *__pyx_tuple__456;
  PyObject *__pyx_tuple__458;
  PyObject *__pyx_tuple__462;
  PyObject *__pyx_tuple__464;
  PyObject *__pyx_tuple__468;
  PyObject *__pyx_tuple__470;
  PyObject *__pyx_tuple__472;
  PyObject *__pyx_tuple__474;
  PyObject *__pyx_tuple__476;
  PyObject *__pyx_tuple__478;
  PyObject *__pyx_tuple__480;
  PyObject *__pyx_tuple__482;
  PyObject *__pyx_tuple__483;
  PyObject *__pyx_tuple__486;
  PyObject *__pyx_tuple__493;
  PyObject *__pyx_tuple__497;
  PyObject *__pyx_tuple__499;
  PyObject *__pyx_tuple__504;
  PyObject *__pyx_tuple__506;
  PyObject *__pyx_tuple__507;
  PyObject *__pyx_tuple__509;
  PyObject *__pyx_tuple__511;
  PyObject *__pyx_tuple__513;
  PyObject *__pyx_tuple__516;
  PyObject *__pyx_tuple__518;
  PyObject *__pyx_tuple__519;
  PyObject *__pyx_tuple__521;
  PyObject *__pyx_tuple__524;
  PyObject *__pyx_tuple__527;
  PyObject *__pyx_tuple__530;
  PyObject *__pyx_tuple__533;
  PyObject *__pyx_tuple__536;
  PyObject *__pyx_tuple__539;
  PyObject *__pyx_tuple__542;
  PyObject *__pyx_tuple__552;
  PyObject *__pyx_codeobj__17;
  PyObject *__pyx_codeobj__32;
  PyObject *__pyx_codeobj__35;
  PyObject *__pyx_codeobj__36;
  PyObject *__pyx_codeobj__37;
  PyObject *__pyx_codeobj__39;
  PyObject *__pyx_codeobj__41;
  PyObject *__pyx_codeobj__61;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__65;
  PyObject *__pyx_codeobj__68;
  PyObject *__pyx_codeobj__70;
  PyObject *__pyx_codeobj__72;
  PyObject *__pyx_codeobj__74;
  PyObject *__pyx_codeobj__76;
  PyObject *__pyx_codeobj__79;
  PyObject *__pyx_codeobj__81;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__84;
  PyObject *__pyx_codeobj__86;
  PyObject *__pyx_codeobj__87;
  PyObject *__pyx_codeobj__89;
  PyObject *__pyx_codeobj__91;
  PyObject *__pyx_codeobj__94;
  PyObject *__pyx_codeobj__96;
  PyObject *__pyx_codeobj__98;
  PyObject *__pyx_codeobj__100;
  PyObject *__pyx_codeobj__103;
  PyObject *__pyx_codeobj__105;
  PyObject *__pyx_codeobj__108;
  PyObject *__pyx_codeobj__110;
  PyObject *__pyx_codeobj__112;
  PyObject *__pyx_codeobj__114;
  PyObject *__pyx_codeobj__116;
  PyObject *__pyx_codeobj__118;
  PyObject *__pyx_codeobj__120;
  PyObject *__pyx_codeobj__122;
  PyObject *__pyx_codeobj__124;
  PyObject *__pyx_codeobj__126;
  PyObject *__pyx_codeobj__128;
  PyObject *__pyx_codeobj__130;
  PyObject *__pyx_codeobj__132;
  PyObject *__pyx_codeobj__134;
  PyObject *__pyx_codeobj__136;
  PyObject *__pyx_codeobj__137;
  PyObject *__pyx_codeobj__139;
  PyObject *__pyx_codeobj__142;
  PyObject *__pyx_codeobj__144;
  PyObject *__pyx_codeobj__146;
  PyObject *__pyx_codeobj__148;
  PyObject *__pyx_codeobj__150;
  PyObject *__pyx_codeobj__152;
  PyObject *__pyx_codeobj__153;
  PyObject *__pyx_codeobj__154;
  PyObject *__pyx_codeobj__155;
  PyObject *__pyx_codeobj__157;
  PyObject *__pyx_codeobj__158;
  PyObject *__pyx_codeobj__159;
  PyObject *__pyx_codeobj__160;
  PyObject *__pyx_codeobj__161;
  PyObject *__pyx_codeobj__162;
  PyObject *__pyx_codeobj__163;
  PyObject *__pyx_codeobj__164;
  PyObject *__pyx_codeobj__165;
  PyObject *__pyx_codeobj__166;
  PyObject *__pyx_codeobj__167;
  PyObject *__pyx_codeobj__168;
  PyObject *__pyx_codeobj__170;
  PyObject *__pyx_codeobj__171;
  PyObject *__pyx_codeobj__173;
  PyObject *__pyx_codeobj__174;
  PyObject *__pyx_codeobj__175;
  PyObject *__pyx_codeobj__176;
  PyObject *__pyx_codeobj__178;
  PyObject *__pyx_codeobj__180;
  PyObject *__pyx_codeobj__182;
  PyObject *__pyx_codeobj__184;
  PyObject *__pyx_codeobj__186;
  PyObject *__pyx_codeobj__188;
  PyObject *__pyx_codeobj__189;
  PyObject *__pyx_codeobj__191;
  PyObject *__pyx_codeobj__193;
  PyObject *__pyx_codeobj__195;
  PyObject *__pyx_codeobj__197;
  PyObject *__pyx_codeobj__199;
  PyObject *__pyx_codeobj__200;
  PyObject *__pyx_codeobj__201;
  PyObject *__pyx_codeobj__203;
  PyObject *__pyx_codeobj__205;
  PyObject *__pyx_codeobj__207;
  PyObject *__pyx_codeobj__208;
  PyObject *__pyx_codeobj__210;
  PyObject *__pyx_codeobj__212;
  PyObject *__pyx_codeobj__214;
  PyObject *__pyx_codeobj__215;
  PyObject *__pyx_codeobj__216;
  PyObject *__pyx_codeobj__218;
  PyObject *__pyx_codeobj__219;
  PyObject *__pyx_codeobj__221;
  PyObject *__pyx_codeobj__222;
  PyObject *__pyx_codeobj__223;
  PyObject *__pyx_codeobj__224;
  PyObject *__pyx_codeobj__225;
  PyObject *__pyx_codeobj__226;
  PyObject *__pyx_codeobj__228;
  PyObject *__pyx_codeobj__230;
  PyObject *__pyx_codeobj__231;
  PyObject *__pyx_codeobj__232;
  PyObject *__pyx_codeobj__233;
  PyObject *__pyx_codeobj__234;
  PyObject *__pyx_codeobj__235;
  PyObject *__pyx_codeobj__236;
  PyObject *__pyx_codeobj__237;
  PyObject *__pyx_codeobj__238;
  PyObject *__pyx_codeobj__239;
  PyObject *__pyx_codeobj__240;
  PyObject *__pyx_codeobj__241;
  PyObject *__pyx_codeobj__242;
  PyObject *__pyx_codeobj__243;
  PyObject *__pyx_codeobj__244;
  PyObject *__pyx_codeobj__245;
  PyObject *__pyx_codeobj__246;
  PyObject *__pyx_codeobj__247;
  PyObject *__pyx_codeobj__248;
  PyObject *__pyx_codeobj__249;
  PyObject *__pyx_codeobj__250;
  PyObject *__pyx_codeobj__251;
  PyObject *__pyx_codeobj__252;
  PyObject *__pyx_codeobj__253;
  PyObject *__pyx_codeobj__254;
  PyObject *__pyx_codeobj__255;
  PyObject *__pyx_codeobj__256;
  PyObject *__pyx_codeobj__257;
  PyObject *__pyx_codeobj__258;
  PyObject *__pyx_codeobj__259;
  PyObject *__pyx_codeobj__260;
  PyObject *__pyx_codeobj__262;
  PyObject *__pyx_codeobj__264;
  PyObject *__pyx_codeobj__266;
  PyObject *__pyx_codeobj__268;
  PyObject *__pyx_codeobj__270;
  PyObject *__pyx_codeobj__272;
  PyObject *__pyx_codeobj__274;
  PyObject *__pyx_codeobj__276;
  PyObject *__pyx_codeobj__278;
  PyObject *__pyx_codeobj__280;
  PyObject *__pyx_codeobj__281;
  PyObject *__pyx_codeobj__282;
  PyObject *__pyx_codeobj__284;
  PyObject *__pyx_codeobj__286;
  PyObject *__pyx_codeobj__287;
  PyObject *__pyx_codeobj__288;
  PyObject *__pyx_codeobj__289;
  PyObject *__pyx_codeobj__291;
  PyObject *__pyx_codeobj__293;
  PyObject *__pyx_codeobj__294;
  PyObject *__pyx_codeobj__296;
  PyObject *__pyx_codeobj__297;
  PyObject *__pyx_codeobj__298;
  PyObject *__pyx_codeobj__299;
  PyObject *__pyx_codeobj__300;
  PyObject *__pyx_codeobj__301;
  PyObject *__pyx_codeobj__302;
  PyObject *__pyx_codeobj__303;
  PyObject *__pyx_codeobj__304;
  PyObject *__pyx_codeobj__305;
  PyObject *__pyx_codeobj__306;
  PyObject *__pyx_codeobj__307;
  PyObject *__pyx_codeobj__308;
  PyObject *__pyx_codeobj__309;
  PyObject *__pyx_codeobj__310;
  PyObject *__pyx_codeobj__311;
  PyObject *__pyx_codeobj__312;
  PyObject *__pyx_codeobj__313;
  PyObject *__pyx_codeobj__314;
  PyObject *__pyx_codeobj__315;
  PyObject *__pyx_codeobj__316;
  PyObject *__pyx_codeobj__318;
  PyObject *__pyx_codeobj__319;
  PyObject *__pyx_codeobj__321;
  PyObject *__pyx_codeobj__322;
  PyObject *__pyx_codeobj__323;
  PyObject *__pyx_codeobj__325;
  PyObject *__pyx_codeobj__327;
  PyObject *__pyx_codeobj__329;
  PyObject *__pyx_codeobj__331;
  PyObject *__pyx_codeobj__333;
  PyObject *__pyx_codeobj__334;
  PyObject *__pyx_codeobj__336;
  PyObject *__pyx_codeobj__337;
  PyObject *__pyx_codeobj__338;
  PyObject *__pyx_codeobj__339;
  PyObject *__pyx_codeobj__341;
  PyObject *__pyx_codeobj__344;
  PyObject *__pyx_codeobj__346;
  PyObject *__pyx_codeobj__347;
  PyObject *__pyx_codeobj__349;
  PyObject *__pyx_codeobj__351;
  PyObject *__pyx_codeobj__353;
  PyObject *__pyx_codeobj__355;
  PyObject *__pyx_codeobj__357;
  PyObject *__pyx_codeobj__359;
  PyObject *__pyx_codeobj__360;
  PyObject *__pyx_codeobj__361;
  PyObject *__pyx_codeobj__362;
  PyObject *__pyx_codeobj__363;
  PyObject *__pyx_codeobj__364;
  PyObject *__pyx_codeobj__366;
  PyObject *__pyx_codeobj__367;
  PyObject *__pyx_codeobj__368;
  PyObject *__pyx_codeobj__369;
  PyObject *__pyx_codeobj__370;
  PyObject *__pyx_codeobj__371;
  PyObject *__pyx_codeobj__372;
  PyObject *__pyx_codeobj__373;
  PyObject *__pyx_codeobj__375;
  PyObject *__pyx_codeobj__377;
  PyObject *__pyx_codeobj__379;
  PyObject *__pyx_codeobj__380;
  PyObject *__pyx_codeobj__382;
  PyObject *__pyx_codeobj__384;
  PyObject *__pyx_codeobj__386;
  PyObject *__pyx_codeobj__389;
  PyObject *__pyx_codeobj__390;
  PyObject *__pyx_codeobj__391;
  PyObject *__pyx_codeobj__392;
  PyObject *__pyx_codeobj__394;
  PyObject *__pyx_codeobj__397;
  PyObject *__pyx_codeobj__400;
  PyObject *__pyx_codeobj__403;
  PyObject *__pyx_codeobj__404;
  PyObject *__pyx_codeobj__406;
  PyObject *__pyx_codeobj__408;
  PyObject *__pyx_codeobj__411;
  PyObject *__pyx_codeobj__413;
  PyObject *__pyx_codeobj__415;
  PyObject *__pyx_codeobj__418;
  PyObject *__pyx_codeobj__419;
  PyObject *__pyx_codeobj__421;
  PyObject *__pyx_codeobj__423;
  PyObject *__pyx_codeobj__425;
  PyObject *__pyx_codeobj__426;
  PyObject *__pyx_codeobj__428;
  PyObject *__pyx_codeobj__430;
  PyObject *__pyx_codeobj__431;
  PyObject *__pyx_codeobj__432;
  PyObject *__pyx_codeobj__434;
  PyObject *__pyx_codeobj__436;
  PyObject *__pyx_codeobj__438;
  PyObject *__pyx_codeobj__439;
  PyObject *__pyx_codeobj__441;
  PyObject *__pyx_codeobj__442;
  PyObject *__pyx_codeobj__443;
  PyObject *__pyx_codeobj__445;
  PyObject *__pyx_codeobj__446;
  PyObject *__pyx_codeobj__447;
  PyObject *__pyx_codeobj__448;
  PyObject *__pyx_codeobj__449;
  PyObject *__pyx_codeobj__450;
  PyObject *__pyx_codeobj__451;
  PyObject *__pyx_codeobj__452;
  PyObject *__pyx_codeobj__453;
  PyObject *__pyx_codeobj__454;
  PyObject *__pyx_codeobj__455;
  PyObject *__pyx_codeobj__457;
  PyObject *__pyx_codeobj__459;
  PyObject *__pyx_codeobj__460;
  PyObject *__pyx_codeobj__461;
  PyObject *__pyx_codeobj__463;
  PyObject *__pyx_codeobj__465;
  PyObject *__pyx_codeobj__466;
  PyObject *__pyx_codeobj__467;
  PyObject *__pyx_codeobj__469;
  PyObject *__pyx_codeobj__471;
  PyObject *__pyx_codeobj__473;
  PyObject *__pyx_codeobj__475;
  PyObject *__pyx_codeobj__477;
  PyObject *__pyx_codeobj__479;
  PyObject *__pyx_codeobj__481;
  PyObject *__pyx_codeobj__484;
  PyObject *__pyx_codeobj__485;
  PyObject *__pyx_codeobj__487;
  PyObject *__pyx_codeobj__488;
  PyObject *__pyx_codeobj__489;
  PyObject *__pyx_codeobj__490;
  PyObject *__pyx_codeobj__491;
  PyObject *__pyx_codeobj__492;
  PyObject *__pyx_codeobj__494;
  PyObject *__pyx_codeobj__495;
  PyObject *__pyx_codeobj__496;
  PyObject *__pyx_codeobj__498;
  PyObject *__pyx_codeobj__500;
  PyObject *__pyx_codeobj__501;
  PyObject *__pyx_codeobj__502;
  PyObject *__pyx_codeobj__503;
  PyObject *__pyx_codeobj__505;
  PyObject *__pyx_codeobj__508;
  PyObject *__pyx_codeobj__510;
  PyObject *__pyx_codeobj__512;
  PyObject *__pyx_codeobj__514;
  PyObject *__pyx_codeobj__515;
  PyObject *__pyx_codeobj__517;
  PyObject *__pyx_codeobj__520;
  PyObject *__pyx_codeobj__522;
  PyObject *__pyx_codeobj__523;
  PyObject *__pyx_codeobj__525;
  PyObject *__pyx_codeobj__526;
  PyObject *__pyx_codeobj__528;
  PyObject *__pyx_codeobj__529;
  PyObject *__pyx_codeobj__531;
  PyObject *__pyx_codeobj__532;
  PyObject *__pyx_codeobj__534;
  PyObject *__pyx_codeobj__535;
  PyObject *__pyx_codeobj__537;
  PyObject *__pyx_codeobj__538;
  PyObject *__pyx_codeobj__540;
  PyObject *__pyx_codeobj__541;
  PyObject *__pyx_codeobj__543;
  PyObject *__pyx_codeobj__544;
  PyObject *__pyx_codeobj__545;
  PyObject *__pyx_codeobj__546;
  PyObject *__pyx_codeobj__547;
  PyObject *__pyx_codeobj__548;
  PyObject *__pyx_codeobj__549;
  PyObject *__pyx_codeobj__550;
  PyObject *__pyx_codeobj__551;
  PyObject *__pyx_codeobj__553;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_dtype);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flatiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_broadcast);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ndarray);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_generic);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_number);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_integer);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_inexact);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_floating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flexible);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_character);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ufunc);
  Py_CLEAR(clear_module_state->__pyx_ptype_9classy_sz_Class);
  Py_CLEAR(clear_module_state->__pyx_type_9classy_sz_Class);
  Py_CLEAR(clear_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings);
  Py_CLEAR(clear_module_state->__pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings);
  Py_CLEAR(clear_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast);
  Py_CLEAR(clear_module_state->__pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast);
  Py_CLEAR(clear_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_9classy_sz___pyx_scope_struct_2_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl);
  Py_CLEAR(clear_module_state->__pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl);
  Py_CLEAR(clear_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl);
  Py_CLEAR(clear_module_state->__pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl);
  Py_CLEAR(clear_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw);
  Py_CLEAR(clear_module_state->__pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw);
  Py_CLEAR(clear_module_state->__pyx_array_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_array);
  Py_CLEAR(clear_module_state->__pyx_MemviewEnum_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_MemviewEnum);
  Py_CLEAR(clear_module_state->__pyx_memoryview_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_memoryview);
  Py_CLEAR(clear_module_state->__pyx_memoryviewslice_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_memoryviewslice);
  Py_CLEAR(clear_module_state->__pyx_kp_u_);
  Py_CLEAR(clear_module_state->__pyx_kp_u_100_theta_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_100_theta_star);
  Py_CLEAR(clear_module_state->__pyx_kp_u_1h);
  Py_CLEAR(clear_module_state->__pyx_kp_u_1h_2h_3h);
  Py_CLEAR(clear_module_state->__pyx_kp_u_1h_2h_hf_3h_covmat_lensing_te);
  Py_CLEAR(clear_module_state->__pyx_kp_u_1h_slow);
  Py_CLEAR(clear_module_state->__pyx_kp_u_2h);
  Py_CLEAR(clear_module_state->__pyx_kp_u_2h_slow);
  Py_CLEAR(clear_module_state->__pyx_kp_u_3h);
  Py_CLEAR(clear_module_state->__pyx_kp_u_3h_slow);
  Py_CLEAR(clear_module_state->__pyx_n_s_A);
  Py_CLEAR(clear_module_state->__pyx_n_u_A10_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_ASCII);
  Py_CLEAR(clear_module_state->__pyx_n_u_A_IA);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_P0);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_u_A_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_A_beta);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_cn);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_ir);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_u_A_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_rs);
  Py_CLEAR(clear_module_state->__pyx_n_u_A_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_s_fast);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_sn);
  Py_CLEAR(clear_module_state->__pyx_n_s_A_xc);
  Py_CLEAR(clear_module_state->__pyx_kp_s_All_dimensions_preceding_dimensi);
  Py_CLEAR(clear_module_state->__pyx_kp_u_All_inputs_should_be_floats_or_1);
  Py_CLEAR(clear_module_state->__pyx_n_u_As);
  Py_CLEAR(clear_module_state->__pyx_n_s_AssertionError);
  Py_CLEAR(clear_module_state->__pyx_n_s_B);
  Py_CLEAR(clear_module_state->__pyx_n_s_B_sz);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Buffer_view_does_not_expose_stri);
  Py_CLEAR(clear_module_state->__pyx_n_s_CRITICAL);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Can_only_compute_up_to_lmax_d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Can_only_create_a_buffer_that_is);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_assign_to_read_only_memor);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_create_writable_memory_vi);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_index_with_type);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_transpose_memoryview_with);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_A_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_A_cn);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_A_ir);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_A_rs);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_A_sn);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_B_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Hubble);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_M1SZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Neff);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Om_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega0_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega0_cdm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega0_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega0_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega_Lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Omega_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_Rho_crit_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_T_cmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class__check_task_dependency);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class__cumulativeNumberDensity);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class__fillparfile);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class__pars_check);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_age);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_angular_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_b_tty);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_b_yyy);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_baryon_temperature);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_bk_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_bk_ttg_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_calcFRel);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_calculate_pkl_fftlog_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_chi_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cib_monopole);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cib_shotnoise);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_IA_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_c1_gal);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_c1_gallens);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_c1_lens);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_c1_tSZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_c1c1);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_cib_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_custom1_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_ee);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_eg);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_gal_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_gal_gal_kcmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_galn_IA);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_galn_gallens);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_galn_galn);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_galn_lens);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_galn_tsz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_gg);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_ggamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_gm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kSZ_kSZ_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kSZ_kSZ_kcmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kSZ_kSZ_kg);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kg);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kg_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kg_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kg_kg);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kg_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_kk);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_km);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_ksz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_lens_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_lensmagn_gallens);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_lensmagn_tsz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_mm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_sz_at_nu_in_GHz_in_micr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_t2t2f);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_tSZ_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_te_y_y);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_y_kcmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_yg);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_ykg);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_cl_ym);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_compute);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_compute_class_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_compute_class_szfast);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_delta_def_custom1);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_density_cl);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Class_did_not_read_input_paramet);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_dl_isw_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_dndzdy_theoretical);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_effective_f_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_effective_galaxy_bias);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_empty);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_gamma_ggamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_getM500_from_y0_H13);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_getPLog10M);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_1e6xdy_from_battaglia);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_1e6xdy_from_gnfw_press);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_Delta_c_of_Omega_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_Ez);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_H);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_IA_of_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_N_centrals);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_N_satellites);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_Omega_m_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_Omega_m_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_Omega_r_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_P_delta_at_m_and_z_b12);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_T10_alpha_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_arcmin_to_rad);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_background);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_bispectrum_f2_kernel);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_c200c_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_c200c_at_m_and_z_B13);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_c200c_at_m_and_z_D08);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_c200m_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_c200m_at_m_and_z_D08);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_c500c_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_c_delta_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_cib_Snu_z_and_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_comoving_volume);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_cov_N_N);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_current_derived_parame);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_custom1_bias_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_custom1_profile_at_k_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_custom1_profile_at_x_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_cvir_of_mvir_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dA);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dA_z1z2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dcib0dz_at_z_and_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_delta_from_delta_def_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_delta_mean_from_delta);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dkappacmbdz_at_l_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dlnsigma_dlnR_at_z_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dndlnM_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dndlnm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dydz_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_dydzdlnm_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_effective_f_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_f_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_f_free);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_f_of_sigma_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_f_tinker08_at_nu_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_f_tinker10_at_nu_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_fftlog_ComputeXiLMsloz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_first_order_bias_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_first_order_bias_at_z_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_first_order_bias_at_z_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_fstar_of_m_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_galaxy_number_counts);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_gas_density_profile_at);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_gas_pressure_2h_at_r_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_b_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_n_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_gnu_tsz_of_nu_in_ghz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_hmf_counter_term_b1min);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_hmf_counter_term_b2min);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_hmf_counter_term_nmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_lensing_noise_at_ell);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m200c_to_m200m_at_z_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m200c_to_m500c_at_z_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m200m_to_m200c_at_z_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m200m_to_m500c_at_z_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m500c_to_m200c_at_z_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m500c_to_m200m_at_z_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m_nfw);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_m_to_xout_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_mass_profile_at_x_M_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_mean_galaxy_bias_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_mean_y);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_mu_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_n5k_cl_K1_at_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_n5k_pk_at_z_and_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_n5k_z_of_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_ng_bar_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_nl_index_at_z_and_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_nl_index_at_z_and_k_no);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_normalization_gas_dens);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_nu_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_params_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_perturbations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_and_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_cb_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_cb_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_lin_at_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_lin_at_k_and_z_fast);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_nonlin_at_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pk_nonlin_at_k_and_z_f);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pkl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pkl_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pkl_reconstructed_from);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pkl_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pknl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pknl_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pknl_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_planck_sigma_at_theta5);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pressure_P_over_P_delt);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_pressure_P_over_P_delt_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_primordial);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_r_delta_of_m_delta_at);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_rad_to_arcmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_radial_kernel_W_custom);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_radial_kernel_W_galaxy);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_radial_kernel_W_galaxy_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_rho_2h_at_r_and_m_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_rho_crit_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_rvir_of_m200c_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_rvir_of_mvir_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_scale_dependent_bias_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_second_order_bias_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_sigma8_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_sigma_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_source_galaxy_number_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_szcounts_dndzdq_at_z_q);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_szcountsz_sigma_at_the);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_te_of_m500c_at_z_arnau);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_te_of_m500c_at_z_lee);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_thermodynamics);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_theta_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_truncated_nfw_profile);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_truncated_nfw_profile_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_ttg_bispectrum_at_z_ef);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_ttg_bispectrum_at_z_tr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_uk);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_uk_nfw);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_unwise_m_min_cut_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_upp_from_gnfw_pressure);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_volume_dVdzdOmega_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_vrms2_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_y_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_yc_at_m_and_z_H13);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_z_of_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_get_z_of_chi_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_h);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_ionization_fraction);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_k_eq);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_lensed_cl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_load_n5k_cl_K1);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_load_n5k_pk_zk);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_load_n5k_z_of_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_luminosity_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_n_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigma8_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmaprim);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmaprim_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_hmcode_window_nf);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_scale);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_nonlinear_scale_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_omega_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_omega_cdm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_b_at_z_2h);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_bb_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_cb_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_em_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_gg_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_lin_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_nonlin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_tilt);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_pk_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_raw_cl);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_rho0_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_rho0_crit);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_rho0_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_rs_drag);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_scale_independent_growth_f);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_scale_independent_growth_f_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_set_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_sigma);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_sigma8_Pcb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_sigma8_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_sigmaM);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_sigma_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_struct_cleanup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_szcounts_ntot);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_szcounts_ntot_rates_loglik);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_szfast);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_szunbinned_loglike);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_tau_reio);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_theta_s_100);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_theta_star_100);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_tllprime_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_x_out_custom1);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_ystar);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_z_of_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_z_of_tau);
  Py_CLEAR(clear_module_state->__pyx_n_s_Class_z_reio);
  Py_CLEAR(clear_module_state->__pyx_n_s_CosmoComputationError);
  Py_CLEAR(clear_module_state->__pyx_n_s_CosmoError);
  Py_CLEAR(clear_module_state->__pyx_n_s_CosmoError___init);
  Py_CLEAR(clear_module_state->__pyx_n_s_CosmoError___str);
  Py_CLEAR(clear_module_state->__pyx_n_s_CosmoSevereError);
  Py_CLEAR(clear_module_state->__pyx_n_s_D);
  Py_CLEAR(clear_module_state->__pyx_n_s_DEBUG);
  Py_CLEAR(clear_module_state->__pyx_n_s_D_A);
  Py_CLEAR(clear_module_state->__pyx_n_s_Delta_c);
  Py_CLEAR(clear_module_state->__pyx_n_u_Deprecated);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Dimension_d_is_not_direct);
  Py_CLEAR(clear_module_state->__pyx_n_u_Dust_temperature_today_in_Kelvin);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dz);
  Py_CLEAR(clear_module_state->__pyx_n_s_Dzmax);
  Py_CLEAR(clear_module_state->__pyx_n_s_Eh);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ellipsis);
  Py_CLEAR(clear_module_state->__pyx_n_u_Emissivity_index_of_sed);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Empty_shape_tuple_for_cython_arr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Error_in_Class);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ez);
  Py_CLEAR(clear_module_state->__pyx_n_s_F);
  Py_CLEAR(clear_module_state->__pyx_n_s_G);
  Py_CLEAR(clear_module_state->__pyx_n_u_Gamma_0_nadm);
  Py_CLEAR(clear_module_state->__pyx_n_s_H);
  Py_CLEAR(clear_module_state->__pyx_n_u_H0);
  Py_CLEAR(clear_module_state->__pyx_n_s_H_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_H_over_c_in_h_over_Mpc_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Hankel);
  Py_CLEAR(clear_module_state->__pyx_n_s_Hubble);
  Py_CLEAR(clear_module_state->__pyx_n_u_I0);
  Py_CLEAR(clear_module_state->__pyx_n_s_INFO);
  Py_CLEAR(clear_module_state->__pyx_n_s_ImportError);
  Py_CLEAR(clear_module_state->__pyx_kp_u_In_order_to_get_pk_tilt_at_k_e_1);
  Py_CLEAR(clear_module_state->__pyx_kp_u_In_order_to_get_sigma_R_z_you_mu);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_IndexError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Index_out_of_bounds_axis_d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Indirect_dimensions_not_supporte);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Input_should_be_a_float_or_a_1D);
  Py_CLEAR(clear_module_state->__pyx_n_s_InterpolatedUnivariateSpline);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_mode_expected_c_or_fortr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_shape_in_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyError);
  Py_CLEAR(clear_module_state->__pyx_n_s_M);
  Py_CLEAR(clear_module_state->__pyx_n_u_M0_HOD_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_s_M1SZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_M1_prime);
  Py_CLEAR(clear_module_state->__pyx_n_u_M1_prime_HOD);
  Py_CLEAR(clear_module_state->__pyx_n_u_M1_prime_HOD_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_s_M500);
  Py_CLEAR(clear_module_state->__pyx_n_s_M500c_zk);
  Py_CLEAR(clear_module_state->__pyx_n_s_MF_extr);
  Py_CLEAR(clear_module_state->__pyx_n_s_MUpper);
  Py_CLEAR(clear_module_state->__pyx_n_s_M_halo);
  Py_CLEAR(clear_module_state->__pyx_n_u_M_max);
  Py_CLEAR(clear_module_state->__pyx_n_s_M_min);
  Py_CLEAR(clear_module_state->__pyx_n_u_M_min);
  Py_CLEAR(clear_module_state->__pyx_n_u_M_min_HOD);
  Py_CLEAR(clear_module_state->__pyx_n_u_M_min_HOD_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_s_MemoryError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_MemoryView_of_r_at_0x_x);
  Py_CLEAR(clear_module_state->__pyx_kp_s_MemoryView_of_r_object);
  Py_CLEAR(clear_module_state->__pyx_n_u_Most_efficient_halo_mass_in_Msun);
  Py_CLEAR(clear_module_state->__pyx_n_s_N);
  Py_CLEAR(clear_module_state->__pyx_n_u_N_dg);
  Py_CLEAR(clear_module_state->__pyx_n_u_N_ncdm);
  Py_CLEAR(clear_module_state->__pyx_n_s_N_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_u_N_ur);
  Py_CLEAR(clear_module_state->__pyx_n_s_Nc);
  Py_CLEAR(clear_module_state->__pyx_n_s_Nc_mean);
  Py_CLEAR(clear_module_state->__pyx_n_s_Neff);
  Py_CLEAR(clear_module_state->__pyx_n_u_Neff);
  Py_CLEAR(clear_module_state->__pyx_n_s_Nmcfit);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_Cl_computed);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_density_Cl_computed);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_lensed_Cl_computed);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_massive_neutrinos_You_must_us);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_power_spectrum_computed_In_or);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_power_spectrum_computed_In_or_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_No_power_spectrum_computed_You_m);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Normalisation_of_L___M_relation);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotImplementedError);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ns);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ntot);
  Py_CLEAR(clear_module_state->__pyx_n_s_Nz);
  Py_CLEAR(clear_module_state->__pyx_n_b_O);
  Py_CLEAR(clear_module_state->__pyx_n_s_Om_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega0_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega0_cdm);
  Py_CLEAR(clear_module_state->__pyx_n_u_Omega0_fld);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega0_k);
  Py_CLEAR(clear_module_state->__pyx_n_u_Omega0_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega0_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega_Lambda);
  Py_CLEAR(clear_module_state->__pyx_n_u_Omega_Lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega_b);
  Py_CLEAR(clear_module_state->__pyx_n_u_Omega_b);
  Py_CLEAR(clear_module_state->__pyx_n_u_Omega_c);
  Py_CLEAR(clear_module_state->__pyx_n_u_Omega_cdm);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega_m);
  Py_CLEAR(clear_module_state->__pyx_n_u_Omega_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_Omega_r);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_P);
  Py_CLEAR(clear_module_state->__pyx_n_s_P0GNFW);
  Py_CLEAR(clear_module_state->__pyx_n_u_P0GNFW);
  Py_CLEAR(clear_module_state->__pyx_n_u_P0_B12);
  Py_CLEAR(clear_module_state->__pyx_n_u_P13_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_P200);
  Py_CLEAR(clear_module_state->__pyx_n_s_PATH_TO_CLASS_SZ_DATA);
  Py_CLEAR(clear_module_state->__pyx_n_s_PArr);
  Py_CLEAR(clear_module_state->__pyx_n_s_PLog10M);
  Py_CLEAR(clear_module_state->__pyx_n_s_PLog10M_full);
  Py_CLEAR(clear_module_state->__pyx_kp_u_P_cb_not_computed_by_CLASS_proba);
  Py_CLEAR(clear_module_state->__pyx_kp_u_P_cb_not_computed_probably_becau);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_u_Power_law_index_of_SED_at_high_f);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Profile);
  Py_CLEAR(clear_module_state->__pyx_n_s_Py0GivenM);
  Py_CLEAR(clear_module_state->__pyx_n_s_Pz);
  Py_CLEAR(clear_module_state->__pyx_n_s_QF);
  Py_CLEAR(clear_module_state->__pyx_n_s_R);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Raised_when_Class_could_not_com);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Raised_when_Class_failed_to_und);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Redshift_evolution_of_L___M_norm);
  Py_CLEAR(clear_module_state->__pyx_n_u_Redshift_evolution_of_dust_tempe);
  Py_CLEAR(clear_module_state->__pyx_n_s_Rho_crit_0);
  Py_CLEAR(clear_module_state->__pyx_n_u_SZ_cat_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_Sequence);
  Py_CLEAR(clear_module_state->__pyx_n_u_Size_of_halo_masses_sourcing_CIB);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Step_may_not_be_zero_axis_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_Stw);
  Py_CLEAR(clear_module_state->__pyx_kp_b_T);
  Py_CLEAR(clear_module_state->__pyx_n_s_TCMB);
  Py_CLEAR(clear_module_state->__pyx_n_s_TKelvin);
  Py_CLEAR(clear_module_state->__pyx_n_s_T_cmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_T_ll_arr);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tcmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tcmb_gNU);
  Py_CLEAR(clear_module_state->__pyx_n_u_Tinker_et_al_10_alpha_consistenc);
  Py_CLEAR(clear_module_state->__pyx_n_s_TkeV);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Type);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unable_to_convert_item_to_object);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Users_boris_Work_CLASS_SZ_SO_SZ);
  Py_CLEAR(clear_module_state->__pyx_n_u_V_0);
  Py_CLEAR(clear_module_state->__pyx_n_u_V_1);
  Py_CLEAR(clear_module_state->__pyx_n_u_V_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_V_3);
  Py_CLEAR(clear_module_state->__pyx_n_u_V_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s_View_MemoryView);
  Py_CLEAR(clear_module_state->__pyx_n_s_Wg);
  Py_CLEAR(clear_module_state->__pyx_n_s_X);
  Py_CLEAR(clear_module_state->__pyx_n_s_Xtw);
  Py_CLEAR(clear_module_state->__pyx_n_s_Y0);
  Py_CLEAR(clear_module_state->__pyx_n_s_Y1);
  Py_CLEAR(clear_module_state->__pyx_n_s_Y2);
  Py_CLEAR(clear_module_state->__pyx_n_s_Y3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Y4);
  Py_CLEAR(clear_module_state->__pyx_n_u_YHe);
  Py_CLEAR(clear_module_state->__pyx_kp_u_You_ask_classy_to_return_an_arra);
  Py_CLEAR(clear_module_state->__pyx_kp_u_You_ask_classy_to_return_an_arra_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_You_ask_classy_to_return_an_arra_3);
  Py_CLEAR(clear_module_state->__pyx_kp_b__10);
  Py_CLEAR(clear_module_state->__pyx_kp_u__10);
  Py_CLEAR(clear_module_state->__pyx_kp_b__11);
  Py_CLEAR(clear_module_state->__pyx_kp_b__12);
  Py_CLEAR(clear_module_state->__pyx_kp_u__13);
  Py_CLEAR(clear_module_state->__pyx_kp_u__14);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_kp_u__20);
  Py_CLEAR(clear_module_state->__pyx_kp_u__22);
  Py_CLEAR(clear_module_state->__pyx_n_s__3);
  Py_CLEAR(clear_module_state->__pyx_kp_u__46);
  Py_CLEAR(clear_module_state->__pyx_n_s__554);
  Py_CLEAR(clear_module_state->__pyx_kp_u__6);
  Py_CLEAR(clear_module_state->__pyx_kp_u__7);
  Py_CLEAR(clear_module_state->__pyx_kp_b__9);
  Py_CLEAR(clear_module_state->__pyx_n_u_a_dark);
  Py_CLEAR(clear_module_state->__pyx_n_s_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_age);
  Py_CLEAR(clear_module_state->__pyx_n_u_age);
  Py_CLEAR(clear_module_state->__pyx_n_s_allocate_buffer);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphaGNFW);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_c_P0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_c_P0_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_c_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_c_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_c_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_c_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_c_beta_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_c_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_c_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_c_xc);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_c_xc_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_m_P0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_m_P0_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_m_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_m_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_m_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_m_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_m_beta_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_m_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_m_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_m_xc);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_m_xc_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_s);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_s);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_s_HOD);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_s_HOD_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_z_P0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_z_P0_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_z_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_z_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_z_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_z_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_z_beta_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_z_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_z_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_s_alpha_z_xc);
  Py_CLEAR(clear_module_state->__pyx_n_u_alpha_z_xc_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphap_m_P0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphap_m_P0_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphap_m_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphap_m_alpha);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphap_m_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphap_m_beta);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphap_m_beta_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphap_m_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphap_m_rho0);
  Py_CLEAR(clear_module_state->__pyx_n_s_alphap_m_xc);
  Py_CLEAR(clear_module_state->__pyx_n_u_alphap_m_xc_B12);
  Py_CLEAR(clear_module_state->__pyx_kp_u_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_angular_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_append);
  Py_CLEAR(clear_module_state->__pyx_n_s_applyMFDebiasCorrection);
  Py_CLEAR(clear_module_state->__pyx_n_s_arange);
  Py_CLEAR(clear_module_state->__pyx_n_s_argmax);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_u_arr_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_asarray);
  Py_CLEAR(clear_module_state->__pyx_n_s_assume_sorted);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_atleast_1d);
  Py_CLEAR(clear_module_state->__pyx_n_s_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_b_tty);
  Py_CLEAR(clear_module_state->__pyx_n_s_b_yyy);
  Py_CLEAR(clear_module_state->__pyx_n_s_background);
  Py_CLEAR(clear_module_state->__pyx_n_u_background);
  Py_CLEAR(clear_module_state->__pyx_kp_u_bad_call);
  Py_CLEAR(clear_module_state->__pyx_n_s_baryon_temperature);
  Py_CLEAR(clear_module_state->__pyx_n_s_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_basicConfig);
  Py_CLEAR(clear_module_state->__pyx_n_u_bb);
  Py_CLEAR(clear_module_state->__pyx_kp_u_bbn_PRIMAT21_class_format_dat);
  Py_CLEAR(clear_module_state->__pyx_n_s_betaGNFW);
  Py_CLEAR(clear_module_state->__pyx_n_u_betaGNFW);
  Py_CLEAR(clear_module_state->__pyx_n_u_beta_B12);
  Py_CLEAR(clear_module_state->__pyx_n_u_beta_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_bh);
  Py_CLEAR(clear_module_state->__pyx_n_s_bk_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_bk_ttg_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_u_boundary);
  Py_CLEAR(clear_module_state->__pyx_n_s_bounds_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_broadcast_arrays);
  Py_CLEAR(clear_module_state->__pyx_kp_u_but_you_asked_a_l_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_c);
  Py_CLEAR(clear_module_state->__pyx_n_u_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_c500);
  Py_CLEAR(clear_module_state->__pyx_n_u_c500);
  Py_CLEAR(clear_module_state->__pyx_n_u_c_B12);
  Py_CLEAR(clear_module_state->__pyx_n_u_c_B16);
  Py_CLEAR(clear_module_state->__pyx_n_s_c_asked);
  Py_CLEAR(clear_module_state->__pyx_n_s_c_delta);
  Py_CLEAR(clear_module_state->__pyx_n_s_calcErrors);
  Py_CLEAR(clear_module_state->__pyx_n_s_calcFRel);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_cmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_hubble);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_pkl);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_pkl_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_pkl_fftlog_alphas);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_pknl);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_pknl_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_sigma);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_sigma8_and_der);
  Py_CLEAR(clear_module_state->__pyx_n_s_calculate_sigma8_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_u_camb);
  Py_CLEAR(clear_module_state->__pyx_n_s_check_task_dependency);
  Py_CLEAR(clear_module_state->__pyx_n_s_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_chi_star);
  Py_CLEAR(clear_module_state->__pyx_n_u_cib_Snu_file_nu);
  Py_CLEAR(clear_module_state->__pyx_n_u_cib_Snu_file_snu);
  Py_CLEAR(clear_module_state->__pyx_n_u_cib_Snu_file_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_cib_monopole);
  Py_CLEAR(clear_module_state->__pyx_n_s_cib_shotnoise);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_IA_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_c1_gal);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_c1_gallens);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_c1_lens);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_c1_tSZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_c1c1);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_cib_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_custom1_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_ee);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_eg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gIA);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_g_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_g_gamma_1h);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_g_gamma_2h);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_g_gamma_ell);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gal_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gal_gal_kcmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_galn_IA);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_galn_gallens);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_galn_galn);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_galn_lens);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_galn_tsz);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_ggamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gk);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gkg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gm);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_gy);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kSZ_kSZ_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kSZ_kSZ_kcmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kSZ_kSZ_kg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kg_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kg_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kg_kg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kg_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_kk);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_km);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_ksz);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_lens_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_lensmagn_gallens);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_lensmagn_tsz);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_md);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_md_ic);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_mkg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_mm);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_my);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_phi_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_t2t2f);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_tSZ_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_te_y_y);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_y_cib);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_y_kcmb);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_yg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_ykg);
  Py_CLEAR(clear_module_state->__pyx_n_s_cl_ym);
  Py_CLEAR(clear_module_state->__pyx_n_s_class);
  Py_CLEAR(clear_module_state->__pyx_n_u_class_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_10);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_11);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_12);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_13);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_4);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_5);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_6);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_7);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_8);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_9);
  Py_CLEAR(clear_module_state->__pyx_kp_u_class_sz_class_sz);
  Py_CLEAR(clear_module_state->__pyx_n_u_class_sz_cosmo);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_sz_in_dict_output);
  Py_CLEAR(clear_module_state->__pyx_n_u_class_sz_integrate);
  Py_CLEAR(clear_module_state->__pyx_kp_s_class_sz_python_classy_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_u_class_sz_tabulate);
  Py_CLEAR(clear_module_state->__pyx_n_s_classy_sz);
  Py_CLEAR(clear_module_state->__pyx_n_u_classy_sz_verbose);
  Py_CLEAR(clear_module_state->__pyx_n_s_classy_szfast);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_cls);
  Py_CLEAR(clear_module_state->__pyx_n_s_cltot);
  Py_CLEAR(clear_module_state->__pyx_n_s_cltotfunc);
  Py_CLEAR(clear_module_state->__pyx_n_s_clusterLogM500);
  Py_CLEAR(clear_module_state->__pyx_n_s_clusterLogM500Max);
  Py_CLEAR(clear_module_state->__pyx_n_s_clusterLogM500Min);
  Py_CLEAR(clear_module_state->__pyx_n_s_clusterM500);
  Py_CLEAR(clear_module_state->__pyx_n_s_clusterM500MinusErr);
  Py_CLEAR(clear_module_state->__pyx_n_s_clusterM500PlusErr);
  Py_CLEAR(clear_module_state->__pyx_n_s_cnew);
  Py_CLEAR(clear_module_state->__pyx_n_s_collections);
  Py_CLEAR(clear_module_state->__pyx_kp_s_collections_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_compile);
  Py_CLEAR(clear_module_state->__pyx_n_s_compute);
  Py_CLEAR(clear_module_state->__pyx_n_s_compute_class_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_compute_class_szfast);
  Py_CLEAR(clear_module_state->__pyx_n_s_compute_class_szfast_locals_gene);
  Py_CLEAR(clear_module_state->__pyx_n_s_compute_pkl);
  Py_CLEAR(clear_module_state->__pyx_n_s_compute_pknl);
  Py_CLEAR(clear_module_state->__pyx_n_s_compute_profile);
  Py_CLEAR(clear_module_state->__pyx_n_u_concentration_parameter);
  Py_CLEAR(clear_module_state->__pyx_kp_u_concentration_parameter_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_configure_logging);
  Py_CLEAR(clear_module_state->__pyx_n_u_conformal_age);
  Py_CLEAR(clear_module_state->__pyx_n_s_contains);
  Py_CLEAR(clear_module_state->__pyx_n_s_contains_specific_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_contains_specific_pattern_or_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_contextlib);
  Py_CLEAR(clear_module_state->__pyx_n_s_contextmanager);
  Py_CLEAR(clear_module_state->__pyx_kp_s_contiguous_and_direct);
  Py_CLEAR(clear_module_state->__pyx_kp_s_contiguous_and_indirect);
  Py_CLEAR(clear_module_state->__pyx_n_s_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_cosh);
  Py_CLEAR(clear_module_state->__pyx_n_u_cosmo);
  Py_CLEAR(clear_module_state->__pyx_n_s_cosmo_arguments);
  Py_CLEAR(clear_module_state->__pyx_n_s_cosmo_model);
  Py_CLEAR(clear_module_state->__pyx_n_u_cosmo_model);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_kp_u_cov_N_N);
  Py_CLEAR(clear_module_state->__pyx_n_u_covmat);
  Py_CLEAR(clear_module_state->__pyx_n_u_cp_B12);
  Py_CLEAR(clear_module_state->__pyx_n_u_cp_B16);
  Py_CLEAR(clear_module_state->__pyx_n_s_cp_pkl_fftlog_alphas_nus);
  Py_CLEAR(clear_module_state->__pyx_n_s_cp_predicted_ee_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_cp_predicted_pp_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_cp_predicted_te_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_cp_predicted_tt_spectrum);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_dsigma2_flat);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_ln1pz);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_lnk);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_lnr);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_lnsigma2_flat);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_pkl_flat);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_pknl);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_pknl_flat);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_cszfast_pk_grid_zmax);
  Py_CLEAR(clear_module_state->__pyx_n_s_ctx);
  Py_CLEAR(clear_module_state->__pyx_n_u_cubic);
  Py_CLEAR(clear_module_state->__pyx_n_s_cumtrapz);
  Py_CLEAR(clear_module_state->__pyx_n_s_cumulativeNumberDensity);
  Py_CLEAR(clear_module_state->__pyx_n_u_current);
  Py_CLEAR(clear_module_state->__pyx_n_s_custom1_W);
  Py_CLEAR(clear_module_state->__pyx_n_s_custom1_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_custom1_ux);
  Py_CLEAR(clear_module_state->__pyx_n_s_d);
  Py_CLEAR(clear_module_state->__pyx_n_u_d_ell);
  Py_CLEAR(clear_module_state->__pyx_n_u_da_rec);
  Py_CLEAR(clear_module_state->__pyx_n_u_da_rec_h);
  Py_CLEAR(clear_module_state->__pyx_n_u_da_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_data);
  Py_CLEAR(clear_module_state->__pyx_n_u_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_dcl);
  Py_CLEAR(clear_module_state->__pyx_n_u_dd);
  Py_CLEAR(clear_module_state->__pyx_n_s_decode);
  Py_CLEAR(clear_module_state->__pyx_n_s_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaultdict);
  Py_CLEAR(clear_module_state->__pyx_n_u_deg_ncdm);
  Py_CLEAR(clear_module_state->__pyx_n_s_delta);
  Py_CLEAR(clear_module_state->__pyx_n_s_deltaSZE);
  Py_CLEAR(clear_module_state->__pyx_n_s_delta_crit);
  Py_CLEAR(clear_module_state->__pyx_n_s_delta_def);
  Py_CLEAR(clear_module_state->__pyx_n_s_delta_def_custom1);
  Py_CLEAR(clear_module_state->__pyx_n_s_density_cl);
  Py_CLEAR(clear_module_state->__pyx_n_s_derived);
  Py_CLEAR(clear_module_state->__pyx_n_u_derived);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_dl);
  Py_CLEAR(clear_module_state->__pyx_n_u_dl);
  Py_CLEAR(clear_module_state->__pyx_n_s_dl_isw_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_dndM);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndM);
  Py_CLEAR(clear_module_state->__pyx_n_s_dndlnM);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndlnM);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndlnm);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndm);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndz_shift_gal);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndz_shift_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndz_shift_source_gal);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndz_stretch_gal);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndz_stretch_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndz_stretch_source_gal);
  Py_CLEAR(clear_module_state->__pyx_n_s_dndzdy);
  Py_CLEAR(clear_module_state->__pyx_n_u_dndzdy);
  Py_CLEAR(clear_module_state->__pyx_n_s_dndzdy_index_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_dndzdy_theoretical);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc);
  Py_CLEAR(clear_module_state->__pyx_n_s_double);
  Py_CLEAR(clear_module_state->__pyx_n_u_ds_d);
  Py_CLEAR(clear_module_state->__pyx_n_u_ds_d_h);
  Py_CLEAR(clear_module_state->__pyx_n_u_ds_rec);
  Py_CLEAR(clear_module_state->__pyx_n_u_ds_rec_h);
  Py_CLEAR(clear_module_state->__pyx_n_u_ds_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtype);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtype_is_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_dumc);
  Py_CLEAR(clear_module_state->__pyx_n_s_dumcp);
  Py_CLEAR(clear_module_state->__pyx_n_s_dx);
  Py_CLEAR(clear_module_state->__pyx_n_u_dydz);
  Py_CLEAR(clear_module_state->__pyx_n_s_dzdr);
  Py_CLEAR(clear_module_state->__pyx_n_s_e);
  Py_CLEAR(clear_module_state->__pyx_n_u_ee);
  Py_CLEAR(clear_module_state->__pyx_n_s_effective_f_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_effective_galaxy_bias);
  Py_CLEAR(clear_module_state->__pyx_n_s_elem);
  Py_CLEAR(clear_module_state->__pyx_n_s_ell);
  Py_CLEAR(clear_module_state->__pyx_n_u_ell);
  Py_CLEAR(clear_module_state->__pyx_n_s_empty);
  Py_CLEAR(clear_module_state->__pyx_n_s_empty_like);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_encode);
  Py_CLEAR(clear_module_state->__pyx_n_s_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_endpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_enter);
  Py_CLEAR(clear_module_state->__pyx_n_s_enumerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_eps1);
  Py_CLEAR(clear_module_state->__pyx_n_s_eps2);
  Py_CLEAR(clear_module_state->__pyx_n_s_eps23);
  Py_CLEAR(clear_module_state->__pyx_n_u_epsilon_V);
  Py_CLEAR(clear_module_state->__pyx_n_s_errmsg);
  Py_CLEAR(clear_module_state->__pyx_n_s_error);
  Py_CLEAR(clear_module_state->__pyx_n_u_eta_V);
  Py_CLEAR(clear_module_state->__pyx_n_s_even);
  Py_CLEAR(clear_module_state->__pyx_n_s_exit);
  Py_CLEAR(clear_module_state->__pyx_n_s_exp);
  Py_CLEAR(clear_module_state->__pyx_n_u_exp_m_2_tau_As);
  Py_CLEAR(clear_module_state->__pyx_n_u_extensive);
  Py_CLEAR(clear_module_state->__pyx_n_s_extrap);
  Py_CLEAR(clear_module_state->__pyx_n_u_extrapolate);
  Py_CLEAR(clear_module_state->__pyx_n_s_extrapolator);
  Py_CLEAR(clear_module_state->__pyx_n_s_f);
  Py_CLEAR(clear_module_state->__pyx_n_u_fNL);
  Py_CLEAR(clear_module_state->__pyx_n_s_fRel);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_rel);
  Py_CLEAR(clear_module_state->__pyx_n_s_fac);
  Py_CLEAR(clear_module_state->__pyx_n_s_fc);
  Py_CLEAR(clear_module_state->__pyx_n_s_fill_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_fillparfile);
  Py_CLEAR(clear_module_state->__pyx_n_s_filterwarnings);
  Py_CLEAR(clear_module_state->__pyx_n_s_find_As);
  Py_CLEAR(clear_module_state->__pyx_n_s_fineLog10M);
  Py_CLEAR(clear_module_state->__pyx_n_s_fineP);
  Py_CLEAR(clear_module_state->__pyx_n_u_first);
  Py_CLEAR(clear_module_state->__pyx_n_s_flag);
  Py_CLEAR(clear_module_state->__pyx_n_s_flags);
  Py_CLEAR(clear_module_state->__pyx_n_s_flatten);
  Py_CLEAR(clear_module_state->__pyx_n_s_float64);
  Py_CLEAR(clear_module_state->__pyx_n_u_float64);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_fortran);
  Py_CLEAR(clear_module_state->__pyx_n_u_fortran);
  Py_CLEAR(clear_module_state->__pyx_n_s_frequency_in_Hz);
  Py_CLEAR(clear_module_state->__pyx_n_u_full_path_and_prefix_to_dndz_nga);
  Py_CLEAR(clear_module_state->__pyx_n_u_full_path_to_dndz_gal);
  Py_CLEAR(clear_module_state->__pyx_n_u_full_path_to_source_dndz_gal);
  Py_CLEAR(clear_module_state->__pyx_n_u_galaxy_samples_list_num);
  Py_CLEAR(clear_module_state->__pyx_n_s_gamma);
  Py_CLEAR(clear_module_state->__pyx_n_s_gammaGNFW);
  Py_CLEAR(clear_module_state->__pyx_n_u_gamma_B12);
  Py_CLEAR(clear_module_state->__pyx_n_u_gamma_B16);
  Py_CLEAR(clear_module_state->__pyx_n_s_gamma_ggamma);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_geomspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_getData);
  Py_CLEAR(clear_module_state->__pyx_n_s_getLogger);
  Py_CLEAR(clear_module_state->__pyx_n_s_getM500_from_y0_H13);
  Py_CLEAR(clear_module_state->__pyx_n_s_getPLog10M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_1e6xdy_from_battaglia_pressu);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_1e6xdy_from_gnfw_pressure_at);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_Delta_c_of_Omega_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_Ez);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_H);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_H0_from_thetas);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_IA_of_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_N_centrals);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_N_satellites);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_Omega_m_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_Omega_m_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_Omega_r_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_P_delta_at_m_and_z_b12);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_Q_of_theta500);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_T10_alpha_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_arcmin_to_rad);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_background);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_bispectrum_f2_kernel);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_c200c_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_c200c_at_m_and_z_B13);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_c200c_at_m_and_z_D08);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_c200m_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_c200m_at_m_and_z_D08);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_c500c_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_c_delta_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_cib_Snu_z_and_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_comoving_volume);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_cov_N_N);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_current_derived_parameters);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_custom1_bias_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_custom1_profile_at_k_m_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_custom1_profile_at_x_m_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_cvir_of_mvir_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dA);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dA_z1z2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dcib0dz_at_z_and_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_delta_from_delta_def_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_delta_mean_from_delta_crit_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dkappacmbdz_at_l_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dlnsigma_dlnR_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dndlnM_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dndlnm);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dndzdq);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dydz_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_dydzdlnm_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_effective_f_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_f_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_f_free);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_f_of_sigma_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_f_tinker08_at_nu_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_f_tinker10_at_nu_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_fftlog_ComputeXiLMsloz);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_first_order_bias_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_first_order_bias_at_z_and_m_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_first_order_bias_at_z_and_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_fstar_of_m_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_galaxy_number_counts);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_gas_density_profile_at_k_M_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_gas_pressure_2h_at_r_and_m_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_b16_200);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_bcm_200);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_gnu_tsz_of_nu_in_ghz);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_hmf_counter_term_b1min_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_hmf_counter_term_b2min_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_hmf_counter_term_nmin_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_hubble);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_lensing_noise_at_ell);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m200c_to_m200m_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m200c_to_m500c_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m200m_to_m200c_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m200m_to_m500c_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m500c_to_m200c_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m500c_to_m200m_at_z_and_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m_nfw);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_m_to_xout_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_mass_profile_at_x_M_z_nfw_20);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_matter_bispectrum_at_z_effec);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_matter_bispectrum_at_z_effec_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_matter_bispectrum_at_z_effec_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_matter_bispectrum_at_z_tree);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_mcmc_parameters);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_mean_galaxy_bias_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_mean_y);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_mu_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_n5k_cl_K1_at_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_n5k_pk_at_z_and_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_n5k_z_of_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_ng_bar_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_nl_index_at_z_and_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_nl_index_at_z_and_k_no_wiggl);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_normalization_gas_density_pr);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_nu_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_params_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_perturbations);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_and_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_cb_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_cb_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_lin_at_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_lin_at_k_and_z_fast);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_nonlin_at_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pk_nonlin_at_k_and_z_fast);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pkl);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pkl_at_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pkl_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pkl_locals_compute_pkl);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pkl_locals_handle_combinatio);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pkl_reconstructed_from_fftlo);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pkl_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pknl);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pknl_at_k_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pknl_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pknl_locals_compute_pknl);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pknl_locals_handle_combinati);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pknl_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_planck_sigma_at_theta500);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pressure_P_over_P_delta_at_x);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_pressure_P_over_P_delta_at_x_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_primordial);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_r_delta_of_m_delta_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_rad_to_arcmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_radial_kernel_W_custom1_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_radial_kernel_W_galaxy_lensi);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_radial_kernel_W_galaxy_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_rho_2h_at_r_and_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_rho_crit_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_rvir_of_m200c_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_rvir_of_mvir_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_scale_dependent_bias_at_z_an);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_second_order_bias_at_z_and_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_sigma8_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_sigma_at_r_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_sigma_at_z_and_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_source_galaxy_number_counts);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_szcounts_dndzdq_at_z_q);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_szcountsz_sigma_at_theta_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_te_of_m500c_at_z_arnaud);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_te_of_m500c_at_z_lee);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_thermodynamics);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_theta_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_truncated_nfw_profile_at_z_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_truncated_nfw_profile_at_z_k_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_ttg_bispectrum_at_z_effectiv);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_ttg_bispectrum_at_z_tree_lev);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_uk);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_uk_nfw);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_uk_nfw_locals_compute_profil);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_uk_nfw_locals_handle_combina);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_unwise_m_min_cut_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_upp_from_gnfw_pressure_at_x);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_volume_dVdzdOmega_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_vrms2_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_y_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_yc_at_m_and_z_H13);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_z_of_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_z_of_chi_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_kp_u_got);
  Py_CLEAR(clear_module_state->__pyx_kp_u_got_differing_extents_in_dimensi);
  Py_CLEAR(clear_module_state->__pyx_n_s_h);
  Py_CLEAR(clear_module_state->__pyx_n_u_h);
  Py_CLEAR(clear_module_state->__pyx_n_s_h_P);
  Py_CLEAR(clear_module_state->__pyx_n_s_h_units);
  Py_CLEAR(clear_module_state->__pyx_n_s_handle_combinations);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_flags);
  Py_CLEAR(clear_module_state->__pyx_kp_u_hf);
  Py_CLEAR(clear_module_state->__pyx_n_u_hf_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_hmf);
  Py_CLEAR(clear_module_state->__pyx_n_s_hplanck);
  Py_CLEAR(clear_module_state->__pyx_n_u_hsv);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_ic_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_ic_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_ic_num);
  Py_CLEAR(clear_module_state->__pyx_n_s_ic_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_id_nu1);
  Py_CLEAR(clear_module_state->__pyx_n_s_id_nu2);
  Py_CLEAR(clear_module_state->__pyx_n_u_ignore);
  Py_CLEAR(clear_module_state->__pyx_n_s_imp);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_M_bins);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_M_bins_prime);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_ic);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_l_prime);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_m_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_md);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_mu);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_pk);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_tau);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_x);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_y);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_index_z_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initial);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_u_input);
  Py_CLEAR(clear_module_state->__pyx_n_s_intUpper);
  Py_CLEAR(clear_module_state->__pyx_n_s_integrate);
  Py_CLEAR(clear_module_state->__pyx_n_s_integrate_only);
  Py_CLEAR(clear_module_state->__pyx_n_s_interp1d);
  Py_CLEAR(clear_module_state->__pyx_n_s_interpolate);
  Py_CLEAR(clear_module_state->__pyx_n_s_ionization_fraction);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_not_implemented_yet);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_not_implemented_yet_Availabl);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_isscalar);
  Py_CLEAR(clear_module_state->__pyx_n_s_issuperset);
  Py_CLEAR(clear_module_state->__pyx_n_u_isw_auto);
  Py_CLEAR(clear_module_state->__pyx_n_u_isw_lens);
  Py_CLEAR(clear_module_state->__pyx_n_u_isw_tsz);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_itemsize);
  Py_CLEAR(clear_module_state->__pyx_kp_s_itemsize_0_for_cython_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_j);
  Py_CLEAR(clear_module_state->__pyx_n_s_join);
  Py_CLEAR(clear_module_state->__pyx_n_s_k);
  Py_CLEAR(clear_module_state->__pyx_n_u_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_k1);
  Py_CLEAR(clear_module_state->__pyx_n_s_k1_in_h_over_Mpc);
  Py_CLEAR(clear_module_state->__pyx_n_s_k2);
  Py_CLEAR(clear_module_state->__pyx_n_s_k2_in_h_over_Mpc);
  Py_CLEAR(clear_module_state->__pyx_n_s_k3);
  Py_CLEAR(clear_module_state->__pyx_n_s_k3_in_h_over_Mpc);
  Py_CLEAR(clear_module_state->__pyx_n_s_kB);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_B);
  Py_CLEAR(clear_module_state->__pyx_kp_u_k_and_z_must_be_broadcastable_to);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_asked);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_eq);
  Py_CLEAR(clear_module_state->__pyx_n_u_k_eq);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_input);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_nl);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_nl_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_k_vals);
  Py_CLEAR(clear_module_state->__pyx_n_s_kars);
  Py_CLEAR(clear_module_state->__pyx_n_s_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_kh);
  Py_CLEAR(clear_module_state->__pyx_n_s_kh_input);
  Py_CLEAR(clear_module_state->__pyx_n_s_kh_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_kh_vals);
  Py_CLEAR(clear_module_state->__pyx_n_s_kind);
  Py_CLEAR(clear_module_state->__pyx_n_s_kk);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ksi_V_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_l);
  Py_CLEAR(clear_module_state->__pyx_n_u_lCl);
  Py_CLEAR(clear_module_state->__pyx_n_s_l_asked);
  Py_CLEAR(clear_module_state->__pyx_n_s_l_max_flag);
  Py_CLEAR(clear_module_state->__pyx_n_u_l_max_lss);
  Py_CLEAR(clear_module_state->__pyx_n_u_l_max_scalars);
  Py_CLEAR(clear_module_state->__pyx_n_s_last_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_lcl);
  Py_CLEAR(clear_module_state->__pyx_n_s_lcp);
  Py_CLEAR(clear_module_state->__pyx_n_s_lensed_cl);
  Py_CLEAR(clear_module_state->__pyx_n_u_lensing);
  Py_CLEAR(clear_module_state->__pyx_kp_u_lensing_term);
  Py_CLEAR(clear_module_state->__pyx_n_s_level);
  Py_CLEAR(clear_module_state->__pyx_kp_u_levelname_s_message_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_levels);
  Py_CLEAR(clear_module_state->__pyx_n_s_likelihood_mode);
  Py_CLEAR(clear_module_state->__pyx_n_u_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_linspace);
  Py_CLEAR(clear_module_state->__pyx_n_u_ll);
  Py_CLEAR(clear_module_state->__pyx_n_s_lmax);
  Py_CLEAR(clear_module_state->__pyx_n_s_lmaxR);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ln10_10_A_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_ln1pzc);
  Py_CLEAR(clear_module_state->__pyx_n_s_lna);
  Py_CLEAR(clear_module_state->__pyx_n_s_load_n5k_cl_K1);
  Py_CLEAR(clear_module_state->__pyx_n_s_load_n5k_pk_zk);
  Py_CLEAR(clear_module_state->__pyx_n_s_load_n5k_z_of_chi);
  Py_CLEAR(clear_module_state->__pyx_n_s_loadtxt);
  Py_CLEAR(clear_module_state->__pyx_n_s_log);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10M);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10M500c_zk);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10Ms);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10x_num);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10xmax_mcfit);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10xmin_mcfit);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10y_center);
  Py_CLEAR(clear_module_state->__pyx_n_u_log10y_center);
  Py_CLEAR(clear_module_state->__pyx_n_s_log10y_edges);
  Py_CLEAR(clear_module_state->__pyx_n_u_log10y_edges);
  Py_CLEAR(clear_module_state->__pyx_n_u_logA);
  Py_CLEAR(clear_module_state->__pyx_n_s_logA_fast);
  Py_CLEAR(clear_module_state->__pyx_n_s_log_y0);
  Py_CLEAR(clear_module_state->__pyx_n_s_log_y0Err);
  Py_CLEAR(clear_module_state->__pyx_n_s_log_y0pred);
  Py_CLEAR(clear_module_state->__pyx_n_s_logging);
  Py_CLEAR(clear_module_state->__pyx_n_s_loglike);
  Py_CLEAR(clear_module_state->__pyx_n_u_loglike);
  Py_CLEAR(clear_module_state->__pyx_n_s_logspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_lowring);
  Py_CLEAR(clear_module_state->__pyx_n_s_lum_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_luminosity_distance);
  Py_CLEAR(clear_module_state->__pyx_n_s_m);
  Py_CLEAR(clear_module_state->__pyx_n_u_mPk);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_asked);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_broadcasted);
  Py_CLEAR(clear_module_state->__pyx_kp_u_m_d_a_zA_Z__to_m_d_a_zA_Z);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_delta);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_flattened);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_input);
  Py_CLEAR(clear_module_state->__pyx_kp_u_m_input_should_be_a_float_or_a_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_len);
  Py_CLEAR(clear_module_state->__pyx_n_u_m_ncdm);
  Py_CLEAR(clear_module_state->__pyx_n_u_m_ncdm_in_eV);
  Py_CLEAR(clear_module_state->__pyx_n_u_m_ncdm_tot);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_vals);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_u_mass_bin_edges);
  Py_CLEAR(clear_module_state->__pyx_n_u_mass_function);
  Py_CLEAR(clear_module_state->__pyx_kp_u_mass_function_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_match);
  Py_CLEAR(clear_module_state->__pyx_n_s_math);
  Py_CLEAR(clear_module_state->__pyx_n_s_max);
  Py_CLEAR(clear_module_state->__pyx_n_s_maxIndex);
  Py_CLEAR(clear_module_state->__pyx_n_s_mcfit);
  Py_CLEAR(clear_module_state->__pyx_n_s_mcfitx);
  Py_CLEAR(clear_module_state->__pyx_n_s_mcmc_parameters);
  Py_CLEAR(clear_module_state->__pyx_n_s_mcut);
  Py_CLEAR(clear_module_state->__pyx_n_u_mcut);
  Py_CLEAR(clear_module_state->__pyx_n_u_mcut_B12);
  Py_CLEAR(clear_module_state->__pyx_n_s_me);
  Py_CLEAR(clear_module_state->__pyx_n_s_memview);
  Py_CLEAR(clear_module_state->__pyx_n_s_message);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_min);
  Py_CLEAR(clear_module_state->__pyx_n_s_minIndex);
  Py_CLEAR(clear_module_state->__pyx_n_u_minimal);
  Py_CLEAR(clear_module_state->__pyx_n_s_mm);
  Py_CLEAR(clear_module_state->__pyx_n_u_mnu);
  Py_CLEAR(clear_module_state->__pyx_n_s_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro_entries);
  Py_CLEAR(clear_module_state->__pyx_n_s_mu_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_n);
  Py_CLEAR(clear_module_state->__pyx_n_u_n5k);
  Py_CLEAR(clear_module_state->__pyx_n_u_nCl);
  Py_CLEAR(clear_module_state->__pyx_n_u_n_e);
  Py_CLEAR(clear_module_state->__pyx_n_s_n_s);
  Py_CLEAR(clear_module_state->__pyx_n_u_n_s);
  Py_CLEAR(clear_module_state->__pyx_n_u_n_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_names);
  Py_CLEAR(clear_module_state->__pyx_n_s_ndim);
  Py_CLEAR(clear_module_state->__pyx_n_u_ndim_masses);
  Py_CLEAR(clear_module_state->__pyx_n_u_ndim_redshifts);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_newaxis);
  Py_CLEAR(clear_module_state->__pyx_n_u_nfw);
  Py_CLEAR(clear_module_state->__pyx_n_s_ngtm);
  Py_CLEAR(clear_module_state->__pyx_n_s_nl);
  Py_CLEAR(clear_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_CLEAR(clear_module_state->__pyx_n_s_nofail);
  Py_CLEAR(clear_module_state->__pyx_n_s_non_class_sz_keys);
  Py_CLEAR(clear_module_state->__pyx_n_u_non_linear);
  Py_CLEAR(clear_module_state->__pyx_n_s_non_linear_check);
  Py_CLEAR(clear_module_state->__pyx_n_u_none);
  Py_CLEAR(clear_module_state->__pyx_n_u_nonlin);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear);
  Py_CLEAR(clear_module_state->__pyx_n_u_nonlinear);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigma8_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp100);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp100_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigmaprime);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_sigmaprime_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_hmcode_window_nfw);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_scale);
  Py_CLEAR(clear_module_state->__pyx_n_s_nonlinear_scale_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_normalize);
  Py_CLEAR(clear_module_state->__pyx_n_s_np);
  Py_CLEAR(clear_module_state->__pyx_n_s_nq);
  Py_CLEAR(clear_module_state->__pyx_n_u_ns);
  Py_CLEAR(clear_module_state->__pyx_n_u_ntot);
  Py_CLEAR(clear_module_state->__pyx_n_s_nu);
  Py_CLEAR(clear_module_state->__pyx_n_u_nu);
  Py_CLEAR(clear_module_state->__pyx_n_s_nu1);
  Py_CLEAR(clear_module_state->__pyx_n_s_nu2);
  Py_CLEAR(clear_module_state->__pyx_n_s_nu_in_GHz);
  Py_CLEAR(clear_module_state->__pyx_n_s_nu_in_ghz);
  Py_CLEAR(clear_module_state->__pyx_n_s_num);
  Py_CLEAR(clear_module_state->__pyx_n_s_numberDensity);
  Py_CLEAR(clear_module_state->__pyx_n_s_number_of_titles);
  Py_CLEAR(clear_module_state->__pyx_n_s_numpy);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy__core_multiarray_failed_to);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy__core_umath_failed_to_impo);
  Py_CLEAR(clear_module_state->__pyx_n_s_nz);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_obsFreqGHz);
  Py_CLEAR(clear_module_state->__pyx_n_s_oldpars);
  Py_CLEAR(clear_module_state->__pyx_n_u_ombh2);
  Py_CLEAR(clear_module_state->__pyx_n_u_omch2);
  Py_CLEAR(clear_module_state->__pyx_n_s_omega);
  Py_CLEAR(clear_module_state->__pyx_n_s_omega_b);
  Py_CLEAR(clear_module_state->__pyx_n_u_omega_b);
  Py_CLEAR(clear_module_state->__pyx_n_u_omega_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_omega_cdm);
  Py_CLEAR(clear_module_state->__pyx_n_u_omega_cdm);
  Py_CLEAR(clear_module_state->__pyx_n_u_omega_mh2);
  Py_CLEAR(clear_module_state->__pyx_n_s_only_clustering_species);
  Py_CLEAR(clear_module_state->__pyx_n_s_other_class_sz_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_outf);
  Py_CLEAR(clear_module_state->__pyx_n_u_output);
  Py_CLEAR(clear_module_state->__pyx_n_s_output_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_output_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_output_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_p);
  Py_CLEAR(clear_module_state->__pyx_n_u_pCl);
  Py_CLEAR(clear_module_state->__pyx_n_s_pack);
  Py_CLEAR(clear_module_state->__pyx_n_s_params_for_emulators);
  Py_CLEAR(clear_module_state->__pyx_n_s_params_settings);
  Py_CLEAR(clear_module_state->__pyx_n_s_params_values_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_pars);
  Py_CLEAR(clear_module_state->__pyx_n_s_pars_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pars_check);
  Py_CLEAR(clear_module_state->__pyx_n_s_path_to_cosmopower_organization);
  Py_CLEAR(clear_module_state->__pyx_n_s_pattern1);
  Py_CLEAR(clear_module_state->__pyx_n_s_pattern2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pattern3);
  Py_CLEAR(clear_module_state->__pyx_n_s_pdict_to_update);
  Py_CLEAR(clear_module_state->__pyx_n_u_perturb);
  Py_CLEAR(clear_module_state->__pyx_n_u_phi_max);
  Py_CLEAR(clear_module_state->__pyx_n_u_phi_min);
  Py_CLEAR(clear_module_state->__pyx_n_s_pi);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_at_k_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_b_at_z_2h);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_bb_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_cb_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_em_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_gg_at_z_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_lin);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_lin_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_lin_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_linzmax);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_nonlin);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_tilt);
  Py_CLEAR(clear_module_state->__pyx_n_s_pk_unvectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_pknl_in_output);
  Py_CLEAR(clear_module_state->__pyx_n_s_pknl_key_value_checks);
  Py_CLEAR(clear_module_state->__pyx_n_u_poisson);
  Py_CLEAR(clear_module_state->__pyx_n_s_pop);
  Py_CLEAR(clear_module_state->__pyx_n_s_power);
  Py_CLEAR(clear_module_state->__pyx_n_u_pp);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_u_pressure_profile);
  Py_CLEAR(clear_module_state->__pyx_kp_u_pressure_profile_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_primordial);
  Py_CLEAR(clear_module_state->__pyx_n_u_primordial);
  Py_CLEAR(clear_module_state->__pyx_n_s_problem_flag);
  Py_CLEAR(clear_module_state->__pyx_n_s_problematic_parameters);
  Py_CLEAR(clear_module_state->__pyx_n_s_profile);
  Py_CLEAR(clear_module_state->__pyx_n_s_pvecback);
  Py_CLEAR(clear_module_state->__pyx_n_s_pvecthermo);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_Enum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_vtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_q);
  Py_CLEAR(clear_module_state->__pyx_n_s_q_arr);
  Py_CLEAR(clear_module_state->__pyx_n_s_q_max);
  Py_CLEAR(clear_module_state->__pyx_n_s_q_threshold);
  Py_CLEAR(clear_module_state->__pyx_n_s_qmax);
  Py_CLEAR(clear_module_state->__pyx_n_s_qobs_asked);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_r);
  Py_CLEAR(clear_module_state->__pyx_n_u_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_r200c);
  Py_CLEAR(clear_module_state->__pyx_n_u_r_0002);
  Py_CLEAR(clear_module_state->__pyx_n_s_r_asked);
  Py_CLEAR(clear_module_state->__pyx_n_s_r_delta);
  Py_CLEAR(clear_module_state->__pyx_n_u_ra_rec);
  Py_CLEAR(clear_module_state->__pyx_n_u_ra_rec_h);
  Py_CLEAR(clear_module_state->__pyx_n_u_ra_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_rates);
  Py_CLEAR(clear_module_state->__pyx_n_u_rates);
  Py_CLEAR(clear_module_state->__pyx_n_s_raw_cl);
  Py_CLEAR(clear_module_state->__pyx_n_s_rcl);
  Py_CLEAR(clear_module_state->__pyx_n_u_rd_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_redshift);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_register);
  Py_CLEAR(clear_module_state->__pyx_n_s_resetwarnings);
  Py_CLEAR(clear_module_state->__pyx_n_s_reshape);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_rho0_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_rho0_crit);
  Py_CLEAR(clear_module_state->__pyx_n_s_rho0_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_rhoc);
  Py_CLEAR(clear_module_state->__pyx_n_u_rs_d);
  Py_CLEAR(clear_module_state->__pyx_n_u_rs_d_h);
  Py_CLEAR(clear_module_state->__pyx_n_s_rs_drag);
  Py_CLEAR(clear_module_state->__pyx_n_u_rs_rec);
  Py_CLEAR(clear_module_state->__pyx_n_u_rs_rec_h);
  Py_CLEAR(clear_module_state->__pyx_n_u_rs_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_rv);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_sBBN_file);
  Py_CLEAR(clear_module_state->__pyx_kp_u_s_was_not_recognized_as_a_deriv);
  Py_CLEAR(clear_module_state->__pyx_n_s_sample_id);
  Py_CLEAR(clear_module_state->__pyx_n_u_scalar);
  Py_CLEAR(clear_module_state->__pyx_n_u_scale);
  Py_CLEAR(clear_module_state->__pyx_n_u_scale_dependent_bias);
  Py_CLEAR(clear_module_state->__pyx_n_s_scale_independent_growth_factor);
  Py_CLEAR(clear_module_state->__pyx_n_s_scale_independent_growth_factor_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_scipy);
  Py_CLEAR(clear_module_state->__pyx_n_s_scipy_interpolate);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_n_s_send);
  Py_CLEAR(clear_module_state->__pyx_n_s_sep);
  Py_CLEAR(clear_module_state->__pyx_n_s_set);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_default);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_verbosity);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_shape);
  Py_CLEAR(clear_module_state->__pyx_n_u_shear_calibration_m);
  Py_CLEAR(clear_module_state->__pyx_n_u_shotnoise);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_u_sigma8);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma8_Pcb);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma8_cb);
  Py_CLEAR(clear_module_state->__pyx_n_u_sigma8_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigmaM);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigmaT);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_8);
  Py_CLEAR(clear_module_state->__pyx_n_u_sigma_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_8_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_cb);
  Py_CLEAR(clear_module_state->__pyx_kp_u_sigma_cb_not_computed_by_CLASS_p);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_disp);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_disp_100);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_disp_100_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_disp_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_log10M);
  Py_CLEAR(clear_module_state->__pyx_n_u_sigma_log10M_HOD);
  Py_CLEAR(clear_module_state->__pyx_n_u_sigma_log10M_HOD_ngal);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_prime);
  Py_CLEAR(clear_module_state->__pyx_n_s_sigma_prime_cb);
  Py_CLEAR(clear_module_state->__pyx_n_s_simps);
  Py_CLEAR(clear_module_state->__pyx_n_s_sinh);
  Py_CLEAR(clear_module_state->__pyx_n_s_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_size_ic_data);
  Py_CLEAR(clear_module_state->__pyx_n_s_skip_background_and_thermo);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_background_and_thermo);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_chi);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_class_sz);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_cmb);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_hubble);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_input);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_pkl);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_pknl);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_sigma8_and_der);
  Py_CLEAR(clear_module_state->__pyx_n_u_skip_sigma8_at_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_specific_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_spectra);
  Py_CLEAR(clear_module_state->__pyx_n_u_spectra);
  Py_CLEAR(clear_module_state->__pyx_n_s_splev);
  Py_CLEAR(clear_module_state->__pyx_n_s_spline);
  Py_CLEAR(clear_module_state->__pyx_n_s_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_splrep);
  Py_CLEAR(clear_module_state->__pyx_n_s_sqrt);
  Py_CLEAR(clear_module_state->__pyx_n_s_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_step);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop);
  Py_CLEAR(clear_module_state->__pyx_n_s_str);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_direct);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_direct_or_indirect);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_indirect);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_strip);
  Py_CLEAR(clear_module_state->__pyx_n_s_struct);
  Py_CLEAR(clear_module_state->__pyx_n_s_struct_cleanup);
  Py_CLEAR(clear_module_state->__pyx_n_s_sum);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_suppress_warnings);
  Py_CLEAR(clear_module_state->__pyx_n_s_sys);
  Py_CLEAR(clear_module_state->__pyx_n_u_sz_cluster_counts);
  Py_CLEAR(clear_module_state->__pyx_n_u_sz_cluster_counts_fft);
  Py_CLEAR(clear_module_state->__pyx_n_u_sz_selection_function_skyfracs_f);
  Py_CLEAR(clear_module_state->__pyx_n_u_sz_selection_function_thetas_fil);
  Py_CLEAR(clear_module_state->__pyx_n_u_sz_selection_function_ylims_file);
  Py_CLEAR(clear_module_state->__pyx_n_u_sz_unbinned_cluster_counts);
  Py_CLEAR(clear_module_state->__pyx_n_s_szcat_snr);
  Py_CLEAR(clear_module_state->__pyx_n_u_szcat_snr);
  Py_CLEAR(clear_module_state->__pyx_n_s_szcat_z);
  Py_CLEAR(clear_module_state->__pyx_n_u_szcat_z);
  Py_CLEAR(clear_module_state->__pyx_n_u_szcount);
  Py_CLEAR(clear_module_state->__pyx_n_s_szcounts_ntot);
  Py_CLEAR(clear_module_state->__pyx_n_s_szcounts_ntot_rates_loglike);
  Py_CLEAR(clear_module_state->__pyx_n_s_szunbinned_loglike);
  Py_CLEAR(clear_module_state->__pyx_n_u_t2t2f);
  Py_CLEAR(clear_module_state->__pyx_n_u_tCl);
  Py_CLEAR(clear_module_state->__pyx_n_u_tabulate_rhob_xout_at_m_and_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_tanh);
  Py_CLEAR(clear_module_state->__pyx_n_s_tau);
  Py_CLEAR(clear_module_state->__pyx_n_u_tau);
  Py_CLEAR(clear_module_state->__pyx_n_u_tau_d);
  Py_CLEAR(clear_module_state->__pyx_n_u_tau_rec);
  Py_CLEAR(clear_module_state->__pyx_n_s_tau_reio);
  Py_CLEAR(clear_module_state->__pyx_n_u_tau_reio);
  Py_CLEAR(clear_module_state->__pyx_n_u_tau_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_tckP);
  Py_CLEAR(clear_module_state->__pyx_n_u_td);
  Py_CLEAR(clear_module_state->__pyx_n_u_te);
  Py_CLEAR(clear_module_state->__pyx_n_u_te_y_y);
  Py_CLEAR(clear_module_state->__pyx_n_u_tensor);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_u_teyy);
  Py_CLEAR(clear_module_state->__pyx_kp_u_the_s_spectrum_was_computed_unti);
  Py_CLEAR(clear_module_state->__pyx_n_s_thermodynamics);
  Py_CLEAR(clear_module_state->__pyx_n_u_thermodynamics);
  Py_CLEAR(clear_module_state->__pyx_n_u_theta);
  Py_CLEAR(clear_module_state->__pyx_n_s_theta500);
  Py_CLEAR(clear_module_state->__pyx_n_s_theta_500);
  Py_CLEAR(clear_module_state->__pyx_n_s_theta_arcmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_theta_mcfit);
  Py_CLEAR(clear_module_state->__pyx_n_s_theta_rad);
  Py_CLEAR(clear_module_state->__pyx_n_s_theta_s_100);
  Py_CLEAR(clear_module_state->__pyx_n_s_theta_star_100);
  Py_CLEAR(clear_module_state->__pyx_n_s_thetae);
  Py_CLEAR(clear_module_state->__pyx_n_u_thetas);
  Py_CLEAR(clear_module_state->__pyx_n_s_throw);
  Py_CLEAR(clear_module_state->__pyx_n_s_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_timesteps);
  Py_CLEAR(clear_module_state->__pyx_n_s_titles);
  Py_CLEAR(clear_module_state->__pyx_n_u_tl);
  Py_CLEAR(clear_module_state->__pyx_n_s_tllprime_sz);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmp);
  Py_CLEAR(clear_module_state->__pyx_n_s_tmpdict);
  Py_CLEAR(clear_module_state->__pyx_n_u_tp);
  Py_CLEAR(clear_module_state->__pyx_n_u_transfer);
  Py_CLEAR(clear_module_state->__pyx_n_s_transfers);
  Py_CLEAR(clear_module_state->__pyx_n_s_transforms);
  Py_CLEAR(clear_module_state->__pyx_n_s_trapz);
  Py_CLEAR(clear_module_state->__pyx_n_u_tt);
  Py_CLEAR(clear_module_state->__pyx_n_s_type);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unable_to_allocate_array_data);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unable_to_allocate_shape_and_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_units);
  Py_CLEAR(clear_module_state->__pyx_n_s_unpack);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_upper);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_pklin);
  Py_CLEAR(clear_module_state->__pyx_n_u_use_pknl_in_2hterms);
  Py_CLEAR(clear_module_state->__pyx_n_u_use_pknl_in_2hterms_IA_only);
  Py_CLEAR(clear_module_state->__pyx_n_s_v);
  Py_CLEAR(clear_module_state->__pyx_n_s_val);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_vec_theta);
  Py_CLEAR(clear_module_state->__pyx_n_u_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_vectorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_verbosity);
  Py_CLEAR(clear_module_state->__pyx_n_s_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_viewdictitems);
  Py_CLEAR(clear_module_state->__pyx_n_s_viewitems);
  Py_CLEAR(clear_module_state->__pyx_n_u_vrms2);
  Py_CLEAR(clear_module_state->__pyx_n_s_want_ee);
  Py_CLEAR(clear_module_state->__pyx_n_s_want_pp);
  Py_CLEAR(clear_module_state->__pyx_n_s_want_te);
  Py_CLEAR(clear_module_state->__pyx_n_s_want_tt);
  Py_CLEAR(clear_module_state->__pyx_n_s_warnings);
  Py_CLEAR(clear_module_state->__pyx_n_s_window_nfw);
  Py_CLEAR(clear_module_state->__pyx_n_s_x);
  Py_CLEAR(clear_module_state->__pyx_n_u_x);
  Py_CLEAR(clear_module_state->__pyx_n_s_x_asked);
  Py_CLEAR(clear_module_state->__pyx_n_u_x_outSZ);
  Py_CLEAR(clear_module_state->__pyx_n_s_x_out_custom1);
  Py_CLEAR(clear_module_state->__pyx_n_s_xc);
  Py_CLEAR(clear_module_state->__pyx_n_u_xc_B12);
  Py_CLEAR(clear_module_state->__pyx_n_u_xc_B16);
  Py_CLEAR(clear_module_state->__pyx_n_s_xe);
  Py_CLEAR(clear_module_state->__pyx_n_s_xi);
  Py_CLEAR(clear_module_state->__pyx_n_u_xi);
  Py_CLEAR(clear_module_state->__pyx_n_u_xi_idr);
  Py_CLEAR(clear_module_state->__pyx_n_s_xi_mcfit);
  Py_CLEAR(clear_module_state->__pyx_n_s_xout);
  Py_CLEAR(clear_module_state->__pyx_n_s_xrange);
  Py_CLEAR(clear_module_state->__pyx_n_s_y);
  Py_CLEAR(clear_module_state->__pyx_n_s_y0);
  Py_CLEAR(clear_module_state->__pyx_n_s_y0Err);
  Py_CLEAR(clear_module_state->__pyx_n_s_yp);
  Py_CLEAR(clear_module_state->__pyx_n_s_ystar);
  Py_CLEAR(clear_module_state->__pyx_n_s_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_z1);
  Py_CLEAR(clear_module_state->__pyx_n_s_z2);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_arr);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_asked);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_broadcasted);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_center);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_center);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_edges);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_edges);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_flattened);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_for_pk_hm);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_input);
  Py_CLEAR(clear_module_state->__pyx_kp_u_z_input_should_be_a_float_or_a_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_len);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_max);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_max_nonlinear);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_max_requested);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_min);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_of_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_of_tau);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_rec);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_reio);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_reio);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_size);
  Py_CLEAR(clear_module_state->__pyx_n_u_z_star);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_step);
  Py_CLEAR(clear_module_state->__pyx_n_s_z_vals);
  Py_CLEAR(clear_module_state->__pyx_n_s_zeros);
  Py_CLEAR(clear_module_state->__pyx_n_s_zi);
  Py_CLEAR(clear_module_state->__pyx_n_s_zmax);
  Py_CLEAR(clear_module_state->__pyx_n_s_zmin);
  Py_CLEAR(clear_module_state->__pyx_n_s_zp);
  Py_CLEAR(clear_module_state->__pyx_n_s_zpk);
  Py_CLEAR(clear_module_state->__pyx_float_0_);
  Py_CLEAR(clear_module_state->__pyx_float_1_);
  Py_CLEAR(clear_module_state->__pyx_float_2_);
  Py_CLEAR(clear_module_state->__pyx_float_3_);
  Py_CLEAR(clear_module_state->__pyx_float_4_);
  Py_CLEAR(clear_module_state->__pyx_float_5_);
  Py_CLEAR(clear_module_state->__pyx_float_0_0);
  Py_CLEAR(clear_module_state->__pyx_float_0_1);
  Py_CLEAR(clear_module_state->__pyx_float_0_5);
  Py_CLEAR(clear_module_state->__pyx_float_1_0);
  Py_CLEAR(clear_module_state->__pyx_float_10_);
  Py_CLEAR(clear_module_state->__pyx_float_1e9);
  Py_CLEAR(clear_module_state->__pyx_float_0_02);
  Py_CLEAR(clear_module_state->__pyx_float_0_04);
  Py_CLEAR(clear_module_state->__pyx_float_0_19);
  Py_CLEAR(clear_module_state->__pyx_float_0_29);
  Py_CLEAR(clear_module_state->__pyx_float_0_88);
  Py_CLEAR(clear_module_state->__pyx_float_100_);
  Py_CLEAR(clear_module_state->__pyx_float_18_1);
  Py_CLEAR(clear_module_state->__pyx_float_1e14);
  Py_CLEAR(clear_module_state->__pyx_float_1e16);
  Py_CLEAR(clear_module_state->__pyx_float_200_);
  Py_CLEAR(clear_module_state->__pyx_float_3_83);
  Py_CLEAR(clear_module_state->__pyx_float_4_35);
  Py_CLEAR(clear_module_state->__pyx_float_4_e3);
  Py_CLEAR(clear_module_state->__pyx_float_500_);
  Py_CLEAR(clear_module_state->__pyx_float_0_154);
  Py_CLEAR(clear_module_state->__pyx_float_0_415);
  Py_CLEAR(clear_module_state->__pyx_float_0_497);
  Py_CLEAR(clear_module_state->__pyx_float_0_731);
  Py_CLEAR(clear_module_state->__pyx_float_1_156);
  Py_CLEAR(clear_module_state->__pyx_float_148_0);
  Py_CLEAR(clear_module_state->__pyx_float_1eneg_10);
  Py_CLEAR(clear_module_state->__pyx_float_8_130);
  Py_CLEAR(clear_module_state->__pyx_float_0_0393);
  Py_CLEAR(clear_module_state->__pyx_float_0_3292);
  Py_CLEAR(clear_module_state->__pyx_float_0_6827);
  Py_CLEAR(clear_module_state->__pyx_float_0_9665);
  Py_CLEAR(clear_module_state->__pyx_float_1_0620);
  Py_CLEAR(clear_module_state->__pyx_float_1eneg_100);
  Py_CLEAR(clear_module_state->__pyx_float_5_4807);
  Py_CLEAR(clear_module_state->__pyx_float_0_00441);
  Py_CLEAR(clear_module_state->__pyx_float_0_022383);
  Py_CLEAR(clear_module_state->__pyx_float_2_61051eneg_18);
  Py_CLEAR(clear_module_state->__pyx_float_1_00000000e_12);
  Py_CLEAR(clear_module_state->__pyx_float_neg_2_);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_2);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_3);
  Py_CLEAR(clear_module_state->__pyx_float_neg_1_0);
  Py_CLEAR(clear_module_state->__pyx_float_neg_10_);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_03);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_66);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_025);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_758);
  Py_CLEAR(clear_module_state->__pyx_float_neg_0_00865);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_4);
  Py_CLEAR(clear_module_state->__pyx_int_5);
  Py_CLEAR(clear_module_state->__pyx_int_6);
  Py_CLEAR(clear_module_state->__pyx_int_7);
  Py_CLEAR(clear_module_state->__pyx_int_8);
  Py_CLEAR(clear_module_state->__pyx_int_9);
  Py_CLEAR(clear_module_state->__pyx_int_10);
  Py_CLEAR(clear_module_state->__pyx_int_100);
  Py_CLEAR(clear_module_state->__pyx_int_200);
  Py_CLEAR(clear_module_state->__pyx_int_300);
  Py_CLEAR(clear_module_state->__pyx_int_500);
  Py_CLEAR(clear_module_state->__pyx_int_600);
  Py_CLEAR(clear_module_state->__pyx_int_1024);
  Py_CLEAR(clear_module_state->__pyx_int_10000);
  Py_CLEAR(clear_module_state->__pyx_int_20000);
  Py_CLEAR(clear_module_state->__pyx_int_112105877);
  Py_CLEAR(clear_module_state->__pyx_int_136983863);
  Py_CLEAR(clear_module_state->__pyx_int_184977713);
  Py_CLEAR(clear_module_state->__pyx_int_10000000000);
  Py_CLEAR(clear_module_state->__pyx_int_0xde0b6b3a7640000);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_int_neg_4);
  Py_CLEAR(clear_module_state->__pyx_int_neg_6);
  Py_CLEAR(clear_module_state->__pyx_k__21);
  Py_CLEAR(clear_module_state->__pyx_slice__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__4);
  Py_CLEAR(clear_module_state->__pyx_tuple__8);
  Py_CLEAR(clear_module_state->__pyx_slice__44);
  Py_CLEAR(clear_module_state->__pyx_slice__47);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__16);
  Py_CLEAR(clear_module_state->__pyx_tuple__18);
  Py_CLEAR(clear_module_state->__pyx_tuple__19);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__25);
  Py_CLEAR(clear_module_state->__pyx_tuple__26);
  Py_CLEAR(clear_module_state->__pyx_tuple__27);
  Py_CLEAR(clear_module_state->__pyx_tuple__28);
  Py_CLEAR(clear_module_state->__pyx_tuple__29);
  Py_CLEAR(clear_module_state->__pyx_tuple__30);
  Py_CLEAR(clear_module_state->__pyx_tuple__31);
  Py_CLEAR(clear_module_state->__pyx_tuple__33);
  Py_CLEAR(clear_module_state->__pyx_tuple__34);
  Py_CLEAR(clear_module_state->__pyx_tuple__38);
  Py_CLEAR(clear_module_state->__pyx_tuple__40);
  Py_CLEAR(clear_module_state->__pyx_tuple__42);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__45);
  Py_CLEAR(clear_module_state->__pyx_tuple__48);
  Py_CLEAR(clear_module_state->__pyx_tuple__49);
  Py_CLEAR(clear_module_state->__pyx_tuple__50);
  Py_CLEAR(clear_module_state->__pyx_tuple__51);
  Py_CLEAR(clear_module_state->__pyx_tuple__52);
  Py_CLEAR(clear_module_state->__pyx_tuple__53);
  Py_CLEAR(clear_module_state->__pyx_tuple__54);
  Py_CLEAR(clear_module_state->__pyx_tuple__55);
  Py_CLEAR(clear_module_state->__pyx_tuple__56);
  Py_CLEAR(clear_module_state->__pyx_tuple__57);
  Py_CLEAR(clear_module_state->__pyx_tuple__58);
  Py_CLEAR(clear_module_state->__pyx_tuple__59);
  Py_CLEAR(clear_module_state->__pyx_tuple__60);
  Py_CLEAR(clear_module_state->__pyx_tuple__62);
  Py_CLEAR(clear_module_state->__pyx_tuple__64);
  Py_CLEAR(clear_module_state->__pyx_tuple__66);
  Py_CLEAR(clear_module_state->__pyx_tuple__67);
  Py_CLEAR(clear_module_state->__pyx_tuple__69);
  Py_CLEAR(clear_module_state->__pyx_tuple__71);
  Py_CLEAR(clear_module_state->__pyx_tuple__73);
  Py_CLEAR(clear_module_state->__pyx_tuple__75);
  Py_CLEAR(clear_module_state->__pyx_tuple__77);
  Py_CLEAR(clear_module_state->__pyx_tuple__78);
  Py_CLEAR(clear_module_state->__pyx_tuple__80);
  Py_CLEAR(clear_module_state->__pyx_tuple__82);
  Py_CLEAR(clear_module_state->__pyx_tuple__85);
  Py_CLEAR(clear_module_state->__pyx_tuple__88);
  Py_CLEAR(clear_module_state->__pyx_tuple__90);
  Py_CLEAR(clear_module_state->__pyx_tuple__92);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_tuple__95);
  Py_CLEAR(clear_module_state->__pyx_tuple__97);
  Py_CLEAR(clear_module_state->__pyx_tuple__99);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__102);
  Py_CLEAR(clear_module_state->__pyx_tuple__104);
  Py_CLEAR(clear_module_state->__pyx_tuple__106);
  Py_CLEAR(clear_module_state->__pyx_tuple__107);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_tuple__111);
  Py_CLEAR(clear_module_state->__pyx_tuple__113);
  Py_CLEAR(clear_module_state->__pyx_tuple__115);
  Py_CLEAR(clear_module_state->__pyx_tuple__117);
  Py_CLEAR(clear_module_state->__pyx_tuple__119);
  Py_CLEAR(clear_module_state->__pyx_tuple__121);
  Py_CLEAR(clear_module_state->__pyx_tuple__123);
  Py_CLEAR(clear_module_state->__pyx_tuple__125);
  Py_CLEAR(clear_module_state->__pyx_tuple__127);
  Py_CLEAR(clear_module_state->__pyx_tuple__129);
  Py_CLEAR(clear_module_state->__pyx_tuple__131);
  Py_CLEAR(clear_module_state->__pyx_tuple__133);
  Py_CLEAR(clear_module_state->__pyx_tuple__135);
  Py_CLEAR(clear_module_state->__pyx_tuple__138);
  Py_CLEAR(clear_module_state->__pyx_tuple__140);
  Py_CLEAR(clear_module_state->__pyx_tuple__141);
  Py_CLEAR(clear_module_state->__pyx_tuple__143);
  Py_CLEAR(clear_module_state->__pyx_tuple__145);
  Py_CLEAR(clear_module_state->__pyx_tuple__147);
  Py_CLEAR(clear_module_state->__pyx_tuple__149);
  Py_CLEAR(clear_module_state->__pyx_tuple__151);
  Py_CLEAR(clear_module_state->__pyx_tuple__156);
  Py_CLEAR(clear_module_state->__pyx_tuple__169);
  Py_CLEAR(clear_module_state->__pyx_tuple__172);
  Py_CLEAR(clear_module_state->__pyx_tuple__177);
  Py_CLEAR(clear_module_state->__pyx_tuple__179);
  Py_CLEAR(clear_module_state->__pyx_tuple__181);
  Py_CLEAR(clear_module_state->__pyx_tuple__183);
  Py_CLEAR(clear_module_state->__pyx_tuple__185);
  Py_CLEAR(clear_module_state->__pyx_tuple__187);
  Py_CLEAR(clear_module_state->__pyx_tuple__190);
  Py_CLEAR(clear_module_state->__pyx_tuple__192);
  Py_CLEAR(clear_module_state->__pyx_tuple__194);
  Py_CLEAR(clear_module_state->__pyx_tuple__196);
  Py_CLEAR(clear_module_state->__pyx_tuple__198);
  Py_CLEAR(clear_module_state->__pyx_tuple__202);
  Py_CLEAR(clear_module_state->__pyx_tuple__204);
  Py_CLEAR(clear_module_state->__pyx_tuple__206);
  Py_CLEAR(clear_module_state->__pyx_tuple__209);
  Py_CLEAR(clear_module_state->__pyx_tuple__211);
  Py_CLEAR(clear_module_state->__pyx_tuple__213);
  Py_CLEAR(clear_module_state->__pyx_tuple__217);
  Py_CLEAR(clear_module_state->__pyx_tuple__220);
  Py_CLEAR(clear_module_state->__pyx_tuple__227);
  Py_CLEAR(clear_module_state->__pyx_tuple__229);
  Py_CLEAR(clear_module_state->__pyx_tuple__261);
  Py_CLEAR(clear_module_state->__pyx_tuple__263);
  Py_CLEAR(clear_module_state->__pyx_tuple__265);
  Py_CLEAR(clear_module_state->__pyx_tuple__267);
  Py_CLEAR(clear_module_state->__pyx_tuple__269);
  Py_CLEAR(clear_module_state->__pyx_tuple__271);
  Py_CLEAR(clear_module_state->__pyx_tuple__273);
  Py_CLEAR(clear_module_state->__pyx_tuple__275);
  Py_CLEAR(clear_module_state->__pyx_tuple__277);
  Py_CLEAR(clear_module_state->__pyx_tuple__279);
  Py_CLEAR(clear_module_state->__pyx_tuple__283);
  Py_CLEAR(clear_module_state->__pyx_tuple__285);
  Py_CLEAR(clear_module_state->__pyx_tuple__290);
  Py_CLEAR(clear_module_state->__pyx_tuple__292);
  Py_CLEAR(clear_module_state->__pyx_tuple__295);
  Py_CLEAR(clear_module_state->__pyx_tuple__317);
  Py_CLEAR(clear_module_state->__pyx_tuple__320);
  Py_CLEAR(clear_module_state->__pyx_tuple__324);
  Py_CLEAR(clear_module_state->__pyx_tuple__326);
  Py_CLEAR(clear_module_state->__pyx_tuple__328);
  Py_CLEAR(clear_module_state->__pyx_tuple__330);
  Py_CLEAR(clear_module_state->__pyx_tuple__332);
  Py_CLEAR(clear_module_state->__pyx_tuple__335);
  Py_CLEAR(clear_module_state->__pyx_tuple__340);
  Py_CLEAR(clear_module_state->__pyx_tuple__342);
  Py_CLEAR(clear_module_state->__pyx_tuple__343);
  Py_CLEAR(clear_module_state->__pyx_tuple__345);
  Py_CLEAR(clear_module_state->__pyx_tuple__348);
  Py_CLEAR(clear_module_state->__pyx_tuple__350);
  Py_CLEAR(clear_module_state->__pyx_tuple__352);
  Py_CLEAR(clear_module_state->__pyx_tuple__354);
  Py_CLEAR(clear_module_state->__pyx_tuple__356);
  Py_CLEAR(clear_module_state->__pyx_tuple__358);
  Py_CLEAR(clear_module_state->__pyx_tuple__365);
  Py_CLEAR(clear_module_state->__pyx_tuple__374);
  Py_CLEAR(clear_module_state->__pyx_tuple__376);
  Py_CLEAR(clear_module_state->__pyx_tuple__378);
  Py_CLEAR(clear_module_state->__pyx_tuple__381);
  Py_CLEAR(clear_module_state->__pyx_tuple__383);
  Py_CLEAR(clear_module_state->__pyx_tuple__385);
  Py_CLEAR(clear_module_state->__pyx_tuple__387);
  Py_CLEAR(clear_module_state->__pyx_tuple__388);
  Py_CLEAR(clear_module_state->__pyx_tuple__393);
  Py_CLEAR(clear_module_state->__pyx_tuple__395);
  Py_CLEAR(clear_module_state->__pyx_tuple__396);
  Py_CLEAR(clear_module_state->__pyx_tuple__398);
  Py_CLEAR(clear_module_state->__pyx_tuple__399);
  Py_CLEAR(clear_module_state->__pyx_tuple__401);
  Py_CLEAR(clear_module_state->__pyx_tuple__402);
  Py_CLEAR(clear_module_state->__pyx_tuple__405);
  Py_CLEAR(clear_module_state->__pyx_tuple__407);
  Py_CLEAR(clear_module_state->__pyx_tuple__409);
  Py_CLEAR(clear_module_state->__pyx_tuple__410);
  Py_CLEAR(clear_module_state->__pyx_tuple__412);
  Py_CLEAR(clear_module_state->__pyx_tuple__414);
  Py_CLEAR(clear_module_state->__pyx_tuple__416);
  Py_CLEAR(clear_module_state->__pyx_tuple__417);
  Py_CLEAR(clear_module_state->__pyx_tuple__420);
  Py_CLEAR(clear_module_state->__pyx_tuple__422);
  Py_CLEAR(clear_module_state->__pyx_tuple__424);
  Py_CLEAR(clear_module_state->__pyx_tuple__427);
  Py_CLEAR(clear_module_state->__pyx_tuple__429);
  Py_CLEAR(clear_module_state->__pyx_tuple__433);
  Py_CLEAR(clear_module_state->__pyx_tuple__435);
  Py_CLEAR(clear_module_state->__pyx_tuple__437);
  Py_CLEAR(clear_module_state->__pyx_tuple__440);
  Py_CLEAR(clear_module_state->__pyx_tuple__444);
  Py_CLEAR(clear_module_state->__pyx_tuple__456);
  Py_CLEAR(clear_module_state->__pyx_tuple__458);
  Py_CLEAR(clear_module_state->__pyx_tuple__462);
  Py_CLEAR(clear_module_state->__pyx_tuple__464);
  Py_CLEAR(clear_module_state->__pyx_tuple__468);
  Py_CLEAR(clear_module_state->__pyx_tuple__470);
  Py_CLEAR(clear_module_state->__pyx_tuple__472);
  Py_CLEAR(clear_module_state->__pyx_tuple__474);
  Py_CLEAR(clear_module_state->__pyx_tuple__476);
  Py_CLEAR(clear_module_state->__pyx_tuple__478);
  Py_CLEAR(clear_module_state->__pyx_tuple__480);
  Py_CLEAR(clear_module_state->__pyx_tuple__482);
  Py_CLEAR(clear_module_state->__pyx_tuple__483);
  Py_CLEAR(clear_module_state->__pyx_tuple__486);
  Py_CLEAR(clear_module_state->__pyx_tuple__493);
  Py_CLEAR(clear_module_state->__pyx_tuple__497);
  Py_CLEAR(clear_module_state->__pyx_tuple__499);
  Py_CLEAR(clear_module_state->__pyx_tuple__504);
  Py_CLEAR(clear_module_state->__pyx_tuple__506);
  Py_CLEAR(clear_module_state->__pyx_tuple__507);
  Py_CLEAR(clear_module_state->__pyx_tuple__509);
  Py_CLEAR(clear_module_state->__pyx_tuple__511);
  Py_CLEAR(clear_module_state->__pyx_tuple__513);
  Py_CLEAR(clear_module_state->__pyx_tuple__516);
  Py_CLEAR(clear_module_state->__pyx_tuple__518);
  Py_CLEAR(clear_module_state->__pyx_tuple__519);
  Py_CLEAR(clear_module_state->__pyx_tuple__521);
  Py_CLEAR(clear_module_state->__pyx_tuple__524);
  Py_CLEAR(clear_module_state->__pyx_tuple__527);
  Py_CLEAR(clear_module_state->__pyx_tuple__530);
  Py_CLEAR(clear_module_state->__pyx_tuple__533);
  Py_CLEAR(clear_module_state->__pyx_tuple__536);
  Py_CLEAR(clear_module_state->__pyx_tuple__539);
  Py_CLEAR(clear_module_state->__pyx_tuple__542);
  Py_CLEAR(clear_module_state->__pyx_tuple__552);
  Py_CLEAR(clear_module_state->__pyx_codeobj__17);
  Py_CLEAR(clear_module_state->__pyx_codeobj__32);
  Py_CLEAR(clear_module_state->__pyx_codeobj__35);
  Py_CLEAR(clear_module_state->__pyx_codeobj__36);
  Py_CLEAR(clear_module_state->__pyx_codeobj__37);
  Py_CLEAR(clear_module_state->__pyx_codeobj__39);
  Py_CLEAR(clear_module_state->__pyx_codeobj__41);
  Py_CLEAR(clear_module_state->__pyx_codeobj__61);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__65);
  Py_CLEAR(clear_module_state->__pyx_codeobj__68);
  Py_CLEAR(clear_module_state->__pyx_codeobj__70);
  Py_CLEAR(clear_module_state->__pyx_codeobj__72);
  Py_CLEAR(clear_module_state->__pyx_codeobj__74);
  Py_CLEAR(clear_module_state->__pyx_codeobj__76);
  Py_CLEAR(clear_module_state->__pyx_codeobj__79);
  Py_CLEAR(clear_module_state->__pyx_codeobj__81);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__84);
  Py_CLEAR(clear_module_state->__pyx_codeobj__86);
  Py_CLEAR(clear_module_state->__pyx_codeobj__87);
  Py_CLEAR(clear_module_state->__pyx_codeobj__89);
  Py_CLEAR(clear_module_state->__pyx_codeobj__91);
  Py_CLEAR(clear_module_state->__pyx_codeobj__94);
  Py_CLEAR(clear_module_state->__pyx_codeobj__96);
  Py_CLEAR(clear_module_state->__pyx_codeobj__98);
  Py_CLEAR(clear_module_state->__pyx_codeobj__100);
  Py_CLEAR(clear_module_state->__pyx_codeobj__103);
  Py_CLEAR(clear_module_state->__pyx_codeobj__105);
  Py_CLEAR(clear_module_state->__pyx_codeobj__108);
  Py_CLEAR(clear_module_state->__pyx_codeobj__110);
  Py_CLEAR(clear_module_state->__pyx_codeobj__112);
  Py_CLEAR(clear_module_state->__pyx_codeobj__114);
  Py_CLEAR(clear_module_state->__pyx_codeobj__116);
  Py_CLEAR(clear_module_state->__pyx_codeobj__118);
  Py_CLEAR(clear_module_state->__pyx_codeobj__120);
  Py_CLEAR(clear_module_state->__pyx_codeobj__122);
  Py_CLEAR(clear_module_state->__pyx_codeobj__124);
  Py_CLEAR(clear_module_state->__pyx_codeobj__126);
  Py_CLEAR(clear_module_state->__pyx_codeobj__128);
  Py_CLEAR(clear_module_state->__pyx_codeobj__130);
  Py_CLEAR(clear_module_state->__pyx_codeobj__132);
  Py_CLEAR(clear_module_state->__pyx_codeobj__134);
  Py_CLEAR(clear_module_state->__pyx_codeobj__136);
  Py_CLEAR(clear_module_state->__pyx_codeobj__137);
  Py_CLEAR(clear_module_state->__pyx_codeobj__139);
  Py_CLEAR(clear_module_state->__pyx_codeobj__142);
  Py_CLEAR(clear_module_state->__pyx_codeobj__144);
  Py_CLEAR(clear_module_state->__pyx_codeobj__146);
  Py_CLEAR(clear_module_state->__pyx_codeobj__148);
  Py_CLEAR(clear_module_state->__pyx_codeobj__150);
  Py_CLEAR(clear_module_state->__pyx_codeobj__152);
  Py_CLEAR(clear_module_state->__pyx_codeobj__153);
  Py_CLEAR(clear_module_state->__pyx_codeobj__154);
  Py_CLEAR(clear_module_state->__pyx_codeobj__155);
  Py_CLEAR(clear_module_state->__pyx_codeobj__157);
  Py_CLEAR(clear_module_state->__pyx_codeobj__158);
  Py_CLEAR(clear_module_state->__pyx_codeobj__159);
  Py_CLEAR(clear_module_state->__pyx_codeobj__160);
  Py_CLEAR(clear_module_state->__pyx_codeobj__161);
  Py_CLEAR(clear_module_state->__pyx_codeobj__162);
  Py_CLEAR(clear_module_state->__pyx_codeobj__163);
  Py_CLEAR(clear_module_state->__pyx_codeobj__164);
  Py_CLEAR(clear_module_state->__pyx_codeobj__165);
  Py_CLEAR(clear_module_state->__pyx_codeobj__166);
  Py_CLEAR(clear_module_state->__pyx_codeobj__167);
  Py_CLEAR(clear_module_state->__pyx_codeobj__168);
  Py_CLEAR(clear_module_state->__pyx_codeobj__170);
  Py_CLEAR(clear_module_state->__pyx_codeobj__171);
  Py_CLEAR(clear_module_state->__pyx_codeobj__173);
  Py_CLEAR(clear_module_state->__pyx_codeobj__174);
  Py_CLEAR(clear_module_state->__pyx_codeobj__175);
  Py_CLEAR(clear_module_state->__pyx_codeobj__176);
  Py_CLEAR(clear_module_state->__pyx_codeobj__178);
  Py_CLEAR(clear_module_state->__pyx_codeobj__180);
  Py_CLEAR(clear_module_state->__pyx_codeobj__182);
  Py_CLEAR(clear_module_state->__pyx_codeobj__184);
  Py_CLEAR(clear_module_state->__pyx_codeobj__186);
  Py_CLEAR(clear_module_state->__pyx_codeobj__188);
  Py_CLEAR(clear_module_state->__pyx_codeobj__189);
  Py_CLEAR(clear_module_state->__pyx_codeobj__191);
  Py_CLEAR(clear_module_state->__pyx_codeobj__193);
  Py_CLEAR(clear_module_state->__pyx_codeobj__195);
  Py_CLEAR(clear_module_state->__pyx_codeobj__197);
  Py_CLEAR(clear_module_state->__pyx_codeobj__199);
  Py_CLEAR(clear_module_state->__pyx_codeobj__200);
  Py_CLEAR(clear_module_state->__pyx_codeobj__201);
  Py_CLEAR(clear_module_state->__pyx_codeobj__203);
  Py_CLEAR(clear_module_state->__pyx_codeobj__205);
  Py_CLEAR(clear_module_state->__pyx_codeobj__207);
  Py_CLEAR(clear_module_state->__pyx_codeobj__208);
  Py_CLEAR(clear_module_state->__pyx_codeobj__210);
  Py_CLEAR(clear_module_state->__pyx_codeobj__212);
  Py_CLEAR(clear_module_state->__pyx_codeobj__214);
  Py_CLEAR(clear_module_state->__pyx_codeobj__215);
  Py_CLEAR(clear_module_state->__pyx_codeobj__216);
  Py_CLEAR(clear_module_state->__pyx_codeobj__218);
  Py_CLEAR(clear_module_state->__pyx_codeobj__219);
  Py_CLEAR(clear_module_state->__pyx_codeobj__221);
  Py_CLEAR(clear_module_state->__pyx_codeobj__222);
  Py_CLEAR(clear_module_state->__pyx_codeobj__223);
  Py_CLEAR(clear_module_state->__pyx_codeobj__224);
  Py_CLEAR(clear_module_state->__pyx_codeobj__225);
  Py_CLEAR(clear_module_state->__pyx_codeobj__226);
  Py_CLEAR(clear_module_state->__pyx_codeobj__228);
  Py_CLEAR(clear_module_state->__pyx_codeobj__230);
  Py_CLEAR(clear_module_state->__pyx_codeobj__231);
  Py_CLEAR(clear_module_state->__pyx_codeobj__232);
  Py_CLEAR(clear_module_state->__pyx_codeobj__233);
  Py_CLEAR(clear_module_state->__pyx_codeobj__234);
  Py_CLEAR(clear_module_state->__pyx_codeobj__235);
  Py_CLEAR(clear_module_state->__pyx_codeobj__236);
  Py_CLEAR(clear_module_state->__pyx_codeobj__237);
  Py_CLEAR(clear_module_state->__pyx_codeobj__238);
  Py_CLEAR(clear_module_state->__pyx_codeobj__239);
  Py_CLEAR(clear_module_state->__pyx_codeobj__240);
  Py_CLEAR(clear_module_state->__pyx_codeobj__241);
  Py_CLEAR(clear_module_state->__pyx_codeobj__242);
  Py_CLEAR(clear_module_state->__pyx_codeobj__243);
  Py_CLEAR(clear_module_state->__pyx_codeobj__244);
  Py_CLEAR(clear_module_state->__pyx_codeobj__245);
  Py_CLEAR(clear_module_state->__pyx_codeobj__246);
  Py_CLEAR(clear_module_state->__pyx_codeobj__247);
  Py_CLEAR(clear_module_state->__pyx_codeobj__248);
  Py_CLEAR(clear_module_state->__pyx_codeobj__249);
  Py_CLEAR(clear_module_state->__pyx_codeobj__250);
  Py_CLEAR(clear_module_state->__pyx_codeobj__251);
  Py_CLEAR(clear_module_state->__pyx_codeobj__252);
  Py_CLEAR(clear_module_state->__pyx_codeobj__253);
  Py_CLEAR(clear_module_state->__pyx_codeobj__254);
  Py_CLEAR(clear_module_state->__pyx_codeobj__255);
  Py_CLEAR(clear_module_state->__pyx_codeobj__256);
  Py_CLEAR(clear_module_state->__pyx_codeobj__257);
  Py_CLEAR(clear_module_state->__pyx_codeobj__258);
  Py_CLEAR(clear_module_state->__pyx_codeobj__259);
  Py_CLEAR(clear_module_state->__pyx_codeobj__260);
  Py_CLEAR(clear_module_state->__pyx_codeobj__262);
  Py_CLEAR(clear_module_state->__pyx_codeobj__264);
  Py_CLEAR(clear_module_state->__pyx_codeobj__266);
  Py_CLEAR(clear_module_state->__pyx_codeobj__268);
  Py_CLEAR(clear_module_state->__pyx_codeobj__270);
  Py_CLEAR(clear_module_state->__pyx_codeobj__272);
  Py_CLEAR(clear_module_state->__pyx_codeobj__274);
  Py_CLEAR(clear_module_state->__pyx_codeobj__276);
  Py_CLEAR(clear_module_state->__pyx_codeobj__278);
  Py_CLEAR(clear_module_state->__pyx_codeobj__280);
  Py_CLEAR(clear_module_state->__pyx_codeobj__281);
  Py_CLEAR(clear_module_state->__pyx_codeobj__282);
  Py_CLEAR(clear_module_state->__pyx_codeobj__284);
  Py_CLEAR(clear_module_state->__pyx_codeobj__286);
  Py_CLEAR(clear_module_state->__pyx_codeobj__287);
  Py_CLEAR(clear_module_state->__pyx_codeobj__288);
  Py_CLEAR(clear_module_state->__pyx_codeobj__289);
  Py_CLEAR(clear_module_state->__pyx_codeobj__291);
  Py_CLEAR(clear_module_state->__pyx_codeobj__293);
  Py_CLEAR(clear_module_state->__pyx_codeobj__294);
  Py_CLEAR(clear_module_state->__pyx_codeobj__296);
  Py_CLEAR(clear_module_state->__pyx_codeobj__297);
  Py_CLEAR(clear_module_state->__pyx_codeobj__298);
  Py_CLEAR(clear_module_state->__pyx_codeobj__299);
  Py_CLEAR(clear_module_state->__pyx_codeobj__300);
  Py_CLEAR(clear_module_state->__pyx_codeobj__301);
  Py_CLEAR(clear_module_state->__pyx_codeobj__302);
  Py_CLEAR(clear_module_state->__pyx_codeobj__303);
  Py_CLEAR(clear_module_state->__pyx_codeobj__304);
  Py_CLEAR(clear_module_state->__pyx_codeobj__305);
  Py_CLEAR(clear_module_state->__pyx_codeobj__306);
  Py_CLEAR(clear_module_state->__pyx_codeobj__307);
  Py_CLEAR(clear_module_state->__pyx_codeobj__308);
  Py_CLEAR(clear_module_state->__pyx_codeobj__309);
  Py_CLEAR(clear_module_state->__pyx_codeobj__310);
  Py_CLEAR(clear_module_state->__pyx_codeobj__311);
  Py_CLEAR(clear_module_state->__pyx_codeobj__312);
  Py_CLEAR(clear_module_state->__pyx_codeobj__313);
  Py_CLEAR(clear_module_state->__pyx_codeobj__314);
  Py_CLEAR(clear_module_state->__pyx_codeobj__315);
  Py_CLEAR(clear_module_state->__pyx_codeobj__316);
  Py_CLEAR(clear_module_state->__pyx_codeobj__318);
  Py_CLEAR(clear_module_state->__pyx_codeobj__319);
  Py_CLEAR(clear_module_state->__pyx_codeobj__321);
  Py_CLEAR(clear_module_state->__pyx_codeobj__322);
  Py_CLEAR(clear_module_state->__pyx_codeobj__323);
  Py_CLEAR(clear_module_state->__pyx_codeobj__325);
  Py_CLEAR(clear_module_state->__pyx_codeobj__327);
  Py_CLEAR(clear_module_state->__pyx_codeobj__329);
  Py_CLEAR(clear_module_state->__pyx_codeobj__331);
  Py_CLEAR(clear_module_state->__pyx_codeobj__333);
  Py_CLEAR(clear_module_state->__pyx_codeobj__334);
  Py_CLEAR(clear_module_state->__pyx_codeobj__336);
  Py_CLEAR(clear_module_state->__pyx_codeobj__337);
  Py_CLEAR(clear_module_state->__pyx_codeobj__338);
  Py_CLEAR(clear_module_state->__pyx_codeobj__339);
  Py_CLEAR(clear_module_state->__pyx_codeobj__341);
  Py_CLEAR(clear_module_state->__pyx_codeobj__344);
  Py_CLEAR(clear_module_state->__pyx_codeobj__346);
  Py_CLEAR(clear_module_state->__pyx_codeobj__347);
  Py_CLEAR(clear_module_state->__pyx_codeobj__349);
  Py_CLEAR(clear_module_state->__pyx_codeobj__351);
  Py_CLEAR(clear_module_state->__pyx_codeobj__353);
  Py_CLEAR(clear_module_state->__pyx_codeobj__355);
  Py_CLEAR(clear_module_state->__pyx_codeobj__357);
  Py_CLEAR(clear_module_state->__pyx_codeobj__359);
  Py_CLEAR(clear_module_state->__pyx_codeobj__360);
  Py_CLEAR(clear_module_state->__pyx_codeobj__361);
  Py_CLEAR(clear_module_state->__pyx_codeobj__362);
  Py_CLEAR(clear_module_state->__pyx_codeobj__363);
  Py_CLEAR(clear_module_state->__pyx_codeobj__364);
  Py_CLEAR(clear_module_state->__pyx_codeobj__366);
  Py_CLEAR(clear_module_state->__pyx_codeobj__367);
  Py_CLEAR(clear_module_state->__pyx_codeobj__368);
  Py_CLEAR(clear_module_state->__pyx_codeobj__369);
  Py_CLEAR(clear_module_state->__pyx_codeobj__370);
  Py_CLEAR(clear_module_state->__pyx_codeobj__371);
  Py_CLEAR(clear_module_state->__pyx_codeobj__372);
  Py_CLEAR(clear_module_state->__pyx_codeobj__373);
  Py_CLEAR(clear_module_state->__pyx_codeobj__375);
  Py_CLEAR(clear_module_state->__pyx_codeobj__377);
  Py_CLEAR(clear_module_state->__pyx_codeobj__379);
  Py_CLEAR(clear_module_state->__pyx_codeobj__380);
  Py_CLEAR(clear_module_state->__pyx_codeobj__382);
  Py_CLEAR(clear_module_state->__pyx_codeobj__384);
  Py_CLEAR(clear_module_state->__pyx_codeobj__386);
  Py_CLEAR(clear_module_state->__pyx_codeobj__389);
  Py_CLEAR(clear_module_state->__pyx_codeobj__390);
  Py_CLEAR(clear_module_state->__pyx_codeobj__391);
  Py_CLEAR(clear_module_state->__pyx_codeobj__392);
  Py_CLEAR(clear_module_state->__pyx_codeobj__394);
  Py_CLEAR(clear_module_state->__pyx_codeobj__397);
  Py_CLEAR(clear_module_state->__pyx_codeobj__400);
  Py_CLEAR(clear_module_state->__pyx_codeobj__403);
  Py_CLEAR(clear_module_state->__pyx_codeobj__404);
  Py_CLEAR(clear_module_state->__pyx_codeobj__406);
  Py_CLEAR(clear_module_state->__pyx_codeobj__408);
  Py_CLEAR(clear_module_state->__pyx_codeobj__411);
  Py_CLEAR(clear_module_state->__pyx_codeobj__413);
  Py_CLEAR(clear_module_state->__pyx_codeobj__415);
  Py_CLEAR(clear_module_state->__pyx_codeobj__418);
  Py_CLEAR(clear_module_state->__pyx_codeobj__419);
  Py_CLEAR(clear_module_state->__pyx_codeobj__421);
  Py_CLEAR(clear_module_state->__pyx_codeobj__423);
  Py_CLEAR(clear_module_state->__pyx_codeobj__425);
  Py_CLEAR(clear_module_state->__pyx_codeobj__426);
  Py_CLEAR(clear_module_state->__pyx_codeobj__428);
  Py_CLEAR(clear_module_state->__pyx_codeobj__430);
  Py_CLEAR(clear_module_state->__pyx_codeobj__431);
  Py_CLEAR(clear_module_state->__pyx_codeobj__432);
  Py_CLEAR(clear_module_state->__pyx_codeobj__434);
  Py_CLEAR(clear_module_state->__pyx_codeobj__436);
  Py_CLEAR(clear_module_state->__pyx_codeobj__438);
  Py_CLEAR(clear_module_state->__pyx_codeobj__439);
  Py_CLEAR(clear_module_state->__pyx_codeobj__441);
  Py_CLEAR(clear_module_state->__pyx_codeobj__442);
  Py_CLEAR(clear_module_state->__pyx_codeobj__443);
  Py_CLEAR(clear_module_state->__pyx_codeobj__445);
  Py_CLEAR(clear_module_state->__pyx_codeobj__446);
  Py_CLEAR(clear_module_state->__pyx_codeobj__447);
  Py_CLEAR(clear_module_state->__pyx_codeobj__448);
  Py_CLEAR(clear_module_state->__pyx_codeobj__449);
  Py_CLEAR(clear_module_state->__pyx_codeobj__450);
  Py_CLEAR(clear_module_state->__pyx_codeobj__451);
  Py_CLEAR(clear_module_state->__pyx_codeobj__452);
  Py_CLEAR(clear_module_state->__pyx_codeobj__453);
  Py_CLEAR(clear_module_state->__pyx_codeobj__454);
  Py_CLEAR(clear_module_state->__pyx_codeobj__455);
  Py_CLEAR(clear_module_state->__pyx_codeobj__457);
  Py_CLEAR(clear_module_state->__pyx_codeobj__459);
  Py_CLEAR(clear_module_state->__pyx_codeobj__460);
  Py_CLEAR(clear_module_state->__pyx_codeobj__461);
  Py_CLEAR(clear_module_state->__pyx_codeobj__463);
  Py_CLEAR(clear_module_state->__pyx_codeobj__465);
  Py_CLEAR(clear_module_state->__pyx_codeobj__466);
  Py_CLEAR(clear_module_state->__pyx_codeobj__467);
  Py_CLEAR(clear_module_state->__pyx_codeobj__469);
  Py_CLEAR(clear_module_state->__pyx_codeobj__471);
  Py_CLEAR(clear_module_state->__pyx_codeobj__473);
  Py_CLEAR(clear_module_state->__pyx_codeobj__475);
  Py_CLEAR(clear_module_state->__pyx_codeobj__477);
  Py_CLEAR(clear_module_state->__pyx_codeobj__479);
  Py_CLEAR(clear_module_state->__pyx_codeobj__481);
  Py_CLEAR(clear_module_state->__pyx_codeobj__484);
  Py_CLEAR(clear_module_state->__pyx_codeobj__485);
  Py_CLEAR(clear_module_state->__pyx_codeobj__487);
  Py_CLEAR(clear_module_state->__pyx_codeobj__488);
  Py_CLEAR(clear_module_state->__pyx_codeobj__489);
  Py_CLEAR(clear_module_state->__pyx_codeobj__490);
  Py_CLEAR(clear_module_state->__pyx_codeobj__491);
  Py_CLEAR(clear_module_state->__pyx_codeobj__492);
  Py_CLEAR(clear_module_state->__pyx_codeobj__494);
  Py_CLEAR(clear_module_state->__pyx_codeobj__495);
  Py_CLEAR(clear_module_state->__pyx_codeobj__496);
  Py_CLEAR(clear_module_state->__pyx_codeobj__498);
  Py_CLEAR(clear_module_state->__pyx_codeobj__500);
  Py_CLEAR(clear_module_state->__pyx_codeobj__501);
  Py_CLEAR(clear_module_state->__pyx_codeobj__502);
  Py_CLEAR(clear_module_state->__pyx_codeobj__503);
  Py_CLEAR(clear_module_state->__pyx_codeobj__505);
  Py_CLEAR(clear_module_state->__pyx_codeobj__508);
  Py_CLEAR(clear_module_state->__pyx_codeobj__510);
  Py_CLEAR(clear_module_state->__pyx_codeobj__512);
  Py_CLEAR(clear_module_state->__pyx_codeobj__514);
  Py_CLEAR(clear_module_state->__pyx_codeobj__515);
  Py_CLEAR(clear_module_state->__pyx_codeobj__517);
  Py_CLEAR(clear_module_state->__pyx_codeobj__520);
  Py_CLEAR(clear_module_state->__pyx_codeobj__522);
  Py_CLEAR(clear_module_state->__pyx_codeobj__523);
  Py_CLEAR(clear_module_state->__pyx_codeobj__525);
  Py_CLEAR(clear_module_state->__pyx_codeobj__526);
  Py_CLEAR(clear_module_state->__pyx_codeobj__528);
  Py_CLEAR(clear_module_state->__pyx_codeobj__529);
  Py_CLEAR(clear_module_state->__pyx_codeobj__531);
  Py_CLEAR(clear_module_state->__pyx_codeobj__532);
  Py_CLEAR(clear_module_state->__pyx_codeobj__534);
  Py_CLEAR(clear_module_state->__pyx_codeobj__535);
  Py_CLEAR(clear_module_state->__pyx_codeobj__537);
  Py_CLEAR(clear_module_state->__pyx_codeobj__538);
  Py_CLEAR(clear_module_state->__pyx_codeobj__540);
  Py_CLEAR(clear_module_state->__pyx_codeobj__541);
  Py_CLEAR(clear_module_state->__pyx_codeobj__543);
  Py_CLEAR(clear_module_state->__pyx_codeobj__544);
  Py_CLEAR(clear_module_state->__pyx_codeobj__545);
  Py_CLEAR(clear_module_state->__pyx_codeobj__546);
  Py_CLEAR(clear_module_state->__pyx_codeobj__547);
  Py_CLEAR(clear_module_state->__pyx_codeobj__548);
  Py_CLEAR(clear_module_state->__pyx_codeobj__549);
  Py_CLEAR(clear_module_state->__pyx_codeobj__550);
  Py_CLEAR(clear_module_state->__pyx_codeobj__551);
  Py_CLEAR(clear_module_state->__pyx_codeobj__553);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_dtype);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flatiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_broadcast);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ndarray);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_generic);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_number);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_integer);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_inexact);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_floating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flexible);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_character);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ufunc);
  Py_VISIT(traverse_module_state->__pyx_ptype_9classy_sz_Class);
  Py_VISIT(traverse_module_state->__pyx_type_9classy_sz_Class);
  Py_VISIT(traverse_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings);
  Py_VISIT(traverse_module_state->__pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings);
  Py_VISIT(traverse_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast);
  Py_VISIT(traverse_module_state->__pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast);
  Py_VISIT(traverse_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_9classy_sz___pyx_scope_struct_2_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl);
  Py_VISIT(traverse_module_state->__pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl);
  Py_VISIT(traverse_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl);
  Py_VISIT(traverse_module_state->__pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl);
  Py_VISIT(traverse_module_state->__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw);
  Py_VISIT(traverse_module_state->__pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw);
  Py_VISIT(traverse_module_state->__pyx_array_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_array);
  Py_VISIT(traverse_module_state->__pyx_MemviewEnum_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_MemviewEnum);
  Py_VISIT(traverse_module_state->__pyx_memoryview_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_memoryview);
  Py_VISIT(traverse_module_state->__pyx_memoryviewslice_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_memoryviewslice);
  Py_VISIT(traverse_module_state->__pyx_kp_u_);
  Py_VISIT(traverse_module_state->__pyx_kp_u_100_theta_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_100_theta_star);
  Py_VISIT(traverse_module_state->__pyx_kp_u_1h);
  Py_VISIT(traverse_module_state->__pyx_kp_u_1h_2h_3h);
  Py_VISIT(traverse_module_state->__pyx_kp_u_1h_2h_hf_3h_covmat_lensing_te);
  Py_VISIT(traverse_module_state->__pyx_kp_u_1h_slow);
  Py_VISIT(traverse_module_state->__pyx_kp_u_2h);
  Py_VISIT(traverse_module_state->__pyx_kp_u_2h_slow);
  Py_VISIT(traverse_module_state->__pyx_kp_u_3h);
  Py_VISIT(traverse_module_state->__pyx_kp_u_3h_slow);
  Py_VISIT(traverse_module_state->__pyx_n_s_A);
  Py_VISIT(traverse_module_state->__pyx_n_u_A10_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_ASCII);
  Py_VISIT(traverse_module_state->__pyx_n_u_A_IA);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_P0);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_u_A_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_A_beta);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_cn);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_ir);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_u_A_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_rs);
  Py_VISIT(traverse_module_state->__pyx_n_u_A_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_s_fast);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_sn);
  Py_VISIT(traverse_module_state->__pyx_n_s_A_xc);
  Py_VISIT(traverse_module_state->__pyx_kp_s_All_dimensions_preceding_dimensi);
  Py_VISIT(traverse_module_state->__pyx_kp_u_All_inputs_should_be_floats_or_1);
  Py_VISIT(traverse_module_state->__pyx_n_u_As);
  Py_VISIT(traverse_module_state->__pyx_n_s_AssertionError);
  Py_VISIT(traverse_module_state->__pyx_n_s_B);
  Py_VISIT(traverse_module_state->__pyx_n_s_B_sz);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Buffer_view_does_not_expose_stri);
  Py_VISIT(traverse_module_state->__pyx_n_s_CRITICAL);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Can_only_compute_up_to_lmax_d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Can_only_create_a_buffer_that_is);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_assign_to_read_only_memor);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_create_writable_memory_vi);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_index_with_type);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_transpose_memoryview_with);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_A_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_A_cn);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_A_ir);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_A_rs);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_A_sn);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_B_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Hubble);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_M1SZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Neff);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Om_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega0_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega0_cdm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega0_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega0_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega_Lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Omega_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_Rho_crit_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_T_cmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class__check_task_dependency);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class__cumulativeNumberDensity);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class__fillparfile);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class__pars_check);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_age);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_angular_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_b_tty);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_b_yyy);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_baryon_temperature);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_bk_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_bk_ttg_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_calcFRel);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_calculate_pkl_fftlog_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_chi_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cib_monopole);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cib_shotnoise);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_IA_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_c1_gal);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_c1_gallens);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_c1_lens);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_c1_tSZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_c1c1);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_cib_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_custom1_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_ee);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_eg);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_gal_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_gal_gal_kcmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_galn_IA);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_galn_gallens);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_galn_galn);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_galn_lens);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_galn_tsz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_gg);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_ggamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_gm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kSZ_kSZ_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kSZ_kSZ_kcmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kSZ_kSZ_kg);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kg);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kg_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kg_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kg_kg);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kg_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_kk);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_km);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_ksz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_lens_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_lensmagn_gallens);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_lensmagn_tsz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_mm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_sz_at_nu_in_GHz_in_micr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_t2t2f);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_tSZ_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_te_y_y);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_y_kcmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_yg);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_ykg);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_cl_ym);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_compute);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_compute_class_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_compute_class_szfast);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_delta_def_custom1);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_density_cl);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Class_did_not_read_input_paramet);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_dl_isw_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_dndzdy_theoretical);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_effective_f_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_effective_galaxy_bias);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_empty);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_gamma_ggamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_getM500_from_y0_H13);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_getPLog10M);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_1e6xdy_from_battaglia);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_1e6xdy_from_gnfw_press);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_Delta_c_of_Omega_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_Ez);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_H);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_IA_of_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_N_centrals);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_N_satellites);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_Omega_m_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_Omega_m_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_Omega_r_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_P_delta_at_m_and_z_b12);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_T10_alpha_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_arcmin_to_rad);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_background);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_bispectrum_f2_kernel);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_c200c_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_c200c_at_m_and_z_B13);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_c200c_at_m_and_z_D08);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_c200m_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_c200m_at_m_and_z_D08);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_c500c_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_c_delta_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_cib_Snu_z_and_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_comoving_volume);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_cov_N_N);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_current_derived_parame);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_custom1_bias_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_custom1_profile_at_k_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_custom1_profile_at_x_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_cvir_of_mvir_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dA);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dA_z1z2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dcib0dz_at_z_and_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_delta_from_delta_def_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_delta_mean_from_delta);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dkappacmbdz_at_l_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dlnsigma_dlnR_at_z_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dndlnM_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dndlnm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dydz_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_dydzdlnm_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_effective_f_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_f_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_f_free);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_f_of_sigma_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_f_tinker08_at_nu_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_f_tinker10_at_nu_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_fftlog_ComputeXiLMsloz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_first_order_bias_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_first_order_bias_at_z_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_first_order_bias_at_z_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_fstar_of_m_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_galaxy_number_counts);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_gas_density_profile_at);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_gas_pressure_2h_at_r_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_b_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_gas_profile_at_x_M_z_n_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_gnu_tsz_of_nu_in_ghz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_hmf_counter_term_b1min);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_hmf_counter_term_b2min);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_hmf_counter_term_nmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_lensing_noise_at_ell);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m200c_to_m200m_at_z_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m200c_to_m500c_at_z_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m200m_to_m200c_at_z_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m200m_to_m500c_at_z_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m500c_to_m200c_at_z_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m500c_to_m200m_at_z_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m_nfw);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_m_to_xout_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_mass_profile_at_x_M_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_matter_bispectrum_at_z_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_mean_galaxy_bias_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_mean_y);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_mu_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_n5k_cl_K1_at_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_n5k_pk_at_z_and_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_n5k_z_of_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_ng_bar_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_nl_index_at_z_and_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_nl_index_at_z_and_k_no);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_normalization_gas_dens);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_nu_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_params_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_perturbations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_and_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_cb_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_cb_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_lin_at_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_lin_at_k_and_z_fast);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_nonlin_at_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pk_nonlin_at_k_and_z_f);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pkl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pkl_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pkl_reconstructed_from);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pkl_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pknl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pknl_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pknl_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_planck_sigma_at_theta5);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pressure_P_over_P_delt);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_pressure_P_over_P_delt_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_primordial);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_r_delta_of_m_delta_at);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_rad_to_arcmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_radial_kernel_W_custom);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_radial_kernel_W_galaxy);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_radial_kernel_W_galaxy_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_rho_2h_at_r_and_m_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_rho_crit_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_rvir_of_m200c_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_rvir_of_mvir_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_scale_dependent_bias_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_second_order_bias_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_sigma8_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_sigma_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_source_galaxy_number_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_szcounts_dndzdq_at_z_q);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_szcountsz_sigma_at_the);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_te_of_m500c_at_z_arnau);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_te_of_m500c_at_z_lee);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_thermodynamics);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_theta_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_truncated_nfw_profile);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_truncated_nfw_profile_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_ttg_bispectrum_at_z_ef);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_ttg_bispectrum_at_z_tr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_uk);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_uk_nfw);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_unwise_m_min_cut_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_upp_from_gnfw_pressure);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_volume_dVdzdOmega_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_vrms2_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_y_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_yc_at_m_and_z_H13);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_z_of_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_get_z_of_chi_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_h);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_ionization_fraction);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_k_eq);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_lensed_cl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_load_n5k_cl_K1);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_load_n5k_pk_zk);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_load_n5k_z_of_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_luminosity_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_n_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigma8_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmaprim);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_sigmaprim_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_hmcode_window_nf);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_scale);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_nonlinear_scale_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_omega_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_omega_cdm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_b_at_z_2h);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_bb_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_cb_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_em_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_gg_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_lin_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_nonlin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_tilt);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_pk_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_raw_cl);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_rho0_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_rho0_crit);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_rho0_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_rs_drag);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_scale_independent_growth_f);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_scale_independent_growth_f_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_set_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_sigma);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_sigma8_Pcb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_sigma8_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_sigmaM);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_sigma_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_struct_cleanup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_szcounts_ntot);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_szcounts_ntot_rates_loglik);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_szfast);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_szunbinned_loglike);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_tau_reio);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_theta_s_100);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_theta_star_100);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_tllprime_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_x_out_custom1);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_ystar);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_z_of_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_z_of_tau);
  Py_VISIT(traverse_module_state->__pyx_n_s_Class_z_reio);
  Py_VISIT(traverse_module_state->__pyx_n_s_CosmoComputationError);
  Py_VISIT(traverse_module_state->__pyx_n_s_CosmoError);
  Py_VISIT(traverse_module_state->__pyx_n_s_CosmoError___init);
  Py_VISIT(traverse_module_state->__pyx_n_s_CosmoError___str);
  Py_VISIT(traverse_module_state->__pyx_n_s_CosmoSevereError);
  Py_VISIT(traverse_module_state->__pyx_n_s_D);
  Py_VISIT(traverse_module_state->__pyx_n_s_DEBUG);
  Py_VISIT(traverse_module_state->__pyx_n_s_D_A);
  Py_VISIT(traverse_module_state->__pyx_n_s_Delta_c);
  Py_VISIT(traverse_module_state->__pyx_n_u_Deprecated);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Dimension_d_is_not_direct);
  Py_VISIT(traverse_module_state->__pyx_n_u_Dust_temperature_today_in_Kelvin);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dz);
  Py_VISIT(traverse_module_state->__pyx_n_s_Dzmax);
  Py_VISIT(traverse_module_state->__pyx_n_s_Eh);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ellipsis);
  Py_VISIT(traverse_module_state->__pyx_n_u_Emissivity_index_of_sed);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Empty_shape_tuple_for_cython_arr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Error_in_Class);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ez);
  Py_VISIT(traverse_module_state->__pyx_n_s_F);
  Py_VISIT(traverse_module_state->__pyx_n_s_G);
  Py_VISIT(traverse_module_state->__pyx_n_u_Gamma_0_nadm);
  Py_VISIT(traverse_module_state->__pyx_n_s_H);
  Py_VISIT(traverse_module_state->__pyx_n_u_H0);
  Py_VISIT(traverse_module_state->__pyx_n_s_H_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_H_over_c_in_h_over_Mpc_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Hankel);
  Py_VISIT(traverse_module_state->__pyx_n_s_Hubble);
  Py_VISIT(traverse_module_state->__pyx_n_u_I0);
  Py_VISIT(traverse_module_state->__pyx_n_s_INFO);
  Py_VISIT(traverse_module_state->__pyx_n_s_ImportError);
  Py_VISIT(traverse_module_state->__pyx_kp_u_In_order_to_get_pk_tilt_at_k_e_1);
  Py_VISIT(traverse_module_state->__pyx_kp_u_In_order_to_get_sigma_R_z_you_mu);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_IndexError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Index_out_of_bounds_axis_d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Indirect_dimensions_not_supporte);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Input_should_be_a_float_or_a_1D);
  Py_VISIT(traverse_module_state->__pyx_n_s_InterpolatedUnivariateSpline);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_mode_expected_c_or_fortr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_shape_in_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyError);
  Py_VISIT(traverse_module_state->__pyx_n_s_M);
  Py_VISIT(traverse_module_state->__pyx_n_u_M0_HOD_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_s_M1SZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_M1_prime);
  Py_VISIT(traverse_module_state->__pyx_n_u_M1_prime_HOD);
  Py_VISIT(traverse_module_state->__pyx_n_u_M1_prime_HOD_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_s_M500);
  Py_VISIT(traverse_module_state->__pyx_n_s_M500c_zk);
  Py_VISIT(traverse_module_state->__pyx_n_s_MF_extr);
  Py_VISIT(traverse_module_state->__pyx_n_s_MUpper);
  Py_VISIT(traverse_module_state->__pyx_n_s_M_halo);
  Py_VISIT(traverse_module_state->__pyx_n_u_M_max);
  Py_VISIT(traverse_module_state->__pyx_n_s_M_min);
  Py_VISIT(traverse_module_state->__pyx_n_u_M_min);
  Py_VISIT(traverse_module_state->__pyx_n_u_M_min_HOD);
  Py_VISIT(traverse_module_state->__pyx_n_u_M_min_HOD_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_s_MemoryError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_MemoryView_of_r_at_0x_x);
  Py_VISIT(traverse_module_state->__pyx_kp_s_MemoryView_of_r_object);
  Py_VISIT(traverse_module_state->__pyx_n_u_Most_efficient_halo_mass_in_Msun);
  Py_VISIT(traverse_module_state->__pyx_n_s_N);
  Py_VISIT(traverse_module_state->__pyx_n_u_N_dg);
  Py_VISIT(traverse_module_state->__pyx_n_u_N_ncdm);
  Py_VISIT(traverse_module_state->__pyx_n_s_N_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_u_N_ur);
  Py_VISIT(traverse_module_state->__pyx_n_s_Nc);
  Py_VISIT(traverse_module_state->__pyx_n_s_Nc_mean);
  Py_VISIT(traverse_module_state->__pyx_n_s_Neff);
  Py_VISIT(traverse_module_state->__pyx_n_u_Neff);
  Py_VISIT(traverse_module_state->__pyx_n_s_Nmcfit);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_Cl_computed);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_density_Cl_computed);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_lensed_Cl_computed);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_massive_neutrinos_You_must_us);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_power_spectrum_computed_In_or);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_power_spectrum_computed_In_or_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_No_power_spectrum_computed_You_m);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Normalisation_of_L___M_relation);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotImplementedError);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ns);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ntot);
  Py_VISIT(traverse_module_state->__pyx_n_s_Nz);
  Py_VISIT(traverse_module_state->__pyx_n_b_O);
  Py_VISIT(traverse_module_state->__pyx_n_s_Om_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega0_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega0_cdm);
  Py_VISIT(traverse_module_state->__pyx_n_u_Omega0_fld);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega0_k);
  Py_VISIT(traverse_module_state->__pyx_n_u_Omega0_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega0_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega_Lambda);
  Py_VISIT(traverse_module_state->__pyx_n_u_Omega_Lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega_b);
  Py_VISIT(traverse_module_state->__pyx_n_u_Omega_b);
  Py_VISIT(traverse_module_state->__pyx_n_u_Omega_c);
  Py_VISIT(traverse_module_state->__pyx_n_u_Omega_cdm);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega_m);
  Py_VISIT(traverse_module_state->__pyx_n_u_Omega_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_Omega_r);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_P);
  Py_VISIT(traverse_module_state->__pyx_n_s_P0GNFW);
  Py_VISIT(traverse_module_state->__pyx_n_u_P0GNFW);
  Py_VISIT(traverse_module_state->__pyx_n_u_P0_B12);
  Py_VISIT(traverse_module_state->__pyx_n_u_P13_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_P200);
  Py_VISIT(traverse_module_state->__pyx_n_s_PATH_TO_CLASS_SZ_DATA);
  Py_VISIT(traverse_module_state->__pyx_n_s_PArr);
  Py_VISIT(traverse_module_state->__pyx_n_s_PLog10M);
  Py_VISIT(traverse_module_state->__pyx_n_s_PLog10M_full);
  Py_VISIT(traverse_module_state->__pyx_kp_u_P_cb_not_computed_by_CLASS_proba);
  Py_VISIT(traverse_module_state->__pyx_kp_u_P_cb_not_computed_probably_becau);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_u_Power_law_index_of_SED_at_high_f);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Profile);
  Py_VISIT(traverse_module_state->__pyx_n_s_Py0GivenM);
  Py_VISIT(traverse_module_state->__pyx_n_s_Pz);
  Py_VISIT(traverse_module_state->__pyx_n_s_QF);
  Py_VISIT(traverse_module_state->__pyx_n_s_R);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Raised_when_Class_could_not_com);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Raised_when_Class_failed_to_und);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Redshift_evolution_of_L___M_norm);
  Py_VISIT(traverse_module_state->__pyx_n_u_Redshift_evolution_of_dust_tempe);
  Py_VISIT(traverse_module_state->__pyx_n_s_Rho_crit_0);
  Py_VISIT(traverse_module_state->__pyx_n_u_SZ_cat_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_Sequence);
  Py_VISIT(traverse_module_state->__pyx_n_u_Size_of_halo_masses_sourcing_CIB);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Step_may_not_be_zero_axis_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_Stw);
  Py_VISIT(traverse_module_state->__pyx_kp_b_T);
  Py_VISIT(traverse_module_state->__pyx_n_s_TCMB);
  Py_VISIT(traverse_module_state->__pyx_n_s_TKelvin);
  Py_VISIT(traverse_module_state->__pyx_n_s_T_cmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_T_ll_arr);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tcmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tcmb_gNU);
  Py_VISIT(traverse_module_state->__pyx_n_u_Tinker_et_al_10_alpha_consistenc);
  Py_VISIT(traverse_module_state->__pyx_n_s_TkeV);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Type);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unable_to_convert_item_to_object);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Users_boris_Work_CLASS_SZ_SO_SZ);
  Py_VISIT(traverse_module_state->__pyx_n_u_V_0);
  Py_VISIT(traverse_module_state->__pyx_n_u_V_1);
  Py_VISIT(traverse_module_state->__pyx_n_u_V_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_V_3);
  Py_VISIT(traverse_module_state->__pyx_n_u_V_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s_View_MemoryView);
  Py_VISIT(traverse_module_state->__pyx_n_s_Wg);
  Py_VISIT(traverse_module_state->__pyx_n_s_X);
  Py_VISIT(traverse_module_state->__pyx_n_s_Xtw);
  Py_VISIT(traverse_module_state->__pyx_n_s_Y0);
  Py_VISIT(traverse_module_state->__pyx_n_s_Y1);
  Py_VISIT(traverse_module_state->__pyx_n_s_Y2);
  Py_VISIT(traverse_module_state->__pyx_n_s_Y3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Y4);
  Py_VISIT(traverse_module_state->__pyx_n_u_YHe);
  Py_VISIT(traverse_module_state->__pyx_kp_u_You_ask_classy_to_return_an_arra);
  Py_VISIT(traverse_module_state->__pyx_kp_u_You_ask_classy_to_return_an_arra_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_You_ask_classy_to_return_an_arra_3);
  Py_VISIT(traverse_module_state->__pyx_kp_b__10);
  Py_VISIT(traverse_module_state->__pyx_kp_u__10);
  Py_VISIT(traverse_module_state->__pyx_kp_b__11);
  Py_VISIT(traverse_module_state->__pyx_kp_b__12);
  Py_VISIT(traverse_module_state->__pyx_kp_u__13);
  Py_VISIT(traverse_module_state->__pyx_kp_u__14);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_kp_u__20);
  Py_VISIT(traverse_module_state->__pyx_kp_u__22);
  Py_VISIT(traverse_module_state->__pyx_n_s__3);
  Py_VISIT(traverse_module_state->__pyx_kp_u__46);
  Py_VISIT(traverse_module_state->__pyx_n_s__554);
  Py_VISIT(traverse_module_state->__pyx_kp_u__6);
  Py_VISIT(traverse_module_state->__pyx_kp_u__7);
  Py_VISIT(traverse_module_state->__pyx_kp_b__9);
  Py_VISIT(traverse_module_state->__pyx_n_u_a_dark);
  Py_VISIT(traverse_module_state->__pyx_n_s_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_age);
  Py_VISIT(traverse_module_state->__pyx_n_u_age);
  Py_VISIT(traverse_module_state->__pyx_n_s_allocate_buffer);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphaGNFW);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_c_P0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_c_P0_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_c_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_c_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_c_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_c_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_c_beta_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_c_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_c_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_c_xc);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_c_xc_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_m_P0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_m_P0_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_m_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_m_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_m_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_m_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_m_beta_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_m_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_m_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_m_xc);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_m_xc_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_s);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_s);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_s_HOD);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_s_HOD_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_z_P0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_z_P0_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_z_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_z_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_z_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_z_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_z_beta_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_z_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_z_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_s_alpha_z_xc);
  Py_VISIT(traverse_module_state->__pyx_n_u_alpha_z_xc_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphap_m_P0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphap_m_P0_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphap_m_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphap_m_alpha);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphap_m_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphap_m_beta);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphap_m_beta_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphap_m_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphap_m_rho0);
  Py_VISIT(traverse_module_state->__pyx_n_s_alphap_m_xc);
  Py_VISIT(traverse_module_state->__pyx_n_u_alphap_m_xc_B12);
  Py_VISIT(traverse_module_state->__pyx_kp_u_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_angular_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_append);
  Py_VISIT(traverse_module_state->__pyx_n_s_applyMFDebiasCorrection);
  Py_VISIT(traverse_module_state->__pyx_n_s_arange);
  Py_VISIT(traverse_module_state->__pyx_n_s_argmax);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_u_arr_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_asarray);
  Py_VISIT(traverse_module_state->__pyx_n_s_assume_sorted);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_atleast_1d);
  Py_VISIT(traverse_module_state->__pyx_n_s_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_b_tty);
  Py_VISIT(traverse_module_state->__pyx_n_s_b_yyy);
  Py_VISIT(traverse_module_state->__pyx_n_s_background);
  Py_VISIT(traverse_module_state->__pyx_n_u_background);
  Py_VISIT(traverse_module_state->__pyx_kp_u_bad_call);
  Py_VISIT(traverse_module_state->__pyx_n_s_baryon_temperature);
  Py_VISIT(traverse_module_state->__pyx_n_s_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_basicConfig);
  Py_VISIT(traverse_module_state->__pyx_n_u_bb);
  Py_VISIT(traverse_module_state->__pyx_kp_u_bbn_PRIMAT21_class_format_dat);
  Py_VISIT(traverse_module_state->__pyx_n_s_betaGNFW);
  Py_VISIT(traverse_module_state->__pyx_n_u_betaGNFW);
  Py_VISIT(traverse_module_state->__pyx_n_u_beta_B12);
  Py_VISIT(traverse_module_state->__pyx_n_u_beta_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_bh);
  Py_VISIT(traverse_module_state->__pyx_n_s_bk_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_bk_ttg_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_u_boundary);
  Py_VISIT(traverse_module_state->__pyx_n_s_bounds_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_broadcast_arrays);
  Py_VISIT(traverse_module_state->__pyx_kp_u_but_you_asked_a_l_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_c);
  Py_VISIT(traverse_module_state->__pyx_n_u_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_c500);
  Py_VISIT(traverse_module_state->__pyx_n_u_c500);
  Py_VISIT(traverse_module_state->__pyx_n_u_c_B12);
  Py_VISIT(traverse_module_state->__pyx_n_u_c_B16);
  Py_VISIT(traverse_module_state->__pyx_n_s_c_asked);
  Py_VISIT(traverse_module_state->__pyx_n_s_c_delta);
  Py_VISIT(traverse_module_state->__pyx_n_s_calcErrors);
  Py_VISIT(traverse_module_state->__pyx_n_s_calcFRel);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_cmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_hubble);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_pkl);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_pkl_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_pkl_fftlog_alphas);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_pknl);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_pknl_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_sigma);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_sigma8_and_der);
  Py_VISIT(traverse_module_state->__pyx_n_s_calculate_sigma8_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_u_camb);
  Py_VISIT(traverse_module_state->__pyx_n_s_check_task_dependency);
  Py_VISIT(traverse_module_state->__pyx_n_s_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_chi_star);
  Py_VISIT(traverse_module_state->__pyx_n_u_cib_Snu_file_nu);
  Py_VISIT(traverse_module_state->__pyx_n_u_cib_Snu_file_snu);
  Py_VISIT(traverse_module_state->__pyx_n_u_cib_Snu_file_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_cib_monopole);
  Py_VISIT(traverse_module_state->__pyx_n_s_cib_shotnoise);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_IA_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_c1_gal);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_c1_gallens);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_c1_lens);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_c1_tSZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_c1c1);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_cib_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_custom1_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_ee);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_eg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gIA);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_g_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_g_gamma_1h);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_g_gamma_2h);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_g_gamma_ell);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gal_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gal_gal_kcmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_galn_IA);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_galn_gallens);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_galn_galn);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_galn_lens);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_galn_tsz);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_ggamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gk);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gkg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gm);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_gy);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kSZ_kSZ_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kSZ_kSZ_kcmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kSZ_kSZ_kg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kg_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kg_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kg_kg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kg_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_kk);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_km);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_ksz);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_lens_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_lensmagn_gallens);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_lensmagn_tsz);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_md);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_md_ic);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_mkg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_mm);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_my);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_phi_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_t2t2f);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_tSZ_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_te_y_y);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_y_cib);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_y_kcmb);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_yg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_ykg);
  Py_VISIT(traverse_module_state->__pyx_n_s_cl_ym);
  Py_VISIT(traverse_module_state->__pyx_n_s_class);
  Py_VISIT(traverse_module_state->__pyx_n_u_class_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_10);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_11);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_12);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_13);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_4);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_5);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_6);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_7);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_8);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_auxiliary_files_includ_9);
  Py_VISIT(traverse_module_state->__pyx_kp_u_class_sz_class_sz);
  Py_VISIT(traverse_module_state->__pyx_n_u_class_sz_cosmo);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_sz_in_dict_output);
  Py_VISIT(traverse_module_state->__pyx_n_u_class_sz_integrate);
  Py_VISIT(traverse_module_state->__pyx_kp_s_class_sz_python_classy_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_u_class_sz_tabulate);
  Py_VISIT(traverse_module_state->__pyx_n_s_classy_sz);
  Py_VISIT(traverse_module_state->__pyx_n_u_classy_sz_verbose);
  Py_VISIT(traverse_module_state->__pyx_n_s_classy_szfast);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_cls);
  Py_VISIT(traverse_module_state->__pyx_n_s_cltot);
  Py_VISIT(traverse_module_state->__pyx_n_s_cltotfunc);
  Py_VISIT(traverse_module_state->__pyx_n_s_clusterLogM500);
  Py_VISIT(traverse_module_state->__pyx_n_s_clusterLogM500Max);
  Py_VISIT(traverse_module_state->__pyx_n_s_clusterLogM500Min);
  Py_VISIT(traverse_module_state->__pyx_n_s_clusterM500);
  Py_VISIT(traverse_module_state->__pyx_n_s_clusterM500MinusErr);
  Py_VISIT(traverse_module_state->__pyx_n_s_clusterM500PlusErr);
  Py_VISIT(traverse_module_state->__pyx_n_s_cnew);
  Py_VISIT(traverse_module_state->__pyx_n_s_collections);
  Py_VISIT(traverse_module_state->__pyx_kp_s_collections_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_compile);
  Py_VISIT(traverse_module_state->__pyx_n_s_compute);
  Py_VISIT(traverse_module_state->__pyx_n_s_compute_class_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_compute_class_szfast);
  Py_VISIT(traverse_module_state->__pyx_n_s_compute_class_szfast_locals_gene);
  Py_VISIT(traverse_module_state->__pyx_n_s_compute_pkl);
  Py_VISIT(traverse_module_state->__pyx_n_s_compute_pknl);
  Py_VISIT(traverse_module_state->__pyx_n_s_compute_profile);
  Py_VISIT(traverse_module_state->__pyx_n_u_concentration_parameter);
  Py_VISIT(traverse_module_state->__pyx_kp_u_concentration_parameter_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_configure_logging);
  Py_VISIT(traverse_module_state->__pyx_n_u_conformal_age);
  Py_VISIT(traverse_module_state->__pyx_n_s_contains);
  Py_VISIT(traverse_module_state->__pyx_n_s_contains_specific_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_contains_specific_pattern_or_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_contextlib);
  Py_VISIT(traverse_module_state->__pyx_n_s_contextmanager);
  Py_VISIT(traverse_module_state->__pyx_kp_s_contiguous_and_direct);
  Py_VISIT(traverse_module_state->__pyx_kp_s_contiguous_and_indirect);
  Py_VISIT(traverse_module_state->__pyx_n_s_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_cosh);
  Py_VISIT(traverse_module_state->__pyx_n_u_cosmo);
  Py_VISIT(traverse_module_state->__pyx_n_s_cosmo_arguments);
  Py_VISIT(traverse_module_state->__pyx_n_s_cosmo_model);
  Py_VISIT(traverse_module_state->__pyx_n_u_cosmo_model);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_kp_u_cov_N_N);
  Py_VISIT(traverse_module_state->__pyx_n_u_covmat);
  Py_VISIT(traverse_module_state->__pyx_n_u_cp_B12);
  Py_VISIT(traverse_module_state->__pyx_n_u_cp_B16);
  Py_VISIT(traverse_module_state->__pyx_n_s_cp_pkl_fftlog_alphas_nus);
  Py_VISIT(traverse_module_state->__pyx_n_s_cp_predicted_ee_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_cp_predicted_pp_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_cp_predicted_te_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_cp_predicted_tt_spectrum);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_dsigma2_flat);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_ln1pz);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_lnk);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_lnr);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_lnsigma2_flat);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_pkl_flat);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_pknl);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_pknl_flat);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_cszfast_pk_grid_zmax);
  Py_VISIT(traverse_module_state->__pyx_n_s_ctx);
  Py_VISIT(traverse_module_state->__pyx_n_u_cubic);
  Py_VISIT(traverse_module_state->__pyx_n_s_cumtrapz);
  Py_VISIT(traverse_module_state->__pyx_n_s_cumulativeNumberDensity);
  Py_VISIT(traverse_module_state->__pyx_n_u_current);
  Py_VISIT(traverse_module_state->__pyx_n_s_custom1_W);
  Py_VISIT(traverse_module_state->__pyx_n_s_custom1_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_custom1_ux);
  Py_VISIT(traverse_module_state->__pyx_n_s_d);
  Py_VISIT(traverse_module_state->__pyx_n_u_d_ell);
  Py_VISIT(traverse_module_state->__pyx_n_u_da_rec);
  Py_VISIT(traverse_module_state->__pyx_n_u_da_rec_h);
  Py_VISIT(traverse_module_state->__pyx_n_u_da_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_data);
  Py_VISIT(traverse_module_state->__pyx_n_u_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_dcl);
  Py_VISIT(traverse_module_state->__pyx_n_u_dd);
  Py_VISIT(traverse_module_state->__pyx_n_s_decode);
  Py_VISIT(traverse_module_state->__pyx_n_s_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaultdict);
  Py_VISIT(traverse_module_state->__pyx_n_u_deg_ncdm);
  Py_VISIT(traverse_module_state->__pyx_n_s_delta);
  Py_VISIT(traverse_module_state->__pyx_n_s_deltaSZE);
  Py_VISIT(traverse_module_state->__pyx_n_s_delta_crit);
  Py_VISIT(traverse_module_state->__pyx_n_s_delta_def);
  Py_VISIT(traverse_module_state->__pyx_n_s_delta_def_custom1);
  Py_VISIT(traverse_module_state->__pyx_n_s_density_cl);
  Py_VISIT(traverse_module_state->__pyx_n_s_derived);
  Py_VISIT(traverse_module_state->__pyx_n_u_derived);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_dl);
  Py_VISIT(traverse_module_state->__pyx_n_u_dl);
  Py_VISIT(traverse_module_state->__pyx_n_s_dl_isw_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_dndM);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndM);
  Py_VISIT(traverse_module_state->__pyx_n_s_dndlnM);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndlnM);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndlnm);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndm);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndz_shift_gal);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndz_shift_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndz_shift_source_gal);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndz_stretch_gal);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndz_stretch_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndz_stretch_source_gal);
  Py_VISIT(traverse_module_state->__pyx_n_s_dndzdy);
  Py_VISIT(traverse_module_state->__pyx_n_u_dndzdy);
  Py_VISIT(traverse_module_state->__pyx_n_s_dndzdy_index_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_dndzdy_theoretical);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc);
  Py_VISIT(traverse_module_state->__pyx_n_s_double);
  Py_VISIT(traverse_module_state->__pyx_n_u_ds_d);
  Py_VISIT(traverse_module_state->__pyx_n_u_ds_d_h);
  Py_VISIT(traverse_module_state->__pyx_n_u_ds_rec);
  Py_VISIT(traverse_module_state->__pyx_n_u_ds_rec_h);
  Py_VISIT(traverse_module_state->__pyx_n_u_ds_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtype);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtype_is_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_dumc);
  Py_VISIT(traverse_module_state->__pyx_n_s_dumcp);
  Py_VISIT(traverse_module_state->__pyx_n_s_dx);
  Py_VISIT(traverse_module_state->__pyx_n_u_dydz);
  Py_VISIT(traverse_module_state->__pyx_n_s_dzdr);
  Py_VISIT(traverse_module_state->__pyx_n_s_e);
  Py_VISIT(traverse_module_state->__pyx_n_u_ee);
  Py_VISIT(traverse_module_state->__pyx_n_s_effective_f_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_effective_galaxy_bias);
  Py_VISIT(traverse_module_state->__pyx_n_s_elem);
  Py_VISIT(traverse_module_state->__pyx_n_s_ell);
  Py_VISIT(traverse_module_state->__pyx_n_u_ell);
  Py_VISIT(traverse_module_state->__pyx_n_s_empty);
  Py_VISIT(traverse_module_state->__pyx_n_s_empty_like);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_encode);
  Py_VISIT(traverse_module_state->__pyx_n_s_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_endpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_enter);
  Py_VISIT(traverse_module_state->__pyx_n_s_enumerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_eps1);
  Py_VISIT(traverse_module_state->__pyx_n_s_eps2);
  Py_VISIT(traverse_module_state->__pyx_n_s_eps23);
  Py_VISIT(traverse_module_state->__pyx_n_u_epsilon_V);
  Py_VISIT(traverse_module_state->__pyx_n_s_errmsg);
  Py_VISIT(traverse_module_state->__pyx_n_s_error);
  Py_VISIT(traverse_module_state->__pyx_n_u_eta_V);
  Py_VISIT(traverse_module_state->__pyx_n_s_even);
  Py_VISIT(traverse_module_state->__pyx_n_s_exit);
  Py_VISIT(traverse_module_state->__pyx_n_s_exp);
  Py_VISIT(traverse_module_state->__pyx_n_u_exp_m_2_tau_As);
  Py_VISIT(traverse_module_state->__pyx_n_u_extensive);
  Py_VISIT(traverse_module_state->__pyx_n_s_extrap);
  Py_VISIT(traverse_module_state->__pyx_n_u_extrapolate);
  Py_VISIT(traverse_module_state->__pyx_n_s_extrapolator);
  Py_VISIT(traverse_module_state->__pyx_n_s_f);
  Py_VISIT(traverse_module_state->__pyx_n_u_fNL);
  Py_VISIT(traverse_module_state->__pyx_n_s_fRel);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_rel);
  Py_VISIT(traverse_module_state->__pyx_n_s_fac);
  Py_VISIT(traverse_module_state->__pyx_n_s_fc);
  Py_VISIT(traverse_module_state->__pyx_n_s_fill_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_fillparfile);
  Py_VISIT(traverse_module_state->__pyx_n_s_filterwarnings);
  Py_VISIT(traverse_module_state->__pyx_n_s_find_As);
  Py_VISIT(traverse_module_state->__pyx_n_s_fineLog10M);
  Py_VISIT(traverse_module_state->__pyx_n_s_fineP);
  Py_VISIT(traverse_module_state->__pyx_n_u_first);
  Py_VISIT(traverse_module_state->__pyx_n_s_flag);
  Py_VISIT(traverse_module_state->__pyx_n_s_flags);
  Py_VISIT(traverse_module_state->__pyx_n_s_flatten);
  Py_VISIT(traverse_module_state->__pyx_n_s_float64);
  Py_VISIT(traverse_module_state->__pyx_n_u_float64);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_fortran);
  Py_VISIT(traverse_module_state->__pyx_n_u_fortran);
  Py_VISIT(traverse_module_state->__pyx_n_s_frequency_in_Hz);
  Py_VISIT(traverse_module_state->__pyx_n_u_full_path_and_prefix_to_dndz_nga);
  Py_VISIT(traverse_module_state->__pyx_n_u_full_path_to_dndz_gal);
  Py_VISIT(traverse_module_state->__pyx_n_u_full_path_to_source_dndz_gal);
  Py_VISIT(traverse_module_state->__pyx_n_u_galaxy_samples_list_num);
  Py_VISIT(traverse_module_state->__pyx_n_s_gamma);
  Py_VISIT(traverse_module_state->__pyx_n_s_gammaGNFW);
  Py_VISIT(traverse_module_state->__pyx_n_u_gamma_B12);
  Py_VISIT(traverse_module_state->__pyx_n_u_gamma_B16);
  Py_VISIT(traverse_module_state->__pyx_n_s_gamma_ggamma);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_geomspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_getData);
  Py_VISIT(traverse_module_state->__pyx_n_s_getLogger);
  Py_VISIT(traverse_module_state->__pyx_n_s_getM500_from_y0_H13);
  Py_VISIT(traverse_module_state->__pyx_n_s_getPLog10M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_1e6xdy_from_battaglia_pressu);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_1e6xdy_from_gnfw_pressure_at);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_Delta_c_of_Omega_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_Ez);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_H);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_H0_from_thetas);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_IA_of_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_N_centrals);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_N_satellites);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_Omega_m_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_Omega_m_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_Omega_r_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_P_delta_at_m_and_z_b12);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_Q_of_theta500);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_T10_alpha_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_arcmin_to_rad);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_background);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_bispectrum_f2_kernel);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_c200c_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_c200c_at_m_and_z_B13);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_c200c_at_m_and_z_D08);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_c200m_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_c200m_at_m_and_z_D08);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_c500c_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_c_delta_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_cib_Snu_z_and_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_comoving_volume);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_cov_N_N);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_current_derived_parameters);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_custom1_bias_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_custom1_profile_at_k_m_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_custom1_profile_at_x_m_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_cvir_of_mvir_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dA);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dA_z1z2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dcib0dz_at_z_and_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_delta_from_delta_def_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_delta_mean_from_delta_crit_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dkappacmbdz_at_l_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dlnsigma_dlnR_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dndlnM_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dndlnm);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dndzdq);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dydz_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_dydzdlnm_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_effective_f_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_f_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_f_free);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_f_of_sigma_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_f_tinker08_at_nu_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_f_tinker10_at_nu_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_fftlog_ComputeXiLMsloz);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_first_order_bias_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_first_order_bias_at_z_and_m_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_first_order_bias_at_z_and_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_fstar_of_m_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_galaxy_number_counts);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_gas_density_profile_at_k_M_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_gas_pressure_2h_at_r_and_m_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_b16_200);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_bcm_200);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_gnu_tsz_of_nu_in_ghz);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_hmf_counter_term_b1min_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_hmf_counter_term_b2min_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_hmf_counter_term_nmin_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_hubble);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_lensing_noise_at_ell);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m200c_to_m200m_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m200c_to_m500c_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m200m_to_m200c_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m200m_to_m500c_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m500c_to_m200c_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m500c_to_m200m_at_z_and_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m_nfw);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_m_to_xout_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_mass_profile_at_x_M_z_nfw_20);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_matter_bispectrum_at_z_effec);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_matter_bispectrum_at_z_effec_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_matter_bispectrum_at_z_effec_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_matter_bispectrum_at_z_tree);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_mcmc_parameters);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_mean_galaxy_bias_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_mean_y);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_mu_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_n5k_cl_K1_at_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_n5k_pk_at_z_and_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_n5k_z_of_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_ng_bar_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_nl_index_at_z_and_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_nl_index_at_z_and_k_no_wiggl);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_normalization_gas_density_pr);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_nu_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_params_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_perturbations);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_and_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_cb_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_cb_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_lin_at_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_lin_at_k_and_z_fast);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_nonlin_at_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pk_nonlin_at_k_and_z_fast);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pkl);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pkl_at_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pkl_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pkl_locals_compute_pkl);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pkl_locals_handle_combinatio);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pkl_reconstructed_from_fftlo);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pkl_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pknl);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pknl_at_k_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pknl_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pknl_locals_compute_pknl);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pknl_locals_handle_combinati);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pknl_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_planck_sigma_at_theta500);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pressure_P_over_P_delta_at_x);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_pressure_P_over_P_delta_at_x_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_primordial);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_r_delta_of_m_delta_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_rad_to_arcmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_radial_kernel_W_custom1_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_radial_kernel_W_galaxy_lensi);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_radial_kernel_W_galaxy_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_rho_2h_at_r_and_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_rho_crit_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_rvir_of_m200c_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_rvir_of_mvir_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_scale_dependent_bias_at_z_an);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_second_order_bias_at_z_and_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_sigma8_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_sigma_at_r_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_sigma_at_z_and_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_source_galaxy_number_counts);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_szcounts_dndzdq_at_z_q);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_szcountsz_sigma_at_theta_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_te_of_m500c_at_z_arnaud);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_te_of_m500c_at_z_lee);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_thermodynamics);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_theta_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_truncated_nfw_profile_at_z_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_truncated_nfw_profile_at_z_k_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_ttg_bispectrum_at_z_effectiv);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_ttg_bispectrum_at_z_tree_lev);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_uk);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_uk_nfw);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_uk_nfw_locals_compute_profil);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_uk_nfw_locals_handle_combina);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_unwise_m_min_cut_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_upp_from_gnfw_pressure_at_x);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_volume_dVdzdOmega_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_vrms2_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_y_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_yc_at_m_and_z_H13);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_z_of_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_z_of_chi_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_kp_u_got);
  Py_VISIT(traverse_module_state->__pyx_kp_u_got_differing_extents_in_dimensi);
  Py_VISIT(traverse_module_state->__pyx_n_s_h);
  Py_VISIT(traverse_module_state->__pyx_n_u_h);
  Py_VISIT(traverse_module_state->__pyx_n_s_h_P);
  Py_VISIT(traverse_module_state->__pyx_n_s_h_units);
  Py_VISIT(traverse_module_state->__pyx_n_s_handle_combinations);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_flags);
  Py_VISIT(traverse_module_state->__pyx_kp_u_hf);
  Py_VISIT(traverse_module_state->__pyx_n_u_hf_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_hmf);
  Py_VISIT(traverse_module_state->__pyx_n_s_hplanck);
  Py_VISIT(traverse_module_state->__pyx_n_u_hsv);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_ic_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_ic_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_ic_num);
  Py_VISIT(traverse_module_state->__pyx_n_s_ic_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_id_nu1);
  Py_VISIT(traverse_module_state->__pyx_n_s_id_nu2);
  Py_VISIT(traverse_module_state->__pyx_n_u_ignore);
  Py_VISIT(traverse_module_state->__pyx_n_s_imp);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_M_bins);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_M_bins_prime);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_ic);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_l_prime);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_m_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_md);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_mu);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_pk);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_tau);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_x);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_y);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_index_z_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initial);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_u_input);
  Py_VISIT(traverse_module_state->__pyx_n_s_intUpper);
  Py_VISIT(traverse_module_state->__pyx_n_s_integrate);
  Py_VISIT(traverse_module_state->__pyx_n_s_integrate_only);
  Py_VISIT(traverse_module_state->__pyx_n_s_interp1d);
  Py_VISIT(traverse_module_state->__pyx_n_s_interpolate);
  Py_VISIT(traverse_module_state->__pyx_n_s_ionization_fraction);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_not_implemented_yet);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_not_implemented_yet_Availabl);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_isscalar);
  Py_VISIT(traverse_module_state->__pyx_n_s_issuperset);
  Py_VISIT(traverse_module_state->__pyx_n_u_isw_auto);
  Py_VISIT(traverse_module_state->__pyx_n_u_isw_lens);
  Py_VISIT(traverse_module_state->__pyx_n_u_isw_tsz);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_itemsize);
  Py_VISIT(traverse_module_state->__pyx_kp_s_itemsize_0_for_cython_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_j);
  Py_VISIT(traverse_module_state->__pyx_n_s_join);
  Py_VISIT(traverse_module_state->__pyx_n_s_k);
  Py_VISIT(traverse_module_state->__pyx_n_u_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_k1);
  Py_VISIT(traverse_module_state->__pyx_n_s_k1_in_h_over_Mpc);
  Py_VISIT(traverse_module_state->__pyx_n_s_k2);
  Py_VISIT(traverse_module_state->__pyx_n_s_k2_in_h_over_Mpc);
  Py_VISIT(traverse_module_state->__pyx_n_s_k3);
  Py_VISIT(traverse_module_state->__pyx_n_s_k3_in_h_over_Mpc);
  Py_VISIT(traverse_module_state->__pyx_n_s_kB);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_B);
  Py_VISIT(traverse_module_state->__pyx_kp_u_k_and_z_must_be_broadcastable_to);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_asked);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_eq);
  Py_VISIT(traverse_module_state->__pyx_n_u_k_eq);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_input);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_nl);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_nl_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_k_vals);
  Py_VISIT(traverse_module_state->__pyx_n_s_kars);
  Py_VISIT(traverse_module_state->__pyx_n_s_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_kh);
  Py_VISIT(traverse_module_state->__pyx_n_s_kh_input);
  Py_VISIT(traverse_module_state->__pyx_n_s_kh_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_kh_vals);
  Py_VISIT(traverse_module_state->__pyx_n_s_kind);
  Py_VISIT(traverse_module_state->__pyx_n_s_kk);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ksi_V_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_l);
  Py_VISIT(traverse_module_state->__pyx_n_u_lCl);
  Py_VISIT(traverse_module_state->__pyx_n_s_l_asked);
  Py_VISIT(traverse_module_state->__pyx_n_s_l_max_flag);
  Py_VISIT(traverse_module_state->__pyx_n_u_l_max_lss);
  Py_VISIT(traverse_module_state->__pyx_n_u_l_max_scalars);
  Py_VISIT(traverse_module_state->__pyx_n_s_last_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_lcl);
  Py_VISIT(traverse_module_state->__pyx_n_s_lcp);
  Py_VISIT(traverse_module_state->__pyx_n_s_lensed_cl);
  Py_VISIT(traverse_module_state->__pyx_n_u_lensing);
  Py_VISIT(traverse_module_state->__pyx_kp_u_lensing_term);
  Py_VISIT(traverse_module_state->__pyx_n_s_level);
  Py_VISIT(traverse_module_state->__pyx_kp_u_levelname_s_message_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_levels);
  Py_VISIT(traverse_module_state->__pyx_n_s_likelihood_mode);
  Py_VISIT(traverse_module_state->__pyx_n_u_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_linspace);
  Py_VISIT(traverse_module_state->__pyx_n_u_ll);
  Py_VISIT(traverse_module_state->__pyx_n_s_lmax);
  Py_VISIT(traverse_module_state->__pyx_n_s_lmaxR);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ln10_10_A_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_ln1pzc);
  Py_VISIT(traverse_module_state->__pyx_n_s_lna);
  Py_VISIT(traverse_module_state->__pyx_n_s_load_n5k_cl_K1);
  Py_VISIT(traverse_module_state->__pyx_n_s_load_n5k_pk_zk);
  Py_VISIT(traverse_module_state->__pyx_n_s_load_n5k_z_of_chi);
  Py_VISIT(traverse_module_state->__pyx_n_s_loadtxt);
  Py_VISIT(traverse_module_state->__pyx_n_s_log);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10M);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10M500c_zk);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10Ms);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10x_num);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10xmax_mcfit);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10xmin_mcfit);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10y_center);
  Py_VISIT(traverse_module_state->__pyx_n_u_log10y_center);
  Py_VISIT(traverse_module_state->__pyx_n_s_log10y_edges);
  Py_VISIT(traverse_module_state->__pyx_n_u_log10y_edges);
  Py_VISIT(traverse_module_state->__pyx_n_u_logA);
  Py_VISIT(traverse_module_state->__pyx_n_s_logA_fast);
  Py_VISIT(traverse_module_state->__pyx_n_s_log_y0);
  Py_VISIT(traverse_module_state->__pyx_n_s_log_y0Err);
  Py_VISIT(traverse_module_state->__pyx_n_s_log_y0pred);
  Py_VISIT(traverse_module_state->__pyx_n_s_logging);
  Py_VISIT(traverse_module_state->__pyx_n_s_loglike);
  Py_VISIT(traverse_module_state->__pyx_n_u_loglike);
  Py_VISIT(traverse_module_state->__pyx_n_s_logspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_lowring);
  Py_VISIT(traverse_module_state->__pyx_n_s_lum_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_luminosity_distance);
  Py_VISIT(traverse_module_state->__pyx_n_s_m);
  Py_VISIT(traverse_module_state->__pyx_n_u_mPk);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_asked);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_broadcasted);
  Py_VISIT(traverse_module_state->__pyx_kp_u_m_d_a_zA_Z__to_m_d_a_zA_Z);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_delta);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_flattened);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_input);
  Py_VISIT(traverse_module_state->__pyx_kp_u_m_input_should_be_a_float_or_a_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_len);
  Py_VISIT(traverse_module_state->__pyx_n_u_m_ncdm);
  Py_VISIT(traverse_module_state->__pyx_n_u_m_ncdm_in_eV);
  Py_VISIT(traverse_module_state->__pyx_n_u_m_ncdm_tot);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_vals);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_u_mass_bin_edges);
  Py_VISIT(traverse_module_state->__pyx_n_u_mass_function);
  Py_VISIT(traverse_module_state->__pyx_kp_u_mass_function_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_match);
  Py_VISIT(traverse_module_state->__pyx_n_s_math);
  Py_VISIT(traverse_module_state->__pyx_n_s_max);
  Py_VISIT(traverse_module_state->__pyx_n_s_maxIndex);
  Py_VISIT(traverse_module_state->__pyx_n_s_mcfit);
  Py_VISIT(traverse_module_state->__pyx_n_s_mcfitx);
  Py_VISIT(traverse_module_state->__pyx_n_s_mcmc_parameters);
  Py_VISIT(traverse_module_state->__pyx_n_s_mcut);
  Py_VISIT(traverse_module_state->__pyx_n_u_mcut);
  Py_VISIT(traverse_module_state->__pyx_n_u_mcut_B12);
  Py_VISIT(traverse_module_state->__pyx_n_s_me);
  Py_VISIT(traverse_module_state->__pyx_n_s_memview);
  Py_VISIT(traverse_module_state->__pyx_n_s_message);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_min);
  Py_VISIT(traverse_module_state->__pyx_n_s_minIndex);
  Py_VISIT(traverse_module_state->__pyx_n_u_minimal);
  Py_VISIT(traverse_module_state->__pyx_n_s_mm);
  Py_VISIT(traverse_module_state->__pyx_n_u_mnu);
  Py_VISIT(traverse_module_state->__pyx_n_s_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro_entries);
  Py_VISIT(traverse_module_state->__pyx_n_s_mu_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_n);
  Py_VISIT(traverse_module_state->__pyx_n_u_n5k);
  Py_VISIT(traverse_module_state->__pyx_n_u_nCl);
  Py_VISIT(traverse_module_state->__pyx_n_u_n_e);
  Py_VISIT(traverse_module_state->__pyx_n_s_n_s);
  Py_VISIT(traverse_module_state->__pyx_n_u_n_s);
  Py_VISIT(traverse_module_state->__pyx_n_u_n_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_names);
  Py_VISIT(traverse_module_state->__pyx_n_s_ndim);
  Py_VISIT(traverse_module_state->__pyx_n_u_ndim_masses);
  Py_VISIT(traverse_module_state->__pyx_n_u_ndim_redshifts);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_newaxis);
  Py_VISIT(traverse_module_state->__pyx_n_u_nfw);
  Py_VISIT(traverse_module_state->__pyx_n_s_ngtm);
  Py_VISIT(traverse_module_state->__pyx_n_s_nl);
  Py_VISIT(traverse_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_VISIT(traverse_module_state->__pyx_n_s_nofail);
  Py_VISIT(traverse_module_state->__pyx_n_s_non_class_sz_keys);
  Py_VISIT(traverse_module_state->__pyx_n_u_non_linear);
  Py_VISIT(traverse_module_state->__pyx_n_s_non_linear_check);
  Py_VISIT(traverse_module_state->__pyx_n_u_none);
  Py_VISIT(traverse_module_state->__pyx_n_u_nonlin);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear);
  Py_VISIT(traverse_module_state->__pyx_n_u_nonlinear);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigma8_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp100);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp100_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigmadisp_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigmaprime);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_sigmaprime_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_hmcode_window_nfw);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_scale);
  Py_VISIT(traverse_module_state->__pyx_n_s_nonlinear_scale_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_normalize);
  Py_VISIT(traverse_module_state->__pyx_n_s_np);
  Py_VISIT(traverse_module_state->__pyx_n_s_nq);
  Py_VISIT(traverse_module_state->__pyx_n_u_ns);
  Py_VISIT(traverse_module_state->__pyx_n_u_ntot);
  Py_VISIT(traverse_module_state->__pyx_n_s_nu);
  Py_VISIT(traverse_module_state->__pyx_n_u_nu);
  Py_VISIT(traverse_module_state->__pyx_n_s_nu1);
  Py_VISIT(traverse_module_state->__pyx_n_s_nu2);
  Py_VISIT(traverse_module_state->__pyx_n_s_nu_in_GHz);
  Py_VISIT(traverse_module_state->__pyx_n_s_nu_in_ghz);
  Py_VISIT(traverse_module_state->__pyx_n_s_num);
  Py_VISIT(traverse_module_state->__pyx_n_s_numberDensity);
  Py_VISIT(traverse_module_state->__pyx_n_s_number_of_titles);
  Py_VISIT(traverse_module_state->__pyx_n_s_numpy);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy__core_multiarray_failed_to);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy__core_umath_failed_to_impo);
  Py_VISIT(traverse_module_state->__pyx_n_s_nz);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_obsFreqGHz);
  Py_VISIT(traverse_module_state->__pyx_n_s_oldpars);
  Py_VISIT(traverse_module_state->__pyx_n_u_ombh2);
  Py_VISIT(traverse_module_state->__pyx_n_u_omch2);
  Py_VISIT(traverse_module_state->__pyx_n_s_omega);
  Py_VISIT(traverse_module_state->__pyx_n_s_omega_b);
  Py_VISIT(traverse_module_state->__pyx_n_u_omega_b);
  Py_VISIT(traverse_module_state->__pyx_n_u_omega_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_omega_cdm);
  Py_VISIT(traverse_module_state->__pyx_n_u_omega_cdm);
  Py_VISIT(traverse_module_state->__pyx_n_u_omega_mh2);
  Py_VISIT(traverse_module_state->__pyx_n_s_only_clustering_species);
  Py_VISIT(traverse_module_state->__pyx_n_s_other_class_sz_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_outf);
  Py_VISIT(traverse_module_state->__pyx_n_u_output);
  Py_VISIT(traverse_module_state->__pyx_n_s_output_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_output_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_output_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_p);
  Py_VISIT(traverse_module_state->__pyx_n_u_pCl);
  Py_VISIT(traverse_module_state->__pyx_n_s_pack);
  Py_VISIT(traverse_module_state->__pyx_n_s_params_for_emulators);
  Py_VISIT(traverse_module_state->__pyx_n_s_params_settings);
  Py_VISIT(traverse_module_state->__pyx_n_s_params_values_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_pars);
  Py_VISIT(traverse_module_state->__pyx_n_s_pars_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pars_check);
  Py_VISIT(traverse_module_state->__pyx_n_s_path_to_cosmopower_organization);
  Py_VISIT(traverse_module_state->__pyx_n_s_pattern1);
  Py_VISIT(traverse_module_state->__pyx_n_s_pattern2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pattern3);
  Py_VISIT(traverse_module_state->__pyx_n_s_pdict_to_update);
  Py_VISIT(traverse_module_state->__pyx_n_u_perturb);
  Py_VISIT(traverse_module_state->__pyx_n_u_phi_max);
  Py_VISIT(traverse_module_state->__pyx_n_u_phi_min);
  Py_VISIT(traverse_module_state->__pyx_n_s_pi);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_at_k_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_b_at_z_2h);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_bb_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_cb_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_em_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_gg_at_z_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_lin);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_lin_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_lin_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_linzmax);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_nonlin);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_tilt);
  Py_VISIT(traverse_module_state->__pyx_n_s_pk_unvectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_pknl_in_output);
  Py_VISIT(traverse_module_state->__pyx_n_s_pknl_key_value_checks);
  Py_VISIT(traverse_module_state->__pyx_n_u_poisson);
  Py_VISIT(traverse_module_state->__pyx_n_s_pop);
  Py_VISIT(traverse_module_state->__pyx_n_s_power);
  Py_VISIT(traverse_module_state->__pyx_n_u_pp);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_u_pressure_profile);
  Py_VISIT(traverse_module_state->__pyx_kp_u_pressure_profile_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_primordial);
  Py_VISIT(traverse_module_state->__pyx_n_u_primordial);
  Py_VISIT(traverse_module_state->__pyx_n_s_problem_flag);
  Py_VISIT(traverse_module_state->__pyx_n_s_problematic_parameters);
  Py_VISIT(traverse_module_state->__pyx_n_s_profile);
  Py_VISIT(traverse_module_state->__pyx_n_s_pvecback);
  Py_VISIT(traverse_module_state->__pyx_n_s_pvecthermo);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_Enum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_vtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_q);
  Py_VISIT(traverse_module_state->__pyx_n_s_q_arr);
  Py_VISIT(traverse_module_state->__pyx_n_s_q_max);
  Py_VISIT(traverse_module_state->__pyx_n_s_q_threshold);
  Py_VISIT(traverse_module_state->__pyx_n_s_qmax);
  Py_VISIT(traverse_module_state->__pyx_n_s_qobs_asked);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_r);
  Py_VISIT(traverse_module_state->__pyx_n_u_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_r200c);
  Py_VISIT(traverse_module_state->__pyx_n_u_r_0002);
  Py_VISIT(traverse_module_state->__pyx_n_s_r_asked);
  Py_VISIT(traverse_module_state->__pyx_n_s_r_delta);
  Py_VISIT(traverse_module_state->__pyx_n_u_ra_rec);
  Py_VISIT(traverse_module_state->__pyx_n_u_ra_rec_h);
  Py_VISIT(traverse_module_state->__pyx_n_u_ra_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_rates);
  Py_VISIT(traverse_module_state->__pyx_n_u_rates);
  Py_VISIT(traverse_module_state->__pyx_n_s_raw_cl);
  Py_VISIT(traverse_module_state->__pyx_n_s_rcl);
  Py_VISIT(traverse_module_state->__pyx_n_u_rd_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_redshift);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_register);
  Py_VISIT(traverse_module_state->__pyx_n_s_resetwarnings);
  Py_VISIT(traverse_module_state->__pyx_n_s_reshape);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_rho0_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_rho0_crit);
  Py_VISIT(traverse_module_state->__pyx_n_s_rho0_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_rhoc);
  Py_VISIT(traverse_module_state->__pyx_n_u_rs_d);
  Py_VISIT(traverse_module_state->__pyx_n_u_rs_d_h);
  Py_VISIT(traverse_module_state->__pyx_n_s_rs_drag);
  Py_VISIT(traverse_module_state->__pyx_n_u_rs_rec);
  Py_VISIT(traverse_module_state->__pyx_n_u_rs_rec_h);
  Py_VISIT(traverse_module_state->__pyx_n_u_rs_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_rv);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_sBBN_file);
  Py_VISIT(traverse_module_state->__pyx_kp_u_s_was_not_recognized_as_a_deriv);
  Py_VISIT(traverse_module_state->__pyx_n_s_sample_id);
  Py_VISIT(traverse_module_state->__pyx_n_u_scalar);
  Py_VISIT(traverse_module_state->__pyx_n_u_scale);
  Py_VISIT(traverse_module_state->__pyx_n_u_scale_dependent_bias);
  Py_VISIT(traverse_module_state->__pyx_n_s_scale_independent_growth_factor);
  Py_VISIT(traverse_module_state->__pyx_n_s_scale_independent_growth_factor_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_scipy);
  Py_VISIT(traverse_module_state->__pyx_n_s_scipy_interpolate);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_n_s_send);
  Py_VISIT(traverse_module_state->__pyx_n_s_sep);
  Py_VISIT(traverse_module_state->__pyx_n_s_set);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_default);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_verbosity);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_shape);
  Py_VISIT(traverse_module_state->__pyx_n_u_shear_calibration_m);
  Py_VISIT(traverse_module_state->__pyx_n_u_shotnoise);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_u_sigma8);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma8_Pcb);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma8_cb);
  Py_VISIT(traverse_module_state->__pyx_n_u_sigma8_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigmaM);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigmaT);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_8);
  Py_VISIT(traverse_module_state->__pyx_n_u_sigma_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_8_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_cb);
  Py_VISIT(traverse_module_state->__pyx_kp_u_sigma_cb_not_computed_by_CLASS_p);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_disp);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_disp_100);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_disp_100_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_disp_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_log10M);
  Py_VISIT(traverse_module_state->__pyx_n_u_sigma_log10M_HOD);
  Py_VISIT(traverse_module_state->__pyx_n_u_sigma_log10M_HOD_ngal);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_prime);
  Py_VISIT(traverse_module_state->__pyx_n_s_sigma_prime_cb);
  Py_VISIT(traverse_module_state->__pyx_n_s_simps);
  Py_VISIT(traverse_module_state->__pyx_n_s_sinh);
  Py_VISIT(traverse_module_state->__pyx_n_s_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_size_ic_data);
  Py_VISIT(traverse_module_state->__pyx_n_s_skip_background_and_thermo);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_background_and_thermo);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_chi);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_class_sz);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_cmb);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_hubble);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_input);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_pkl);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_pknl);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_sigma8_and_der);
  Py_VISIT(traverse_module_state->__pyx_n_u_skip_sigma8_at_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_specific_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_spectra);
  Py_VISIT(traverse_module_state->__pyx_n_u_spectra);
  Py_VISIT(traverse_module_state->__pyx_n_s_splev);
  Py_VISIT(traverse_module_state->__pyx_n_s_spline);
  Py_VISIT(traverse_module_state->__pyx_n_s_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_splrep);
  Py_VISIT(traverse_module_state->__pyx_n_s_sqrt);
  Py_VISIT(traverse_module_state->__pyx_n_s_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_step);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop);
  Py_VISIT(traverse_module_state->__pyx_n_s_str);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_direct);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_direct_or_indirect);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_indirect);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_strip);
  Py_VISIT(traverse_module_state->__pyx_n_s_struct);
  Py_VISIT(traverse_module_state->__pyx_n_s_struct_cleanup);
  Py_VISIT(traverse_module_state->__pyx_n_s_sum);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_suppress_warnings);
  Py_VISIT(traverse_module_state->__pyx_n_s_sys);
  Py_VISIT(traverse_module_state->__pyx_n_u_sz_cluster_counts);
  Py_VISIT(traverse_module_state->__pyx_n_u_sz_cluster_counts_fft);
  Py_VISIT(traverse_module_state->__pyx_n_u_sz_selection_function_skyfracs_f);
  Py_VISIT(traverse_module_state->__pyx_n_u_sz_selection_function_thetas_fil);
  Py_VISIT(traverse_module_state->__pyx_n_u_sz_selection_function_ylims_file);
  Py_VISIT(traverse_module_state->__pyx_n_u_sz_unbinned_cluster_counts);
  Py_VISIT(traverse_module_state->__pyx_n_s_szcat_snr);
  Py_VISIT(traverse_module_state->__pyx_n_u_szcat_snr);
  Py_VISIT(traverse_module_state->__pyx_n_s_szcat_z);
  Py_VISIT(traverse_module_state->__pyx_n_u_szcat_z);
  Py_VISIT(traverse_module_state->__pyx_n_u_szcount);
  Py_VISIT(traverse_module_state->__pyx_n_s_szcounts_ntot);
  Py_VISIT(traverse_module_state->__pyx_n_s_szcounts_ntot_rates_loglike);
  Py_VISIT(traverse_module_state->__pyx_n_s_szunbinned_loglike);
  Py_VISIT(traverse_module_state->__pyx_n_u_t2t2f);
  Py_VISIT(traverse_module_state->__pyx_n_u_tCl);
  Py_VISIT(traverse_module_state->__pyx_n_u_tabulate_rhob_xout_at_m_and_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_tanh);
  Py_VISIT(traverse_module_state->__pyx_n_s_tau);
  Py_VISIT(traverse_module_state->__pyx_n_u_tau);
  Py_VISIT(traverse_module_state->__pyx_n_u_tau_d);
  Py_VISIT(traverse_module_state->__pyx_n_u_tau_rec);
  Py_VISIT(traverse_module_state->__pyx_n_s_tau_reio);
  Py_VISIT(traverse_module_state->__pyx_n_u_tau_reio);
  Py_VISIT(traverse_module_state->__pyx_n_u_tau_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_tckP);
  Py_VISIT(traverse_module_state->__pyx_n_u_td);
  Py_VISIT(traverse_module_state->__pyx_n_u_te);
  Py_VISIT(traverse_module_state->__pyx_n_u_te_y_y);
  Py_VISIT(traverse_module_state->__pyx_n_u_tensor);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_u_teyy);
  Py_VISIT(traverse_module_state->__pyx_kp_u_the_s_spectrum_was_computed_unti);
  Py_VISIT(traverse_module_state->__pyx_n_s_thermodynamics);
  Py_VISIT(traverse_module_state->__pyx_n_u_thermodynamics);
  Py_VISIT(traverse_module_state->__pyx_n_u_theta);
  Py_VISIT(traverse_module_state->__pyx_n_s_theta500);
  Py_VISIT(traverse_module_state->__pyx_n_s_theta_500);
  Py_VISIT(traverse_module_state->__pyx_n_s_theta_arcmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_theta_mcfit);
  Py_VISIT(traverse_module_state->__pyx_n_s_theta_rad);
  Py_VISIT(traverse_module_state->__pyx_n_s_theta_s_100);
  Py_VISIT(traverse_module_state->__pyx_n_s_theta_star_100);
  Py_VISIT(traverse_module_state->__pyx_n_s_thetae);
  Py_VISIT(traverse_module_state->__pyx_n_u_thetas);
  Py_VISIT(traverse_module_state->__pyx_n_s_throw);
  Py_VISIT(traverse_module_state->__pyx_n_s_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_timesteps);
  Py_VISIT(traverse_module_state->__pyx_n_s_titles);
  Py_VISIT(traverse_module_state->__pyx_n_u_tl);
  Py_VISIT(traverse_module_state->__pyx_n_s_tllprime_sz);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmp);
  Py_VISIT(traverse_module_state->__pyx_n_s_tmpdict);
  Py_VISIT(traverse_module_state->__pyx_n_u_tp);
  Py_VISIT(traverse_module_state->__pyx_n_u_transfer);
  Py_VISIT(traverse_module_state->__pyx_n_s_transfers);
  Py_VISIT(traverse_module_state->__pyx_n_s_transforms);
  Py_VISIT(traverse_module_state->__pyx_n_s_trapz);
  Py_VISIT(traverse_module_state->__pyx_n_u_tt);
  Py_VISIT(traverse_module_state->__pyx_n_s_type);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unable_to_allocate_array_data);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unable_to_allocate_shape_and_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_units);
  Py_VISIT(traverse_module_state->__pyx_n_s_unpack);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_upper);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_pklin);
  Py_VISIT(traverse_module_state->__pyx_n_u_use_pknl_in_2hterms);
  Py_VISIT(traverse_module_state->__pyx_n_u_use_pknl_in_2hterms_IA_only);
  Py_VISIT(traverse_module_state->__pyx_n_s_v);
  Py_VISIT(traverse_module_state->__pyx_n_s_val);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_vec_theta);
  Py_VISIT(traverse_module_state->__pyx_n_u_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_vectorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_verbosity);
  Py_VISIT(traverse_module_state->__pyx_n_s_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_viewdictitems);
  Py_VISIT(traverse_module_state->__pyx_n_s_viewitems);
  Py_VISIT(traverse_module_state->__pyx_n_u_vrms2);
  Py_VISIT(traverse_module_state->__pyx_n_s_want_ee);
  Py_VISIT(traverse_module_state->__pyx_n_s_want_pp);
  Py_VISIT(traverse_module_state->__pyx_n_s_want_te);
  Py_VISIT(traverse_module_state->__pyx_n_s_want_tt);
  Py_VISIT(traverse_module_state->__pyx_n_s_warnings);
  Py_VISIT(traverse_module_state->__pyx_n_s_window_nfw);
  Py_VISIT(traverse_module_state->__pyx_n_s_x);
  Py_VISIT(traverse_module_state->__pyx_n_u_x);
  Py_VISIT(traverse_module_state->__pyx_n_s_x_asked);
  Py_VISIT(traverse_module_state->__pyx_n_u_x_outSZ);
  Py_VISIT(traverse_module_state->__pyx_n_s_x_out_custom1);
  Py_VISIT(traverse_module_state->__pyx_n_s_xc);
  Py_VISIT(traverse_module_state->__pyx_n_u_xc_B12);
  Py_VISIT(traverse_module_state->__pyx_n_u_xc_B16);
  Py_VISIT(traverse_module_state->__pyx_n_s_xe);
  Py_VISIT(traverse_module_state->__pyx_n_s_xi);
  Py_VISIT(traverse_module_state->__pyx_n_u_xi);
  Py_VISIT(traverse_module_state->__pyx_n_u_xi_idr);
  Py_VISIT(traverse_module_state->__pyx_n_s_xi_mcfit);
  Py_VISIT(traverse_module_state->__pyx_n_s_xout);
  Py_VISIT(traverse_module_state->__pyx_n_s_xrange);
  Py_VISIT(traverse_module_state->__pyx_n_s_y);
  Py_VISIT(traverse_module_state->__pyx_n_s_y0);
  Py_VISIT(traverse_module_state->__pyx_n_s_y0Err);
  Py_VISIT(traverse_module_state->__pyx_n_s_yp);
  Py_VISIT(traverse_module_state->__pyx_n_s_ystar);
  Py_VISIT(traverse_module_state->__pyx_n_s_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_z1);
  Py_VISIT(traverse_module_state->__pyx_n_s_z2);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_arr);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_asked);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_broadcasted);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_center);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_center);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_edges);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_edges);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_flattened);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_for_pk_hm);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_input);
  Py_VISIT(traverse_module_state->__pyx_kp_u_z_input_should_be_a_float_or_a_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_len);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_max);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_max_nonlinear);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_max_requested);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_min);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_of_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_of_tau);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_rec);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_reio);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_reio);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_size);
  Py_VISIT(traverse_module_state->__pyx_n_u_z_star);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_step);
  Py_VISIT(traverse_module_state->__pyx_n_s_z_vals);
  Py_VISIT(traverse_module_state->__pyx_n_s_zeros);
  Py_VISIT(traverse_module_state->__pyx_n_s_zi);
  Py_VISIT(traverse_module_state->__pyx_n_s_zmax);
  Py_VISIT(traverse_module_state->__pyx_n_s_zmin);
  Py_VISIT(traverse_module_state->__pyx_n_s_zp);
  Py_VISIT(traverse_module_state->__pyx_n_s_zpk);
  Py_VISIT(traverse_module_state->__pyx_float_0_);
  Py_VISIT(traverse_module_state->__pyx_float_1_);
  Py_VISIT(traverse_module_state->__pyx_float_2_);
  Py_VISIT(traverse_module_state->__pyx_float_3_);
  Py_VISIT(traverse_module_state->__pyx_float_4_);
  Py_VISIT(traverse_module_state->__pyx_float_5_);
  Py_VISIT(traverse_module_state->__pyx_float_0_0);
  Py_VISIT(traverse_module_state->__pyx_float_0_1);
  Py_VISIT(traverse_module_state->__pyx_float_0_5);
  Py_VISIT(traverse_module_state->__pyx_float_1_0);
  Py_VISIT(traverse_module_state->__pyx_float_10_);
  Py_VISIT(traverse_module_state->__pyx_float_1e9);
  Py_VISIT(traverse_module_state->__pyx_float_0_02);
  Py_VISIT(traverse_module_state->__pyx_float_0_04);
  Py_VISIT(traverse_module_state->__pyx_float_0_19);
  Py_VISIT(traverse_module_state->__pyx_float_0_29);
  Py_VISIT(traverse_module_state->__pyx_float_0_88);
  Py_VISIT(traverse_module_state->__pyx_float_100_);
  Py_VISIT(traverse_module_state->__pyx_float_18_1);
  Py_VISIT(traverse_module_state->__pyx_float_1e14);
  Py_VISIT(traverse_module_state->__pyx_float_1e16);
  Py_VISIT(traverse_module_state->__pyx_float_200_);
  Py_VISIT(traverse_module_state->__pyx_float_3_83);
  Py_VISIT(traverse_module_state->__pyx_float_4_35);
  Py_VISIT(traverse_module_state->__pyx_float_4_e3);
  Py_VISIT(traverse_module_state->__pyx_float_500_);
  Py_VISIT(traverse_module_state->__pyx_float_0_154);
  Py_VISIT(traverse_module_state->__pyx_float_0_415);
  Py_VISIT(traverse_module_state->__pyx_float_0_497);
  Py_VISIT(traverse_module_state->__pyx_float_0_731);
  Py_VISIT(traverse_module_state->__pyx_float_1_156);
  Py_VISIT(traverse_module_state->__pyx_float_148_0);
  Py_VISIT(traverse_module_state->__pyx_float_1eneg_10);
  Py_VISIT(traverse_module_state->__pyx_float_8_130);
  Py_VISIT(traverse_module_state->__pyx_float_0_0393);
  Py_VISIT(traverse_module_state->__pyx_float_0_3292);
  Py_VISIT(traverse_module_state->__pyx_float_0_6827);
  Py_VISIT(traverse_module_state->__pyx_float_0_9665);
  Py_VISIT(traverse_module_state->__pyx_float_1_0620);
  Py_VISIT(traverse_module_state->__pyx_float_1eneg_100);
  Py_VISIT(traverse_module_state->__pyx_float_5_4807);
  Py_VISIT(traverse_module_state->__pyx_float_0_00441);
  Py_VISIT(traverse_module_state->__pyx_float_0_022383);
  Py_VISIT(traverse_module_state->__pyx_float_2_61051eneg_18);
  Py_VISIT(traverse_module_state->__pyx_float_1_00000000e_12);
  Py_VISIT(traverse_module_state->__pyx_float_neg_2_);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_2);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_3);
  Py_VISIT(traverse_module_state->__pyx_float_neg_1_0);
  Py_VISIT(traverse_module_state->__pyx_float_neg_10_);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_03);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_66);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_025);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_758);
  Py_VISIT(traverse_module_state->__pyx_float_neg_0_00865);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_4);
  Py_VISIT(traverse_module_state->__pyx_int_5);
  Py_VISIT(traverse_module_state->__pyx_int_6);
  Py_VISIT(traverse_module_state->__pyx_int_7);
  Py_VISIT(traverse_module_state->__pyx_int_8);
  Py_VISIT(traverse_module_state->__pyx_int_9);
  Py_VISIT(traverse_module_state->__pyx_int_10);
  Py_VISIT(traverse_module_state->__pyx_int_100);
  Py_VISIT(traverse_module_state->__pyx_int_200);
  Py_VISIT(traverse_module_state->__pyx_int_300);
  Py_VISIT(traverse_module_state->__pyx_int_500);
  Py_VISIT(traverse_module_state->__pyx_int_600);
  Py_VISIT(traverse_module_state->__pyx_int_1024);
  Py_VISIT(traverse_module_state->__pyx_int_10000);
  Py_VISIT(traverse_module_state->__pyx_int_20000);
  Py_VISIT(traverse_module_state->__pyx_int_112105877);
  Py_VISIT(traverse_module_state->__pyx_int_136983863);
  Py_VISIT(traverse_module_state->__pyx_int_184977713);
  Py_VISIT(traverse_module_state->__pyx_int_10000000000);
  Py_VISIT(traverse_module_state->__pyx_int_0xde0b6b3a7640000);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_int_neg_4);
  Py_VISIT(traverse_module_state->__pyx_int_neg_6);
  Py_VISIT(traverse_module_state->__pyx_k__21);
  Py_VISIT(traverse_module_state->__pyx_slice__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__4);
  Py_VISIT(traverse_module_state->__pyx_tuple__8);
  Py_VISIT(traverse_module_state->__pyx_slice__44);
  Py_VISIT(traverse_module_state->__pyx_slice__47);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__16);
  Py_VISIT(traverse_module_state->__pyx_tuple__18);
  Py_VISIT(traverse_module_state->__pyx_tuple__19);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__25);
  Py_VISIT(traverse_module_state->__pyx_tuple__26);
  Py_VISIT(traverse_module_state->__pyx_tuple__27);
  Py_VISIT(traverse_module_state->__pyx_tuple__28);
  Py_VISIT(traverse_module_state->__pyx_tuple__29);
  Py_VISIT(traverse_module_state->__pyx_tuple__30);
  Py_VISIT(traverse_module_state->__pyx_tuple__31);
  Py_VISIT(traverse_module_state->__pyx_tuple__33);
  Py_VISIT(traverse_module_state->__pyx_tuple__34);
  Py_VISIT(traverse_module_state->__pyx_tuple__38);
  Py_VISIT(traverse_module_state->__pyx_tuple__40);
  Py_VISIT(traverse_module_state->__pyx_tuple__42);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__45);
  Py_VISIT(traverse_module_state->__pyx_tuple__48);
  Py_VISIT(traverse_module_state->__pyx_tuple__49);
  Py_VISIT(traverse_module_state->__pyx_tuple__50);
  Py_VISIT(traverse_module_state->__pyx_tuple__51);
  Py_VISIT(traverse_module_state->__pyx_tuple__52);
  Py_VISIT(traverse_module_state->__pyx_tuple__53);
  Py_VISIT(traverse_module_state->__pyx_tuple__54);
  Py_VISIT(traverse_module_state->__pyx_tuple__55);
  Py_VISIT(traverse_module_state->__pyx_tuple__56);
  Py_VISIT(traverse_module_state->__pyx_tuple__57);
  Py_VISIT(traverse_module_state->__pyx_tuple__58);
  Py_VISIT(traverse_module_state->__pyx_tuple__59);
  Py_VISIT(traverse_module_state->__pyx_tuple__60);
  Py_VISIT(traverse_module_state->__pyx_tuple__62);
  Py_VISIT(traverse_module_state->__pyx_tuple__64);
  Py_VISIT(traverse_module_state->__pyx_tuple__66);
  Py_VISIT(traverse_module_state->__pyx_tuple__67);
  Py_VISIT(traverse_module_state->__pyx_tuple__69);
  Py_VISIT(traverse_module_state->__pyx_tuple__71);
  Py_VISIT(traverse_module_state->__pyx_tuple__73);
  Py_VISIT(traverse_module_state->__pyx_tuple__75);
  Py_VISIT(traverse_module_state->__pyx_tuple__77);
  Py_VISIT(traverse_module_state->__pyx_tuple__78);
  Py_VISIT(traverse_module_state->__pyx_tuple__80);
  Py_VISIT(traverse_module_state->__pyx_tuple__82);
  Py_VISIT(traverse_module_state->__pyx_tuple__85);
  Py_VISIT(traverse_module_state->__pyx_tuple__88);
  Py_VISIT(traverse_module_state->__pyx_tuple__90);
  Py_VISIT(traverse_module_state->__pyx_tuple__92);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_tuple__95);
  Py_VISIT(traverse_module_state->__pyx_tuple__97);
  Py_VISIT(traverse_module_state->__pyx_tuple__99);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__102);
  Py_VISIT(traverse_module_state->__pyx_tuple__104);
  Py_VISIT(traverse_module_state->__pyx_tuple__106);
  Py_VISIT(traverse_module_state->__pyx_tuple__107);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_tuple__111);
  Py_VISIT(traverse_module_state->__pyx_tuple__113);
  Py_VISIT(traverse_module_state->__pyx_tuple__115);
  Py_VISIT(traverse_module_state->__pyx_tuple__117);
  Py_VISIT(traverse_module_state->__pyx_tuple__119);
  Py_VISIT(traverse_module_state->__pyx_tuple__121);
  Py_VISIT(traverse_module_state->__pyx_tuple__123);
  Py_VISIT(traverse_module_state->__pyx_tuple__125);
  Py_VISIT(traverse_module_state->__pyx_tuple__127);
  Py_VISIT(traverse_module_state->__pyx_tuple__129);
  Py_VISIT(traverse_module_state->__pyx_tuple__131);
  Py_VISIT(traverse_module_state->__pyx_tuple__133);
  Py_VISIT(traverse_module_state->__pyx_tuple__135);
  Py_VISIT(traverse_module_state->__pyx_tuple__138);
  Py_VISIT(traverse_module_state->__pyx_tuple__140);
  Py_VISIT(traverse_module_state->__pyx_tuple__141);
  Py_VISIT(traverse_module_state->__pyx_tuple__143);
  Py_VISIT(traverse_module_state->__pyx_tuple__145);
  Py_VISIT(traverse_module_state->__pyx_tuple__147);
  Py_VISIT(traverse_module_state->__pyx_tuple__149);
  Py_VISIT(traverse_module_state->__pyx_tuple__151);
  Py_VISIT(traverse_module_state->__pyx_tuple__156);
  Py_VISIT(traverse_module_state->__pyx_tuple__169);
  Py_VISIT(traverse_module_state->__pyx_tuple__172);
  Py_VISIT(traverse_module_state->__pyx_tuple__177);
  Py_VISIT(traverse_module_state->__pyx_tuple__179);
  Py_VISIT(traverse_module_state->__pyx_tuple__181);
  Py_VISIT(traverse_module_state->__pyx_tuple__183);
  Py_VISIT(traverse_module_state->__pyx_tuple__185);
  Py_VISIT(traverse_module_state->__pyx_tuple__187);
  Py_VISIT(traverse_module_state->__pyx_tuple__190);
  Py_VISIT(traverse_module_state->__pyx_tuple__192);
  Py_VISIT(traverse_module_state->__pyx_tuple__194);
  Py_VISIT(traverse_module_state->__pyx_tuple__196);
  Py_VISIT(traverse_module_state->__pyx_tuple__198);
  Py_VISIT(traverse_module_state->__pyx_tuple__202);
  Py_VISIT(traverse_module_state->__pyx_tuple__204);
  Py_VISIT(traverse_module_state->__pyx_tuple__206);
  Py_VISIT(traverse_module_state->__pyx_tuple__209);
  Py_VISIT(traverse_module_state->__pyx_tuple__211);
  Py_VISIT(traverse_module_state->__pyx_tuple__213);
  Py_VISIT(traverse_module_state->__pyx_tuple__217);
  Py_VISIT(traverse_module_state->__pyx_tuple__220);
  Py_VISIT(traverse_module_state->__pyx_tuple__227);
  Py_VISIT(traverse_module_state->__pyx_tuple__229);
  Py_VISIT(traverse_module_state->__pyx_tuple__261);
  Py_VISIT(traverse_module_state->__pyx_tuple__263);
  Py_VISIT(traverse_module_state->__pyx_tuple__265);
  Py_VISIT(traverse_module_state->__pyx_tuple__267);
  Py_VISIT(traverse_module_state->__pyx_tuple__269);
  Py_VISIT(traverse_module_state->__pyx_tuple__271);
  Py_VISIT(traverse_module_state->__pyx_tuple__273);
  Py_VISIT(traverse_module_state->__pyx_tuple__275);
  Py_VISIT(traverse_module_state->__pyx_tuple__277);
  Py_VISIT(traverse_module_state->__pyx_tuple__279);
  Py_VISIT(traverse_module_state->__pyx_tuple__283);
  Py_VISIT(traverse_module_state->__pyx_tuple__285);
  Py_VISIT(traverse_module_state->__pyx_tuple__290);
  Py_VISIT(traverse_module_state->__pyx_tuple__292);
  Py_VISIT(traverse_module_state->__pyx_tuple__295);
  Py_VISIT(traverse_module_state->__pyx_tuple__317);
  Py_VISIT(traverse_module_state->__pyx_tuple__320);
  Py_VISIT(traverse_module_state->__pyx_tuple__324);
  Py_VISIT(traverse_module_state->__pyx_tuple__326);
  Py_VISIT(traverse_module_state->__pyx_tuple__328);
  Py_VISIT(traverse_module_state->__pyx_tuple__330);
  Py_VISIT(traverse_module_state->__pyx_tuple__332);
  Py_VISIT(traverse_module_state->__pyx_tuple__335);
  Py_VISIT(traverse_module_state->__pyx_tuple__340);
  Py_VISIT(traverse_module_state->__pyx_tuple__342);
  Py_VISIT(traverse_module_state->__pyx_tuple__343);
  Py_VISIT(traverse_module_state->__pyx_tuple__345);
  Py_VISIT(traverse_module_state->__pyx_tuple__348);
  Py_VISIT(traverse_module_state->__pyx_tuple__350);
  Py_VISIT(traverse_module_state->__pyx_tuple__352);
  Py_VISIT(traverse_module_state->__pyx_tuple__354);
  Py_VISIT(traverse_module_state->__pyx_tuple__356);
  Py_VISIT(traverse_module_state->__pyx_tuple__358);
  Py_VISIT(traverse_module_state->__pyx_tuple__365);
  Py_VISIT(traverse_module_state->__pyx_tuple__374);
  Py_VISIT(traverse_module_state->__pyx_tuple__376);
  Py_VISIT(traverse_module_state->__pyx_tuple__378);
  Py_VISIT(traverse_module_state->__pyx_tuple__381);
  Py_VISIT(traverse_module_state->__pyx_tuple__383);
  Py_VISIT(traverse_module_state->__pyx_tuple__385);
  Py_VISIT(traverse_module_state->__pyx_tuple__387);
  Py_VISIT(traverse_module_state->__pyx_tuple__388);
  Py_VISIT(traverse_module_state->__pyx_tuple__393);
  Py_VISIT(traverse_module_state->__pyx_tuple__395);
  Py_VISIT(traverse_module_state->__pyx_tuple__396);
  Py_VISIT(traverse_module_state->__pyx_tuple__398);
  Py_VISIT(traverse_module_state->__pyx_tuple__399);
  Py_VISIT(traverse_module_state->__pyx_tuple__401);
  Py_VISIT(traverse_module_state->__pyx_tuple__402);
  Py_VISIT(traverse_module_state->__pyx_tuple__405);
  Py_VISIT(traverse_module_state->__pyx_tuple__407);
  Py_VISIT(traverse_module_state->__pyx_tuple__409);
  Py_VISIT(traverse_module_state->__pyx_tuple__410);
  Py_VISIT(traverse_module_state->__pyx_tuple__412);
  Py_VISIT(traverse_module_state->__pyx_tuple__414);
  Py_VISIT(traverse_module_state->__pyx_tuple__416);
  Py_VISIT(traverse_module_state->__pyx_tuple__417);
  Py_VISIT(traverse_module_state->__pyx_tuple__420);
  Py_VISIT(traverse_module_state->__pyx_tuple__422);
  Py_VISIT(traverse_module_state->__pyx_tuple__424);
  Py_VISIT(traverse_module_state->__pyx_tuple__427);
  Py_VISIT(traverse_module_state->__pyx_tuple__429);
  Py_VISIT(traverse_module_state->__pyx_tuple__433);
  Py_VISIT(traverse_module_state->__pyx_tuple__435);
  Py_VISIT(traverse_module_state->__pyx_tuple__437);
  Py_VISIT(traverse_module_state->__pyx_tuple__440);
  Py_VISIT(traverse_module_state->__pyx_tuple__444);
  Py_VISIT(traverse_module_state->__pyx_tuple__456);
  Py_VISIT(traverse_module_state->__pyx_tuple__458);
  Py_VISIT(traverse_module_state->__pyx_tuple__462);
  Py_VISIT(traverse_module_state->__pyx_tuple__464);
  Py_VISIT(traverse_module_state->__pyx_tuple__468);
  Py_VISIT(traverse_module_state->__pyx_tuple__470);
  Py_VISIT(traverse_module_state->__pyx_tuple__472);
  Py_VISIT(traverse_module_state->__pyx_tuple__474);
  Py_VISIT(traverse_module_state->__pyx_tuple__476);
  Py_VISIT(traverse_module_state->__pyx_tuple__478);
  Py_VISIT(traverse_module_state->__pyx_tuple__480);
  Py_VISIT(traverse_module_state->__pyx_tuple__482);
  Py_VISIT(traverse_module_state->__pyx_tuple__483);
  Py_VISIT(traverse_module_state->__pyx_tuple__486);
  Py_VISIT(traverse_module_state->__pyx_tuple__493);
  Py_VISIT(traverse_module_state->__pyx_tuple__497);
  Py_VISIT(traverse_module_state->__pyx_tuple__499);
  Py_VISIT(traverse_module_state->__pyx_tuple__504);
  Py_VISIT(traverse_module_state->__pyx_tuple__506);
  Py_VISIT(traverse_module_state->__pyx_tuple__507);
  Py_VISIT(traverse_module_state->__pyx_tuple__509);
  Py_VISIT(traverse_module_state->__pyx_tuple__511);
  Py_VISIT(traverse_module_state->__pyx_tuple__513);
  Py_VISIT(traverse_module_state->__pyx_tuple__516);
  Py_VISIT(traverse_module_state->__pyx_tuple__518);
  Py_VISIT(traverse_module_state->__pyx_tuple__519);
  Py_VISIT(traverse_module_state->__pyx_tuple__521);
  Py_VISIT(traverse_module_state->__pyx_tuple__524);
  Py_VISIT(traverse_module_state->__pyx_tuple__527);
  Py_VISIT(traverse_module_state->__pyx_tuple__530);
  Py_VISIT(traverse_module_state->__pyx_tuple__533);
  Py_VISIT(traverse_module_state->__pyx_tuple__536);
  Py_VISIT(traverse_module_state->__pyx_tuple__539);
  Py_VISIT(traverse_module_state->__pyx_tuple__542);
  Py_VISIT(traverse_module_state->__pyx_tuple__552);
  Py_VISIT(traverse_module_state->__pyx_codeobj__17);
  Py_VISIT(traverse_module_state->__pyx_codeobj__32);
  Py_VISIT(traverse_module_state->__pyx_codeobj__35);
  Py_VISIT(traverse_module_state->__pyx_codeobj__36);
  Py_VISIT(traverse_module_state->__pyx_codeobj__37);
  Py_VISIT(traverse_module_state->__pyx_codeobj__39);
  Py_VISIT(traverse_module_state->__pyx_codeobj__41);
  Py_VISIT(traverse_module_state->__pyx_codeobj__61);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__65);
  Py_VISIT(traverse_module_state->__pyx_codeobj__68);
  Py_VISIT(traverse_module_state->__pyx_codeobj__70);
  Py_VISIT(traverse_module_state->__pyx_codeobj__72);
  Py_VISIT(traverse_module_state->__pyx_codeobj__74);
  Py_VISIT(traverse_module_state->__pyx_codeobj__76);
  Py_VISIT(traverse_module_state->__pyx_codeobj__79);
  Py_VISIT(traverse_module_state->__pyx_codeobj__81);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__84);
  Py_VISIT(traverse_module_state->__pyx_codeobj__86);
  Py_VISIT(traverse_module_state->__pyx_codeobj__87);
  Py_VISIT(traverse_module_state->__pyx_codeobj__89);
  Py_VISIT(traverse_module_state->__pyx_codeobj__91);
  Py_VISIT(traverse_module_state->__pyx_codeobj__94);
  Py_VISIT(traverse_module_state->__pyx_codeobj__96);
  Py_VISIT(traverse_module_state->__pyx_codeobj__98);
  Py_VISIT(traverse_module_state->__pyx_codeobj__100);
  Py_VISIT(traverse_module_state->__pyx_codeobj__103);
  Py_VISIT(traverse_module_state->__pyx_codeobj__105);
  Py_VISIT(traverse_module_state->__pyx_codeobj__108);
  Py_VISIT(traverse_module_state->__pyx_codeobj__110);
  Py_VISIT(traverse_module_state->__pyx_codeobj__112);
  Py_VISIT(traverse_module_state->__pyx_codeobj__114);
  Py_VISIT(traverse_module_state->__pyx_codeobj__116);
  Py_VISIT(traverse_module_state->__pyx_codeobj__118);
  Py_VISIT(traverse_module_state->__pyx_codeobj__120);
  Py_VISIT(traverse_module_state->__pyx_codeobj__122);
  Py_VISIT(traverse_module_state->__pyx_codeobj__124);
  Py_VISIT(traverse_module_state->__pyx_codeobj__126);
  Py_VISIT(traverse_module_state->__pyx_codeobj__128);
  Py_VISIT(traverse_module_state->__pyx_codeobj__130);
  Py_VISIT(traverse_module_state->__pyx_codeobj__132);
  Py_VISIT(traverse_module_state->__pyx_codeobj__134);
  Py_VISIT(traverse_module_state->__pyx_codeobj__136);
  Py_VISIT(traverse_module_state->__pyx_codeobj__137);
  Py_VISIT(traverse_module_state->__pyx_codeobj__139);
  Py_VISIT(traverse_module_state->__pyx_codeobj__142);
  Py_VISIT(traverse_module_state->__pyx_codeobj__144);
  Py_VISIT(traverse_module_state->__pyx_codeobj__146);
  Py_VISIT(traverse_module_state->__pyx_codeobj__148);
  Py_VISIT(traverse_module_state->__pyx_codeobj__150);
  Py_VISIT(traverse_module_state->__pyx_codeobj__152);
  Py_VISIT(traverse_module_state->__pyx_codeobj__153);
  Py_VISIT(traverse_module_state->__pyx_codeobj__154);
  Py_VISIT(traverse_module_state->__pyx_codeobj__155);
  Py_VISIT(traverse_module_state->__pyx_codeobj__157);
  Py_VISIT(traverse_module_state->__pyx_codeobj__158);
  Py_VISIT(traverse_module_state->__pyx_codeobj__159);
  Py_VISIT(traverse_module_state->__pyx_codeobj__160);
  Py_VISIT(traverse_module_state->__pyx_codeobj__161);
  Py_VISIT(traverse_module_state->__pyx_codeobj__162);
  Py_VISIT(traverse_module_state->__pyx_codeobj__163);
  Py_VISIT(traverse_module_state->__pyx_codeobj__164);
  Py_VISIT(traverse_module_state->__pyx_codeobj__165);
  Py_VISIT(traverse_module_state->__pyx_codeobj__166);
  Py_VISIT(traverse_module_state->__pyx_codeobj__167);
  Py_VISIT(traverse_module_state->__pyx_codeobj__168);
  Py_VISIT(traverse_module_state->__pyx_codeobj__170);
  Py_VISIT(traverse_module_state->__pyx_codeobj__171);
  Py_VISIT(traverse_module_state->__pyx_codeobj__173);
  Py_VISIT(traverse_module_state->__pyx_codeobj__174);
  Py_VISIT(traverse_module_state->__pyx_codeobj__175);
  Py_VISIT(traverse_module_state->__pyx_codeobj__176);
  Py_VISIT(traverse_module_state->__pyx_codeobj__178);
  Py_VISIT(traverse_module_state->__pyx_codeobj__180);
  Py_VISIT(traverse_module_state->__pyx_codeobj__182);
  Py_VISIT(traverse_module_state->__pyx_codeobj__184);
  Py_VISIT(traverse_module_state->__pyx_codeobj__186);
  Py_VISIT(traverse_module_state->__pyx_codeobj__188);
  Py_VISIT(traverse_module_state->__pyx_codeobj__189);
  Py_VISIT(traverse_module_state->__pyx_codeobj__191);
  Py_VISIT(traverse_module_state->__pyx_codeobj__193);
  Py_VISIT(traverse_module_state->__pyx_codeobj__195);
  Py_VISIT(traverse_module_state->__pyx_codeobj__197);
  Py_VISIT(traverse_module_state->__pyx_codeobj__199);
  Py_VISIT(traverse_module_state->__pyx_codeobj__200);
  Py_VISIT(traverse_module_state->__pyx_codeobj__201);
  Py_VISIT(traverse_module_state->__pyx_codeobj__203);
  Py_VISIT(traverse_module_state->__pyx_codeobj__205);
  Py_VISIT(traverse_module_state->__pyx_codeobj__207);
  Py_VISIT(traverse_module_state->__pyx_codeobj__208);
  Py_VISIT(traverse_module_state->__pyx_codeobj__210);
  Py_VISIT(traverse_module_state->__pyx_codeobj__212);
  Py_VISIT(traverse_module_state->__pyx_codeobj__214);
  Py_VISIT(traverse_module_state->__pyx_codeobj__215);
  Py_VISIT(traverse_module_state->__pyx_codeobj__216);
  Py_VISIT(traverse_module_state->__pyx_codeobj__218);
  Py_VISIT(traverse_module_state->__pyx_codeobj__219);
  Py_VISIT(traverse_module_state->__pyx_codeobj__221);
  Py_VISIT(traverse_module_state->__pyx_codeobj__222);
  Py_VISIT(traverse_module_state->__pyx_codeobj__223);
  Py_VISIT(traverse_module_state->__pyx_codeobj__224);
  Py_VISIT(traverse_module_state->__pyx_codeobj__225);
  Py_VISIT(traverse_module_state->__pyx_codeobj__226);
  Py_VISIT(traverse_module_state->__pyx_codeobj__228);
  Py_VISIT(traverse_module_state->__pyx_codeobj__230);
  Py_VISIT(traverse_module_state->__pyx_codeobj__231);
  Py_VISIT(traverse_module_state->__pyx_codeobj__232);
  Py_VISIT(traverse_module_state->__pyx_codeobj__233);
  Py_VISIT(traverse_module_state->__pyx_codeobj__234);
  Py_VISIT(traverse_module_state->__pyx_codeobj__235);
  Py_VISIT(traverse_module_state->__pyx_codeobj__236);
  Py_VISIT(traverse_module_state->__pyx_codeobj__237);
  Py_VISIT(traverse_module_state->__pyx_codeobj__238);
  Py_VISIT(traverse_module_state->__pyx_codeobj__239);
  Py_VISIT(traverse_module_state->__pyx_codeobj__240);
  Py_VISIT(traverse_module_state->__pyx_codeobj__241);
  Py_VISIT(traverse_module_state->__pyx_codeobj__242);
  Py_VISIT(traverse_module_state->__pyx_codeobj__243);
  Py_VISIT(traverse_module_state->__pyx_codeobj__244);
  Py_VISIT(traverse_module_state->__pyx_codeobj__245);
  Py_VISIT(traverse_module_state->__pyx_codeobj__246);
  Py_VISIT(traverse_module_state->__pyx_codeobj__247);
  Py_VISIT(traverse_module_state->__pyx_codeobj__248);
  Py_VISIT(traverse_module_state->__pyx_codeobj__249);
  Py_VISIT(traverse_module_state->__pyx_codeobj__250);
  Py_VISIT(traverse_module_state->__pyx_codeobj__251);
  Py_VISIT(traverse_module_state->__pyx_codeobj__252);
  Py_VISIT(traverse_module_state->__pyx_codeobj__253);
  Py_VISIT(traverse_module_state->__pyx_codeobj__254);
  Py_VISIT(traverse_module_state->__pyx_codeobj__255);
  Py_VISIT(traverse_module_state->__pyx_codeobj__256);
  Py_VISIT(traverse_module_state->__pyx_codeobj__257);
  Py_VISIT(traverse_module_state->__pyx_codeobj__258);
  Py_VISIT(traverse_module_state->__pyx_codeobj__259);
  Py_VISIT(traverse_module_state->__pyx_codeobj__260);
  Py_VISIT(traverse_module_state->__pyx_codeobj__262);
  Py_VISIT(traverse_module_state->__pyx_codeobj__264);
  Py_VISIT(traverse_module_state->__pyx_codeobj__266);
  Py_VISIT(traverse_module_state->__pyx_codeobj__268);
  Py_VISIT(traverse_module_state->__pyx_codeobj__270);
  Py_VISIT(traverse_module_state->__pyx_codeobj__272);
  Py_VISIT(traverse_module_state->__pyx_codeobj__274);
  Py_VISIT(traverse_module_state->__pyx_codeobj__276);
  Py_VISIT(traverse_module_state->__pyx_codeobj__278);
  Py_VISIT(traverse_module_state->__pyx_codeobj__280);
  Py_VISIT(traverse_module_state->__pyx_codeobj__281);
  Py_VISIT(traverse_module_state->__pyx_codeobj__282);
  Py_VISIT(traverse_module_state->__pyx_codeobj__284);
  Py_VISIT(traverse_module_state->__pyx_codeobj__286);
  Py_VISIT(traverse_module_state->__pyx_codeobj__287);
  Py_VISIT(traverse_module_state->__pyx_codeobj__288);
  Py_VISIT(traverse_module_state->__pyx_codeobj__289);
  Py_VISIT(traverse_module_state->__pyx_codeobj__291);
  Py_VISIT(traverse_module_state->__pyx_codeobj__293);
  Py_VISIT(traverse_module_state->__pyx_codeobj__294);
  Py_VISIT(traverse_module_state->__pyx_codeobj__296);
  Py_VISIT(traverse_module_state->__pyx_codeobj__297);
  Py_VISIT(traverse_module_state->__pyx_codeobj__298);
  Py_VISIT(traverse_module_state->__pyx_codeobj__299);
  Py_VISIT(traverse_module_state->__pyx_codeobj__300);
  Py_VISIT(traverse_module_state->__pyx_codeobj__301);
  Py_VISIT(traverse_module_state->__pyx_codeobj__302);
  Py_VISIT(traverse_module_state->__pyx_codeobj__303);
  Py_VISIT(traverse_module_state->__pyx_codeobj__304);
  Py_VISIT(traverse_module_state->__pyx_codeobj__305);
  Py_VISIT(traverse_module_state->__pyx_codeobj__306);
  Py_VISIT(traverse_module_state->__pyx_codeobj__307);
  Py_VISIT(traverse_module_state->__pyx_codeobj__308);
  Py_VISIT(traverse_module_state->__pyx_codeobj__309);
  Py_VISIT(traverse_module_state->__pyx_codeobj__310);
  Py_VISIT(traverse_module_state->__pyx_codeobj__311);
  Py_VISIT(traverse_module_state->__pyx_codeobj__312);
  Py_VISIT(traverse_module_state->__pyx_codeobj__313);
  Py_VISIT(traverse_module_state->__pyx_codeobj__314);
  Py_VISIT(traverse_module_state->__pyx_codeobj__315);
  Py_VISIT(traverse_module_state->__pyx_codeobj__316);
  Py_VISIT(traverse_module_state->__pyx_codeobj__318);
  Py_VISIT(traverse_module_state->__pyx_codeobj__319);
  Py_VISIT(traverse_module_state->__pyx_codeobj__321);
  Py_VISIT(traverse_module_state->__pyx_codeobj__322);
  Py_VISIT(traverse_module_state->__pyx_codeobj__323);
  Py_VISIT(traverse_module_state->__pyx_codeobj__325);
  Py_VISIT(traverse_module_state->__pyx_codeobj__327);
  Py_VISIT(traverse_module_state->__pyx_codeobj__329);
  Py_VISIT(traverse_module_state->__pyx_codeobj__331);
  Py_VISIT(traverse_module_state->__pyx_codeobj__333);
  Py_VISIT(traverse_module_state->__pyx_codeobj__334);
  Py_VISIT(traverse_module_state->__pyx_codeobj__336);
  Py_VISIT(traverse_module_state->__pyx_codeobj__337);
  Py_VISIT(traverse_module_state->__pyx_codeobj__338);
  Py_VISIT(traverse_module_state->__pyx_codeobj__339);
  Py_VISIT(traverse_module_state->__pyx_codeobj__341);
  Py_VISIT(traverse_module_state->__pyx_codeobj__344);
  Py_VISIT(traverse_module_state->__pyx_codeobj__346);
  Py_VISIT(traverse_module_state->__pyx_codeobj__347);
  Py_VISIT(traverse_module_state->__pyx_codeobj__349);
  Py_VISIT(traverse_module_state->__pyx_codeobj__351);
  Py_VISIT(traverse_module_state->__pyx_codeobj__353);
  Py_VISIT(traverse_module_state->__pyx_codeobj__355);
  Py_VISIT(traverse_module_state->__pyx_codeobj__357);
  Py_VISIT(traverse_module_state->__pyx_codeobj__359);
  Py_VISIT(traverse_module_state->__pyx_codeobj__360);
  Py_VISIT(traverse_module_state->__pyx_codeobj__361);
  Py_VISIT(traverse_module_state->__pyx_codeobj__362);
  Py_VISIT(traverse_module_state->__pyx_codeobj__363);
  Py_VISIT(traverse_module_state->__pyx_codeobj__364);
  Py_VISIT(traverse_module_state->__pyx_codeobj__366);
  Py_VISIT(traverse_module_state->__pyx_codeobj__367);
  Py_VISIT(traverse_module_state->__pyx_codeobj__368);
  Py_VISIT(traverse_module_state->__pyx_codeobj__369);
  Py_VISIT(traverse_module_state->__pyx_codeobj__370);
  Py_VISIT(traverse_module_state->__pyx_codeobj__371);
  Py_VISIT(traverse_module_state->__pyx_codeobj__372);
  Py_VISIT(traverse_module_state->__pyx_codeobj__373);
  Py_VISIT(traverse_module_state->__pyx_codeobj__375);
  Py_VISIT(traverse_module_state->__pyx_codeobj__377);
  Py_VISIT(traverse_module_state->__pyx_codeobj__379);
  Py_VISIT(traverse_module_state->__pyx_codeobj__380);
  Py_VISIT(traverse_module_state->__pyx_codeobj__382);
  Py_VISIT(traverse_module_state->__pyx_codeobj__384);
  Py_VISIT(traverse_module_state->__pyx_codeobj__386);
  Py_VISIT(traverse_module_state->__pyx_codeobj__389);
  Py_VISIT(traverse_module_state->__pyx_codeobj__390);
  Py_VISIT(traverse_module_state->__pyx_codeobj__391);
  Py_VISIT(traverse_module_state->__pyx_codeobj__392);
  Py_VISIT(traverse_module_state->__pyx_codeobj__394);
  Py_VISIT(traverse_module_state->__pyx_codeobj__397);
  Py_VISIT(traverse_module_state->__pyx_codeobj__400);
  Py_VISIT(traverse_module_state->__pyx_codeobj__403);
  Py_VISIT(traverse_module_state->__pyx_codeobj__404);
  Py_VISIT(traverse_module_state->__pyx_codeobj__406);
  Py_VISIT(traverse_module_state->__pyx_codeobj__408);
  Py_VISIT(traverse_module_state->__pyx_codeobj__411);
  Py_VISIT(traverse_module_state->__pyx_codeobj__413);
  Py_VISIT(traverse_module_state->__pyx_codeobj__415);
  Py_VISIT(traverse_module_state->__pyx_codeobj__418);
  Py_VISIT(traverse_module_state->__pyx_codeobj__419);
  Py_VISIT(traverse_module_state->__pyx_codeobj__421);
  Py_VISIT(traverse_module_state->__pyx_codeobj__423);
  Py_VISIT(traverse_module_state->__pyx_codeobj__425);
  Py_VISIT(traverse_module_state->__pyx_codeobj__426);
  Py_VISIT(traverse_module_state->__pyx_codeobj__428);
  Py_VISIT(traverse_module_state->__pyx_codeobj__430);
  Py_VISIT(traverse_module_state->__pyx_codeobj__431);
  Py_VISIT(traverse_module_state->__pyx_codeobj__432);
  Py_VISIT(traverse_module_state->__pyx_codeobj__434);
  Py_VISIT(traverse_module_state->__pyx_codeobj__436);
  Py_VISIT(traverse_module_state->__pyx_codeobj__438);
  Py_VISIT(traverse_module_state->__pyx_codeobj__439);
  Py_VISIT(traverse_module_state->__pyx_codeobj__441);
  Py_VISIT(traverse_module_state->__pyx_codeobj__442);
  Py_VISIT(traverse_module_state->__pyx_codeobj__443);
  Py_VISIT(traverse_module_state->__pyx_codeobj__445);
  Py_VISIT(traverse_module_state->__pyx_codeobj__446);
  Py_VISIT(traverse_module_state->__pyx_codeobj__447);
  Py_VISIT(traverse_module_state->__pyx_codeobj__448);
  Py_VISIT(traverse_module_state->__pyx_codeobj__449);
  Py_VISIT(traverse_module_state->__pyx_codeobj__450);
  Py_VISIT(traverse_module_state->__pyx_codeobj__451);
  Py_VISIT(traverse_module_state->__pyx_codeobj__452);
  Py_VISIT(traverse_module_state->__pyx_codeobj__453);
  Py_VISIT(traverse_module_state->__pyx_codeobj__454);
  Py_VISIT(traverse_module_state->__pyx_codeobj__455);
  Py_VISIT(traverse_module_state->__pyx_codeobj__457);
  Py_VISIT(traverse_module_state->__pyx_codeobj__459);
  Py_VISIT(traverse_module_state->__pyx_codeobj__460);
  Py_VISIT(traverse_module_state->__pyx_codeobj__461);
  Py_VISIT(traverse_module_state->__pyx_codeobj__463);
  Py_VISIT(traverse_module_state->__pyx_codeobj__465);
  Py_VISIT(traverse_module_state->__pyx_codeobj__466);
  Py_VISIT(traverse_module_state->__pyx_codeobj__467);
  Py_VISIT(traverse_module_state->__pyx_codeobj__469);
  Py_VISIT(traverse_module_state->__pyx_codeobj__471);
  Py_VISIT(traverse_module_state->__pyx_codeobj__473);
  Py_VISIT(traverse_module_state->__pyx_codeobj__475);
  Py_VISIT(traverse_module_state->__pyx_codeobj__477);
  Py_VISIT(traverse_module_state->__pyx_codeobj__479);
  Py_VISIT(traverse_module_state->__pyx_codeobj__481);
  Py_VISIT(traverse_module_state->__pyx_codeobj__484);
  Py_VISIT(traverse_module_state->__pyx_codeobj__485);
  Py_VISIT(traverse_module_state->__pyx_codeobj__487);
  Py_VISIT(traverse_module_state->__pyx_codeobj__488);
  Py_VISIT(traverse_module_state->__pyx_codeobj__489);
  Py_VISIT(traverse_module_state->__pyx_codeobj__490);
  Py_VISIT(traverse_module_state->__pyx_codeobj__491);
  Py_VISIT(traverse_module_state->__pyx_codeobj__492);
  Py_VISIT(traverse_module_state->__pyx_codeobj__494);
  Py_VISIT(traverse_module_state->__pyx_codeobj__495);
  Py_VISIT(traverse_module_state->__pyx_codeobj__496);
  Py_VISIT(traverse_module_state->__pyx_codeobj__498);
  Py_VISIT(traverse_module_state->__pyx_codeobj__500);
  Py_VISIT(traverse_module_state->__pyx_codeobj__501);
  Py_VISIT(traverse_module_state->__pyx_codeobj__502);
  Py_VISIT(traverse_module_state->__pyx_codeobj__503);
  Py_VISIT(traverse_module_state->__pyx_codeobj__505);
  Py_VISIT(traverse_module_state->__pyx_codeobj__508);
  Py_VISIT(traverse_module_state->__pyx_codeobj__510);
  Py_VISIT(traverse_module_state->__pyx_codeobj__512);
  Py_VISIT(traverse_module_state->__pyx_codeobj__514);
  Py_VISIT(traverse_module_state->__pyx_codeobj__515);
  Py_VISIT(traverse_module_state->__pyx_codeobj__517);
  Py_VISIT(traverse_module_state->__pyx_codeobj__520);
  Py_VISIT(traverse_module_state->__pyx_codeobj__522);
  Py_VISIT(traverse_module_state->__pyx_codeobj__523);
  Py_VISIT(traverse_module_state->__pyx_codeobj__525);
  Py_VISIT(traverse_module_state->__pyx_codeobj__526);
  Py_VISIT(traverse_module_state->__pyx_codeobj__528);
  Py_VISIT(traverse_module_state->__pyx_codeobj__529);
  Py_VISIT(traverse_module_state->__pyx_codeobj__531);
  Py_VISIT(traverse_module_state->__pyx_codeobj__532);
  Py_VISIT(traverse_module_state->__pyx_codeobj__534);
  Py_VISIT(traverse_module_state->__pyx_codeobj__535);
  Py_VISIT(traverse_module_state->__pyx_codeobj__537);
  Py_VISIT(traverse_module_state->__pyx_codeobj__538);
  Py_VISIT(traverse_module_state->__pyx_codeobj__540);
  Py_VISIT(traverse_module_state->__pyx_codeobj__541);
  Py_VISIT(traverse_module_state->__pyx_codeobj__543);
  Py_VISIT(traverse_module_state->__pyx_codeobj__544);
  Py_VISIT(traverse_module_state->__pyx_codeobj__545);
  Py_VISIT(traverse_module_state->__pyx_codeobj__546);
  Py_VISIT(traverse_module_state->__pyx_codeobj__547);
  Py_VISIT(traverse_module_state->__pyx_codeobj__548);
  Py_VISIT(traverse_module_state->__pyx_codeobj__549);
  Py_VISIT(traverse_module_state->__pyx_codeobj__550);
  Py_VISIT(traverse_module_state->__pyx_codeobj__551);
  Py_VISIT(traverse_module_state->__pyx_codeobj__553);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_4type_type __pyx_mstate_global->__pyx_ptype_7cpython_4type_type
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_5numpy_dtype __pyx_mstate_global->__pyx_ptype_5numpy_dtype
#define __pyx_ptype_5numpy_flatiter __pyx_mstate_global->__pyx_ptype_5numpy_flatiter
#define __pyx_ptype_5numpy_broadcast __pyx_mstate_global->__pyx_ptype_5numpy_broadcast
#define __pyx_ptype_5numpy_ndarray __pyx_mstate_global->__pyx_ptype_5numpy_ndarray
#define __pyx_ptype_5numpy_generic __pyx_mstate_global->__pyx_ptype_5numpy_generic
#define __pyx_ptype_5numpy_number __pyx_mstate_global->__pyx_ptype_5numpy_number
#define __pyx_ptype_5numpy_integer __pyx_mstate_global->__pyx_ptype_5numpy_integer
#define __pyx_ptype_5numpy_signedinteger __pyx_mstate_global->__pyx_ptype_5numpy_signedinteger
#define __pyx_ptype_5numpy_unsignedinteger __pyx_mstate_global->__pyx_ptype_5numpy_unsignedinteger
#define __pyx_ptype_5numpy_inexact __pyx_mstate_global->__pyx_ptype_5numpy_inexact
#define __pyx_ptype_5numpy_floating __pyx_mstate_global->__pyx_ptype_5numpy_floating
#define __pyx_ptype_5numpy_complexfloating __pyx_mstate_global->__pyx_ptype_5numpy_complexfloating
#define __pyx_ptype_5numpy_flexible __pyx_mstate_global->__pyx_ptype_5numpy_flexible
#define __pyx_ptype_5numpy_character __pyx_mstate_global->__pyx_ptype_5numpy_character
#define __pyx_ptype_5numpy_ufunc __pyx_mstate_global->__pyx_ptype_5numpy_ufunc
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_9classy_sz_Class __pyx_mstate_global->__pyx_type_9classy_sz_Class
#define __pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings __pyx_mstate_global->__pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings
#define __pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast __pyx_mstate_global->__pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast
#define __pyx_type_9classy_sz___pyx_scope_struct_2_genexpr __pyx_mstate_global->__pyx_type_9classy_sz___pyx_scope_struct_2_genexpr
#define __pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl __pyx_mstate_global->__pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl
#define __pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl __pyx_mstate_global->__pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl
#define __pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw __pyx_mstate_global->__pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw
#define __pyx_type___pyx_array __pyx_mstate_global->__pyx_type___pyx_array
#define __pyx_type___pyx_MemviewEnum __pyx_mstate_global->__pyx_type___pyx_MemviewEnum
#define __pyx_type___pyx_memoryview __pyx_mstate_global->__pyx_type___pyx_memoryview
#define __pyx_type___pyx_memoryviewslice __pyx_mstate_global->__pyx_type___pyx_memoryviewslice
#endif
#define __pyx_ptype_9classy_sz_Class __pyx_mstate_global->__pyx_ptype_9classy_sz_Class
#define __pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings __pyx_mstate_global->__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings
#define __pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast __pyx_mstate_global->__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast
#define __pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr __pyx_mstate_global->__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr
#define __pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl __pyx_mstate_global->__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl
#define __pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl __pyx_mstate_global->__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl
#define __pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw __pyx_mstate_global->__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw
#define __pyx_array_type __pyx_mstate_global->__pyx_array_type
#define __pyx_MemviewEnum_type __pyx_mstate_global->__pyx_MemviewEnum_type
#define __pyx_memoryview_type __pyx_mstate_global->__pyx_memoryview_type
#define __pyx_memoryviewslice_type __pyx_mstate_global->__pyx_memoryviewslice_type
#define __pyx_kp_u_ __pyx_mstate_global->__pyx_kp_u_
#define __pyx_kp_u_100_theta_s __pyx_mstate_global->__pyx_kp_u_100_theta_s
#define __pyx_kp_u_100_theta_star __pyx_mstate_global->__pyx_kp_u_100_theta_star
#define __pyx_kp_u_1h __pyx_mstate_global->__pyx_kp_u_1h
#define __pyx_kp_u_1h_2h_3h __pyx_mstate_global->__pyx_kp_u_1h_2h_3h
#define __pyx_kp_u_1h_2h_hf_3h_covmat_lensing_te __pyx_mstate_global->__pyx_kp_u_1h_2h_hf_3h_covmat_lensing_te
#define __pyx_kp_u_1h_slow __pyx_mstate_global->__pyx_kp_u_1h_slow
#define __pyx_kp_u_2h __pyx_mstate_global->__pyx_kp_u_2h
#define __pyx_kp_u_2h_slow __pyx_mstate_global->__pyx_kp_u_2h_slow
#define __pyx_kp_u_3h __pyx_mstate_global->__pyx_kp_u_3h
#define __pyx_kp_u_3h_slow __pyx_mstate_global->__pyx_kp_u_3h_slow
#define __pyx_n_s_A __pyx_mstate_global->__pyx_n_s_A
#define __pyx_n_u_A10_file __pyx_mstate_global->__pyx_n_u_A10_file
#define __pyx_n_s_ASCII __pyx_mstate_global->__pyx_n_s_ASCII
#define __pyx_n_u_A_IA __pyx_mstate_global->__pyx_n_u_A_IA
#define __pyx_n_s_A_P0 __pyx_mstate_global->__pyx_n_s_A_P0
#define __pyx_n_s_A_alpha __pyx_mstate_global->__pyx_n_s_A_alpha
#define __pyx_n_u_A_alpha __pyx_mstate_global->__pyx_n_u_A_alpha
#define __pyx_n_s_A_beta __pyx_mstate_global->__pyx_n_s_A_beta
#define __pyx_n_u_A_beta __pyx_mstate_global->__pyx_n_u_A_beta
#define __pyx_n_s_A_cib __pyx_mstate_global->__pyx_n_s_A_cib
#define __pyx_n_s_A_cn __pyx_mstate_global->__pyx_n_s_A_cn
#define __pyx_n_s_A_ir __pyx_mstate_global->__pyx_n_s_A_ir
#define __pyx_n_s_A_rho0 __pyx_mstate_global->__pyx_n_s_A_rho0
#define __pyx_n_u_A_rho0 __pyx_mstate_global->__pyx_n_u_A_rho0
#define __pyx_n_s_A_rs __pyx_mstate_global->__pyx_n_s_A_rs
#define __pyx_n_u_A_s __pyx_mstate_global->__pyx_n_u_A_s
#define __pyx_n_s_A_s_fast __pyx_mstate_global->__pyx_n_s_A_s_fast
#define __pyx_n_s_A_sn __pyx_mstate_global->__pyx_n_s_A_sn
#define __pyx_n_s_A_xc __pyx_mstate_global->__pyx_n_s_A_xc
#define __pyx_kp_s_All_dimensions_preceding_dimensi __pyx_mstate_global->__pyx_kp_s_All_dimensions_preceding_dimensi
#define __pyx_kp_u_All_inputs_should_be_floats_or_1 __pyx_mstate_global->__pyx_kp_u_All_inputs_should_be_floats_or_1
#define __pyx_n_u_As __pyx_mstate_global->__pyx_n_u_As
#define __pyx_n_s_AssertionError __pyx_mstate_global->__pyx_n_s_AssertionError
#define __pyx_n_s_B __pyx_mstate_global->__pyx_n_s_B
#define __pyx_n_s_B_sz __pyx_mstate_global->__pyx_n_s_B_sz
#define __pyx_kp_s_Buffer_view_does_not_expose_stri __pyx_mstate_global->__pyx_kp_s_Buffer_view_does_not_expose_stri
#define __pyx_n_s_CRITICAL __pyx_mstate_global->__pyx_n_s_CRITICAL
#define __pyx_kp_u_Can_only_compute_up_to_lmax_d __pyx_mstate_global->__pyx_kp_u_Can_only_compute_up_to_lmax_d
#define __pyx_kp_s_Can_only_create_a_buffer_that_is __pyx_mstate_global->__pyx_kp_s_Can_only_create_a_buffer_that_is
#define __pyx_kp_s_Cannot_assign_to_read_only_memor __pyx_mstate_global->__pyx_kp_s_Cannot_assign_to_read_only_memor
#define __pyx_kp_s_Cannot_create_writable_memory_vi __pyx_mstate_global->__pyx_kp_s_Cannot_create_writable_memory_vi
#define __pyx_kp_u_Cannot_index_with_type __pyx_mstate_global->__pyx_kp_u_Cannot_index_with_type
#define __pyx_kp_s_Cannot_transpose_memoryview_with __pyx_mstate_global->__pyx_kp_s_Cannot_transpose_memoryview_with
#define __pyx_n_s_Class __pyx_mstate_global->__pyx_n_s_Class
#define __pyx_n_s_Class_A_cib __pyx_mstate_global->__pyx_n_s_Class_A_cib
#define __pyx_n_s_Class_A_cn __pyx_mstate_global->__pyx_n_s_Class_A_cn
#define __pyx_n_s_Class_A_ir __pyx_mstate_global->__pyx_n_s_Class_A_ir
#define __pyx_n_s_Class_A_rs __pyx_mstate_global->__pyx_n_s_Class_A_rs
#define __pyx_n_s_Class_A_sn __pyx_mstate_global->__pyx_n_s_Class_A_sn
#define __pyx_n_s_Class_B_sz __pyx_mstate_global->__pyx_n_s_Class_B_sz
#define __pyx_n_s_Class_Hubble __pyx_mstate_global->__pyx_n_s_Class_Hubble
#define __pyx_n_s_Class_M1SZ __pyx_mstate_global->__pyx_n_s_Class_M1SZ
#define __pyx_n_s_Class_Neff __pyx_mstate_global->__pyx_n_s_Class_Neff
#define __pyx_n_s_Class_Om_m __pyx_mstate_global->__pyx_n_s_Class_Om_m
#define __pyx_n_s_Class_Omega0_b __pyx_mstate_global->__pyx_n_s_Class_Omega0_b
#define __pyx_n_s_Class_Omega0_cdm __pyx_mstate_global->__pyx_n_s_Class_Omega0_cdm
#define __pyx_n_s_Class_Omega0_k __pyx_mstate_global->__pyx_n_s_Class_Omega0_k
#define __pyx_n_s_Class_Omega0_m __pyx_mstate_global->__pyx_n_s_Class_Omega0_m
#define __pyx_n_s_Class_Omega_Lambda __pyx_mstate_global->__pyx_n_s_Class_Omega_Lambda
#define __pyx_n_s_Class_Omega_b __pyx_mstate_global->__pyx_n_s_Class_Omega_b
#define __pyx_n_s_Class_Omega_g __pyx_mstate_global->__pyx_n_s_Class_Omega_g
#define __pyx_n_s_Class_Omega_m __pyx_mstate_global->__pyx_n_s_Class_Omega_m
#define __pyx_n_s_Class_Omega_r __pyx_mstate_global->__pyx_n_s_Class_Omega_r
#define __pyx_n_s_Class_Rho_crit_0 __pyx_mstate_global->__pyx_n_s_Class_Rho_crit_0
#define __pyx_n_s_Class_T_cmb __pyx_mstate_global->__pyx_n_s_Class_T_cmb
#define __pyx_n_s_Class___reduce_cython __pyx_mstate_global->__pyx_n_s_Class___reduce_cython
#define __pyx_n_s_Class___setstate_cython __pyx_mstate_global->__pyx_n_s_Class___setstate_cython
#define __pyx_n_s_Class__check_task_dependency __pyx_mstate_global->__pyx_n_s_Class__check_task_dependency
#define __pyx_n_s_Class__cumulativeNumberDensity __pyx_mstate_global->__pyx_n_s_Class__cumulativeNumberDensity
#define __pyx_n_s_Class__fillparfile __pyx_mstate_global->__pyx_n_s_Class__fillparfile
#define __pyx_n_s_Class__pars_check __pyx_mstate_global->__pyx_n_s_Class__pars_check
#define __pyx_n_s_Class_age __pyx_mstate_global->__pyx_n_s_Class_age
#define __pyx_n_s_Class_alpha __pyx_mstate_global->__pyx_n_s_Class_alpha
#define __pyx_n_s_Class_angular_distance __pyx_mstate_global->__pyx_n_s_Class_angular_distance
#define __pyx_n_s_Class_b_tty __pyx_mstate_global->__pyx_n_s_Class_b_tty
#define __pyx_n_s_Class_b_yyy __pyx_mstate_global->__pyx_n_s_Class_b_yyy
#define __pyx_n_s_Class_baryon_temperature __pyx_mstate_global->__pyx_n_s_Class_baryon_temperature
#define __pyx_n_s_Class_bk_at_z_hm __pyx_mstate_global->__pyx_n_s_Class_bk_at_z_hm
#define __pyx_n_s_Class_bk_ttg_at_z_hm __pyx_mstate_global->__pyx_n_s_Class_bk_ttg_at_z_hm
#define __pyx_n_s_Class_calcFRel __pyx_mstate_global->__pyx_n_s_Class_calcFRel
#define __pyx_n_s_Class_calculate_pkl_fftlog_alpha __pyx_mstate_global->__pyx_n_s_Class_calculate_pkl_fftlog_alpha
#define __pyx_n_s_Class_chi_star __pyx_mstate_global->__pyx_n_s_Class_chi_star
#define __pyx_n_s_Class_cib_monopole __pyx_mstate_global->__pyx_n_s_Class_cib_monopole
#define __pyx_n_s_Class_cib_shotnoise __pyx_mstate_global->__pyx_n_s_Class_cib_shotnoise
#define __pyx_n_s_Class_cl_IA_g __pyx_mstate_global->__pyx_n_s_Class_cl_IA_g
#define __pyx_n_s_Class_cl_c1_gal __pyx_mstate_global->__pyx_n_s_Class_cl_c1_gal
#define __pyx_n_s_Class_cl_c1_gallens __pyx_mstate_global->__pyx_n_s_Class_cl_c1_gallens
#define __pyx_n_s_Class_cl_c1_lens __pyx_mstate_global->__pyx_n_s_Class_cl_c1_lens
#define __pyx_n_s_Class_cl_c1_tSZ __pyx_mstate_global->__pyx_n_s_Class_cl_c1_tSZ
#define __pyx_n_s_Class_cl_c1c1 __pyx_mstate_global->__pyx_n_s_Class_cl_c1c1
#define __pyx_n_s_Class_cl_cib_cib __pyx_mstate_global->__pyx_n_s_Class_cl_cib_cib
#define __pyx_n_s_Class_cl_custom1_cib __pyx_mstate_global->__pyx_n_s_Class_cl_custom1_cib
#define __pyx_n_s_Class_cl_ee __pyx_mstate_global->__pyx_n_s_Class_cl_ee
#define __pyx_n_s_Class_cl_eg __pyx_mstate_global->__pyx_n_s_Class_cl_eg
#define __pyx_n_s_Class_cl_gal_cib __pyx_mstate_global->__pyx_n_s_Class_cl_gal_cib
#define __pyx_n_s_Class_cl_gal_gal_kcmb __pyx_mstate_global->__pyx_n_s_Class_cl_gal_gal_kcmb
#define __pyx_n_s_Class_cl_galn_IA __pyx_mstate_global->__pyx_n_s_Class_cl_galn_IA
#define __pyx_n_s_Class_cl_galn_gallens __pyx_mstate_global->__pyx_n_s_Class_cl_galn_gallens
#define __pyx_n_s_Class_cl_galn_galn __pyx_mstate_global->__pyx_n_s_Class_cl_galn_galn
#define __pyx_n_s_Class_cl_galn_lens __pyx_mstate_global->__pyx_n_s_Class_cl_galn_lens
#define __pyx_n_s_Class_cl_galn_tsz __pyx_mstate_global->__pyx_n_s_Class_cl_galn_tsz
#define __pyx_n_s_Class_cl_gg __pyx_mstate_global->__pyx_n_s_Class_cl_gg
#define __pyx_n_s_Class_cl_ggamma __pyx_mstate_global->__pyx_n_s_Class_cl_ggamma
#define __pyx_n_s_Class_cl_gm __pyx_mstate_global->__pyx_n_s_Class_cl_gm
#define __pyx_n_s_Class_cl_kSZ_kSZ_g __pyx_mstate_global->__pyx_n_s_Class_cl_kSZ_kSZ_g
#define __pyx_n_s_Class_cl_kSZ_kSZ_kcmb __pyx_mstate_global->__pyx_n_s_Class_cl_kSZ_kSZ_kcmb
#define __pyx_n_s_Class_cl_kSZ_kSZ_kg __pyx_mstate_global->__pyx_n_s_Class_cl_kSZ_kSZ_kg
#define __pyx_n_s_Class_cl_kg __pyx_mstate_global->__pyx_n_s_Class_cl_kg
#define __pyx_n_s_Class_cl_kg_cib __pyx_mstate_global->__pyx_n_s_Class_cl_kg_cib
#define __pyx_n_s_Class_cl_kg_k __pyx_mstate_global->__pyx_n_s_Class_cl_kg_k
#define __pyx_n_s_Class_cl_kg_kg __pyx_mstate_global->__pyx_n_s_Class_cl_kg_kg
#define __pyx_n_s_Class_cl_kg_m __pyx_mstate_global->__pyx_n_s_Class_cl_kg_m
#define __pyx_n_s_Class_cl_kk __pyx_mstate_global->__pyx_n_s_Class_cl_kk
#define __pyx_n_s_Class_cl_km __pyx_mstate_global->__pyx_n_s_Class_cl_km
#define __pyx_n_s_Class_cl_ksz __pyx_mstate_global->__pyx_n_s_Class_cl_ksz
#define __pyx_n_s_Class_cl_lens_cib __pyx_mstate_global->__pyx_n_s_Class_cl_lens_cib
#define __pyx_n_s_Class_cl_lensmagn_gallens __pyx_mstate_global->__pyx_n_s_Class_cl_lensmagn_gallens
#define __pyx_n_s_Class_cl_lensmagn_tsz __pyx_mstate_global->__pyx_n_s_Class_cl_lensmagn_tsz
#define __pyx_n_s_Class_cl_mm __pyx_mstate_global->__pyx_n_s_Class_cl_mm
#define __pyx_n_s_Class_cl_sz __pyx_mstate_global->__pyx_n_s_Class_cl_sz
#define __pyx_n_s_Class_cl_sz_at_nu_in_GHz_in_micr __pyx_mstate_global->__pyx_n_s_Class_cl_sz_at_nu_in_GHz_in_micr
#define __pyx_n_s_Class_cl_t2t2f __pyx_mstate_global->__pyx_n_s_Class_cl_t2t2f
#define __pyx_n_s_Class_cl_tSZ_cib __pyx_mstate_global->__pyx_n_s_Class_cl_tSZ_cib
#define __pyx_n_s_Class_cl_te_y_y __pyx_mstate_global->__pyx_n_s_Class_cl_te_y_y
#define __pyx_n_s_Class_cl_y_kcmb __pyx_mstate_global->__pyx_n_s_Class_cl_y_kcmb
#define __pyx_n_s_Class_cl_yg __pyx_mstate_global->__pyx_n_s_Class_cl_yg
#define __pyx_n_s_Class_cl_ykg __pyx_mstate_global->__pyx_n_s_Class_cl_ykg
#define __pyx_n_s_Class_cl_ym __pyx_mstate_global->__pyx_n_s_Class_cl_ym
#define __pyx_n_s_Class_compute __pyx_mstate_global->__pyx_n_s_Class_compute
#define __pyx_n_s_Class_compute_class_sz __pyx_mstate_global->__pyx_n_s_Class_compute_class_sz
#define __pyx_n_s_Class_compute_class_szfast __pyx_mstate_global->__pyx_n_s_Class_compute_class_szfast
#define __pyx_n_s_Class_delta_def_custom1 __pyx_mstate_global->__pyx_n_s_Class_delta_def_custom1
#define __pyx_n_s_Class_density_cl __pyx_mstate_global->__pyx_n_s_Class_density_cl
#define __pyx_kp_u_Class_did_not_read_input_paramet __pyx_mstate_global->__pyx_kp_u_Class_did_not_read_input_paramet
#define __pyx_n_s_Class_dl_isw_sz __pyx_mstate_global->__pyx_n_s_Class_dl_isw_sz
#define __pyx_n_s_Class_dndzdy_theoretical __pyx_mstate_global->__pyx_n_s_Class_dndzdy_theoretical
#define __pyx_n_s_Class_effective_f_sigma8 __pyx_mstate_global->__pyx_n_s_Class_effective_f_sigma8
#define __pyx_n_s_Class_effective_galaxy_bias __pyx_mstate_global->__pyx_n_s_Class_effective_galaxy_bias
#define __pyx_n_s_Class_empty __pyx_mstate_global->__pyx_n_s_Class_empty
#define __pyx_n_s_Class_gamma_ggamma __pyx_mstate_global->__pyx_n_s_Class_gamma_ggamma
#define __pyx_n_s_Class_getM500_from_y0_H13 __pyx_mstate_global->__pyx_n_s_Class_getM500_from_y0_H13
#define __pyx_n_s_Class_getPLog10M __pyx_mstate_global->__pyx_n_s_Class_getPLog10M
#define __pyx_n_s_Class_get_1e6xdy_from_battaglia __pyx_mstate_global->__pyx_n_s_Class_get_1e6xdy_from_battaglia
#define __pyx_n_s_Class_get_1e6xdy_from_gnfw_press __pyx_mstate_global->__pyx_n_s_Class_get_1e6xdy_from_gnfw_press
#define __pyx_n_s_Class_get_Delta_c_of_Omega_m __pyx_mstate_global->__pyx_n_s_Class_get_Delta_c_of_Omega_m
#define __pyx_n_s_Class_get_Ez __pyx_mstate_global->__pyx_n_s_Class_get_Ez
#define __pyx_n_s_Class_get_H __pyx_mstate_global->__pyx_n_s_Class_get_H
#define __pyx_n_s_Class_get_IA_of_z __pyx_mstate_global->__pyx_n_s_Class_get_IA_of_z
#define __pyx_n_s_Class_get_N_centrals __pyx_mstate_global->__pyx_n_s_Class_get_N_centrals
#define __pyx_n_s_Class_get_N_satellites __pyx_mstate_global->__pyx_n_s_Class_get_N_satellites
#define __pyx_n_s_Class_get_Omega_m_0 __pyx_mstate_global->__pyx_n_s_Class_get_Omega_m_0
#define __pyx_n_s_Class_get_Omega_m_at_z __pyx_mstate_global->__pyx_n_s_Class_get_Omega_m_at_z
#define __pyx_n_s_Class_get_Omega_r_0 __pyx_mstate_global->__pyx_n_s_Class_get_Omega_r_0
#define __pyx_n_s_Class_get_P_delta_at_m_and_z_b12 __pyx_mstate_global->__pyx_n_s_Class_get_P_delta_at_m_and_z_b12
#define __pyx_n_s_Class_get_T10_alpha_at_z __pyx_mstate_global->__pyx_n_s_Class_get_T10_alpha_at_z
#define __pyx_n_s_Class_get_arcmin_to_rad __pyx_mstate_global->__pyx_n_s_Class_get_arcmin_to_rad
#define __pyx_n_s_Class_get_background __pyx_mstate_global->__pyx_n_s_Class_get_background
#define __pyx_n_s_Class_get_bispectrum_f2_kernel __pyx_mstate_global->__pyx_n_s_Class_get_bispectrum_f2_kernel
#define __pyx_n_s_Class_get_c200c_at_m_and_z __pyx_mstate_global->__pyx_n_s_Class_get_c200c_at_m_and_z
#define __pyx_n_s_Class_get_c200c_at_m_and_z_B13 __pyx_mstate_global->__pyx_n_s_Class_get_c200c_at_m_and_z_B13
#define __pyx_n_s_Class_get_c200c_at_m_and_z_D08 __pyx_mstate_global->__pyx_n_s_Class_get_c200c_at_m_and_z_D08
#define __pyx_n_s_Class_get_c200m_at_m_and_z __pyx_mstate_global->__pyx_n_s_Class_get_c200m_at_m_and_z
#define __pyx_n_s_Class_get_c200m_at_m_and_z_D08 __pyx_mstate_global->__pyx_n_s_Class_get_c200m_at_m_and_z_D08
#define __pyx_n_s_Class_get_c500c_at_m_and_z __pyx_mstate_global->__pyx_n_s_Class_get_c500c_at_m_and_z
#define __pyx_n_s_Class_get_c_delta_at_m_and_z __pyx_mstate_global->__pyx_n_s_Class_get_c_delta_at_m_and_z
#define __pyx_n_s_Class_get_chi __pyx_mstate_global->__pyx_n_s_Class_get_chi
#define __pyx_n_s_Class_get_cib_Snu_z_and_nu __pyx_mstate_global->__pyx_n_s_Class_get_cib_Snu_z_and_nu
#define __pyx_n_s_Class_get_comoving_volume __pyx_mstate_global->__pyx_n_s_Class_get_comoving_volume
#define __pyx_n_s_Class_get_cov_N_N __pyx_mstate_global->__pyx_n_s_Class_get_cov_N_N
#define __pyx_n_s_Class_get_current_derived_parame __pyx_mstate_global->__pyx_n_s_Class_get_current_derived_parame
#define __pyx_n_s_Class_get_custom1_bias_at_z __pyx_mstate_global->__pyx_n_s_Class_get_custom1_bias_at_z
#define __pyx_n_s_Class_get_custom1_profile_at_k_m __pyx_mstate_global->__pyx_n_s_Class_get_custom1_profile_at_k_m
#define __pyx_n_s_Class_get_custom1_profile_at_x_m __pyx_mstate_global->__pyx_n_s_Class_get_custom1_profile_at_x_m
#define __pyx_n_s_Class_get_cvir_of_mvir_at_z __pyx_mstate_global->__pyx_n_s_Class_get_cvir_of_mvir_at_z
#define __pyx_n_s_Class_get_dA __pyx_mstate_global->__pyx_n_s_Class_get_dA
#define __pyx_n_s_Class_get_dA_z1z2 __pyx_mstate_global->__pyx_n_s_Class_get_dA_z1z2
#define __pyx_n_s_Class_get_dcib0dz_at_z_and_nu __pyx_mstate_global->__pyx_n_s_Class_get_dcib0dz_at_z_and_nu
#define __pyx_n_s_Class_get_delta_from_delta_def_a __pyx_mstate_global->__pyx_n_s_Class_get_delta_from_delta_def_a
#define __pyx_n_s_Class_get_delta_mean_from_delta __pyx_mstate_global->__pyx_n_s_Class_get_delta_mean_from_delta
#define __pyx_n_s_Class_get_dkappacmbdz_at_l_and_z __pyx_mstate_global->__pyx_n_s_Class_get_dkappacmbdz_at_l_and_z
#define __pyx_n_s_Class_get_dlnsigma_dlnR_at_z_and __pyx_mstate_global->__pyx_n_s_Class_get_dlnsigma_dlnR_at_z_and
#define __pyx_n_s_Class_get_dndlnM_at_z_and_M __pyx_mstate_global->__pyx_n_s_Class_get_dndlnM_at_z_and_M
#define __pyx_n_s_Class_get_dndlnm __pyx_mstate_global->__pyx_n_s_Class_get_dndlnm
#define __pyx_n_s_Class_get_dydz_at_z __pyx_mstate_global->__pyx_n_s_Class_get_dydz_at_z
#define __pyx_n_s_Class_get_dydzdlnm_at_z_and_m __pyx_mstate_global->__pyx_n_s_Class_get_dydzdlnm_at_z_and_m
#define __pyx_n_s_Class_get_effective_f_sigma8 __pyx_mstate_global->__pyx_n_s_Class_get_effective_f_sigma8
#define __pyx_n_s_Class_get_f_b __pyx_mstate_global->__pyx_n_s_Class_get_f_b
#define __pyx_n_s_Class_get_f_free __pyx_mstate_global->__pyx_n_s_Class_get_f_free
#define __pyx_n_s_Class_get_f_of_sigma_at_m_and_z __pyx_mstate_global->__pyx_n_s_Class_get_f_of_sigma_at_m_and_z
#define __pyx_n_s_Class_get_f_tinker08_at_nu_and_z __pyx_mstate_global->__pyx_n_s_Class_get_f_tinker08_at_nu_and_z
#define __pyx_n_s_Class_get_f_tinker10_at_nu_and_z __pyx_mstate_global->__pyx_n_s_Class_get_f_tinker10_at_nu_and_z
#define __pyx_n_s_Class_get_fftlog_ComputeXiLMsloz __pyx_mstate_global->__pyx_n_s_Class_get_fftlog_ComputeXiLMsloz
#define __pyx_n_s_Class_get_first_order_bias_at_z __pyx_mstate_global->__pyx_n_s_Class_get_first_order_bias_at_z
#define __pyx_n_s_Class_get_first_order_bias_at_z_2 __pyx_mstate_global->__pyx_n_s_Class_get_first_order_bias_at_z_2
#define __pyx_n_s_Class_get_first_order_bias_at_z_3 __pyx_mstate_global->__pyx_n_s_Class_get_first_order_bias_at_z_3
#define __pyx_n_s_Class_get_fstar_of_m_at_z __pyx_mstate_global->__pyx_n_s_Class_get_fstar_of_m_at_z
#define __pyx_n_s_Class_get_galaxy_number_counts __pyx_mstate_global->__pyx_n_s_Class_get_galaxy_number_counts
#define __pyx_n_s_Class_get_gas_density_profile_at __pyx_mstate_global->__pyx_n_s_Class_get_gas_density_profile_at
#define __pyx_n_s_Class_get_gas_pressure_2h_at_r_a __pyx_mstate_global->__pyx_n_s_Class_get_gas_pressure_2h_at_r_a
#define __pyx_n_s_Class_get_gas_profile_at_x_M_z_b __pyx_mstate_global->__pyx_n_s_Class_get_gas_profile_at_x_M_z_b
#define __pyx_n_s_Class_get_gas_profile_at_x_M_z_b_2 __pyx_mstate_global->__pyx_n_s_Class_get_gas_profile_at_x_M_z_b_2
#define __pyx_n_s_Class_get_gas_profile_at_x_M_z_n __pyx_mstate_global->__pyx_n_s_Class_get_gas_profile_at_x_M_z_n
#define __pyx_n_s_Class_get_gas_profile_at_x_M_z_n_2 __pyx_mstate_global->__pyx_n_s_Class_get_gas_profile_at_x_M_z_n_2
#define __pyx_n_s_Class_get_gnu_tsz_of_nu_in_ghz __pyx_mstate_global->__pyx_n_s_Class_get_gnu_tsz_of_nu_in_ghz
#define __pyx_n_s_Class_get_hmf_counter_term_b1min __pyx_mstate_global->__pyx_n_s_Class_get_hmf_counter_term_b1min
#define __pyx_n_s_Class_get_hmf_counter_term_b2min __pyx_mstate_global->__pyx_n_s_Class_get_hmf_counter_term_b2min
#define __pyx_n_s_Class_get_hmf_counter_term_nmin __pyx_mstate_global->__pyx_n_s_Class_get_hmf_counter_term_nmin
#define __pyx_n_s_Class_get_lensing_noise_at_ell __pyx_mstate_global->__pyx_n_s_Class_get_lensing_noise_at_ell
#define __pyx_n_s_Class_get_m200c_to_m200m_at_z_an __pyx_mstate_global->__pyx_n_s_Class_get_m200c_to_m200m_at_z_an
#define __pyx_n_s_Class_get_m200c_to_m500c_at_z_an __pyx_mstate_global->__pyx_n_s_Class_get_m200c_to_m500c_at_z_an
#define __pyx_n_s_Class_get_m200m_to_m200c_at_z_an __pyx_mstate_global->__pyx_n_s_Class_get_m200m_to_m200c_at_z_an
#define __pyx_n_s_Class_get_m200m_to_m500c_at_z_an __pyx_mstate_global->__pyx_n_s_Class_get_m200m_to_m500c_at_z_an
#define __pyx_n_s_Class_get_m500c_to_m200c_at_z_an __pyx_mstate_global->__pyx_n_s_Class_get_m500c_to_m200c_at_z_an
#define __pyx_n_s_Class_get_m500c_to_m200m_at_z_an __pyx_mstate_global->__pyx_n_s_Class_get_m500c_to_m200m_at_z_an
#define __pyx_n_s_Class_get_m_nfw __pyx_mstate_global->__pyx_n_s_Class_get_m_nfw
#define __pyx_n_s_Class_get_m_to_xout_at_z_and_m __pyx_mstate_global->__pyx_n_s_Class_get_m_to_xout_at_z_and_m
#define __pyx_n_s_Class_get_mass_profile_at_x_M_z __pyx_mstate_global->__pyx_n_s_Class_get_mass_profile_at_x_M_z
#define __pyx_n_s_Class_get_matter_bispectrum_at_z __pyx_mstate_global->__pyx_n_s_Class_get_matter_bispectrum_at_z
#define __pyx_n_s_Class_get_matter_bispectrum_at_z_2 __pyx_mstate_global->__pyx_n_s_Class_get_matter_bispectrum_at_z_2
#define __pyx_n_s_Class_get_matter_bispectrum_at_z_3 __pyx_mstate_global->__pyx_n_s_Class_get_matter_bispectrum_at_z_3
#define __pyx_n_s_Class_get_matter_bispectrum_at_z_4 __pyx_mstate_global->__pyx_n_s_Class_get_matter_bispectrum_at_z_4
#define __pyx_n_s_Class_get_mean_galaxy_bias_at_z __pyx_mstate_global->__pyx_n_s_Class_get_mean_galaxy_bias_at_z
#define __pyx_n_s_Class_get_mean_y __pyx_mstate_global->__pyx_n_s_Class_get_mean_y
#define __pyx_n_s_Class_get_mu_e __pyx_mstate_global->__pyx_n_s_Class_get_mu_e
#define __pyx_n_s_Class_get_n5k_cl_K1_at_chi __pyx_mstate_global->__pyx_n_s_Class_get_n5k_cl_K1_at_chi
#define __pyx_n_s_Class_get_n5k_pk_at_z_and_k __pyx_mstate_global->__pyx_n_s_Class_get_n5k_pk_at_z_and_k
#define __pyx_n_s_Class_get_n5k_z_of_chi __pyx_mstate_global->__pyx_n_s_Class_get_n5k_z_of_chi
#define __pyx_n_s_Class_get_ng_bar_at_z __pyx_mstate_global->__pyx_n_s_Class_get_ng_bar_at_z
#define __pyx_n_s_Class_get_nl_index_at_z_and_k __pyx_mstate_global->__pyx_n_s_Class_get_nl_index_at_z_and_k
#define __pyx_n_s_Class_get_nl_index_at_z_and_k_no __pyx_mstate_global->__pyx_n_s_Class_get_nl_index_at_z_and_k_no
#define __pyx_n_s_Class_get_normalization_gas_dens __pyx_mstate_global->__pyx_n_s_Class_get_normalization_gas_dens
#define __pyx_n_s_Class_get_nu_at_z_and_m __pyx_mstate_global->__pyx_n_s_Class_get_nu_at_z_and_m
#define __pyx_n_s_Class_get_params_sz __pyx_mstate_global->__pyx_n_s_Class_get_params_sz
#define __pyx_n_s_Class_get_perturbations __pyx_mstate_global->__pyx_n_s_Class_get_perturbations
#define __pyx_n_s_Class_get_pk __pyx_mstate_global->__pyx_n_s_Class_get_pk
#define __pyx_n_s_Class_get_pk_and_k_and_z __pyx_mstate_global->__pyx_n_s_Class_get_pk_and_k_and_z
#define __pyx_n_s_Class_get_pk_array __pyx_mstate_global->__pyx_n_s_Class_get_pk_array
#define __pyx_n_s_Class_get_pk_cb __pyx_mstate_global->__pyx_n_s_Class_get_pk_cb
#define __pyx_n_s_Class_get_pk_cb_array __pyx_mstate_global->__pyx_n_s_Class_get_pk_cb_array
#define __pyx_n_s_Class_get_pk_cb_lin __pyx_mstate_global->__pyx_n_s_Class_get_pk_cb_lin
#define __pyx_n_s_Class_get_pk_lin __pyx_mstate_global->__pyx_n_s_Class_get_pk_lin
#define __pyx_n_s_Class_get_pk_lin_at_k_and_z __pyx_mstate_global->__pyx_n_s_Class_get_pk_lin_at_k_and_z
#define __pyx_n_s_Class_get_pk_lin_at_k_and_z_fast __pyx_mstate_global->__pyx_n_s_Class_get_pk_lin_at_k_and_z_fast
#define __pyx_n_s_Class_get_pk_nonlin_at_k_and_z __pyx_mstate_global->__pyx_n_s_Class_get_pk_nonlin_at_k_and_z
#define __pyx_n_s_Class_get_pk_nonlin_at_k_and_z_f __pyx_mstate_global->__pyx_n_s_Class_get_pk_nonlin_at_k_and_z_f
#define __pyx_n_s_Class_get_pkl __pyx_mstate_global->__pyx_n_s_Class_get_pkl
#define __pyx_n_s_Class_get_pkl_at_z __pyx_mstate_global->__pyx_n_s_Class_get_pkl_at_z
#define __pyx_n_s_Class_get_pkl_reconstructed_from __pyx_mstate_global->__pyx_n_s_Class_get_pkl_reconstructed_from
#define __pyx_n_s_Class_get_pkl_unvectorized __pyx_mstate_global->__pyx_n_s_Class_get_pkl_unvectorized
#define __pyx_n_s_Class_get_pknl __pyx_mstate_global->__pyx_n_s_Class_get_pknl
#define __pyx_n_s_Class_get_pknl_at_z __pyx_mstate_global->__pyx_n_s_Class_get_pknl_at_z
#define __pyx_n_s_Class_get_pknl_unvectorized __pyx_mstate_global->__pyx_n_s_Class_get_pknl_unvectorized
#define __pyx_n_s_Class_get_planck_sigma_at_theta5 __pyx_mstate_global->__pyx_n_s_Class_get_planck_sigma_at_theta5
#define __pyx_n_s_Class_get_pressure_P_over_P_delt __pyx_mstate_global->__pyx_n_s_Class_get_pressure_P_over_P_delt
#define __pyx_n_s_Class_get_pressure_P_over_P_delt_2 __pyx_mstate_global->__pyx_n_s_Class_get_pressure_P_over_P_delt_2
#define __pyx_n_s_Class_get_primordial __pyx_mstate_global->__pyx_n_s_Class_get_primordial
#define __pyx_n_s_Class_get_r_delta_of_m_delta_at __pyx_mstate_global->__pyx_n_s_Class_get_r_delta_of_m_delta_at
#define __pyx_n_s_Class_get_rad_to_arcmin __pyx_mstate_global->__pyx_n_s_Class_get_rad_to_arcmin
#define __pyx_n_s_Class_get_radial_kernel_W_custom __pyx_mstate_global->__pyx_n_s_Class_get_radial_kernel_W_custom
#define __pyx_n_s_Class_get_radial_kernel_W_galaxy __pyx_mstate_global->__pyx_n_s_Class_get_radial_kernel_W_galaxy
#define __pyx_n_s_Class_get_radial_kernel_W_galaxy_2 __pyx_mstate_global->__pyx_n_s_Class_get_radial_kernel_W_galaxy_2
#define __pyx_n_s_Class_get_rho_2h_at_r_and_m_and __pyx_mstate_global->__pyx_n_s_Class_get_rho_2h_at_r_and_m_and
#define __pyx_n_s_Class_get_rho_crit_at_z __pyx_mstate_global->__pyx_n_s_Class_get_rho_crit_at_z
#define __pyx_n_s_Class_get_rvir_of_m200c_at_z __pyx_mstate_global->__pyx_n_s_Class_get_rvir_of_m200c_at_z
#define __pyx_n_s_Class_get_rvir_of_mvir_at_z __pyx_mstate_global->__pyx_n_s_Class_get_rvir_of_mvir_at_z
#define __pyx_n_s_Class_get_scale_dependent_bias_a __pyx_mstate_global->__pyx_n_s_Class_get_scale_dependent_bias_a
#define __pyx_n_s_Class_get_second_order_bias_at_z __pyx_mstate_global->__pyx_n_s_Class_get_second_order_bias_at_z
#define __pyx_n_s_Class_get_sigma8_at_z __pyx_mstate_global->__pyx_n_s_Class_get_sigma8_at_z
#define __pyx_n_s_Class_get_sigma_at_z_and_m __pyx_mstate_global->__pyx_n_s_Class_get_sigma_at_z_and_m
#define __pyx_n_s_Class_get_source_galaxy_number_c __pyx_mstate_global->__pyx_n_s_Class_get_source_galaxy_number_c
#define __pyx_n_s_Class_get_szcounts_dndzdq_at_z_q __pyx_mstate_global->__pyx_n_s_Class_get_szcounts_dndzdq_at_z_q
#define __pyx_n_s_Class_get_szcountsz_sigma_at_the __pyx_mstate_global->__pyx_n_s_Class_get_szcountsz_sigma_at_the
#define __pyx_n_s_Class_get_te_of_m500c_at_z_arnau __pyx_mstate_global->__pyx_n_s_Class_get_te_of_m500c_at_z_arnau
#define __pyx_n_s_Class_get_te_of_m500c_at_z_lee __pyx_mstate_global->__pyx_n_s_Class_get_te_of_m500c_at_z_lee
#define __pyx_n_s_Class_get_thermodynamics __pyx_mstate_global->__pyx_n_s_Class_get_thermodynamics
#define __pyx_n_s_Class_get_theta_at_m_and_z __pyx_mstate_global->__pyx_n_s_Class_get_theta_at_m_and_z
#define __pyx_n_s_Class_get_transfer __pyx_mstate_global->__pyx_n_s_Class_get_transfer
#define __pyx_n_s_Class_get_truncated_nfw_profile __pyx_mstate_global->__pyx_n_s_Class_get_truncated_nfw_profile
#define __pyx_n_s_Class_get_truncated_nfw_profile_2 __pyx_mstate_global->__pyx_n_s_Class_get_truncated_nfw_profile_2
#define __pyx_n_s_Class_get_ttg_bispectrum_at_z_ef __pyx_mstate_global->__pyx_n_s_Class_get_ttg_bispectrum_at_z_ef
#define __pyx_n_s_Class_get_ttg_bispectrum_at_z_tr __pyx_mstate_global->__pyx_n_s_Class_get_ttg_bispectrum_at_z_tr
#define __pyx_n_s_Class_get_uk __pyx_mstate_global->__pyx_n_s_Class_get_uk
#define __pyx_n_s_Class_get_uk_nfw __pyx_mstate_global->__pyx_n_s_Class_get_uk_nfw
#define __pyx_n_s_Class_get_unwise_m_min_cut_at_z __pyx_mstate_global->__pyx_n_s_Class_get_unwise_m_min_cut_at_z
#define __pyx_n_s_Class_get_upp_from_gnfw_pressure __pyx_mstate_global->__pyx_n_s_Class_get_upp_from_gnfw_pressure
#define __pyx_n_s_Class_get_volume_dVdzdOmega_at_z __pyx_mstate_global->__pyx_n_s_Class_get_volume_dVdzdOmega_at_z
#define __pyx_n_s_Class_get_vrms2_at_z __pyx_mstate_global->__pyx_n_s_Class_get_vrms2_at_z
#define __pyx_n_s_Class_get_y_at_m_and_z __pyx_mstate_global->__pyx_n_s_Class_get_y_at_m_and_z
#define __pyx_n_s_Class_get_yc_at_m_and_z_H13 __pyx_mstate_global->__pyx_n_s_Class_get_yc_at_m_and_z_H13
#define __pyx_n_s_Class_get_z_of_chi __pyx_mstate_global->__pyx_n_s_Class_get_z_of_chi
#define __pyx_n_s_Class_get_z_of_chi_unvectorized __pyx_mstate_global->__pyx_n_s_Class_get_z_of_chi_unvectorized
#define __pyx_n_s_Class_h __pyx_mstate_global->__pyx_n_s_Class_h
#define __pyx_n_s_Class_ionization_fraction __pyx_mstate_global->__pyx_n_s_Class_ionization_fraction
#define __pyx_n_s_Class_k_eq __pyx_mstate_global->__pyx_n_s_Class_k_eq
#define __pyx_n_s_Class_lensed_cl __pyx_mstate_global->__pyx_n_s_Class_lensed_cl
#define __pyx_n_s_Class_load_n5k_cl_K1 __pyx_mstate_global->__pyx_n_s_Class_load_n5k_cl_K1
#define __pyx_n_s_Class_load_n5k_pk_zk __pyx_mstate_global->__pyx_n_s_Class_load_n5k_pk_zk
#define __pyx_n_s_Class_load_n5k_z_of_chi __pyx_mstate_global->__pyx_n_s_Class_load_n5k_z_of_chi
#define __pyx_n_s_Class_luminosity_distance __pyx_mstate_global->__pyx_n_s_Class_luminosity_distance
#define __pyx_n_s_Class_n_s __pyx_mstate_global->__pyx_n_s_Class_n_s
#define __pyx_n_s_Class_nonlinear_hmcode_sigma8 __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigma8
#define __pyx_n_s_Class_nonlinear_hmcode_sigma8_cb __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigma8_cb
#define __pyx_n_s_Class_nonlinear_hmcode_sigmadisp __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp
#define __pyx_n_s_Class_nonlinear_hmcode_sigmadisp_2 __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_2
#define __pyx_n_s_Class_nonlinear_hmcode_sigmadisp_3 __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_3
#define __pyx_n_s_Class_nonlinear_hmcode_sigmadisp_4 __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_4
#define __pyx_n_s_Class_nonlinear_hmcode_sigmaprim __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigmaprim
#define __pyx_n_s_Class_nonlinear_hmcode_sigmaprim_2 __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_sigmaprim_2
#define __pyx_n_s_Class_nonlinear_hmcode_window_nf __pyx_mstate_global->__pyx_n_s_Class_nonlinear_hmcode_window_nf
#define __pyx_n_s_Class_nonlinear_scale __pyx_mstate_global->__pyx_n_s_Class_nonlinear_scale
#define __pyx_n_s_Class_nonlinear_scale_cb __pyx_mstate_global->__pyx_n_s_Class_nonlinear_scale_cb
#define __pyx_n_s_Class_omega_b __pyx_mstate_global->__pyx_n_s_Class_omega_b
#define __pyx_n_s_Class_omega_cdm __pyx_mstate_global->__pyx_n_s_Class_omega_cdm
#define __pyx_n_s_Class_pk __pyx_mstate_global->__pyx_n_s_Class_pk
#define __pyx_n_s_Class_pk_at_z_hm __pyx_mstate_global->__pyx_n_s_Class_pk_at_z_hm
#define __pyx_n_s_Class_pk_b_at_z_2h __pyx_mstate_global->__pyx_n_s_Class_pk_b_at_z_2h
#define __pyx_n_s_Class_pk_bb_at_z_hm __pyx_mstate_global->__pyx_n_s_Class_pk_bb_at_z_hm
#define __pyx_n_s_Class_pk_cb __pyx_mstate_global->__pyx_n_s_Class_pk_cb
#define __pyx_n_s_Class_pk_cb_lin __pyx_mstate_global->__pyx_n_s_Class_pk_cb_lin
#define __pyx_n_s_Class_pk_em_at_z_hm __pyx_mstate_global->__pyx_n_s_Class_pk_em_at_z_hm
#define __pyx_n_s_Class_pk_gg_at_z_hm __pyx_mstate_global->__pyx_n_s_Class_pk_gg_at_z_hm
#define __pyx_n_s_Class_pk_lin __pyx_mstate_global->__pyx_n_s_Class_pk_lin
#define __pyx_n_s_Class_pk_lin_unvectorized __pyx_mstate_global->__pyx_n_s_Class_pk_lin_unvectorized
#define __pyx_n_s_Class_pk_nonlin __pyx_mstate_global->__pyx_n_s_Class_pk_nonlin
#define __pyx_n_s_Class_pk_tilt __pyx_mstate_global->__pyx_n_s_Class_pk_tilt
#define __pyx_n_s_Class_pk_unvectorized __pyx_mstate_global->__pyx_n_s_Class_pk_unvectorized
#define __pyx_n_s_Class_raw_cl __pyx_mstate_global->__pyx_n_s_Class_raw_cl
#define __pyx_n_s_Class_rho0_cb __pyx_mstate_global->__pyx_n_s_Class_rho0_cb
#define __pyx_n_s_Class_rho0_crit __pyx_mstate_global->__pyx_n_s_Class_rho0_crit
#define __pyx_n_s_Class_rho0_m __pyx_mstate_global->__pyx_n_s_Class_rho0_m
#define __pyx_n_s_Class_rs_drag __pyx_mstate_global->__pyx_n_s_Class_rs_drag
#define __pyx_n_s_Class_scale_independent_growth_f __pyx_mstate_global->__pyx_n_s_Class_scale_independent_growth_f
#define __pyx_n_s_Class_scale_independent_growth_f_2 __pyx_mstate_global->__pyx_n_s_Class_scale_independent_growth_f_2
#define __pyx_n_s_Class_set __pyx_mstate_global->__pyx_n_s_Class_set
#define __pyx_n_s_Class_set_default __pyx_mstate_global->__pyx_n_s_Class_set_default
#define __pyx_n_s_Class_sigma __pyx_mstate_global->__pyx_n_s_Class_sigma
#define __pyx_n_s_Class_sigma8 __pyx_mstate_global->__pyx_n_s_Class_sigma8
#define __pyx_n_s_Class_sigma8_Pcb __pyx_mstate_global->__pyx_n_s_Class_sigma8_Pcb
#define __pyx_n_s_Class_sigma8_cb __pyx_mstate_global->__pyx_n_s_Class_sigma8_cb
#define __pyx_n_s_Class_sigmaM __pyx_mstate_global->__pyx_n_s_Class_sigmaM
#define __pyx_n_s_Class_sigma_cb __pyx_mstate_global->__pyx_n_s_Class_sigma_cb
#define __pyx_n_s_Class_struct_cleanup __pyx_mstate_global->__pyx_n_s_Class_struct_cleanup
#define __pyx_n_s_Class_szcounts_ntot __pyx_mstate_global->__pyx_n_s_Class_szcounts_ntot
#define __pyx_n_s_Class_szcounts_ntot_rates_loglik __pyx_mstate_global->__pyx_n_s_Class_szcounts_ntot_rates_loglik
#define __pyx_n_s_Class_szfast __pyx_mstate_global->__pyx_n_s_Class_szfast
#define __pyx_n_s_Class_szunbinned_loglike __pyx_mstate_global->__pyx_n_s_Class_szunbinned_loglike
#define __pyx_n_s_Class_tau_reio __pyx_mstate_global->__pyx_n_s_Class_tau_reio
#define __pyx_n_s_Class_theta_s_100 __pyx_mstate_global->__pyx_n_s_Class_theta_s_100
#define __pyx_n_s_Class_theta_star_100 __pyx_mstate_global->__pyx_n_s_Class_theta_star_100
#define __pyx_n_s_Class_tllprime_sz __pyx_mstate_global->__pyx_n_s_Class_tllprime_sz
#define __pyx_n_s_Class_x_out_custom1 __pyx_mstate_global->__pyx_n_s_Class_x_out_custom1
#define __pyx_n_s_Class_ystar __pyx_mstate_global->__pyx_n_s_Class_ystar
#define __pyx_n_s_Class_z_of_r __pyx_mstate_global->__pyx_n_s_Class_z_of_r
#define __pyx_n_s_Class_z_of_tau __pyx_mstate_global->__pyx_n_s_Class_z_of_tau
#define __pyx_n_s_Class_z_reio __pyx_mstate_global->__pyx_n_s_Class_z_reio
#define __pyx_n_s_CosmoComputationError __pyx_mstate_global->__pyx_n_s_CosmoComputationError
#define __pyx_n_s_CosmoError __pyx_mstate_global->__pyx_n_s_CosmoError
#define __pyx_n_s_CosmoError___init __pyx_mstate_global->__pyx_n_s_CosmoError___init
#define __pyx_n_s_CosmoError___str __pyx_mstate_global->__pyx_n_s_CosmoError___str
#define __pyx_n_s_CosmoSevereError __pyx_mstate_global->__pyx_n_s_CosmoSevereError
#define __pyx_n_s_D __pyx_mstate_global->__pyx_n_s_D
#define __pyx_n_s_DEBUG __pyx_mstate_global->__pyx_n_s_DEBUG
#define __pyx_n_s_D_A __pyx_mstate_global->__pyx_n_s_D_A
#define __pyx_n_s_Delta_c __pyx_mstate_global->__pyx_n_s_Delta_c
#define __pyx_n_u_Deprecated __pyx_mstate_global->__pyx_n_u_Deprecated
#define __pyx_kp_s_Dimension_d_is_not_direct __pyx_mstate_global->__pyx_kp_s_Dimension_d_is_not_direct
#define __pyx_n_u_Dust_temperature_today_in_Kelvin __pyx_mstate_global->__pyx_n_u_Dust_temperature_today_in_Kelvin
#define __pyx_n_s_Dz __pyx_mstate_global->__pyx_n_s_Dz
#define __pyx_n_s_Dzmax __pyx_mstate_global->__pyx_n_s_Dzmax
#define __pyx_n_s_Eh __pyx_mstate_global->__pyx_n_s_Eh
#define __pyx_n_s_Ellipsis __pyx_mstate_global->__pyx_n_s_Ellipsis
#define __pyx_n_u_Emissivity_index_of_sed __pyx_mstate_global->__pyx_n_u_Emissivity_index_of_sed
#define __pyx_kp_s_Empty_shape_tuple_for_cython_arr __pyx_mstate_global->__pyx_kp_s_Empty_shape_tuple_for_cython_arr
#define __pyx_kp_u_Error_in_Class __pyx_mstate_global->__pyx_kp_u_Error_in_Class
#define __pyx_n_s_Ez __pyx_mstate_global->__pyx_n_s_Ez
#define __pyx_n_s_F __pyx_mstate_global->__pyx_n_s_F
#define __pyx_n_s_G __pyx_mstate_global->__pyx_n_s_G
#define __pyx_n_u_Gamma_0_nadm __pyx_mstate_global->__pyx_n_u_Gamma_0_nadm
#define __pyx_n_s_H __pyx_mstate_global->__pyx_n_s_H
#define __pyx_n_u_H0 __pyx_mstate_global->__pyx_n_u_H0
#define __pyx_n_s_H_array __pyx_mstate_global->__pyx_n_s_H_array
#define __pyx_n_s_H_over_c_in_h_over_Mpc_array __pyx_mstate_global->__pyx_n_s_H_over_c_in_h_over_Mpc_array
#define __pyx_n_s_Hankel __pyx_mstate_global->__pyx_n_s_Hankel
#define __pyx_n_s_Hubble __pyx_mstate_global->__pyx_n_s_Hubble
#define __pyx_n_u_I0 __pyx_mstate_global->__pyx_n_u_I0
#define __pyx_n_s_INFO __pyx_mstate_global->__pyx_n_s_INFO
#define __pyx_n_s_ImportError __pyx_mstate_global->__pyx_n_s_ImportError
#define __pyx_kp_u_In_order_to_get_pk_tilt_at_k_e_1 __pyx_mstate_global->__pyx_kp_u_In_order_to_get_pk_tilt_at_k_e_1
#define __pyx_kp_u_In_order_to_get_sigma_R_z_you_mu __pyx_mstate_global->__pyx_kp_u_In_order_to_get_sigma_R_z_you_mu
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_n_s_IndexError __pyx_mstate_global->__pyx_n_s_IndexError
#define __pyx_kp_s_Index_out_of_bounds_axis_d __pyx_mstate_global->__pyx_kp_s_Index_out_of_bounds_axis_d
#define __pyx_kp_s_Indirect_dimensions_not_supporte __pyx_mstate_global->__pyx_kp_s_Indirect_dimensions_not_supporte
#define __pyx_kp_u_Input_should_be_a_float_or_a_1D __pyx_mstate_global->__pyx_kp_u_Input_should_be_a_float_or_a_1D
#define __pyx_n_s_InterpolatedUnivariateSpline __pyx_mstate_global->__pyx_n_s_InterpolatedUnivariateSpline
#define __pyx_kp_u_Invalid_mode_expected_c_or_fortr __pyx_mstate_global->__pyx_kp_u_Invalid_mode_expected_c_or_fortr
#define __pyx_kp_u_Invalid_shape_in_axis __pyx_mstate_global->__pyx_kp_u_Invalid_shape_in_axis
#define __pyx_n_s_KeyError __pyx_mstate_global->__pyx_n_s_KeyError
#define __pyx_n_s_M __pyx_mstate_global->__pyx_n_s_M
#define __pyx_n_u_M0_HOD_ngal __pyx_mstate_global->__pyx_n_u_M0_HOD_ngal
#define __pyx_n_s_M1SZ __pyx_mstate_global->__pyx_n_s_M1SZ
#define __pyx_n_s_M1_prime __pyx_mstate_global->__pyx_n_s_M1_prime
#define __pyx_n_u_M1_prime_HOD __pyx_mstate_global->__pyx_n_u_M1_prime_HOD
#define __pyx_n_u_M1_prime_HOD_ngal __pyx_mstate_global->__pyx_n_u_M1_prime_HOD_ngal
#define __pyx_n_s_M500 __pyx_mstate_global->__pyx_n_s_M500
#define __pyx_n_s_M500c_zk __pyx_mstate_global->__pyx_n_s_M500c_zk
#define __pyx_n_s_MF_extr __pyx_mstate_global->__pyx_n_s_MF_extr
#define __pyx_n_s_MUpper __pyx_mstate_global->__pyx_n_s_MUpper
#define __pyx_n_s_M_halo __pyx_mstate_global->__pyx_n_s_M_halo
#define __pyx_n_u_M_max __pyx_mstate_global->__pyx_n_u_M_max
#define __pyx_n_s_M_min __pyx_mstate_global->__pyx_n_s_M_min
#define __pyx_n_u_M_min __pyx_mstate_global->__pyx_n_u_M_min
#define __pyx_n_u_M_min_HOD __pyx_mstate_global->__pyx_n_u_M_min_HOD
#define __pyx_n_u_M_min_HOD_ngal __pyx_mstate_global->__pyx_n_u_M_min_HOD_ngal
#define __pyx_n_s_MemoryError __pyx_mstate_global->__pyx_n_s_MemoryError
#define __pyx_kp_s_MemoryView_of_r_at_0x_x __pyx_mstate_global->__pyx_kp_s_MemoryView_of_r_at_0x_x
#define __pyx_kp_s_MemoryView_of_r_object __pyx_mstate_global->__pyx_kp_s_MemoryView_of_r_object
#define __pyx_n_u_Most_efficient_halo_mass_in_Msun __pyx_mstate_global->__pyx_n_u_Most_efficient_halo_mass_in_Msun
#define __pyx_n_s_N __pyx_mstate_global->__pyx_n_s_N
#define __pyx_n_u_N_dg __pyx_mstate_global->__pyx_n_u_N_dg
#define __pyx_n_u_N_ncdm __pyx_mstate_global->__pyx_n_u_N_ncdm
#define __pyx_n_s_N_ngal __pyx_mstate_global->__pyx_n_s_N_ngal
#define __pyx_n_u_N_ur __pyx_mstate_global->__pyx_n_u_N_ur
#define __pyx_n_s_Nc __pyx_mstate_global->__pyx_n_s_Nc
#define __pyx_n_s_Nc_mean __pyx_mstate_global->__pyx_n_s_Nc_mean
#define __pyx_n_s_Neff __pyx_mstate_global->__pyx_n_s_Neff
#define __pyx_n_u_Neff __pyx_mstate_global->__pyx_n_u_Neff
#define __pyx_n_s_Nmcfit __pyx_mstate_global->__pyx_n_s_Nmcfit
#define __pyx_kp_u_No_Cl_computed __pyx_mstate_global->__pyx_kp_u_No_Cl_computed
#define __pyx_kp_u_No_density_Cl_computed __pyx_mstate_global->__pyx_kp_u_No_density_Cl_computed
#define __pyx_kp_u_No_lensed_Cl_computed __pyx_mstate_global->__pyx_kp_u_No_lensed_Cl_computed
#define __pyx_kp_u_No_massive_neutrinos_You_must_us __pyx_mstate_global->__pyx_kp_u_No_massive_neutrinos_You_must_us
#define __pyx_kp_u_No_power_spectrum_computed_In_or __pyx_mstate_global->__pyx_kp_u_No_power_spectrum_computed_In_or
#define __pyx_kp_u_No_power_spectrum_computed_In_or_2 __pyx_mstate_global->__pyx_kp_u_No_power_spectrum_computed_In_or_2
#define __pyx_kp_u_No_power_spectrum_computed_You_m __pyx_mstate_global->__pyx_kp_u_No_power_spectrum_computed_You_m
#define __pyx_kp_u_Normalisation_of_L___M_relation __pyx_mstate_global->__pyx_kp_u_Normalisation_of_L___M_relation
#define __pyx_n_s_NotImplementedError __pyx_mstate_global->__pyx_n_s_NotImplementedError
#define __pyx_n_s_Ns __pyx_mstate_global->__pyx_n_s_Ns
#define __pyx_n_s_Ntot __pyx_mstate_global->__pyx_n_s_Ntot
#define __pyx_n_s_Nz __pyx_mstate_global->__pyx_n_s_Nz
#define __pyx_n_b_O __pyx_mstate_global->__pyx_n_b_O
#define __pyx_n_s_Om_m __pyx_mstate_global->__pyx_n_s_Om_m
#define __pyx_n_s_Omega0_b __pyx_mstate_global->__pyx_n_s_Omega0_b
#define __pyx_n_s_Omega0_cdm __pyx_mstate_global->__pyx_n_s_Omega0_cdm
#define __pyx_n_u_Omega0_fld __pyx_mstate_global->__pyx_n_u_Omega0_fld
#define __pyx_n_s_Omega0_k __pyx_mstate_global->__pyx_n_s_Omega0_k
#define __pyx_n_u_Omega0_lambda __pyx_mstate_global->__pyx_n_u_Omega0_lambda
#define __pyx_n_s_Omega0_m __pyx_mstate_global->__pyx_n_s_Omega0_m
#define __pyx_n_s_Omega_Lambda __pyx_mstate_global->__pyx_n_s_Omega_Lambda
#define __pyx_n_u_Omega_Lambda __pyx_mstate_global->__pyx_n_u_Omega_Lambda
#define __pyx_n_s_Omega_b __pyx_mstate_global->__pyx_n_s_Omega_b
#define __pyx_n_u_Omega_b __pyx_mstate_global->__pyx_n_u_Omega_b
#define __pyx_n_u_Omega_c __pyx_mstate_global->__pyx_n_u_Omega_c
#define __pyx_n_u_Omega_cdm __pyx_mstate_global->__pyx_n_u_Omega_cdm
#define __pyx_n_s_Omega_g __pyx_mstate_global->__pyx_n_s_Omega_g
#define __pyx_n_s_Omega_m __pyx_mstate_global->__pyx_n_s_Omega_m
#define __pyx_n_u_Omega_m __pyx_mstate_global->__pyx_n_u_Omega_m
#define __pyx_n_s_Omega_r __pyx_mstate_global->__pyx_n_s_Omega_r
#define __pyx_kp_u_Out_of_bounds_on_buffer_access_a __pyx_mstate_global->__pyx_kp_u_Out_of_bounds_on_buffer_access_a
#define __pyx_n_s_P __pyx_mstate_global->__pyx_n_s_P
#define __pyx_n_s_P0GNFW __pyx_mstate_global->__pyx_n_s_P0GNFW
#define __pyx_n_u_P0GNFW __pyx_mstate_global->__pyx_n_u_P0GNFW
#define __pyx_n_u_P0_B12 __pyx_mstate_global->__pyx_n_u_P0_B12
#define __pyx_n_u_P13_file __pyx_mstate_global->__pyx_n_u_P13_file
#define __pyx_n_s_P200 __pyx_mstate_global->__pyx_n_s_P200
#define __pyx_n_s_PATH_TO_CLASS_SZ_DATA __pyx_mstate_global->__pyx_n_s_PATH_TO_CLASS_SZ_DATA
#define __pyx_n_s_PArr __pyx_mstate_global->__pyx_n_s_PArr
#define __pyx_n_s_PLog10M __pyx_mstate_global->__pyx_n_s_PLog10M
#define __pyx_n_s_PLog10M_full __pyx_mstate_global->__pyx_n_s_PLog10M_full
#define __pyx_kp_u_P_cb_not_computed_by_CLASS_proba __pyx_mstate_global->__pyx_kp_u_P_cb_not_computed_by_CLASS_proba
#define __pyx_kp_u_P_cb_not_computed_probably_becau __pyx_mstate_global->__pyx_kp_u_P_cb_not_computed_probably_becau
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_n_u_Power_law_index_of_SED_at_high_f __pyx_mstate_global->__pyx_n_u_Power_law_index_of_SED_at_high_f
#define __pyx_kp_u_Profile __pyx_mstate_global->__pyx_kp_u_Profile
#define __pyx_n_s_Py0GivenM __pyx_mstate_global->__pyx_n_s_Py0GivenM
#define __pyx_n_s_Pz __pyx_mstate_global->__pyx_n_s_Pz
#define __pyx_n_s_QF __pyx_mstate_global->__pyx_n_s_QF
#define __pyx_n_s_R __pyx_mstate_global->__pyx_n_s_R
#define __pyx_kp_s_Raised_when_Class_could_not_com __pyx_mstate_global->__pyx_kp_s_Raised_when_Class_could_not_com
#define __pyx_kp_s_Raised_when_Class_failed_to_und __pyx_mstate_global->__pyx_kp_s_Raised_when_Class_failed_to_und
#define __pyx_kp_u_Redshift_evolution_of_L___M_norm __pyx_mstate_global->__pyx_kp_u_Redshift_evolution_of_L___M_norm
#define __pyx_n_u_Redshift_evolution_of_dust_tempe __pyx_mstate_global->__pyx_n_u_Redshift_evolution_of_dust_tempe
#define __pyx_n_s_Rho_crit_0 __pyx_mstate_global->__pyx_n_s_Rho_crit_0
#define __pyx_n_u_SZ_cat_file __pyx_mstate_global->__pyx_n_u_SZ_cat_file
#define __pyx_n_s_Sequence __pyx_mstate_global->__pyx_n_s_Sequence
#define __pyx_n_u_Size_of_halo_masses_sourcing_CIB __pyx_mstate_global->__pyx_n_u_Size_of_halo_masses_sourcing_CIB
#define __pyx_kp_s_Step_may_not_be_zero_axis_d __pyx_mstate_global->__pyx_kp_s_Step_may_not_be_zero_axis_d
#define __pyx_n_s_Stw __pyx_mstate_global->__pyx_n_s_Stw
#define __pyx_kp_b_T __pyx_mstate_global->__pyx_kp_b_T
#define __pyx_n_s_TCMB __pyx_mstate_global->__pyx_n_s_TCMB
#define __pyx_n_s_TKelvin __pyx_mstate_global->__pyx_n_s_TKelvin
#define __pyx_n_s_T_cmb __pyx_mstate_global->__pyx_n_s_T_cmb
#define __pyx_n_s_T_ll_arr __pyx_mstate_global->__pyx_n_s_T_ll_arr
#define __pyx_n_s_Tb __pyx_mstate_global->__pyx_n_s_Tb
#define __pyx_n_s_Tcmb __pyx_mstate_global->__pyx_n_s_Tcmb
#define __pyx_n_s_Tcmb_gNU __pyx_mstate_global->__pyx_n_s_Tcmb_gNU
#define __pyx_n_u_Tinker_et_al_10_alpha_consistenc __pyx_mstate_global->__pyx_n_u_Tinker_et_al_10_alpha_consistenc
#define __pyx_n_s_TkeV __pyx_mstate_global->__pyx_n_s_TkeV
#define __pyx_kp_u_Type __pyx_mstate_global->__pyx_kp_u_Type
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_kp_s_Unable_to_convert_item_to_object __pyx_mstate_global->__pyx_kp_s_Unable_to_convert_item_to_object
#define __pyx_kp_u_Users_boris_Work_CLASS_SZ_SO_SZ __pyx_mstate_global->__pyx_kp_u_Users_boris_Work_CLASS_SZ_SO_SZ
#define __pyx_n_u_V_0 __pyx_mstate_global->__pyx_n_u_V_0
#define __pyx_n_u_V_1 __pyx_mstate_global->__pyx_n_u_V_1
#define __pyx_n_u_V_2 __pyx_mstate_global->__pyx_n_u_V_2
#define __pyx_n_u_V_3 __pyx_mstate_global->__pyx_n_u_V_3
#define __pyx_n_u_V_4 __pyx_mstate_global->__pyx_n_u_V_4
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s_View_MemoryView __pyx_mstate_global->__pyx_n_s_View_MemoryView
#define __pyx_n_s_Wg __pyx_mstate_global->__pyx_n_s_Wg
#define __pyx_n_s_X __pyx_mstate_global->__pyx_n_s_X
#define __pyx_n_s_Xtw __pyx_mstate_global->__pyx_n_s_Xtw
#define __pyx_n_s_Y0 __pyx_mstate_global->__pyx_n_s_Y0
#define __pyx_n_s_Y1 __pyx_mstate_global->__pyx_n_s_Y1
#define __pyx_n_s_Y2 __pyx_mstate_global->__pyx_n_s_Y2
#define __pyx_n_s_Y3 __pyx_mstate_global->__pyx_n_s_Y3
#define __pyx_n_s_Y4 __pyx_mstate_global->__pyx_n_s_Y4
#define __pyx_n_u_YHe __pyx_mstate_global->__pyx_n_u_YHe
#define __pyx_kp_u_You_ask_classy_to_return_an_arra __pyx_mstate_global->__pyx_kp_u_You_ask_classy_to_return_an_arra
#define __pyx_kp_u_You_ask_classy_to_return_an_arra_2 __pyx_mstate_global->__pyx_kp_u_You_ask_classy_to_return_an_arra_2
#define __pyx_kp_u_You_ask_classy_to_return_an_arra_3 __pyx_mstate_global->__pyx_kp_u_You_ask_classy_to_return_an_arra_3
#define __pyx_kp_b__10 __pyx_mstate_global->__pyx_kp_b__10
#define __pyx_kp_u__10 __pyx_mstate_global->__pyx_kp_u__10
#define __pyx_kp_b__11 __pyx_mstate_global->__pyx_kp_b__11
#define __pyx_kp_b__12 __pyx_mstate_global->__pyx_kp_b__12
#define __pyx_kp_u__13 __pyx_mstate_global->__pyx_kp_u__13
#define __pyx_kp_u__14 __pyx_mstate_global->__pyx_kp_u__14
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_kp_u__20 __pyx_mstate_global->__pyx_kp_u__20
#define __pyx_kp_u__22 __pyx_mstate_global->__pyx_kp_u__22
#define __pyx_n_s__3 __pyx_mstate_global->__pyx_n_s__3
#define __pyx_kp_u__46 __pyx_mstate_global->__pyx_kp_u__46
#define __pyx_n_s__554 __pyx_mstate_global->__pyx_n_s__554
#define __pyx_kp_u__6 __pyx_mstate_global->__pyx_kp_u__6
#define __pyx_kp_u__7 __pyx_mstate_global->__pyx_kp_u__7
#define __pyx_kp_b__9 __pyx_mstate_global->__pyx_kp_b__9
#define __pyx_n_u_a_dark __pyx_mstate_global->__pyx_n_u_a_dark
#define __pyx_n_s_abc __pyx_mstate_global->__pyx_n_s_abc
#define __pyx_n_s_add __pyx_mstate_global->__pyx_n_s_add
#define __pyx_n_s_age __pyx_mstate_global->__pyx_n_s_age
#define __pyx_n_u_age __pyx_mstate_global->__pyx_n_u_age
#define __pyx_n_s_allocate_buffer __pyx_mstate_global->__pyx_n_s_allocate_buffer
#define __pyx_n_s_alpha __pyx_mstate_global->__pyx_n_s_alpha
#define __pyx_n_s_alphaGNFW __pyx_mstate_global->__pyx_n_s_alphaGNFW
#define __pyx_n_u_alpha_B12 __pyx_mstate_global->__pyx_n_u_alpha_B12
#define __pyx_n_s_alpha_c_P0 __pyx_mstate_global->__pyx_n_s_alpha_c_P0
#define __pyx_n_u_alpha_c_P0_B12 __pyx_mstate_global->__pyx_n_u_alpha_c_P0_B12
#define __pyx_n_s_alpha_c_alpha __pyx_mstate_global->__pyx_n_s_alpha_c_alpha
#define __pyx_n_u_alpha_c_alpha __pyx_mstate_global->__pyx_n_u_alpha_c_alpha
#define __pyx_n_s_alpha_c_beta __pyx_mstate_global->__pyx_n_s_alpha_c_beta
#define __pyx_n_u_alpha_c_beta __pyx_mstate_global->__pyx_n_u_alpha_c_beta
#define __pyx_n_u_alpha_c_beta_B12 __pyx_mstate_global->__pyx_n_u_alpha_c_beta_B12
#define __pyx_n_s_alpha_c_rho0 __pyx_mstate_global->__pyx_n_s_alpha_c_rho0
#define __pyx_n_u_alpha_c_rho0 __pyx_mstate_global->__pyx_n_u_alpha_c_rho0
#define __pyx_n_s_alpha_c_xc __pyx_mstate_global->__pyx_n_s_alpha_c_xc
#define __pyx_n_u_alpha_c_xc_B12 __pyx_mstate_global->__pyx_n_u_alpha_c_xc_B12
#define __pyx_n_s_alpha_m_P0 __pyx_mstate_global->__pyx_n_s_alpha_m_P0
#define __pyx_n_u_alpha_m_P0_B12 __pyx_mstate_global->__pyx_n_u_alpha_m_P0_B12
#define __pyx_n_s_alpha_m_alpha __pyx_mstate_global->__pyx_n_s_alpha_m_alpha
#define __pyx_n_u_alpha_m_alpha __pyx_mstate_global->__pyx_n_u_alpha_m_alpha
#define __pyx_n_s_alpha_m_beta __pyx_mstate_global->__pyx_n_s_alpha_m_beta
#define __pyx_n_u_alpha_m_beta __pyx_mstate_global->__pyx_n_u_alpha_m_beta
#define __pyx_n_u_alpha_m_beta_B12 __pyx_mstate_global->__pyx_n_u_alpha_m_beta_B12
#define __pyx_n_s_alpha_m_rho0 __pyx_mstate_global->__pyx_n_s_alpha_m_rho0
#define __pyx_n_u_alpha_m_rho0 __pyx_mstate_global->__pyx_n_u_alpha_m_rho0
#define __pyx_n_s_alpha_m_xc __pyx_mstate_global->__pyx_n_s_alpha_m_xc
#define __pyx_n_u_alpha_m_xc_B12 __pyx_mstate_global->__pyx_n_u_alpha_m_xc_B12
#define __pyx_n_s_alpha_s __pyx_mstate_global->__pyx_n_s_alpha_s
#define __pyx_n_u_alpha_s __pyx_mstate_global->__pyx_n_u_alpha_s
#define __pyx_n_u_alpha_s_HOD __pyx_mstate_global->__pyx_n_u_alpha_s_HOD
#define __pyx_n_u_alpha_s_HOD_ngal __pyx_mstate_global->__pyx_n_u_alpha_s_HOD_ngal
#define __pyx_n_u_alpha_t __pyx_mstate_global->__pyx_n_u_alpha_t
#define __pyx_n_s_alpha_z_P0 __pyx_mstate_global->__pyx_n_s_alpha_z_P0
#define __pyx_n_u_alpha_z_P0_B12 __pyx_mstate_global->__pyx_n_u_alpha_z_P0_B12
#define __pyx_n_s_alpha_z_alpha __pyx_mstate_global->__pyx_n_s_alpha_z_alpha
#define __pyx_n_u_alpha_z_alpha __pyx_mstate_global->__pyx_n_u_alpha_z_alpha
#define __pyx_n_s_alpha_z_beta __pyx_mstate_global->__pyx_n_s_alpha_z_beta
#define __pyx_n_u_alpha_z_beta __pyx_mstate_global->__pyx_n_u_alpha_z_beta
#define __pyx_n_u_alpha_z_beta_B12 __pyx_mstate_global->__pyx_n_u_alpha_z_beta_B12
#define __pyx_n_s_alpha_z_rho0 __pyx_mstate_global->__pyx_n_s_alpha_z_rho0
#define __pyx_n_u_alpha_z_rho0 __pyx_mstate_global->__pyx_n_u_alpha_z_rho0
#define __pyx_n_s_alpha_z_xc __pyx_mstate_global->__pyx_n_s_alpha_z_xc
#define __pyx_n_u_alpha_z_xc_B12 __pyx_mstate_global->__pyx_n_u_alpha_z_xc_B12
#define __pyx_n_s_alphap_m_P0 __pyx_mstate_global->__pyx_n_s_alphap_m_P0
#define __pyx_n_u_alphap_m_P0_B12 __pyx_mstate_global->__pyx_n_u_alphap_m_P0_B12
#define __pyx_n_s_alphap_m_alpha __pyx_mstate_global->__pyx_n_s_alphap_m_alpha
#define __pyx_n_u_alphap_m_alpha __pyx_mstate_global->__pyx_n_u_alphap_m_alpha
#define __pyx_n_s_alphap_m_beta __pyx_mstate_global->__pyx_n_s_alphap_m_beta
#define __pyx_n_u_alphap_m_beta __pyx_mstate_global->__pyx_n_u_alphap_m_beta
#define __pyx_n_u_alphap_m_beta_B12 __pyx_mstate_global->__pyx_n_u_alphap_m_beta_B12
#define __pyx_n_s_alphap_m_rho0 __pyx_mstate_global->__pyx_n_s_alphap_m_rho0
#define __pyx_n_u_alphap_m_rho0 __pyx_mstate_global->__pyx_n_u_alphap_m_rho0
#define __pyx_n_s_alphap_m_xc __pyx_mstate_global->__pyx_n_s_alphap_m_xc
#define __pyx_n_u_alphap_m_xc_B12 __pyx_mstate_global->__pyx_n_u_alphap_m_xc_B12
#define __pyx_kp_u_and __pyx_mstate_global->__pyx_kp_u_and
#define __pyx_n_s_angular_distance __pyx_mstate_global->__pyx_n_s_angular_distance
#define __pyx_n_s_append __pyx_mstate_global->__pyx_n_s_append
#define __pyx_n_s_applyMFDebiasCorrection __pyx_mstate_global->__pyx_n_s_applyMFDebiasCorrection
#define __pyx_n_s_arange __pyx_mstate_global->__pyx_n_s_arange
#define __pyx_n_s_argmax __pyx_mstate_global->__pyx_n_s_argmax
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_u_arr_0 __pyx_mstate_global->__pyx_n_u_arr_0
#define __pyx_n_s_array __pyx_mstate_global->__pyx_n_s_array
#define __pyx_n_s_asarray __pyx_mstate_global->__pyx_n_s_asarray
#define __pyx_n_s_assume_sorted __pyx_mstate_global->__pyx_n_s_assume_sorted
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_atleast_1d __pyx_mstate_global->__pyx_n_s_atleast_1d
#define __pyx_n_s_axis __pyx_mstate_global->__pyx_n_s_axis
#define __pyx_n_s_b_tty __pyx_mstate_global->__pyx_n_s_b_tty
#define __pyx_n_s_b_yyy __pyx_mstate_global->__pyx_n_s_b_yyy
#define __pyx_n_s_background __pyx_mstate_global->__pyx_n_s_background
#define __pyx_n_u_background __pyx_mstate_global->__pyx_n_u_background
#define __pyx_kp_u_bad_call __pyx_mstate_global->__pyx_kp_u_bad_call
#define __pyx_n_s_baryon_temperature __pyx_mstate_global->__pyx_n_s_baryon_temperature
#define __pyx_n_s_base __pyx_mstate_global->__pyx_n_s_base
#define __pyx_n_s_basicConfig __pyx_mstate_global->__pyx_n_s_basicConfig
#define __pyx_n_u_bb __pyx_mstate_global->__pyx_n_u_bb
#define __pyx_kp_u_bbn_PRIMAT21_class_format_dat __pyx_mstate_global->__pyx_kp_u_bbn_PRIMAT21_class_format_dat
#define __pyx_n_s_betaGNFW __pyx_mstate_global->__pyx_n_s_betaGNFW
#define __pyx_n_u_betaGNFW __pyx_mstate_global->__pyx_n_u_betaGNFW
#define __pyx_n_u_beta_B12 __pyx_mstate_global->__pyx_n_u_beta_B12
#define __pyx_n_u_beta_s __pyx_mstate_global->__pyx_n_u_beta_s
#define __pyx_n_s_bh __pyx_mstate_global->__pyx_n_s_bh
#define __pyx_n_s_bk_at_z_hm __pyx_mstate_global->__pyx_n_s_bk_at_z_hm
#define __pyx_n_s_bk_ttg_at_z_hm __pyx_mstate_global->__pyx_n_s_bk_ttg_at_z_hm
#define __pyx_n_u_boundary __pyx_mstate_global->__pyx_n_u_boundary
#define __pyx_n_s_bounds_error __pyx_mstate_global->__pyx_n_s_bounds_error
#define __pyx_n_s_broadcast_arrays __pyx_mstate_global->__pyx_n_s_broadcast_arrays
#define __pyx_kp_u_but_you_asked_a_l_i __pyx_mstate_global->__pyx_kp_u_but_you_asked_a_l_i
#define __pyx_n_s_c __pyx_mstate_global->__pyx_n_s_c
#define __pyx_n_u_c __pyx_mstate_global->__pyx_n_u_c
#define __pyx_n_s_c500 __pyx_mstate_global->__pyx_n_s_c500
#define __pyx_n_u_c500 __pyx_mstate_global->__pyx_n_u_c500
#define __pyx_n_u_c_B12 __pyx_mstate_global->__pyx_n_u_c_B12
#define __pyx_n_u_c_B16 __pyx_mstate_global->__pyx_n_u_c_B16
#define __pyx_n_s_c_asked __pyx_mstate_global->__pyx_n_s_c_asked
#define __pyx_n_s_c_delta __pyx_mstate_global->__pyx_n_s_c_delta
#define __pyx_n_s_calcErrors __pyx_mstate_global->__pyx_n_s_calcErrors
#define __pyx_n_s_calcFRel __pyx_mstate_global->__pyx_n_s_calcFRel
#define __pyx_n_s_calculate_chi __pyx_mstate_global->__pyx_n_s_calculate_chi
#define __pyx_n_s_calculate_cmb __pyx_mstate_global->__pyx_n_s_calculate_cmb
#define __pyx_n_s_calculate_hubble __pyx_mstate_global->__pyx_n_s_calculate_hubble
#define __pyx_n_s_calculate_pkl __pyx_mstate_global->__pyx_n_s_calculate_pkl
#define __pyx_n_s_calculate_pkl_at_z __pyx_mstate_global->__pyx_n_s_calculate_pkl_at_z
#define __pyx_n_s_calculate_pkl_fftlog_alphas __pyx_mstate_global->__pyx_n_s_calculate_pkl_fftlog_alphas
#define __pyx_n_s_calculate_pknl __pyx_mstate_global->__pyx_n_s_calculate_pknl
#define __pyx_n_s_calculate_pknl_at_z __pyx_mstate_global->__pyx_n_s_calculate_pknl_at_z
#define __pyx_n_s_calculate_sigma __pyx_mstate_global->__pyx_n_s_calculate_sigma
#define __pyx_n_s_calculate_sigma8_and_der __pyx_mstate_global->__pyx_n_s_calculate_sigma8_and_der
#define __pyx_n_s_calculate_sigma8_at_z __pyx_mstate_global->__pyx_n_s_calculate_sigma8_at_z
#define __pyx_n_u_camb __pyx_mstate_global->__pyx_n_u_camb
#define __pyx_n_s_check_task_dependency __pyx_mstate_global->__pyx_n_s_check_task_dependency
#define __pyx_n_s_chi __pyx_mstate_global->__pyx_n_s_chi
#define __pyx_n_s_chi_star __pyx_mstate_global->__pyx_n_s_chi_star
#define __pyx_n_u_cib_Snu_file_nu __pyx_mstate_global->__pyx_n_u_cib_Snu_file_nu
#define __pyx_n_u_cib_Snu_file_snu __pyx_mstate_global->__pyx_n_u_cib_Snu_file_snu
#define __pyx_n_u_cib_Snu_file_z __pyx_mstate_global->__pyx_n_u_cib_Snu_file_z
#define __pyx_n_s_cib_monopole __pyx_mstate_global->__pyx_n_s_cib_monopole
#define __pyx_n_s_cib_shotnoise __pyx_mstate_global->__pyx_n_s_cib_shotnoise
#define __pyx_n_s_cl __pyx_mstate_global->__pyx_n_s_cl
#define __pyx_n_s_cl_IA_g __pyx_mstate_global->__pyx_n_s_cl_IA_g
#define __pyx_n_s_cl_c1_gal __pyx_mstate_global->__pyx_n_s_cl_c1_gal
#define __pyx_n_s_cl_c1_gallens __pyx_mstate_global->__pyx_n_s_cl_c1_gallens
#define __pyx_n_s_cl_c1_lens __pyx_mstate_global->__pyx_n_s_cl_c1_lens
#define __pyx_n_s_cl_c1_tSZ __pyx_mstate_global->__pyx_n_s_cl_c1_tSZ
#define __pyx_n_s_cl_c1c1 __pyx_mstate_global->__pyx_n_s_cl_c1c1
#define __pyx_n_s_cl_cib __pyx_mstate_global->__pyx_n_s_cl_cib
#define __pyx_n_s_cl_cib_cib __pyx_mstate_global->__pyx_n_s_cl_cib_cib
#define __pyx_n_s_cl_custom1_cib __pyx_mstate_global->__pyx_n_s_cl_custom1_cib
#define __pyx_n_s_cl_ee __pyx_mstate_global->__pyx_n_s_cl_ee
#define __pyx_n_s_cl_eg __pyx_mstate_global->__pyx_n_s_cl_eg
#define __pyx_n_s_cl_gIA __pyx_mstate_global->__pyx_n_s_cl_gIA
#define __pyx_n_s_cl_g_cib __pyx_mstate_global->__pyx_n_s_cl_g_cib
#define __pyx_n_s_cl_g_gamma_1h __pyx_mstate_global->__pyx_n_s_cl_g_gamma_1h
#define __pyx_n_s_cl_g_gamma_2h __pyx_mstate_global->__pyx_n_s_cl_g_gamma_2h
#define __pyx_n_s_cl_g_gamma_ell __pyx_mstate_global->__pyx_n_s_cl_g_gamma_ell
#define __pyx_n_s_cl_gal_cib __pyx_mstate_global->__pyx_n_s_cl_gal_cib
#define __pyx_n_s_cl_gal_gal_kcmb __pyx_mstate_global->__pyx_n_s_cl_gal_gal_kcmb
#define __pyx_n_s_cl_galn_IA __pyx_mstate_global->__pyx_n_s_cl_galn_IA
#define __pyx_n_s_cl_galn_gallens __pyx_mstate_global->__pyx_n_s_cl_galn_gallens
#define __pyx_n_s_cl_galn_galn __pyx_mstate_global->__pyx_n_s_cl_galn_galn
#define __pyx_n_s_cl_galn_lens __pyx_mstate_global->__pyx_n_s_cl_galn_lens
#define __pyx_n_s_cl_galn_tsz __pyx_mstate_global->__pyx_n_s_cl_galn_tsz
#define __pyx_n_s_cl_gg __pyx_mstate_global->__pyx_n_s_cl_gg
#define __pyx_n_s_cl_ggamma __pyx_mstate_global->__pyx_n_s_cl_ggamma
#define __pyx_n_s_cl_gk __pyx_mstate_global->__pyx_n_s_cl_gk
#define __pyx_n_s_cl_gkg __pyx_mstate_global->__pyx_n_s_cl_gkg
#define __pyx_n_s_cl_gm __pyx_mstate_global->__pyx_n_s_cl_gm
#define __pyx_n_s_cl_gy __pyx_mstate_global->__pyx_n_s_cl_gy
#define __pyx_n_s_cl_kSZ_kSZ_g __pyx_mstate_global->__pyx_n_s_cl_kSZ_kSZ_g
#define __pyx_n_s_cl_kSZ_kSZ_kcmb __pyx_mstate_global->__pyx_n_s_cl_kSZ_kSZ_kcmb
#define __pyx_n_s_cl_kSZ_kSZ_kg __pyx_mstate_global->__pyx_n_s_cl_kSZ_kSZ_kg
#define __pyx_n_s_cl_kg __pyx_mstate_global->__pyx_n_s_cl_kg
#define __pyx_n_s_cl_kg_cib __pyx_mstate_global->__pyx_n_s_cl_kg_cib
#define __pyx_n_s_cl_kg_k __pyx_mstate_global->__pyx_n_s_cl_kg_k
#define __pyx_n_s_cl_kg_kg __pyx_mstate_global->__pyx_n_s_cl_kg_kg
#define __pyx_n_s_cl_kg_m __pyx_mstate_global->__pyx_n_s_cl_kg_m
#define __pyx_n_s_cl_kk __pyx_mstate_global->__pyx_n_s_cl_kk
#define __pyx_n_s_cl_km __pyx_mstate_global->__pyx_n_s_cl_km
#define __pyx_n_s_cl_ksz __pyx_mstate_global->__pyx_n_s_cl_ksz
#define __pyx_n_s_cl_lens_cib __pyx_mstate_global->__pyx_n_s_cl_lens_cib
#define __pyx_n_s_cl_lensmagn_gallens __pyx_mstate_global->__pyx_n_s_cl_lensmagn_gallens
#define __pyx_n_s_cl_lensmagn_tsz __pyx_mstate_global->__pyx_n_s_cl_lensmagn_tsz
#define __pyx_n_s_cl_md __pyx_mstate_global->__pyx_n_s_cl_md
#define __pyx_n_s_cl_md_ic __pyx_mstate_global->__pyx_n_s_cl_md_ic
#define __pyx_n_s_cl_mkg __pyx_mstate_global->__pyx_n_s_cl_mkg
#define __pyx_n_s_cl_mm __pyx_mstate_global->__pyx_n_s_cl_mm
#define __pyx_n_s_cl_my __pyx_mstate_global->__pyx_n_s_cl_my
#define __pyx_n_s_cl_phi_cib __pyx_mstate_global->__pyx_n_s_cl_phi_cib
#define __pyx_n_s_cl_sz __pyx_mstate_global->__pyx_n_s_cl_sz
#define __pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2 __pyx_mstate_global->__pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2
#define __pyx_n_s_cl_t2t2f __pyx_mstate_global->__pyx_n_s_cl_t2t2f
#define __pyx_n_s_cl_tSZ_cib __pyx_mstate_global->__pyx_n_s_cl_tSZ_cib
#define __pyx_n_s_cl_te_y_y __pyx_mstate_global->__pyx_n_s_cl_te_y_y
#define __pyx_n_s_cl_y_cib __pyx_mstate_global->__pyx_n_s_cl_y_cib
#define __pyx_n_s_cl_y_kcmb __pyx_mstate_global->__pyx_n_s_cl_y_kcmb
#define __pyx_n_s_cl_yg __pyx_mstate_global->__pyx_n_s_cl_yg
#define __pyx_n_s_cl_ykg __pyx_mstate_global->__pyx_n_s_cl_ykg
#define __pyx_n_s_cl_ym __pyx_mstate_global->__pyx_n_s_cl_ym
#define __pyx_n_s_class __pyx_mstate_global->__pyx_n_s_class
#define __pyx_n_u_class_2 __pyx_mstate_global->__pyx_n_u_class_2
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_kp_u_class_sz_auxiliary_files_includ __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ
#define __pyx_kp_u_class_sz_auxiliary_files_includ_10 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_10
#define __pyx_kp_u_class_sz_auxiliary_files_includ_11 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_11
#define __pyx_kp_u_class_sz_auxiliary_files_includ_12 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_12
#define __pyx_kp_u_class_sz_auxiliary_files_includ_13 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_13
#define __pyx_kp_u_class_sz_auxiliary_files_includ_2 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_2
#define __pyx_kp_u_class_sz_auxiliary_files_includ_3 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_3
#define __pyx_kp_u_class_sz_auxiliary_files_includ_4 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_4
#define __pyx_kp_u_class_sz_auxiliary_files_includ_5 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_5
#define __pyx_kp_u_class_sz_auxiliary_files_includ_6 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_6
#define __pyx_kp_u_class_sz_auxiliary_files_includ_7 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_7
#define __pyx_kp_u_class_sz_auxiliary_files_includ_8 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_8
#define __pyx_kp_u_class_sz_auxiliary_files_includ_9 __pyx_mstate_global->__pyx_kp_u_class_sz_auxiliary_files_includ_9
#define __pyx_kp_u_class_sz_class_sz __pyx_mstate_global->__pyx_kp_u_class_sz_class_sz
#define __pyx_n_u_class_sz_cosmo __pyx_mstate_global->__pyx_n_u_class_sz_cosmo
#define __pyx_n_s_class_sz_in_dict_output __pyx_mstate_global->__pyx_n_s_class_sz_in_dict_output
#define __pyx_n_u_class_sz_integrate __pyx_mstate_global->__pyx_n_u_class_sz_integrate
#define __pyx_kp_s_class_sz_python_classy_pyx __pyx_mstate_global->__pyx_kp_s_class_sz_python_classy_pyx
#define __pyx_n_u_class_sz_tabulate __pyx_mstate_global->__pyx_n_u_class_sz_tabulate
#define __pyx_n_s_classy_sz __pyx_mstate_global->__pyx_n_s_classy_sz
#define __pyx_n_u_classy_sz_verbose __pyx_mstate_global->__pyx_n_u_classy_sz_verbose
#define __pyx_n_s_classy_szfast __pyx_mstate_global->__pyx_n_s_classy_szfast
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_cls __pyx_mstate_global->__pyx_n_s_cls
#define __pyx_n_s_cltot __pyx_mstate_global->__pyx_n_s_cltot
#define __pyx_n_s_cltotfunc __pyx_mstate_global->__pyx_n_s_cltotfunc
#define __pyx_n_s_clusterLogM500 __pyx_mstate_global->__pyx_n_s_clusterLogM500
#define __pyx_n_s_clusterLogM500Max __pyx_mstate_global->__pyx_n_s_clusterLogM500Max
#define __pyx_n_s_clusterLogM500Min __pyx_mstate_global->__pyx_n_s_clusterLogM500Min
#define __pyx_n_s_clusterM500 __pyx_mstate_global->__pyx_n_s_clusterM500
#define __pyx_n_s_clusterM500MinusErr __pyx_mstate_global->__pyx_n_s_clusterM500MinusErr
#define __pyx_n_s_clusterM500PlusErr __pyx_mstate_global->__pyx_n_s_clusterM500PlusErr
#define __pyx_n_s_cnew __pyx_mstate_global->__pyx_n_s_cnew
#define __pyx_n_s_collections __pyx_mstate_global->__pyx_n_s_collections
#define __pyx_kp_s_collections_abc __pyx_mstate_global->__pyx_kp_s_collections_abc
#define __pyx_n_s_compile __pyx_mstate_global->__pyx_n_s_compile
#define __pyx_n_s_compute __pyx_mstate_global->__pyx_n_s_compute
#define __pyx_n_s_compute_class_sz __pyx_mstate_global->__pyx_n_s_compute_class_sz
#define __pyx_n_s_compute_class_szfast __pyx_mstate_global->__pyx_n_s_compute_class_szfast
#define __pyx_n_s_compute_class_szfast_locals_gene __pyx_mstate_global->__pyx_n_s_compute_class_szfast_locals_gene
#define __pyx_n_s_compute_pkl __pyx_mstate_global->__pyx_n_s_compute_pkl
#define __pyx_n_s_compute_pknl __pyx_mstate_global->__pyx_n_s_compute_pknl
#define __pyx_n_s_compute_profile __pyx_mstate_global->__pyx_n_s_compute_profile
#define __pyx_n_u_concentration_parameter __pyx_mstate_global->__pyx_n_u_concentration_parameter
#define __pyx_kp_u_concentration_parameter_2 __pyx_mstate_global->__pyx_kp_u_concentration_parameter_2
#define __pyx_n_s_configure_logging __pyx_mstate_global->__pyx_n_s_configure_logging
#define __pyx_n_u_conformal_age __pyx_mstate_global->__pyx_n_u_conformal_age
#define __pyx_n_s_contains __pyx_mstate_global->__pyx_n_s_contains
#define __pyx_n_s_contains_specific_keys __pyx_mstate_global->__pyx_n_s_contains_specific_keys
#define __pyx_n_s_contains_specific_pattern_or_key __pyx_mstate_global->__pyx_n_s_contains_specific_pattern_or_key
#define __pyx_n_s_contextlib __pyx_mstate_global->__pyx_n_s_contextlib
#define __pyx_n_s_contextmanager __pyx_mstate_global->__pyx_n_s_contextmanager
#define __pyx_kp_s_contiguous_and_direct __pyx_mstate_global->__pyx_kp_s_contiguous_and_direct
#define __pyx_kp_s_contiguous_and_indirect __pyx_mstate_global->__pyx_kp_s_contiguous_and_indirect
#define __pyx_n_s_copy __pyx_mstate_global->__pyx_n_s_copy
#define __pyx_n_s_cosh __pyx_mstate_global->__pyx_n_s_cosh
#define __pyx_n_u_cosmo __pyx_mstate_global->__pyx_n_u_cosmo
#define __pyx_n_s_cosmo_arguments __pyx_mstate_global->__pyx_n_s_cosmo_arguments
#define __pyx_n_s_cosmo_model __pyx_mstate_global->__pyx_n_s_cosmo_model
#define __pyx_n_u_cosmo_model __pyx_mstate_global->__pyx_n_u_cosmo_model
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_kp_u_cov_N_N __pyx_mstate_global->__pyx_kp_u_cov_N_N
#define __pyx_n_u_covmat __pyx_mstate_global->__pyx_n_u_covmat
#define __pyx_n_u_cp_B12 __pyx_mstate_global->__pyx_n_u_cp_B12
#define __pyx_n_u_cp_B16 __pyx_mstate_global->__pyx_n_u_cp_B16
#define __pyx_n_s_cp_pkl_fftlog_alphas_nus __pyx_mstate_global->__pyx_n_s_cp_pkl_fftlog_alphas_nus
#define __pyx_n_s_cp_predicted_ee_spectrum __pyx_mstate_global->__pyx_n_s_cp_predicted_ee_spectrum
#define __pyx_n_s_cp_predicted_pp_spectrum __pyx_mstate_global->__pyx_n_s_cp_predicted_pp_spectrum
#define __pyx_n_s_cp_predicted_te_spectrum __pyx_mstate_global->__pyx_n_s_cp_predicted_te_spectrum
#define __pyx_n_s_cp_predicted_tt_spectrum __pyx_mstate_global->__pyx_n_s_cp_predicted_tt_spectrum
#define __pyx_n_s_cszfast __pyx_mstate_global->__pyx_n_s_cszfast
#define __pyx_n_s_cszfast_pk_grid_dsigma2_flat __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_dsigma2_flat
#define __pyx_n_s_cszfast_pk_grid_k __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_k
#define __pyx_n_s_cszfast_pk_grid_ln1pz __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_ln1pz
#define __pyx_n_s_cszfast_pk_grid_lnk __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_lnk
#define __pyx_n_s_cszfast_pk_grid_lnr __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_lnr
#define __pyx_n_s_cszfast_pk_grid_lnsigma2_flat __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_lnsigma2_flat
#define __pyx_n_s_cszfast_pk_grid_pkl_flat __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_pkl_flat
#define __pyx_n_s_cszfast_pk_grid_pknl __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_pknl
#define __pyx_n_s_cszfast_pk_grid_pknl_flat __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_pknl_flat
#define __pyx_n_s_cszfast_pk_grid_z __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_z
#define __pyx_n_s_cszfast_pk_grid_zmax __pyx_mstate_global->__pyx_n_s_cszfast_pk_grid_zmax
#define __pyx_n_s_ctx __pyx_mstate_global->__pyx_n_s_ctx
#define __pyx_n_u_cubic __pyx_mstate_global->__pyx_n_u_cubic
#define __pyx_n_s_cumtrapz __pyx_mstate_global->__pyx_n_s_cumtrapz
#define __pyx_n_s_cumulativeNumberDensity __pyx_mstate_global->__pyx_n_s_cumulativeNumberDensity
#define __pyx_n_u_current __pyx_mstate_global->__pyx_n_u_current
#define __pyx_n_s_custom1_W __pyx_mstate_global->__pyx_n_s_custom1_W
#define __pyx_n_s_custom1_b __pyx_mstate_global->__pyx_n_s_custom1_b
#define __pyx_n_s_custom1_ux __pyx_mstate_global->__pyx_n_s_custom1_ux
#define __pyx_n_s_d __pyx_mstate_global->__pyx_n_s_d
#define __pyx_n_u_d_ell __pyx_mstate_global->__pyx_n_u_d_ell
#define __pyx_n_u_da_rec __pyx_mstate_global->__pyx_n_u_da_rec
#define __pyx_n_u_da_rec_h __pyx_mstate_global->__pyx_n_u_da_rec_h
#define __pyx_n_u_da_star __pyx_mstate_global->__pyx_n_u_da_star
#define __pyx_n_s_data __pyx_mstate_global->__pyx_n_s_data
#define __pyx_n_u_data __pyx_mstate_global->__pyx_n_u_data
#define __pyx_n_s_dcl __pyx_mstate_global->__pyx_n_s_dcl
#define __pyx_n_u_dd __pyx_mstate_global->__pyx_n_u_dd
#define __pyx_n_s_decode __pyx_mstate_global->__pyx_n_s_decode
#define __pyx_n_s_default __pyx_mstate_global->__pyx_n_s_default
#define __pyx_n_s_defaultdict __pyx_mstate_global->__pyx_n_s_defaultdict
#define __pyx_n_u_deg_ncdm __pyx_mstate_global->__pyx_n_u_deg_ncdm
#define __pyx_n_s_delta __pyx_mstate_global->__pyx_n_s_delta
#define __pyx_n_s_deltaSZE __pyx_mstate_global->__pyx_n_s_deltaSZE
#define __pyx_n_s_delta_crit __pyx_mstate_global->__pyx_n_s_delta_crit
#define __pyx_n_s_delta_def __pyx_mstate_global->__pyx_n_s_delta_def
#define __pyx_n_s_delta_def_custom1 __pyx_mstate_global->__pyx_n_s_delta_def_custom1
#define __pyx_n_s_density_cl __pyx_mstate_global->__pyx_n_s_density_cl
#define __pyx_n_s_derived __pyx_mstate_global->__pyx_n_s_derived
#define __pyx_n_u_derived __pyx_mstate_global->__pyx_n_u_derived
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_dl __pyx_mstate_global->__pyx_n_s_dl
#define __pyx_n_u_dl __pyx_mstate_global->__pyx_n_u_dl
#define __pyx_n_s_dl_isw_sz __pyx_mstate_global->__pyx_n_s_dl_isw_sz
#define __pyx_n_s_dndM __pyx_mstate_global->__pyx_n_s_dndM
#define __pyx_n_u_dndM __pyx_mstate_global->__pyx_n_u_dndM
#define __pyx_n_s_dndlnM __pyx_mstate_global->__pyx_n_s_dndlnM
#define __pyx_n_u_dndlnM __pyx_mstate_global->__pyx_n_u_dndlnM
#define __pyx_n_u_dndlnm __pyx_mstate_global->__pyx_n_u_dndlnm
#define __pyx_n_u_dndm __pyx_mstate_global->__pyx_n_u_dndm
#define __pyx_n_u_dndz_shift_gal __pyx_mstate_global->__pyx_n_u_dndz_shift_gal
#define __pyx_n_u_dndz_shift_ngal __pyx_mstate_global->__pyx_n_u_dndz_shift_ngal
#define __pyx_n_u_dndz_shift_source_gal __pyx_mstate_global->__pyx_n_u_dndz_shift_source_gal
#define __pyx_n_u_dndz_stretch_gal __pyx_mstate_global->__pyx_n_u_dndz_stretch_gal
#define __pyx_n_u_dndz_stretch_ngal __pyx_mstate_global->__pyx_n_u_dndz_stretch_ngal
#define __pyx_n_u_dndz_stretch_source_gal __pyx_mstate_global->__pyx_n_u_dndz_stretch_source_gal
#define __pyx_n_s_dndzdy __pyx_mstate_global->__pyx_n_s_dndzdy
#define __pyx_n_u_dndzdy __pyx_mstate_global->__pyx_n_u_dndzdy
#define __pyx_n_s_dndzdy_index_z __pyx_mstate_global->__pyx_n_s_dndzdy_index_z
#define __pyx_n_s_dndzdy_theoretical __pyx_mstate_global->__pyx_n_s_dndzdy_theoretical
#define __pyx_n_s_doc __pyx_mstate_global->__pyx_n_s_doc
#define __pyx_n_s_double __pyx_mstate_global->__pyx_n_s_double
#define __pyx_n_u_ds_d __pyx_mstate_global->__pyx_n_u_ds_d
#define __pyx_n_u_ds_d_h __pyx_mstate_global->__pyx_n_u_ds_d_h
#define __pyx_n_u_ds_rec __pyx_mstate_global->__pyx_n_u_ds_rec
#define __pyx_n_u_ds_rec_h __pyx_mstate_global->__pyx_n_u_ds_rec_h
#define __pyx_n_u_ds_star __pyx_mstate_global->__pyx_n_u_ds_star
#define __pyx_n_s_dtype __pyx_mstate_global->__pyx_n_s_dtype
#define __pyx_n_s_dtype_is_object __pyx_mstate_global->__pyx_n_s_dtype_is_object
#define __pyx_n_s_dumc __pyx_mstate_global->__pyx_n_s_dumc
#define __pyx_n_s_dumcp __pyx_mstate_global->__pyx_n_s_dumcp
#define __pyx_n_s_dx __pyx_mstate_global->__pyx_n_s_dx
#define __pyx_n_u_dydz __pyx_mstate_global->__pyx_n_u_dydz
#define __pyx_n_s_dzdr __pyx_mstate_global->__pyx_n_s_dzdr
#define __pyx_n_s_e __pyx_mstate_global->__pyx_n_s_e
#define __pyx_n_u_ee __pyx_mstate_global->__pyx_n_u_ee
#define __pyx_n_s_effective_f_sigma8 __pyx_mstate_global->__pyx_n_s_effective_f_sigma8
#define __pyx_n_s_effective_galaxy_bias __pyx_mstate_global->__pyx_n_s_effective_galaxy_bias
#define __pyx_n_s_elem __pyx_mstate_global->__pyx_n_s_elem
#define __pyx_n_s_ell __pyx_mstate_global->__pyx_n_s_ell
#define __pyx_n_u_ell __pyx_mstate_global->__pyx_n_u_ell
#define __pyx_n_s_empty __pyx_mstate_global->__pyx_n_s_empty
#define __pyx_n_s_empty_like __pyx_mstate_global->__pyx_n_s_empty_like
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_encode __pyx_mstate_global->__pyx_n_s_encode
#define __pyx_n_s_end __pyx_mstate_global->__pyx_n_s_end
#define __pyx_n_s_endpoint __pyx_mstate_global->__pyx_n_s_endpoint
#define __pyx_n_s_enter __pyx_mstate_global->__pyx_n_s_enter
#define __pyx_n_s_enumerate __pyx_mstate_global->__pyx_n_s_enumerate
#define __pyx_n_s_eps1 __pyx_mstate_global->__pyx_n_s_eps1
#define __pyx_n_s_eps2 __pyx_mstate_global->__pyx_n_s_eps2
#define __pyx_n_s_eps23 __pyx_mstate_global->__pyx_n_s_eps23
#define __pyx_n_u_epsilon_V __pyx_mstate_global->__pyx_n_u_epsilon_V
#define __pyx_n_s_errmsg __pyx_mstate_global->__pyx_n_s_errmsg
#define __pyx_n_s_error __pyx_mstate_global->__pyx_n_s_error
#define __pyx_n_u_eta_V __pyx_mstate_global->__pyx_n_u_eta_V
#define __pyx_n_s_even __pyx_mstate_global->__pyx_n_s_even
#define __pyx_n_s_exit __pyx_mstate_global->__pyx_n_s_exit
#define __pyx_n_s_exp __pyx_mstate_global->__pyx_n_s_exp
#define __pyx_n_u_exp_m_2_tau_As __pyx_mstate_global->__pyx_n_u_exp_m_2_tau_As
#define __pyx_n_u_extensive __pyx_mstate_global->__pyx_n_u_extensive
#define __pyx_n_s_extrap __pyx_mstate_global->__pyx_n_s_extrap
#define __pyx_n_u_extrapolate __pyx_mstate_global->__pyx_n_u_extrapolate
#define __pyx_n_s_extrapolator __pyx_mstate_global->__pyx_n_s_extrapolator
#define __pyx_n_s_f __pyx_mstate_global->__pyx_n_s_f
#define __pyx_n_u_fNL __pyx_mstate_global->__pyx_n_u_fNL
#define __pyx_n_s_fRel __pyx_mstate_global->__pyx_n_s_fRel
#define __pyx_n_s_f_b __pyx_mstate_global->__pyx_n_s_f_b
#define __pyx_n_s_f_rel __pyx_mstate_global->__pyx_n_s_f_rel
#define __pyx_n_s_fac __pyx_mstate_global->__pyx_n_s_fac
#define __pyx_n_s_fc __pyx_mstate_global->__pyx_n_s_fc
#define __pyx_n_s_fill_value __pyx_mstate_global->__pyx_n_s_fill_value
#define __pyx_n_s_fillparfile __pyx_mstate_global->__pyx_n_s_fillparfile
#define __pyx_n_s_filterwarnings __pyx_mstate_global->__pyx_n_s_filterwarnings
#define __pyx_n_s_find_As __pyx_mstate_global->__pyx_n_s_find_As
#define __pyx_n_s_fineLog10M __pyx_mstate_global->__pyx_n_s_fineLog10M
#define __pyx_n_s_fineP __pyx_mstate_global->__pyx_n_s_fineP
#define __pyx_n_u_first __pyx_mstate_global->__pyx_n_u_first
#define __pyx_n_s_flag __pyx_mstate_global->__pyx_n_s_flag
#define __pyx_n_s_flags __pyx_mstate_global->__pyx_n_s_flags
#define __pyx_n_s_flatten __pyx_mstate_global->__pyx_n_s_flatten
#define __pyx_n_s_float64 __pyx_mstate_global->__pyx_n_s_float64
#define __pyx_n_u_float64 __pyx_mstate_global->__pyx_n_u_float64
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_s_fortran __pyx_mstate_global->__pyx_n_s_fortran
#define __pyx_n_u_fortran __pyx_mstate_global->__pyx_n_u_fortran
#define __pyx_n_s_frequency_in_Hz __pyx_mstate_global->__pyx_n_s_frequency_in_Hz
#define __pyx_n_u_full_path_and_prefix_to_dndz_nga __pyx_mstate_global->__pyx_n_u_full_path_and_prefix_to_dndz_nga
#define __pyx_n_u_full_path_to_dndz_gal __pyx_mstate_global->__pyx_n_u_full_path_to_dndz_gal
#define __pyx_n_u_full_path_to_source_dndz_gal __pyx_mstate_global->__pyx_n_u_full_path_to_source_dndz_gal
#define __pyx_n_u_galaxy_samples_list_num __pyx_mstate_global->__pyx_n_u_galaxy_samples_list_num
#define __pyx_n_s_gamma __pyx_mstate_global->__pyx_n_s_gamma
#define __pyx_n_s_gammaGNFW __pyx_mstate_global->__pyx_n_s_gammaGNFW
#define __pyx_n_u_gamma_B12 __pyx_mstate_global->__pyx_n_u_gamma_B12
#define __pyx_n_u_gamma_B16 __pyx_mstate_global->__pyx_n_u_gamma_B16
#define __pyx_n_s_gamma_ggamma __pyx_mstate_global->__pyx_n_s_gamma_ggamma
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_genexpr __pyx_mstate_global->__pyx_n_s_genexpr
#define __pyx_n_s_geomspace __pyx_mstate_global->__pyx_n_s_geomspace
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_getData __pyx_mstate_global->__pyx_n_s_getData
#define __pyx_n_s_getLogger __pyx_mstate_global->__pyx_n_s_getLogger
#define __pyx_n_s_getM500_from_y0_H13 __pyx_mstate_global->__pyx_n_s_getM500_from_y0_H13
#define __pyx_n_s_getPLog10M __pyx_mstate_global->__pyx_n_s_getPLog10M
#define __pyx_n_s_get_1e6xdy_from_battaglia_pressu __pyx_mstate_global->__pyx_n_s_get_1e6xdy_from_battaglia_pressu
#define __pyx_n_s_get_1e6xdy_from_gnfw_pressure_at __pyx_mstate_global->__pyx_n_s_get_1e6xdy_from_gnfw_pressure_at
#define __pyx_n_s_get_Delta_c_of_Omega_m __pyx_mstate_global->__pyx_n_s_get_Delta_c_of_Omega_m
#define __pyx_n_s_get_Ez __pyx_mstate_global->__pyx_n_s_get_Ez
#define __pyx_n_s_get_H __pyx_mstate_global->__pyx_n_s_get_H
#define __pyx_n_s_get_H0_from_thetas __pyx_mstate_global->__pyx_n_s_get_H0_from_thetas
#define __pyx_n_s_get_IA_of_z __pyx_mstate_global->__pyx_n_s_get_IA_of_z
#define __pyx_n_s_get_N_centrals __pyx_mstate_global->__pyx_n_s_get_N_centrals
#define __pyx_n_s_get_N_satellites __pyx_mstate_global->__pyx_n_s_get_N_satellites
#define __pyx_n_s_get_Omega_m_0 __pyx_mstate_global->__pyx_n_s_get_Omega_m_0
#define __pyx_n_s_get_Omega_m_at_z __pyx_mstate_global->__pyx_n_s_get_Omega_m_at_z
#define __pyx_n_s_get_Omega_r_0 __pyx_mstate_global->__pyx_n_s_get_Omega_r_0
#define __pyx_n_s_get_P_delta_at_m_and_z_b12 __pyx_mstate_global->__pyx_n_s_get_P_delta_at_m_and_z_b12
#define __pyx_n_s_get_Q_of_theta500 __pyx_mstate_global->__pyx_n_s_get_Q_of_theta500
#define __pyx_n_s_get_T10_alpha_at_z __pyx_mstate_global->__pyx_n_s_get_T10_alpha_at_z
#define __pyx_n_s_get_arcmin_to_rad __pyx_mstate_global->__pyx_n_s_get_arcmin_to_rad
#define __pyx_n_s_get_background __pyx_mstate_global->__pyx_n_s_get_background
#define __pyx_n_s_get_bispectrum_f2_kernel __pyx_mstate_global->__pyx_n_s_get_bispectrum_f2_kernel
#define __pyx_n_s_get_c200c_at_m_and_z __pyx_mstate_global->__pyx_n_s_get_c200c_at_m_and_z
#define __pyx_n_s_get_c200c_at_m_and_z_B13 __pyx_mstate_global->__pyx_n_s_get_c200c_at_m_and_z_B13
#define __pyx_n_s_get_c200c_at_m_and_z_D08 __pyx_mstate_global->__pyx_n_s_get_c200c_at_m_and_z_D08
#define __pyx_n_s_get_c200m_at_m_and_z __pyx_mstate_global->__pyx_n_s_get_c200m_at_m_and_z
#define __pyx_n_s_get_c200m_at_m_and_z_D08 __pyx_mstate_global->__pyx_n_s_get_c200m_at_m_and_z_D08
#define __pyx_n_s_get_c500c_at_m_and_z __pyx_mstate_global->__pyx_n_s_get_c500c_at_m_and_z
#define __pyx_n_s_get_c_delta_at_m_and_z __pyx_mstate_global->__pyx_n_s_get_c_delta_at_m_and_z
#define __pyx_n_s_get_chi __pyx_mstate_global->__pyx_n_s_get_chi
#define __pyx_n_s_get_cib_Snu_z_and_nu __pyx_mstate_global->__pyx_n_s_get_cib_Snu_z_and_nu
#define __pyx_n_s_get_comoving_volume __pyx_mstate_global->__pyx_n_s_get_comoving_volume
#define __pyx_n_s_get_cov_N_N __pyx_mstate_global->__pyx_n_s_get_cov_N_N
#define __pyx_n_s_get_current_derived_parameters __pyx_mstate_global->__pyx_n_s_get_current_derived_parameters
#define __pyx_n_s_get_custom1_bias_at_z __pyx_mstate_global->__pyx_n_s_get_custom1_bias_at_z
#define __pyx_n_s_get_custom1_profile_at_k_m_z __pyx_mstate_global->__pyx_n_s_get_custom1_profile_at_k_m_z
#define __pyx_n_s_get_custom1_profile_at_x_m_z __pyx_mstate_global->__pyx_n_s_get_custom1_profile_at_x_m_z
#define __pyx_n_s_get_cvir_of_mvir_at_z __pyx_mstate_global->__pyx_n_s_get_cvir_of_mvir_at_z
#define __pyx_n_s_get_dA __pyx_mstate_global->__pyx_n_s_get_dA
#define __pyx_n_s_get_dA_z1z2 __pyx_mstate_global->__pyx_n_s_get_dA_z1z2
#define __pyx_n_s_get_dcib0dz_at_z_and_nu __pyx_mstate_global->__pyx_n_s_get_dcib0dz_at_z_and_nu
#define __pyx_n_s_get_delta_from_delta_def_at_z __pyx_mstate_global->__pyx_n_s_get_delta_from_delta_def_at_z
#define __pyx_n_s_get_delta_mean_from_delta_crit_a __pyx_mstate_global->__pyx_n_s_get_delta_mean_from_delta_crit_a
#define __pyx_n_s_get_dkappacmbdz_at_l_and_z __pyx_mstate_global->__pyx_n_s_get_dkappacmbdz_at_l_and_z
#define __pyx_n_s_get_dlnsigma_dlnR_at_z_and_m __pyx_mstate_global->__pyx_n_s_get_dlnsigma_dlnR_at_z_and_m
#define __pyx_n_s_get_dndlnM_at_z_and_M __pyx_mstate_global->__pyx_n_s_get_dndlnM_at_z_and_M
#define __pyx_n_s_get_dndlnm __pyx_mstate_global->__pyx_n_s_get_dndlnm
#define __pyx_n_s_get_dndzdq __pyx_mstate_global->__pyx_n_s_get_dndzdq
#define __pyx_n_s_get_dydz_at_z __pyx_mstate_global->__pyx_n_s_get_dydz_at_z
#define __pyx_n_s_get_dydzdlnm_at_z_and_m __pyx_mstate_global->__pyx_n_s_get_dydzdlnm_at_z_and_m
#define __pyx_n_s_get_effective_f_sigma8 __pyx_mstate_global->__pyx_n_s_get_effective_f_sigma8
#define __pyx_n_s_get_f_b __pyx_mstate_global->__pyx_n_s_get_f_b
#define __pyx_n_s_get_f_free __pyx_mstate_global->__pyx_n_s_get_f_free
#define __pyx_n_s_get_f_of_sigma_at_m_and_z __pyx_mstate_global->__pyx_n_s_get_f_of_sigma_at_m_and_z
#define __pyx_n_s_get_f_tinker08_at_nu_and_z __pyx_mstate_global->__pyx_n_s_get_f_tinker08_at_nu_and_z
#define __pyx_n_s_get_f_tinker10_at_nu_and_z __pyx_mstate_global->__pyx_n_s_get_f_tinker10_at_nu_and_z
#define __pyx_n_s_get_fftlog_ComputeXiLMsloz __pyx_mstate_global->__pyx_n_s_get_fftlog_ComputeXiLMsloz
#define __pyx_n_s_get_first_order_bias_at_z_and_m __pyx_mstate_global->__pyx_n_s_get_first_order_bias_at_z_and_m
#define __pyx_n_s_get_first_order_bias_at_z_and_m_2 __pyx_mstate_global->__pyx_n_s_get_first_order_bias_at_z_and_m_2
#define __pyx_n_s_get_first_order_bias_at_z_and_nu __pyx_mstate_global->__pyx_n_s_get_first_order_bias_at_z_and_nu
#define __pyx_n_s_get_fstar_of_m_at_z __pyx_mstate_global->__pyx_n_s_get_fstar_of_m_at_z
#define __pyx_n_s_get_galaxy_number_counts __pyx_mstate_global->__pyx_n_s_get_galaxy_number_counts
#define __pyx_n_s_get_gas_density_profile_at_k_M_z __pyx_mstate_global->__pyx_n_s_get_gas_density_profile_at_k_M_z
#define __pyx_n_s_get_gas_pressure_2h_at_r_and_m_a __pyx_mstate_global->__pyx_n_s_get_gas_pressure_2h_at_r_and_m_a
#define __pyx_n_s_get_gas_profile_at_x_M_z_b16_200 __pyx_mstate_global->__pyx_n_s_get_gas_profile_at_x_M_z_b16_200
#define __pyx_n_s_get_gas_profile_at_x_M_z_bcm_200 __pyx_mstate_global->__pyx_n_s_get_gas_profile_at_x_M_z_bcm_200
#define __pyx_n_s_get_gas_profile_at_x_M_z_nfw_200 __pyx_mstate_global->__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200
#define __pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2 __pyx_mstate_global->__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2
#define __pyx_n_s_get_gnu_tsz_of_nu_in_ghz __pyx_mstate_global->__pyx_n_s_get_gnu_tsz_of_nu_in_ghz
#define __pyx_n_s_get_hmf_counter_term_b1min_at_z __pyx_mstate_global->__pyx_n_s_get_hmf_counter_term_b1min_at_z
#define __pyx_n_s_get_hmf_counter_term_b2min_at_z __pyx_mstate_global->__pyx_n_s_get_hmf_counter_term_b2min_at_z
#define __pyx_n_s_get_hmf_counter_term_nmin_at_z __pyx_mstate_global->__pyx_n_s_get_hmf_counter_term_nmin_at_z
#define __pyx_n_s_get_hubble __pyx_mstate_global->__pyx_n_s_get_hubble
#define __pyx_n_s_get_lensing_noise_at_ell __pyx_mstate_global->__pyx_n_s_get_lensing_noise_at_ell
#define __pyx_n_s_get_m200c_to_m200m_at_z_and_M __pyx_mstate_global->__pyx_n_s_get_m200c_to_m200m_at_z_and_M
#define __pyx_n_s_get_m200c_to_m500c_at_z_and_M __pyx_mstate_global->__pyx_n_s_get_m200c_to_m500c_at_z_and_M
#define __pyx_n_s_get_m200m_to_m200c_at_z_and_M __pyx_mstate_global->__pyx_n_s_get_m200m_to_m200c_at_z_and_M
#define __pyx_n_s_get_m200m_to_m500c_at_z_and_M __pyx_mstate_global->__pyx_n_s_get_m200m_to_m500c_at_z_and_M
#define __pyx_n_s_get_m500c_to_m200c_at_z_and_M __pyx_mstate_global->__pyx_n_s_get_m500c_to_m200c_at_z_and_M
#define __pyx_n_s_get_m500c_to_m200m_at_z_and_M __pyx_mstate_global->__pyx_n_s_get_m500c_to_m200m_at_z_and_M
#define __pyx_n_s_get_m_nfw __pyx_mstate_global->__pyx_n_s_get_m_nfw
#define __pyx_n_s_get_m_to_xout_at_z_and_m __pyx_mstate_global->__pyx_n_s_get_m_to_xout_at_z_and_m
#define __pyx_n_s_get_mass_profile_at_x_M_z_nfw_20 __pyx_mstate_global->__pyx_n_s_get_mass_profile_at_x_M_z_nfw_20
#define __pyx_n_s_get_matter_bispectrum_at_z_effec __pyx_mstate_global->__pyx_n_s_get_matter_bispectrum_at_z_effec
#define __pyx_n_s_get_matter_bispectrum_at_z_effec_2 __pyx_mstate_global->__pyx_n_s_get_matter_bispectrum_at_z_effec_2
#define __pyx_n_s_get_matter_bispectrum_at_z_effec_3 __pyx_mstate_global->__pyx_n_s_get_matter_bispectrum_at_z_effec_3
#define __pyx_n_s_get_matter_bispectrum_at_z_tree __pyx_mstate_global->__pyx_n_s_get_matter_bispectrum_at_z_tree
#define __pyx_n_s_get_mcmc_parameters __pyx_mstate_global->__pyx_n_s_get_mcmc_parameters
#define __pyx_n_s_get_mean_galaxy_bias_at_z __pyx_mstate_global->__pyx_n_s_get_mean_galaxy_bias_at_z
#define __pyx_n_s_get_mean_y __pyx_mstate_global->__pyx_n_s_get_mean_y
#define __pyx_n_s_get_mu_e __pyx_mstate_global->__pyx_n_s_get_mu_e
#define __pyx_n_s_get_n5k_cl_K1_at_chi __pyx_mstate_global->__pyx_n_s_get_n5k_cl_K1_at_chi
#define __pyx_n_s_get_n5k_pk_at_z_and_k __pyx_mstate_global->__pyx_n_s_get_n5k_pk_at_z_and_k
#define __pyx_n_s_get_n5k_z_of_chi __pyx_mstate_global->__pyx_n_s_get_n5k_z_of_chi
#define __pyx_n_s_get_ng_bar_at_z __pyx_mstate_global->__pyx_n_s_get_ng_bar_at_z
#define __pyx_n_s_get_nl_index_at_z_and_k __pyx_mstate_global->__pyx_n_s_get_nl_index_at_z_and_k
#define __pyx_n_s_get_nl_index_at_z_and_k_no_wiggl __pyx_mstate_global->__pyx_n_s_get_nl_index_at_z_and_k_no_wiggl
#define __pyx_n_s_get_normalization_gas_density_pr __pyx_mstate_global->__pyx_n_s_get_normalization_gas_density_pr
#define __pyx_n_s_get_nu_at_z_and_m __pyx_mstate_global->__pyx_n_s_get_nu_at_z_and_m
#define __pyx_n_s_get_params_sz __pyx_mstate_global->__pyx_n_s_get_params_sz
#define __pyx_n_s_get_perturbations __pyx_mstate_global->__pyx_n_s_get_perturbations
#define __pyx_n_s_get_pk __pyx_mstate_global->__pyx_n_s_get_pk
#define __pyx_n_s_get_pk_and_k_and_z __pyx_mstate_global->__pyx_n_s_get_pk_and_k_and_z
#define __pyx_n_s_get_pk_array __pyx_mstate_global->__pyx_n_s_get_pk_array
#define __pyx_n_s_get_pk_cb __pyx_mstate_global->__pyx_n_s_get_pk_cb
#define __pyx_n_s_get_pk_cb_array __pyx_mstate_global->__pyx_n_s_get_pk_cb_array
#define __pyx_n_s_get_pk_cb_lin __pyx_mstate_global->__pyx_n_s_get_pk_cb_lin
#define __pyx_n_s_get_pk_lin __pyx_mstate_global->__pyx_n_s_get_pk_lin
#define __pyx_n_s_get_pk_lin_at_k_and_z __pyx_mstate_global->__pyx_n_s_get_pk_lin_at_k_and_z
#define __pyx_n_s_get_pk_lin_at_k_and_z_fast __pyx_mstate_global->__pyx_n_s_get_pk_lin_at_k_and_z_fast
#define __pyx_n_s_get_pk_nonlin_at_k_and_z __pyx_mstate_global->__pyx_n_s_get_pk_nonlin_at_k_and_z
#define __pyx_n_s_get_pk_nonlin_at_k_and_z_fast __pyx_mstate_global->__pyx_n_s_get_pk_nonlin_at_k_and_z_fast
#define __pyx_n_s_get_pkl __pyx_mstate_global->__pyx_n_s_get_pkl
#define __pyx_n_s_get_pkl_at_k_and_z __pyx_mstate_global->__pyx_n_s_get_pkl_at_k_and_z
#define __pyx_n_s_get_pkl_at_z __pyx_mstate_global->__pyx_n_s_get_pkl_at_z
#define __pyx_n_s_get_pkl_locals_compute_pkl __pyx_mstate_global->__pyx_n_s_get_pkl_locals_compute_pkl
#define __pyx_n_s_get_pkl_locals_handle_combinatio __pyx_mstate_global->__pyx_n_s_get_pkl_locals_handle_combinatio
#define __pyx_n_s_get_pkl_reconstructed_from_fftlo __pyx_mstate_global->__pyx_n_s_get_pkl_reconstructed_from_fftlo
#define __pyx_n_s_get_pkl_unvectorized __pyx_mstate_global->__pyx_n_s_get_pkl_unvectorized
#define __pyx_n_s_get_pknl __pyx_mstate_global->__pyx_n_s_get_pknl
#define __pyx_n_s_get_pknl_at_k_and_z __pyx_mstate_global->__pyx_n_s_get_pknl_at_k_and_z
#define __pyx_n_s_get_pknl_at_z __pyx_mstate_global->__pyx_n_s_get_pknl_at_z
#define __pyx_n_s_get_pknl_locals_compute_pknl __pyx_mstate_global->__pyx_n_s_get_pknl_locals_compute_pknl
#define __pyx_n_s_get_pknl_locals_handle_combinati __pyx_mstate_global->__pyx_n_s_get_pknl_locals_handle_combinati
#define __pyx_n_s_get_pknl_unvectorized __pyx_mstate_global->__pyx_n_s_get_pknl_unvectorized
#define __pyx_n_s_get_planck_sigma_at_theta500 __pyx_mstate_global->__pyx_n_s_get_planck_sigma_at_theta500
#define __pyx_n_s_get_pressure_P_over_P_delta_at_x __pyx_mstate_global->__pyx_n_s_get_pressure_P_over_P_delta_at_x
#define __pyx_n_s_get_pressure_P_over_P_delta_at_x_2 __pyx_mstate_global->__pyx_n_s_get_pressure_P_over_P_delta_at_x_2
#define __pyx_n_s_get_primordial __pyx_mstate_global->__pyx_n_s_get_primordial
#define __pyx_n_s_get_r_delta_of_m_delta_at_z __pyx_mstate_global->__pyx_n_s_get_r_delta_of_m_delta_at_z
#define __pyx_n_s_get_rad_to_arcmin __pyx_mstate_global->__pyx_n_s_get_rad_to_arcmin
#define __pyx_n_s_get_radial_kernel_W_custom1_at_z __pyx_mstate_global->__pyx_n_s_get_radial_kernel_W_custom1_at_z
#define __pyx_n_s_get_radial_kernel_W_galaxy_lensi __pyx_mstate_global->__pyx_n_s_get_radial_kernel_W_galaxy_lensi
#define __pyx_n_s_get_radial_kernel_W_galaxy_ngal __pyx_mstate_global->__pyx_n_s_get_radial_kernel_W_galaxy_ngal
#define __pyx_n_s_get_rho_2h_at_r_and_m_and_z __pyx_mstate_global->__pyx_n_s_get_rho_2h_at_r_and_m_and_z
#define __pyx_n_s_get_rho_crit_at_z __pyx_mstate_global->__pyx_n_s_get_rho_crit_at_z
#define __pyx_n_s_get_rvir_of_m200c_at_z __pyx_mstate_global->__pyx_n_s_get_rvir_of_m200c_at_z
#define __pyx_n_s_get_rvir_of_mvir_at_z __pyx_mstate_global->__pyx_n_s_get_rvir_of_mvir_at_z
#define __pyx_n_s_get_scale_dependent_bias_at_z_an __pyx_mstate_global->__pyx_n_s_get_scale_dependent_bias_at_z_an
#define __pyx_n_s_get_second_order_bias_at_z_and_n __pyx_mstate_global->__pyx_n_s_get_second_order_bias_at_z_and_n
#define __pyx_n_s_get_sigma8_at_z __pyx_mstate_global->__pyx_n_s_get_sigma8_at_z
#define __pyx_n_s_get_sigma_at_r_and_z __pyx_mstate_global->__pyx_n_s_get_sigma_at_r_and_z
#define __pyx_n_s_get_sigma_at_z_and_m __pyx_mstate_global->__pyx_n_s_get_sigma_at_z_and_m
#define __pyx_n_s_get_source_galaxy_number_counts __pyx_mstate_global->__pyx_n_s_get_source_galaxy_number_counts
#define __pyx_n_s_get_szcounts_dndzdq_at_z_q __pyx_mstate_global->__pyx_n_s_get_szcounts_dndzdq_at_z_q
#define __pyx_n_s_get_szcountsz_sigma_at_theta_in __pyx_mstate_global->__pyx_n_s_get_szcountsz_sigma_at_theta_in
#define __pyx_n_s_get_te_of_m500c_at_z_arnaud __pyx_mstate_global->__pyx_n_s_get_te_of_m500c_at_z_arnaud
#define __pyx_n_s_get_te_of_m500c_at_z_lee __pyx_mstate_global->__pyx_n_s_get_te_of_m500c_at_z_lee
#define __pyx_n_s_get_thermodynamics __pyx_mstate_global->__pyx_n_s_get_thermodynamics
#define __pyx_n_s_get_theta_at_m_and_z __pyx_mstate_global->__pyx_n_s_get_theta_at_m_and_z
#define __pyx_n_s_get_transfer __pyx_mstate_global->__pyx_n_s_get_transfer
#define __pyx_n_s_get_truncated_nfw_profile_at_z_k __pyx_mstate_global->__pyx_n_s_get_truncated_nfw_profile_at_z_k
#define __pyx_n_s_get_truncated_nfw_profile_at_z_k_2 __pyx_mstate_global->__pyx_n_s_get_truncated_nfw_profile_at_z_k_2
#define __pyx_n_s_get_ttg_bispectrum_at_z_effectiv __pyx_mstate_global->__pyx_n_s_get_ttg_bispectrum_at_z_effectiv
#define __pyx_n_s_get_ttg_bispectrum_at_z_tree_lev __pyx_mstate_global->__pyx_n_s_get_ttg_bispectrum_at_z_tree_lev
#define __pyx_n_s_get_uk __pyx_mstate_global->__pyx_n_s_get_uk
#define __pyx_n_s_get_uk_nfw __pyx_mstate_global->__pyx_n_s_get_uk_nfw
#define __pyx_n_s_get_uk_nfw_locals_compute_profil __pyx_mstate_global->__pyx_n_s_get_uk_nfw_locals_compute_profil
#define __pyx_n_s_get_uk_nfw_locals_handle_combina __pyx_mstate_global->__pyx_n_s_get_uk_nfw_locals_handle_combina
#define __pyx_n_s_get_unwise_m_min_cut_at_z __pyx_mstate_global->__pyx_n_s_get_unwise_m_min_cut_at_z
#define __pyx_n_s_get_upp_from_gnfw_pressure_at_x __pyx_mstate_global->__pyx_n_s_get_upp_from_gnfw_pressure_at_x
#define __pyx_n_s_get_volume_dVdzdOmega_at_z __pyx_mstate_global->__pyx_n_s_get_volume_dVdzdOmega_at_z
#define __pyx_n_s_get_vrms2_at_z __pyx_mstate_global->__pyx_n_s_get_vrms2_at_z
#define __pyx_n_s_get_y_at_m_and_z __pyx_mstate_global->__pyx_n_s_get_y_at_m_and_z
#define __pyx_n_s_get_yc_at_m_and_z_H13 __pyx_mstate_global->__pyx_n_s_get_yc_at_m_and_z_H13
#define __pyx_n_s_get_z_of_chi __pyx_mstate_global->__pyx_n_s_get_z_of_chi
#define __pyx_n_s_get_z_of_chi_unvectorized __pyx_mstate_global->__pyx_n_s_get_z_of_chi_unvectorized
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_kp_u_got __pyx_mstate_global->__pyx_kp_u_got
#define __pyx_kp_u_got_differing_extents_in_dimensi __pyx_mstate_global->__pyx_kp_u_got_differing_extents_in_dimensi
#define __pyx_n_s_h __pyx_mstate_global->__pyx_n_s_h
#define __pyx_n_u_h __pyx_mstate_global->__pyx_n_u_h
#define __pyx_n_s_h_P __pyx_mstate_global->__pyx_n_s_h_P
#define __pyx_n_s_h_units __pyx_mstate_global->__pyx_n_s_h_units
#define __pyx_n_s_handle_combinations __pyx_mstate_global->__pyx_n_s_handle_combinations
#define __pyx_n_s_has_flags __pyx_mstate_global->__pyx_n_s_has_flags
#define __pyx_kp_u_hf __pyx_mstate_global->__pyx_kp_u_hf
#define __pyx_n_u_hf_2 __pyx_mstate_global->__pyx_n_u_hf_2
#define __pyx_n_u_hmf __pyx_mstate_global->__pyx_n_u_hmf
#define __pyx_n_s_hplanck __pyx_mstate_global->__pyx_n_s_hplanck
#define __pyx_n_u_hsv __pyx_mstate_global->__pyx_n_u_hsv
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_s_ic_info __pyx_mstate_global->__pyx_n_s_ic_info
#define __pyx_n_s_ic_key __pyx_mstate_global->__pyx_n_s_ic_key
#define __pyx_n_s_ic_num __pyx_mstate_global->__pyx_n_s_ic_num
#define __pyx_n_s_ic_suffix __pyx_mstate_global->__pyx_n_s_ic_suffix
#define __pyx_n_s_id __pyx_mstate_global->__pyx_n_s_id
#define __pyx_n_s_id_nu1 __pyx_mstate_global->__pyx_n_s_id_nu1
#define __pyx_n_s_id_nu2 __pyx_mstate_global->__pyx_n_s_id_nu2
#define __pyx_n_u_ignore __pyx_mstate_global->__pyx_n_u_ignore
#define __pyx_n_s_imp __pyx_mstate_global->__pyx_n_s_imp
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_n_s_index_M_bins __pyx_mstate_global->__pyx_n_s_index_M_bins
#define __pyx_n_s_index_M_bins_prime __pyx_mstate_global->__pyx_n_s_index_M_bins_prime
#define __pyx_n_s_index_g __pyx_mstate_global->__pyx_n_s_index_g
#define __pyx_n_s_index_ic __pyx_mstate_global->__pyx_n_s_index_ic
#define __pyx_n_s_index_k __pyx_mstate_global->__pyx_n_s_index_k
#define __pyx_n_s_index_l __pyx_mstate_global->__pyx_n_s_index_l
#define __pyx_n_s_index_l_prime __pyx_mstate_global->__pyx_n_s_index_l_prime
#define __pyx_n_s_index_m __pyx_mstate_global->__pyx_n_s_index_m
#define __pyx_n_s_index_m_z __pyx_mstate_global->__pyx_n_s_index_m_z
#define __pyx_n_s_index_md __pyx_mstate_global->__pyx_n_s_index_md
#define __pyx_n_s_index_mu __pyx_mstate_global->__pyx_n_s_index_mu
#define __pyx_n_s_index_pk __pyx_mstate_global->__pyx_n_s_index_pk
#define __pyx_n_s_index_r __pyx_mstate_global->__pyx_n_s_index_r
#define __pyx_n_s_index_tau __pyx_mstate_global->__pyx_n_s_index_tau
#define __pyx_n_s_index_x __pyx_mstate_global->__pyx_n_s_index_x
#define __pyx_n_s_index_y __pyx_mstate_global->__pyx_n_s_index_y
#define __pyx_n_s_index_z __pyx_mstate_global->__pyx_n_s_index_z
#define __pyx_n_s_index_z_r __pyx_mstate_global->__pyx_n_s_index_z_r
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initial __pyx_mstate_global->__pyx_n_s_initial
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_u_input __pyx_mstate_global->__pyx_n_u_input
#define __pyx_n_s_intUpper __pyx_mstate_global->__pyx_n_s_intUpper
#define __pyx_n_s_integrate __pyx_mstate_global->__pyx_n_s_integrate
#define __pyx_n_s_integrate_only __pyx_mstate_global->__pyx_n_s_integrate_only
#define __pyx_n_s_interp1d __pyx_mstate_global->__pyx_n_s_interp1d
#define __pyx_n_s_interpolate __pyx_mstate_global->__pyx_n_s_interpolate
#define __pyx_n_s_ionization_fraction __pyx_mstate_global->__pyx_n_s_ionization_fraction
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_kp_u_is_not_implemented_yet __pyx_mstate_global->__pyx_kp_u_is_not_implemented_yet
#define __pyx_kp_u_is_not_implemented_yet_Availabl __pyx_mstate_global->__pyx_kp_u_is_not_implemented_yet_Availabl
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_isscalar __pyx_mstate_global->__pyx_n_s_isscalar
#define __pyx_n_s_issuperset __pyx_mstate_global->__pyx_n_s_issuperset
#define __pyx_n_u_isw_auto __pyx_mstate_global->__pyx_n_u_isw_auto
#define __pyx_n_u_isw_lens __pyx_mstate_global->__pyx_n_u_isw_lens
#define __pyx_n_u_isw_tsz __pyx_mstate_global->__pyx_n_u_isw_tsz
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_itemsize __pyx_mstate_global->__pyx_n_s_itemsize
#define __pyx_kp_s_itemsize_0_for_cython_array __pyx_mstate_global->__pyx_kp_s_itemsize_0_for_cython_array
#define __pyx_n_s_j __pyx_mstate_global->__pyx_n_s_j
#define __pyx_n_s_join __pyx_mstate_global->__pyx_n_s_join
#define __pyx_n_s_k __pyx_mstate_global->__pyx_n_s_k
#define __pyx_n_u_k __pyx_mstate_global->__pyx_n_u_k
#define __pyx_n_s_k1 __pyx_mstate_global->__pyx_n_s_k1
#define __pyx_n_s_k1_in_h_over_Mpc __pyx_mstate_global->__pyx_n_s_k1_in_h_over_Mpc
#define __pyx_n_s_k2 __pyx_mstate_global->__pyx_n_s_k2
#define __pyx_n_s_k2_in_h_over_Mpc __pyx_mstate_global->__pyx_n_s_k2_in_h_over_Mpc
#define __pyx_n_s_k3 __pyx_mstate_global->__pyx_n_s_k3
#define __pyx_n_s_k3_in_h_over_Mpc __pyx_mstate_global->__pyx_n_s_k3_in_h_over_Mpc
#define __pyx_n_s_kB __pyx_mstate_global->__pyx_n_s_kB
#define __pyx_n_s_k_B __pyx_mstate_global->__pyx_n_s_k_B
#define __pyx_kp_u_k_and_z_must_be_broadcastable_to __pyx_mstate_global->__pyx_kp_u_k_and_z_must_be_broadcastable_to
#define __pyx_n_s_k_array __pyx_mstate_global->__pyx_n_s_k_array
#define __pyx_n_s_k_asked __pyx_mstate_global->__pyx_n_s_k_asked
#define __pyx_n_s_k_eq __pyx_mstate_global->__pyx_n_s_k_eq
#define __pyx_n_u_k_eq __pyx_mstate_global->__pyx_n_u_k_eq
#define __pyx_n_s_k_input __pyx_mstate_global->__pyx_n_s_k_input
#define __pyx_n_s_k_len __pyx_mstate_global->__pyx_n_s_k_len
#define __pyx_n_s_k_nl __pyx_mstate_global->__pyx_n_s_k_nl
#define __pyx_n_s_k_nl_cb __pyx_mstate_global->__pyx_n_s_k_nl_cb
#define __pyx_n_s_k_size __pyx_mstate_global->__pyx_n_s_k_size
#define __pyx_n_s_k_vals __pyx_mstate_global->__pyx_n_s_k_vals
#define __pyx_n_s_kars __pyx_mstate_global->__pyx_n_s_kars
#define __pyx_n_s_key __pyx_mstate_global->__pyx_n_s_key
#define __pyx_n_s_kh __pyx_mstate_global->__pyx_n_s_kh
#define __pyx_n_s_kh_input __pyx_mstate_global->__pyx_n_s_kh_input
#define __pyx_n_s_kh_len __pyx_mstate_global->__pyx_n_s_kh_len
#define __pyx_n_s_kh_vals __pyx_mstate_global->__pyx_n_s_kh_vals
#define __pyx_n_s_kind __pyx_mstate_global->__pyx_n_s_kind
#define __pyx_n_s_kk __pyx_mstate_global->__pyx_n_s_kk
#define __pyx_kp_u_ksi_V_2 __pyx_mstate_global->__pyx_kp_u_ksi_V_2
#define __pyx_n_s_l __pyx_mstate_global->__pyx_n_s_l
#define __pyx_n_u_lCl __pyx_mstate_global->__pyx_n_u_lCl
#define __pyx_n_s_l_asked __pyx_mstate_global->__pyx_n_s_l_asked
#define __pyx_n_s_l_max_flag __pyx_mstate_global->__pyx_n_s_l_max_flag
#define __pyx_n_u_l_max_lss __pyx_mstate_global->__pyx_n_u_l_max_lss
#define __pyx_n_u_l_max_scalars __pyx_mstate_global->__pyx_n_u_l_max_scalars
#define __pyx_n_s_last_index __pyx_mstate_global->__pyx_n_s_last_index
#define __pyx_n_s_lcl __pyx_mstate_global->__pyx_n_s_lcl
#define __pyx_n_s_lcp __pyx_mstate_global->__pyx_n_s_lcp
#define __pyx_n_s_lensed_cl __pyx_mstate_global->__pyx_n_s_lensed_cl
#define __pyx_n_u_lensing __pyx_mstate_global->__pyx_n_u_lensing
#define __pyx_kp_u_lensing_term __pyx_mstate_global->__pyx_kp_u_lensing_term
#define __pyx_n_s_level __pyx_mstate_global->__pyx_n_s_level
#define __pyx_kp_u_levelname_s_message_s __pyx_mstate_global->__pyx_kp_u_levelname_s_message_s
#define __pyx_n_s_levels __pyx_mstate_global->__pyx_n_s_levels
#define __pyx_n_s_likelihood_mode __pyx_mstate_global->__pyx_n_s_likelihood_mode
#define __pyx_n_u_lin __pyx_mstate_global->__pyx_n_u_lin
#define __pyx_n_s_linspace __pyx_mstate_global->__pyx_n_s_linspace
#define __pyx_n_u_ll __pyx_mstate_global->__pyx_n_u_ll
#define __pyx_n_s_lmax __pyx_mstate_global->__pyx_n_s_lmax
#define __pyx_n_s_lmaxR __pyx_mstate_global->__pyx_n_s_lmaxR
#define __pyx_kp_u_ln10_10_A_s __pyx_mstate_global->__pyx_kp_u_ln10_10_A_s
#define __pyx_n_s_ln1pzc __pyx_mstate_global->__pyx_n_s_ln1pzc
#define __pyx_n_s_lna __pyx_mstate_global->__pyx_n_s_lna
#define __pyx_n_s_load_n5k_cl_K1 __pyx_mstate_global->__pyx_n_s_load_n5k_cl_K1
#define __pyx_n_s_load_n5k_pk_zk __pyx_mstate_global->__pyx_n_s_load_n5k_pk_zk
#define __pyx_n_s_load_n5k_z_of_chi __pyx_mstate_global->__pyx_n_s_load_n5k_z_of_chi
#define __pyx_n_s_loadtxt __pyx_mstate_global->__pyx_n_s_loadtxt
#define __pyx_n_s_log __pyx_mstate_global->__pyx_n_s_log
#define __pyx_n_s_log10 __pyx_mstate_global->__pyx_n_s_log10
#define __pyx_n_s_log10M __pyx_mstate_global->__pyx_n_s_log10M
#define __pyx_n_s_log10M500c_zk __pyx_mstate_global->__pyx_n_s_log10M500c_zk
#define __pyx_n_s_log10Ms __pyx_mstate_global->__pyx_n_s_log10Ms
#define __pyx_n_s_log10x_num __pyx_mstate_global->__pyx_n_s_log10x_num
#define __pyx_n_s_log10xmax_mcfit __pyx_mstate_global->__pyx_n_s_log10xmax_mcfit
#define __pyx_n_s_log10xmin_mcfit __pyx_mstate_global->__pyx_n_s_log10xmin_mcfit
#define __pyx_n_s_log10y_center __pyx_mstate_global->__pyx_n_s_log10y_center
#define __pyx_n_u_log10y_center __pyx_mstate_global->__pyx_n_u_log10y_center
#define __pyx_n_s_log10y_edges __pyx_mstate_global->__pyx_n_s_log10y_edges
#define __pyx_n_u_log10y_edges __pyx_mstate_global->__pyx_n_u_log10y_edges
#define __pyx_n_u_logA __pyx_mstate_global->__pyx_n_u_logA
#define __pyx_n_s_logA_fast __pyx_mstate_global->__pyx_n_s_logA_fast
#define __pyx_n_s_log_y0 __pyx_mstate_global->__pyx_n_s_log_y0
#define __pyx_n_s_log_y0Err __pyx_mstate_global->__pyx_n_s_log_y0Err
#define __pyx_n_s_log_y0pred __pyx_mstate_global->__pyx_n_s_log_y0pred
#define __pyx_n_s_logging __pyx_mstate_global->__pyx_n_s_logging
#define __pyx_n_s_loglike __pyx_mstate_global->__pyx_n_s_loglike
#define __pyx_n_u_loglike __pyx_mstate_global->__pyx_n_u_loglike
#define __pyx_n_s_logspace __pyx_mstate_global->__pyx_n_s_logspace
#define __pyx_n_s_lowring __pyx_mstate_global->__pyx_n_s_lowring
#define __pyx_n_s_lum_distance __pyx_mstate_global->__pyx_n_s_lum_distance
#define __pyx_n_s_luminosity_distance __pyx_mstate_global->__pyx_n_s_luminosity_distance
#define __pyx_n_s_m __pyx_mstate_global->__pyx_n_s_m
#define __pyx_n_u_mPk __pyx_mstate_global->__pyx_n_u_mPk
#define __pyx_n_s_m_asked __pyx_mstate_global->__pyx_n_s_m_asked
#define __pyx_n_s_m_broadcasted __pyx_mstate_global->__pyx_n_s_m_broadcasted
#define __pyx_kp_u_m_d_a_zA_Z__to_m_d_a_zA_Z __pyx_mstate_global->__pyx_kp_u_m_d_a_zA_Z__to_m_d_a_zA_Z
#define __pyx_n_s_m_delta __pyx_mstate_global->__pyx_n_s_m_delta
#define __pyx_n_s_m_flattened __pyx_mstate_global->__pyx_n_s_m_flattened
#define __pyx_n_s_m_input __pyx_mstate_global->__pyx_n_s_m_input
#define __pyx_kp_u_m_input_should_be_a_float_or_a_1 __pyx_mstate_global->__pyx_kp_u_m_input_should_be_a_float_or_a_1
#define __pyx_n_s_m_len __pyx_mstate_global->__pyx_n_s_m_len
#define __pyx_n_u_m_ncdm __pyx_mstate_global->__pyx_n_u_m_ncdm
#define __pyx_n_u_m_ncdm_in_eV __pyx_mstate_global->__pyx_n_u_m_ncdm_in_eV
#define __pyx_n_u_m_ncdm_tot __pyx_mstate_global->__pyx_n_u_m_ncdm_tot
#define __pyx_n_s_m_vals __pyx_mstate_global->__pyx_n_s_m_vals
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_u_mass_bin_edges __pyx_mstate_global->__pyx_n_u_mass_bin_edges
#define __pyx_n_u_mass_function __pyx_mstate_global->__pyx_n_u_mass_function
#define __pyx_kp_u_mass_function_2 __pyx_mstate_global->__pyx_kp_u_mass_function_2
#define __pyx_n_s_match __pyx_mstate_global->__pyx_n_s_match
#define __pyx_n_s_math __pyx_mstate_global->__pyx_n_s_math
#define __pyx_n_s_max __pyx_mstate_global->__pyx_n_s_max
#define __pyx_n_s_maxIndex __pyx_mstate_global->__pyx_n_s_maxIndex
#define __pyx_n_s_mcfit __pyx_mstate_global->__pyx_n_s_mcfit
#define __pyx_n_s_mcfitx __pyx_mstate_global->__pyx_n_s_mcfitx
#define __pyx_n_s_mcmc_parameters __pyx_mstate_global->__pyx_n_s_mcmc_parameters
#define __pyx_n_s_mcut __pyx_mstate_global->__pyx_n_s_mcut
#define __pyx_n_u_mcut __pyx_mstate_global->__pyx_n_u_mcut
#define __pyx_n_u_mcut_B12 __pyx_mstate_global->__pyx_n_u_mcut_B12
#define __pyx_n_s_me __pyx_mstate_global->__pyx_n_s_me
#define __pyx_n_s_memview __pyx_mstate_global->__pyx_n_s_memview
#define __pyx_n_s_message __pyx_mstate_global->__pyx_n_s_message
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_n_s_min __pyx_mstate_global->__pyx_n_s_min
#define __pyx_n_s_minIndex __pyx_mstate_global->__pyx_n_s_minIndex
#define __pyx_n_u_minimal __pyx_mstate_global->__pyx_n_u_minimal
#define __pyx_n_s_mm __pyx_mstate_global->__pyx_n_s_mm
#define __pyx_n_u_mnu __pyx_mstate_global->__pyx_n_u_mnu
#define __pyx_n_s_mode __pyx_mstate_global->__pyx_n_s_mode
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_n_s_mro_entries __pyx_mstate_global->__pyx_n_s_mro_entries
#define __pyx_n_s_mu_size __pyx_mstate_global->__pyx_n_s_mu_size
#define __pyx_n_s_n __pyx_mstate_global->__pyx_n_s_n
#define __pyx_n_u_n5k __pyx_mstate_global->__pyx_n_u_n5k
#define __pyx_n_u_nCl __pyx_mstate_global->__pyx_n_u_nCl
#define __pyx_n_u_n_e __pyx_mstate_global->__pyx_n_u_n_e
#define __pyx_n_s_n_s __pyx_mstate_global->__pyx_n_s_n_s
#define __pyx_n_u_n_s __pyx_mstate_global->__pyx_n_u_n_s
#define __pyx_n_u_n_t __pyx_mstate_global->__pyx_n_u_n_t
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_names __pyx_mstate_global->__pyx_n_s_names
#define __pyx_n_s_ndim __pyx_mstate_global->__pyx_n_s_ndim
#define __pyx_n_u_ndim_masses __pyx_mstate_global->__pyx_n_u_ndim_masses
#define __pyx_n_u_ndim_redshifts __pyx_mstate_global->__pyx_n_u_ndim_redshifts
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_newaxis __pyx_mstate_global->__pyx_n_s_newaxis
#define __pyx_n_u_nfw __pyx_mstate_global->__pyx_n_u_nfw
#define __pyx_n_s_ngtm __pyx_mstate_global->__pyx_n_s_ngtm
#define __pyx_n_s_nl __pyx_mstate_global->__pyx_n_s_nl
#define __pyx_kp_s_no_default___reduce___due_to_non __pyx_mstate_global->__pyx_kp_s_no_default___reduce___due_to_non
#define __pyx_n_s_nofail __pyx_mstate_global->__pyx_n_s_nofail
#define __pyx_n_s_non_class_sz_keys __pyx_mstate_global->__pyx_n_s_non_class_sz_keys
#define __pyx_n_u_non_linear __pyx_mstate_global->__pyx_n_u_non_linear
#define __pyx_n_s_non_linear_check __pyx_mstate_global->__pyx_n_s_non_linear_check
#define __pyx_n_u_none __pyx_mstate_global->__pyx_n_u_none
#define __pyx_n_u_nonlin __pyx_mstate_global->__pyx_n_u_nonlin
#define __pyx_n_s_nonlinear __pyx_mstate_global->__pyx_n_s_nonlinear
#define __pyx_n_u_nonlinear __pyx_mstate_global->__pyx_n_u_nonlinear
#define __pyx_n_s_nonlinear_hmcode_sigma8 __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigma8
#define __pyx_n_s_nonlinear_hmcode_sigma8_cb __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigma8_cb
#define __pyx_n_s_nonlinear_hmcode_sigmadisp __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigmadisp
#define __pyx_n_s_nonlinear_hmcode_sigmadisp100 __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigmadisp100
#define __pyx_n_s_nonlinear_hmcode_sigmadisp100_cb __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigmadisp100_cb
#define __pyx_n_s_nonlinear_hmcode_sigmadisp_cb __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigmadisp_cb
#define __pyx_n_s_nonlinear_hmcode_sigmaprime __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigmaprime
#define __pyx_n_s_nonlinear_hmcode_sigmaprime_cb __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_sigmaprime_cb
#define __pyx_n_s_nonlinear_hmcode_window_nfw __pyx_mstate_global->__pyx_n_s_nonlinear_hmcode_window_nfw
#define __pyx_n_s_nonlinear_scale __pyx_mstate_global->__pyx_n_s_nonlinear_scale
#define __pyx_n_s_nonlinear_scale_cb __pyx_mstate_global->__pyx_n_s_nonlinear_scale_cb
#define __pyx_n_s_normalize __pyx_mstate_global->__pyx_n_s_normalize
#define __pyx_n_s_np __pyx_mstate_global->__pyx_n_s_np
#define __pyx_n_s_nq __pyx_mstate_global->__pyx_n_s_nq
#define __pyx_n_u_ns __pyx_mstate_global->__pyx_n_u_ns
#define __pyx_n_u_ntot __pyx_mstate_global->__pyx_n_u_ntot
#define __pyx_n_s_nu __pyx_mstate_global->__pyx_n_s_nu
#define __pyx_n_u_nu __pyx_mstate_global->__pyx_n_u_nu
#define __pyx_n_s_nu1 __pyx_mstate_global->__pyx_n_s_nu1
#define __pyx_n_s_nu2 __pyx_mstate_global->__pyx_n_s_nu2
#define __pyx_n_s_nu_in_GHz __pyx_mstate_global->__pyx_n_s_nu_in_GHz
#define __pyx_n_s_nu_in_ghz __pyx_mstate_global->__pyx_n_s_nu_in_ghz
#define __pyx_n_s_num __pyx_mstate_global->__pyx_n_s_num
#define __pyx_n_s_numberDensity __pyx_mstate_global->__pyx_n_s_numberDensity
#define __pyx_n_s_number_of_titles __pyx_mstate_global->__pyx_n_s_number_of_titles
#define __pyx_n_s_numpy __pyx_mstate_global->__pyx_n_s_numpy
#define __pyx_kp_u_numpy__core_multiarray_failed_to __pyx_mstate_global->__pyx_kp_u_numpy__core_multiarray_failed_to
#define __pyx_kp_u_numpy__core_umath_failed_to_impo __pyx_mstate_global->__pyx_kp_u_numpy__core_umath_failed_to_impo
#define __pyx_n_s_nz __pyx_mstate_global->__pyx_n_s_nz
#define __pyx_n_s_obj __pyx_mstate_global->__pyx_n_s_obj
#define __pyx_n_s_obsFreqGHz __pyx_mstate_global->__pyx_n_s_obsFreqGHz
#define __pyx_n_s_oldpars __pyx_mstate_global->__pyx_n_s_oldpars
#define __pyx_n_u_ombh2 __pyx_mstate_global->__pyx_n_u_ombh2
#define __pyx_n_u_omch2 __pyx_mstate_global->__pyx_n_u_omch2
#define __pyx_n_s_omega __pyx_mstate_global->__pyx_n_s_omega
#define __pyx_n_s_omega_b __pyx_mstate_global->__pyx_n_s_omega_b
#define __pyx_n_u_omega_b __pyx_mstate_global->__pyx_n_u_omega_b
#define __pyx_n_u_omega_c __pyx_mstate_global->__pyx_n_u_omega_c
#define __pyx_n_s_omega_cdm __pyx_mstate_global->__pyx_n_s_omega_cdm
#define __pyx_n_u_omega_cdm __pyx_mstate_global->__pyx_n_u_omega_cdm
#define __pyx_n_u_omega_mh2 __pyx_mstate_global->__pyx_n_u_omega_mh2
#define __pyx_n_s_only_clustering_species __pyx_mstate_global->__pyx_n_s_only_clustering_species
#define __pyx_n_s_other_class_sz_keys __pyx_mstate_global->__pyx_n_s_other_class_sz_keys
#define __pyx_n_s_outf __pyx_mstate_global->__pyx_n_s_outf
#define __pyx_n_u_output __pyx_mstate_global->__pyx_n_u_output
#define __pyx_n_s_output_format __pyx_mstate_global->__pyx_n_s_output_format
#define __pyx_n_s_output_keys __pyx_mstate_global->__pyx_n_s_output_keys
#define __pyx_n_s_output_string __pyx_mstate_global->__pyx_n_s_output_string
#define __pyx_n_s_p __pyx_mstate_global->__pyx_n_s_p
#define __pyx_n_u_pCl __pyx_mstate_global->__pyx_n_u_pCl
#define __pyx_n_s_pack __pyx_mstate_global->__pyx_n_s_pack
#define __pyx_n_s_params_for_emulators __pyx_mstate_global->__pyx_n_s_params_for_emulators
#define __pyx_n_s_params_settings __pyx_mstate_global->__pyx_n_s_params_settings
#define __pyx_n_s_params_values_dict __pyx_mstate_global->__pyx_n_s_params_values_dict
#define __pyx_n_s_pars __pyx_mstate_global->__pyx_n_s_pars
#define __pyx_n_s_pars_2 __pyx_mstate_global->__pyx_n_s_pars_2
#define __pyx_n_s_pars_check __pyx_mstate_global->__pyx_n_s_pars_check
#define __pyx_n_s_path_to_cosmopower_organization __pyx_mstate_global->__pyx_n_s_path_to_cosmopower_organization
#define __pyx_n_s_pattern1 __pyx_mstate_global->__pyx_n_s_pattern1
#define __pyx_n_s_pattern2 __pyx_mstate_global->__pyx_n_s_pattern2
#define __pyx_n_s_pattern3 __pyx_mstate_global->__pyx_n_s_pattern3
#define __pyx_n_s_pdict_to_update __pyx_mstate_global->__pyx_n_s_pdict_to_update
#define __pyx_n_u_perturb __pyx_mstate_global->__pyx_n_u_perturb
#define __pyx_n_u_phi_max __pyx_mstate_global->__pyx_n_u_phi_max
#define __pyx_n_u_phi_min __pyx_mstate_global->__pyx_n_u_phi_min
#define __pyx_n_s_pi __pyx_mstate_global->__pyx_n_s_pi
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_pk __pyx_mstate_global->__pyx_n_s_pk
#define __pyx_n_s_pk_array __pyx_mstate_global->__pyx_n_s_pk_array
#define __pyx_n_s_pk_at_k_z __pyx_mstate_global->__pyx_n_s_pk_at_k_z
#define __pyx_n_s_pk_at_z_hm __pyx_mstate_global->__pyx_n_s_pk_at_z_hm
#define __pyx_n_s_pk_b_at_z_2h __pyx_mstate_global->__pyx_n_s_pk_b_at_z_2h
#define __pyx_n_s_pk_bb_at_z_hm __pyx_mstate_global->__pyx_n_s_pk_bb_at_z_hm
#define __pyx_n_s_pk_cb __pyx_mstate_global->__pyx_n_s_pk_cb
#define __pyx_n_s_pk_cb_lin __pyx_mstate_global->__pyx_n_s_pk_cb_lin
#define __pyx_n_s_pk_em_at_z_hm __pyx_mstate_global->__pyx_n_s_pk_em_at_z_hm
#define __pyx_n_s_pk_gg_at_z_hm __pyx_mstate_global->__pyx_n_s_pk_gg_at_z_hm
#define __pyx_n_s_pk_lin __pyx_mstate_global->__pyx_n_s_pk_lin
#define __pyx_n_s_pk_lin_array __pyx_mstate_global->__pyx_n_s_pk_lin_array
#define __pyx_n_s_pk_lin_unvectorized __pyx_mstate_global->__pyx_n_s_pk_lin_unvectorized
#define __pyx_n_s_pk_linzmax __pyx_mstate_global->__pyx_n_s_pk_linzmax
#define __pyx_n_s_pk_nonlin __pyx_mstate_global->__pyx_n_s_pk_nonlin
#define __pyx_n_s_pk_tilt __pyx_mstate_global->__pyx_n_s_pk_tilt
#define __pyx_n_s_pk_unvectorized __pyx_mstate_global->__pyx_n_s_pk_unvectorized
#define __pyx_n_s_pknl_in_output __pyx_mstate_global->__pyx_n_s_pknl_in_output
#define __pyx_n_s_pknl_key_value_checks __pyx_mstate_global->__pyx_n_s_pknl_key_value_checks
#define __pyx_n_u_poisson __pyx_mstate_global->__pyx_n_u_poisson
#define __pyx_n_s_pop __pyx_mstate_global->__pyx_n_s_pop
#define __pyx_n_s_power __pyx_mstate_global->__pyx_n_s_power
#define __pyx_n_u_pp __pyx_mstate_global->__pyx_n_u_pp
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_u_pressure_profile __pyx_mstate_global->__pyx_n_u_pressure_profile
#define __pyx_kp_u_pressure_profile_2 __pyx_mstate_global->__pyx_kp_u_pressure_profile_2
#define __pyx_n_s_primordial __pyx_mstate_global->__pyx_n_s_primordial
#define __pyx_n_u_primordial __pyx_mstate_global->__pyx_n_u_primordial
#define __pyx_n_s_problem_flag __pyx_mstate_global->__pyx_n_s_problem_flag
#define __pyx_n_s_problematic_parameters __pyx_mstate_global->__pyx_n_s_problematic_parameters
#define __pyx_n_s_profile __pyx_mstate_global->__pyx_n_s_profile
#define __pyx_n_s_pvecback __pyx_mstate_global->__pyx_n_s_pvecback
#define __pyx_n_s_pvecthermo __pyx_mstate_global->__pyx_n_s_pvecthermo
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_Enum __pyx_mstate_global->__pyx_n_s_pyx_unpickle_Enum
#define __pyx_n_s_pyx_vtable __pyx_mstate_global->__pyx_n_s_pyx_vtable
#define __pyx_n_s_q __pyx_mstate_global->__pyx_n_s_q
#define __pyx_n_s_q_arr __pyx_mstate_global->__pyx_n_s_q_arr
#define __pyx_n_s_q_max __pyx_mstate_global->__pyx_n_s_q_max
#define __pyx_n_s_q_threshold __pyx_mstate_global->__pyx_n_s_q_threshold
#define __pyx_n_s_qmax __pyx_mstate_global->__pyx_n_s_qmax
#define __pyx_n_s_qobs_asked __pyx_mstate_global->__pyx_n_s_qobs_asked
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_r __pyx_mstate_global->__pyx_n_s_r
#define __pyx_n_u_r __pyx_mstate_global->__pyx_n_u_r
#define __pyx_n_s_r200c __pyx_mstate_global->__pyx_n_s_r200c
#define __pyx_n_u_r_0002 __pyx_mstate_global->__pyx_n_u_r_0002
#define __pyx_n_s_r_asked __pyx_mstate_global->__pyx_n_s_r_asked
#define __pyx_n_s_r_delta __pyx_mstate_global->__pyx_n_s_r_delta
#define __pyx_n_u_ra_rec __pyx_mstate_global->__pyx_n_u_ra_rec
#define __pyx_n_u_ra_rec_h __pyx_mstate_global->__pyx_n_u_ra_rec_h
#define __pyx_n_u_ra_star __pyx_mstate_global->__pyx_n_u_ra_star
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_rates __pyx_mstate_global->__pyx_n_s_rates
#define __pyx_n_u_rates __pyx_mstate_global->__pyx_n_u_rates
#define __pyx_n_s_raw_cl __pyx_mstate_global->__pyx_n_s_raw_cl
#define __pyx_n_s_rcl __pyx_mstate_global->__pyx_n_s_rcl
#define __pyx_n_u_rd_star __pyx_mstate_global->__pyx_n_u_rd_star
#define __pyx_n_s_re __pyx_mstate_global->__pyx_n_s_re
#define __pyx_n_s_redshift __pyx_mstate_global->__pyx_n_s_redshift
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_register __pyx_mstate_global->__pyx_n_s_register
#define __pyx_n_s_resetwarnings __pyx_mstate_global->__pyx_n_s_resetwarnings
#define __pyx_n_s_reshape __pyx_mstate_global->__pyx_n_s_reshape
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_rho0_cb __pyx_mstate_global->__pyx_n_s_rho0_cb
#define __pyx_n_s_rho0_crit __pyx_mstate_global->__pyx_n_s_rho0_crit
#define __pyx_n_s_rho0_m __pyx_mstate_global->__pyx_n_s_rho0_m
#define __pyx_n_s_rhoc __pyx_mstate_global->__pyx_n_s_rhoc
#define __pyx_n_u_rs_d __pyx_mstate_global->__pyx_n_u_rs_d
#define __pyx_n_u_rs_d_h __pyx_mstate_global->__pyx_n_u_rs_d_h
#define __pyx_n_s_rs_drag __pyx_mstate_global->__pyx_n_s_rs_drag
#define __pyx_n_u_rs_rec __pyx_mstate_global->__pyx_n_u_rs_rec
#define __pyx_n_u_rs_rec_h __pyx_mstate_global->__pyx_n_u_rs_rec_h
#define __pyx_n_u_rs_star __pyx_mstate_global->__pyx_n_u_rs_star
#define __pyx_n_s_rv __pyx_mstate_global->__pyx_n_s_rv
#define __pyx_kp_u_s __pyx_mstate_global->__pyx_kp_u_s
#define __pyx_kp_u_sBBN_file __pyx_mstate_global->__pyx_kp_u_sBBN_file
#define __pyx_kp_u_s_was_not_recognized_as_a_deriv __pyx_mstate_global->__pyx_kp_u_s_was_not_recognized_as_a_deriv
#define __pyx_n_s_sample_id __pyx_mstate_global->__pyx_n_s_sample_id
#define __pyx_n_u_scalar __pyx_mstate_global->__pyx_n_u_scalar
#define __pyx_n_u_scale __pyx_mstate_global->__pyx_n_u_scale
#define __pyx_n_u_scale_dependent_bias __pyx_mstate_global->__pyx_n_u_scale_dependent_bias
#define __pyx_n_s_scale_independent_growth_factor __pyx_mstate_global->__pyx_n_s_scale_independent_growth_factor
#define __pyx_n_s_scale_independent_growth_factor_2 __pyx_mstate_global->__pyx_n_s_scale_independent_growth_factor_2
#define __pyx_n_s_scipy __pyx_mstate_global->__pyx_n_s_scipy
#define __pyx_n_s_scipy_interpolate __pyx_mstate_global->__pyx_n_s_scipy_interpolate
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_n_s_send __pyx_mstate_global->__pyx_n_s_send
#define __pyx_n_s_sep __pyx_mstate_global->__pyx_n_s_sep
#define __pyx_n_s_set __pyx_mstate_global->__pyx_n_s_set
#define __pyx_n_s_set_default __pyx_mstate_global->__pyx_n_s_set_default
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_set_verbosity __pyx_mstate_global->__pyx_n_s_set_verbosity
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_shape __pyx_mstate_global->__pyx_n_s_shape
#define __pyx_n_u_shear_calibration_m __pyx_mstate_global->__pyx_n_u_shear_calibration_m
#define __pyx_n_u_shotnoise __pyx_mstate_global->__pyx_n_u_shotnoise
#define __pyx_n_s_sigma __pyx_mstate_global->__pyx_n_s_sigma
#define __pyx_n_s_sigma8 __pyx_mstate_global->__pyx_n_s_sigma8
#define __pyx_n_u_sigma8 __pyx_mstate_global->__pyx_n_u_sigma8
#define __pyx_n_s_sigma8_Pcb __pyx_mstate_global->__pyx_n_s_sigma8_Pcb
#define __pyx_n_s_sigma8_cb __pyx_mstate_global->__pyx_n_s_sigma8_cb
#define __pyx_n_u_sigma8_cb __pyx_mstate_global->__pyx_n_u_sigma8_cb
#define __pyx_n_s_sigmaM __pyx_mstate_global->__pyx_n_s_sigmaM
#define __pyx_n_s_sigmaT __pyx_mstate_global->__pyx_n_s_sigmaT
#define __pyx_n_s_sigma_8 __pyx_mstate_global->__pyx_n_s_sigma_8
#define __pyx_n_u_sigma_8 __pyx_mstate_global->__pyx_n_u_sigma_8
#define __pyx_n_s_sigma_8_cb __pyx_mstate_global->__pyx_n_s_sigma_8_cb
#define __pyx_n_s_sigma_cb __pyx_mstate_global->__pyx_n_s_sigma_cb
#define __pyx_kp_u_sigma_cb_not_computed_by_CLASS_p __pyx_mstate_global->__pyx_kp_u_sigma_cb_not_computed_by_CLASS_p
#define __pyx_n_s_sigma_disp __pyx_mstate_global->__pyx_n_s_sigma_disp
#define __pyx_n_s_sigma_disp_100 __pyx_mstate_global->__pyx_n_s_sigma_disp_100
#define __pyx_n_s_sigma_disp_100_cb __pyx_mstate_global->__pyx_n_s_sigma_disp_100_cb
#define __pyx_n_s_sigma_disp_cb __pyx_mstate_global->__pyx_n_s_sigma_disp_cb
#define __pyx_n_s_sigma_int __pyx_mstate_global->__pyx_n_s_sigma_int
#define __pyx_n_s_sigma_log10M __pyx_mstate_global->__pyx_n_s_sigma_log10M
#define __pyx_n_u_sigma_log10M_HOD __pyx_mstate_global->__pyx_n_u_sigma_log10M_HOD
#define __pyx_n_u_sigma_log10M_HOD_ngal __pyx_mstate_global->__pyx_n_u_sigma_log10M_HOD_ngal
#define __pyx_n_s_sigma_prime __pyx_mstate_global->__pyx_n_s_sigma_prime
#define __pyx_n_s_sigma_prime_cb __pyx_mstate_global->__pyx_n_s_sigma_prime_cb
#define __pyx_n_s_simps __pyx_mstate_global->__pyx_n_s_simps
#define __pyx_n_s_sinh __pyx_mstate_global->__pyx_n_s_sinh
#define __pyx_n_s_size __pyx_mstate_global->__pyx_n_s_size
#define __pyx_n_s_size_ic_data __pyx_mstate_global->__pyx_n_s_size_ic_data
#define __pyx_n_s_skip_background_and_thermo __pyx_mstate_global->__pyx_n_s_skip_background_and_thermo
#define __pyx_n_u_skip_background_and_thermo __pyx_mstate_global->__pyx_n_u_skip_background_and_thermo
#define __pyx_n_u_skip_chi __pyx_mstate_global->__pyx_n_u_skip_chi
#define __pyx_n_u_skip_class_sz __pyx_mstate_global->__pyx_n_u_skip_class_sz
#define __pyx_n_u_skip_cmb __pyx_mstate_global->__pyx_n_u_skip_cmb
#define __pyx_n_u_skip_hubble __pyx_mstate_global->__pyx_n_u_skip_hubble
#define __pyx_n_u_skip_input __pyx_mstate_global->__pyx_n_u_skip_input
#define __pyx_n_u_skip_pkl __pyx_mstate_global->__pyx_n_u_skip_pkl
#define __pyx_n_u_skip_pknl __pyx_mstate_global->__pyx_n_u_skip_pknl
#define __pyx_n_u_skip_sigma8_and_der __pyx_mstate_global->__pyx_n_u_skip_sigma8_and_der
#define __pyx_n_u_skip_sigma8_at_z __pyx_mstate_global->__pyx_n_u_skip_sigma8_at_z
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_specific_keys __pyx_mstate_global->__pyx_n_s_specific_keys
#define __pyx_n_s_spectra __pyx_mstate_global->__pyx_n_s_spectra
#define __pyx_n_u_spectra __pyx_mstate_global->__pyx_n_u_spectra
#define __pyx_n_s_splev __pyx_mstate_global->__pyx_n_s_splev
#define __pyx_n_s_spline __pyx_mstate_global->__pyx_n_s_spline
#define __pyx_n_s_split __pyx_mstate_global->__pyx_n_s_split
#define __pyx_n_s_splrep __pyx_mstate_global->__pyx_n_s_splrep
#define __pyx_n_s_sqrt __pyx_mstate_global->__pyx_n_s_sqrt
#define __pyx_n_s_start __pyx_mstate_global->__pyx_n_s_start
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_step __pyx_mstate_global->__pyx_n_s_step
#define __pyx_n_s_stop __pyx_mstate_global->__pyx_n_s_stop
#define __pyx_n_s_str __pyx_mstate_global->__pyx_n_s_str
#define __pyx_kp_s_strided_and_direct __pyx_mstate_global->__pyx_kp_s_strided_and_direct
#define __pyx_kp_s_strided_and_direct_or_indirect __pyx_mstate_global->__pyx_kp_s_strided_and_direct_or_indirect
#define __pyx_kp_s_strided_and_indirect __pyx_mstate_global->__pyx_kp_s_strided_and_indirect
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_strip __pyx_mstate_global->__pyx_n_s_strip
#define __pyx_n_s_struct __pyx_mstate_global->__pyx_n_s_struct
#define __pyx_n_s_struct_cleanup __pyx_mstate_global->__pyx_n_s_struct_cleanup
#define __pyx_n_s_sum __pyx_mstate_global->__pyx_n_s_sum
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_suppress_warnings __pyx_mstate_global->__pyx_n_s_suppress_warnings
#define __pyx_n_s_sys __pyx_mstate_global->__pyx_n_s_sys
#define __pyx_n_u_sz_cluster_counts __pyx_mstate_global->__pyx_n_u_sz_cluster_counts
#define __pyx_n_u_sz_cluster_counts_fft __pyx_mstate_global->__pyx_n_u_sz_cluster_counts_fft
#define __pyx_n_u_sz_selection_function_skyfracs_f __pyx_mstate_global->__pyx_n_u_sz_selection_function_skyfracs_f
#define __pyx_n_u_sz_selection_function_thetas_fil __pyx_mstate_global->__pyx_n_u_sz_selection_function_thetas_fil
#define __pyx_n_u_sz_selection_function_ylims_file __pyx_mstate_global->__pyx_n_u_sz_selection_function_ylims_file
#define __pyx_n_u_sz_unbinned_cluster_counts __pyx_mstate_global->__pyx_n_u_sz_unbinned_cluster_counts
#define __pyx_n_s_szcat_snr __pyx_mstate_global->__pyx_n_s_szcat_snr
#define __pyx_n_u_szcat_snr __pyx_mstate_global->__pyx_n_u_szcat_snr
#define __pyx_n_s_szcat_z __pyx_mstate_global->__pyx_n_s_szcat_z
#define __pyx_n_u_szcat_z __pyx_mstate_global->__pyx_n_u_szcat_z
#define __pyx_n_u_szcount __pyx_mstate_global->__pyx_n_u_szcount
#define __pyx_n_s_szcounts_ntot __pyx_mstate_global->__pyx_n_s_szcounts_ntot
#define __pyx_n_s_szcounts_ntot_rates_loglike __pyx_mstate_global->__pyx_n_s_szcounts_ntot_rates_loglike
#define __pyx_n_s_szunbinned_loglike __pyx_mstate_global->__pyx_n_s_szunbinned_loglike
#define __pyx_n_u_t2t2f __pyx_mstate_global->__pyx_n_u_t2t2f
#define __pyx_n_u_tCl __pyx_mstate_global->__pyx_n_u_tCl
#define __pyx_n_u_tabulate_rhob_xout_at_m_and_z __pyx_mstate_global->__pyx_n_u_tabulate_rhob_xout_at_m_and_z
#define __pyx_n_s_tanh __pyx_mstate_global->__pyx_n_s_tanh
#define __pyx_n_s_tau __pyx_mstate_global->__pyx_n_s_tau
#define __pyx_n_u_tau __pyx_mstate_global->__pyx_n_u_tau
#define __pyx_n_u_tau_d __pyx_mstate_global->__pyx_n_u_tau_d
#define __pyx_n_u_tau_rec __pyx_mstate_global->__pyx_n_u_tau_rec
#define __pyx_n_s_tau_reio __pyx_mstate_global->__pyx_n_s_tau_reio
#define __pyx_n_u_tau_reio __pyx_mstate_global->__pyx_n_u_tau_reio
#define __pyx_n_u_tau_star __pyx_mstate_global->__pyx_n_u_tau_star
#define __pyx_n_s_tckP __pyx_mstate_global->__pyx_n_s_tckP
#define __pyx_n_u_td __pyx_mstate_global->__pyx_n_u_td
#define __pyx_n_u_te __pyx_mstate_global->__pyx_n_u_te
#define __pyx_n_u_te_y_y __pyx_mstate_global->__pyx_n_u_te_y_y
#define __pyx_n_u_tensor __pyx_mstate_global->__pyx_n_u_tensor
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_u_teyy __pyx_mstate_global->__pyx_n_u_teyy
#define __pyx_kp_u_the_s_spectrum_was_computed_unti __pyx_mstate_global->__pyx_kp_u_the_s_spectrum_was_computed_unti
#define __pyx_n_s_thermodynamics __pyx_mstate_global->__pyx_n_s_thermodynamics
#define __pyx_n_u_thermodynamics __pyx_mstate_global->__pyx_n_u_thermodynamics
#define __pyx_n_u_theta __pyx_mstate_global->__pyx_n_u_theta
#define __pyx_n_s_theta500 __pyx_mstate_global->__pyx_n_s_theta500
#define __pyx_n_s_theta_500 __pyx_mstate_global->__pyx_n_s_theta_500
#define __pyx_n_s_theta_arcmin __pyx_mstate_global->__pyx_n_s_theta_arcmin
#define __pyx_n_s_theta_mcfit __pyx_mstate_global->__pyx_n_s_theta_mcfit
#define __pyx_n_s_theta_rad __pyx_mstate_global->__pyx_n_s_theta_rad
#define __pyx_n_s_theta_s_100 __pyx_mstate_global->__pyx_n_s_theta_s_100
#define __pyx_n_s_theta_star_100 __pyx_mstate_global->__pyx_n_s_theta_star_100
#define __pyx_n_s_thetae __pyx_mstate_global->__pyx_n_s_thetae
#define __pyx_n_u_thetas __pyx_mstate_global->__pyx_n_u_thetas
#define __pyx_n_s_throw __pyx_mstate_global->__pyx_n_s_throw
#define __pyx_n_s_time __pyx_mstate_global->__pyx_n_s_time
#define __pyx_n_s_timesteps __pyx_mstate_global->__pyx_n_s_timesteps
#define __pyx_n_s_titles __pyx_mstate_global->__pyx_n_s_titles
#define __pyx_n_u_tl __pyx_mstate_global->__pyx_n_u_tl
#define __pyx_n_s_tllprime_sz __pyx_mstate_global->__pyx_n_s_tllprime_sz
#define __pyx_n_s_tmp __pyx_mstate_global->__pyx_n_s_tmp
#define __pyx_n_s_tmpdict __pyx_mstate_global->__pyx_n_s_tmpdict
#define __pyx_n_u_tp __pyx_mstate_global->__pyx_n_u_tp
#define __pyx_n_u_transfer __pyx_mstate_global->__pyx_n_u_transfer
#define __pyx_n_s_transfers __pyx_mstate_global->__pyx_n_s_transfers
#define __pyx_n_s_transforms __pyx_mstate_global->__pyx_n_s_transforms
#define __pyx_n_s_trapz __pyx_mstate_global->__pyx_n_s_trapz
#define __pyx_n_u_tt __pyx_mstate_global->__pyx_n_u_tt
#define __pyx_n_s_type __pyx_mstate_global->__pyx_n_s_type
#define __pyx_kp_s_unable_to_allocate_array_data __pyx_mstate_global->__pyx_kp_s_unable_to_allocate_array_data
#define __pyx_kp_s_unable_to_allocate_shape_and_str __pyx_mstate_global->__pyx_kp_s_unable_to_allocate_shape_and_str
#define __pyx_n_s_units __pyx_mstate_global->__pyx_n_s_units
#define __pyx_n_s_unpack __pyx_mstate_global->__pyx_n_s_unpack
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_upper __pyx_mstate_global->__pyx_n_s_upper
#define __pyx_n_s_use_pklin __pyx_mstate_global->__pyx_n_s_use_pklin
#define __pyx_n_u_use_pknl_in_2hterms __pyx_mstate_global->__pyx_n_u_use_pknl_in_2hterms
#define __pyx_n_u_use_pknl_in_2hterms_IA_only __pyx_mstate_global->__pyx_n_u_use_pknl_in_2hterms_IA_only
#define __pyx_n_s_v __pyx_mstate_global->__pyx_n_s_v
#define __pyx_n_s_val __pyx_mstate_global->__pyx_n_s_val
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_n_s_vec_theta __pyx_mstate_global->__pyx_n_s_vec_theta
#define __pyx_n_u_vector __pyx_mstate_global->__pyx_n_u_vector
#define __pyx_n_s_vectorize __pyx_mstate_global->__pyx_n_s_vectorize
#define __pyx_n_s_verbosity __pyx_mstate_global->__pyx_n_s_verbosity
#define __pyx_n_s_version __pyx_mstate_global->__pyx_n_s_version
#define __pyx_n_s_version_info __pyx_mstate_global->__pyx_n_s_version_info
#define __pyx_n_s_viewdictitems __pyx_mstate_global->__pyx_n_s_viewdictitems
#define __pyx_n_s_viewitems __pyx_mstate_global->__pyx_n_s_viewitems
#define __pyx_n_u_vrms2 __pyx_mstate_global->__pyx_n_u_vrms2
#define __pyx_n_s_want_ee __pyx_mstate_global->__pyx_n_s_want_ee
#define __pyx_n_s_want_pp __pyx_mstate_global->__pyx_n_s_want_pp
#define __pyx_n_s_want_te __pyx_mstate_global->__pyx_n_s_want_te
#define __pyx_n_s_want_tt __pyx_mstate_global->__pyx_n_s_want_tt
#define __pyx_n_s_warnings __pyx_mstate_global->__pyx_n_s_warnings
#define __pyx_n_s_window_nfw __pyx_mstate_global->__pyx_n_s_window_nfw
#define __pyx_n_s_x __pyx_mstate_global->__pyx_n_s_x
#define __pyx_n_u_x __pyx_mstate_global->__pyx_n_u_x
#define __pyx_n_s_x_asked __pyx_mstate_global->__pyx_n_s_x_asked
#define __pyx_n_u_x_outSZ __pyx_mstate_global->__pyx_n_u_x_outSZ
#define __pyx_n_s_x_out_custom1 __pyx_mstate_global->__pyx_n_s_x_out_custom1
#define __pyx_n_s_xc __pyx_mstate_global->__pyx_n_s_xc
#define __pyx_n_u_xc_B12 __pyx_mstate_global->__pyx_n_u_xc_B12
#define __pyx_n_u_xc_B16 __pyx_mstate_global->__pyx_n_u_xc_B16
#define __pyx_n_s_xe __pyx_mstate_global->__pyx_n_s_xe
#define __pyx_n_s_xi __pyx_mstate_global->__pyx_n_s_xi
#define __pyx_n_u_xi __pyx_mstate_global->__pyx_n_u_xi
#define __pyx_n_u_xi_idr __pyx_mstate_global->__pyx_n_u_xi_idr
#define __pyx_n_s_xi_mcfit __pyx_mstate_global->__pyx_n_s_xi_mcfit
#define __pyx_n_s_xout __pyx_mstate_global->__pyx_n_s_xout
#define __pyx_n_s_xrange __pyx_mstate_global->__pyx_n_s_xrange
#define __pyx_n_s_y __pyx_mstate_global->__pyx_n_s_y
#define __pyx_n_s_y0 __pyx_mstate_global->__pyx_n_s_y0
#define __pyx_n_s_y0Err __pyx_mstate_global->__pyx_n_s_y0Err
#define __pyx_n_s_yp __pyx_mstate_global->__pyx_n_s_yp
#define __pyx_n_s_ystar __pyx_mstate_global->__pyx_n_s_ystar
#define __pyx_n_s_z __pyx_mstate_global->__pyx_n_s_z
#define __pyx_n_s_z1 __pyx_mstate_global->__pyx_n_s_z1
#define __pyx_n_s_z2 __pyx_mstate_global->__pyx_n_s_z2
#define __pyx_n_s_z_arr __pyx_mstate_global->__pyx_n_s_z_arr
#define __pyx_n_s_z_array __pyx_mstate_global->__pyx_n_s_z_array
#define __pyx_n_s_z_asked __pyx_mstate_global->__pyx_n_s_z_asked
#define __pyx_n_s_z_broadcasted __pyx_mstate_global->__pyx_n_s_z_broadcasted
#define __pyx_n_s_z_center __pyx_mstate_global->__pyx_n_s_z_center
#define __pyx_n_u_z_center __pyx_mstate_global->__pyx_n_u_z_center
#define __pyx_n_u_z_d __pyx_mstate_global->__pyx_n_u_z_d
#define __pyx_n_s_z_edges __pyx_mstate_global->__pyx_n_s_z_edges
#define __pyx_n_u_z_edges __pyx_mstate_global->__pyx_n_u_z_edges
#define __pyx_n_s_z_flattened __pyx_mstate_global->__pyx_n_s_z_flattened
#define __pyx_n_u_z_for_pk_hm __pyx_mstate_global->__pyx_n_u_z_for_pk_hm
#define __pyx_n_s_z_input __pyx_mstate_global->__pyx_n_s_z_input
#define __pyx_kp_u_z_input_should_be_a_float_or_a_1 __pyx_mstate_global->__pyx_kp_u_z_input_should_be_a_float_or_a_1
#define __pyx_n_s_z_len __pyx_mstate_global->__pyx_n_s_z_len
#define __pyx_n_u_z_max __pyx_mstate_global->__pyx_n_u_z_max
#define __pyx_n_s_z_max_nonlinear __pyx_mstate_global->__pyx_n_s_z_max_nonlinear
#define __pyx_n_s_z_max_requested __pyx_mstate_global->__pyx_n_s_z_max_requested
#define __pyx_n_u_z_min __pyx_mstate_global->__pyx_n_u_z_min
#define __pyx_n_s_z_of_r __pyx_mstate_global->__pyx_n_s_z_of_r
#define __pyx_n_s_z_of_tau __pyx_mstate_global->__pyx_n_s_z_of_tau
#define __pyx_n_u_z_rec __pyx_mstate_global->__pyx_n_u_z_rec
#define __pyx_n_s_z_reio __pyx_mstate_global->__pyx_n_s_z_reio
#define __pyx_n_u_z_reio __pyx_mstate_global->__pyx_n_u_z_reio
#define __pyx_n_s_z_size __pyx_mstate_global->__pyx_n_s_z_size
#define __pyx_n_u_z_star __pyx_mstate_global->__pyx_n_u_z_star
#define __pyx_n_s_z_step __pyx_mstate_global->__pyx_n_s_z_step
#define __pyx_n_s_z_vals __pyx_mstate_global->__pyx_n_s_z_vals
#define __pyx_n_s_zeros __pyx_mstate_global->__pyx_n_s_zeros
#define __pyx_n_s_zi __pyx_mstate_global->__pyx_n_s_zi
#define __pyx_n_s_zmax __pyx_mstate_global->__pyx_n_s_zmax
#define __pyx_n_s_zmin __pyx_mstate_global->__pyx_n_s_zmin
#define __pyx_n_s_zp __pyx_mstate_global->__pyx_n_s_zp
#define __pyx_n_s_zpk __pyx_mstate_global->__pyx_n_s_zpk
#define __pyx_float_0_ __pyx_mstate_global->__pyx_float_0_
#define __pyx_float_1_ __pyx_mstate_global->__pyx_float_1_
#define __pyx_float_2_ __pyx_mstate_global->__pyx_float_2_
#define __pyx_float_3_ __pyx_mstate_global->__pyx_float_3_
#define __pyx_float_4_ __pyx_mstate_global->__pyx_float_4_
#define __pyx_float_5_ __pyx_mstate_global->__pyx_float_5_
#define __pyx_float_0_0 __pyx_mstate_global->__pyx_float_0_0
#define __pyx_float_0_1 __pyx_mstate_global->__pyx_float_0_1
#define __pyx_float_0_5 __pyx_mstate_global->__pyx_float_0_5
#define __pyx_float_1_0 __pyx_mstate_global->__pyx_float_1_0
#define __pyx_float_10_ __pyx_mstate_global->__pyx_float_10_
#define __pyx_float_1e9 __pyx_mstate_global->__pyx_float_1e9
#define __pyx_float_0_02 __pyx_mstate_global->__pyx_float_0_02
#define __pyx_float_0_04 __pyx_mstate_global->__pyx_float_0_04
#define __pyx_float_0_19 __pyx_mstate_global->__pyx_float_0_19
#define __pyx_float_0_29 __pyx_mstate_global->__pyx_float_0_29
#define __pyx_float_0_88 __pyx_mstate_global->__pyx_float_0_88
#define __pyx_float_100_ __pyx_mstate_global->__pyx_float_100_
#define __pyx_float_18_1 __pyx_mstate_global->__pyx_float_18_1
#define __pyx_float_1e14 __pyx_mstate_global->__pyx_float_1e14
#define __pyx_float_1e16 __pyx_mstate_global->__pyx_float_1e16
#define __pyx_float_200_ __pyx_mstate_global->__pyx_float_200_
#define __pyx_float_3_83 __pyx_mstate_global->__pyx_float_3_83
#define __pyx_float_4_35 __pyx_mstate_global->__pyx_float_4_35
#define __pyx_float_4_e3 __pyx_mstate_global->__pyx_float_4_e3
#define __pyx_float_500_ __pyx_mstate_global->__pyx_float_500_
#define __pyx_float_0_154 __pyx_mstate_global->__pyx_float_0_154
#define __pyx_float_0_415 __pyx_mstate_global->__pyx_float_0_415
#define __pyx_float_0_497 __pyx_mstate_global->__pyx_float_0_497
#define __pyx_float_0_731 __pyx_mstate_global->__pyx_float_0_731
#define __pyx_float_1_156 __pyx_mstate_global->__pyx_float_1_156
#define __pyx_float_148_0 __pyx_mstate_global->__pyx_float_148_0
#define __pyx_float_1eneg_10 __pyx_mstate_global->__pyx_float_1eneg_10
#define __pyx_float_8_130 __pyx_mstate_global->__pyx_float_8_130
#define __pyx_float_0_0393 __pyx_mstate_global->__pyx_float_0_0393
#define __pyx_float_0_3292 __pyx_mstate_global->__pyx_float_0_3292
#define __pyx_float_0_6827 __pyx_mstate_global->__pyx_float_0_6827
#define __pyx_float_0_9665 __pyx_mstate_global->__pyx_float_0_9665
#define __pyx_float_1_0620 __pyx_mstate_global->__pyx_float_1_0620
#define __pyx_float_1eneg_100 __pyx_mstate_global->__pyx_float_1eneg_100
#define __pyx_float_5_4807 __pyx_mstate_global->__pyx_float_5_4807
#define __pyx_float_0_00441 __pyx_mstate_global->__pyx_float_0_00441
#define __pyx_float_0_022383 __pyx_mstate_global->__pyx_float_0_022383
#define __pyx_float_2_61051eneg_18 __pyx_mstate_global->__pyx_float_2_61051eneg_18
#define __pyx_float_1_00000000e_12 __pyx_mstate_global->__pyx_float_1_00000000e_12
#define __pyx_float_neg_2_ __pyx_mstate_global->__pyx_float_neg_2_
#define __pyx_float_neg_0_2 __pyx_mstate_global->__pyx_float_neg_0_2
#define __pyx_float_neg_0_3 __pyx_mstate_global->__pyx_float_neg_0_3
#define __pyx_float_neg_1_0 __pyx_mstate_global->__pyx_float_neg_1_0
#define __pyx_float_neg_10_ __pyx_mstate_global->__pyx_float_neg_10_
#define __pyx_float_neg_0_03 __pyx_mstate_global->__pyx_float_neg_0_03
#define __pyx_float_neg_0_66 __pyx_mstate_global->__pyx_float_neg_0_66
#define __pyx_float_neg_0_025 __pyx_mstate_global->__pyx_float_neg_0_025
#define __pyx_float_neg_0_758 __pyx_mstate_global->__pyx_float_neg_0_758
#define __pyx_float_neg_0_00865 __pyx_mstate_global->__pyx_float_neg_0_00865
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_4 __pyx_mstate_global->__pyx_int_4
#define __pyx_int_5 __pyx_mstate_global->__pyx_int_5
#define __pyx_int_6 __pyx_mstate_global->__pyx_int_6
#define __pyx_int_7 __pyx_mstate_global->__pyx_int_7
#define __pyx_int_8 __pyx_mstate_global->__pyx_int_8
#define __pyx_int_9 __pyx_mstate_global->__pyx_int_9
#define __pyx_int_10 __pyx_mstate_global->__pyx_int_10
#define __pyx_int_100 __pyx_mstate_global->__pyx_int_100
#define __pyx_int_200 __pyx_mstate_global->__pyx_int_200
#define __pyx_int_300 __pyx_mstate_global->__pyx_int_300
#define __pyx_int_500 __pyx_mstate_global->__pyx_int_500
#define __pyx_int_600 __pyx_mstate_global->__pyx_int_600
#define __pyx_int_1024 __pyx_mstate_global->__pyx_int_1024
#define __pyx_int_10000 __pyx_mstate_global->__pyx_int_10000
#define __pyx_int_20000 __pyx_mstate_global->__pyx_int_20000
#define __pyx_int_112105877 __pyx_mstate_global->__pyx_int_112105877
#define __pyx_int_136983863 __pyx_mstate_global->__pyx_int_136983863
#define __pyx_int_184977713 __pyx_mstate_global->__pyx_int_184977713
#define __pyx_int_10000000000 __pyx_mstate_global->__pyx_int_10000000000
#define __pyx_int_0xde0b6b3a7640000 __pyx_mstate_global->__pyx_int_0xde0b6b3a7640000
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_int_neg_4 __pyx_mstate_global->__pyx_int_neg_4
#define __pyx_int_neg_6 __pyx_mstate_global->__pyx_int_neg_6
#define __pyx_k__21 __pyx_mstate_global->__pyx_k__21
#define __pyx_slice__5 __pyx_mstate_global->__pyx_slice__5
#define __pyx_tuple__4 __pyx_mstate_global->__pyx_tuple__4
#define __pyx_tuple__8 __pyx_mstate_global->__pyx_tuple__8
#define __pyx_slice__44 __pyx_mstate_global->__pyx_slice__44
#define __pyx_slice__47 __pyx_mstate_global->__pyx_slice__47
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__16 __pyx_mstate_global->__pyx_tuple__16
#define __pyx_tuple__18 __pyx_mstate_global->__pyx_tuple__18
#define __pyx_tuple__19 __pyx_mstate_global->__pyx_tuple__19
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_tuple__25 __pyx_mstate_global->__pyx_tuple__25
#define __pyx_tuple__26 __pyx_mstate_global->__pyx_tuple__26
#define __pyx_tuple__27 __pyx_mstate_global->__pyx_tuple__27
#define __pyx_tuple__28 __pyx_mstate_global->__pyx_tuple__28
#define __pyx_tuple__29 __pyx_mstate_global->__pyx_tuple__29
#define __pyx_tuple__30 __pyx_mstate_global->__pyx_tuple__30
#define __pyx_tuple__31 __pyx_mstate_global->__pyx_tuple__31
#define __pyx_tuple__33 __pyx_mstate_global->__pyx_tuple__33
#define __pyx_tuple__34 __pyx_mstate_global->__pyx_tuple__34
#define __pyx_tuple__38 __pyx_mstate_global->__pyx_tuple__38
#define __pyx_tuple__40 __pyx_mstate_global->__pyx_tuple__40
#define __pyx_tuple__42 __pyx_mstate_global->__pyx_tuple__42
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__45 __pyx_mstate_global->__pyx_tuple__45
#define __pyx_tuple__48 __pyx_mstate_global->__pyx_tuple__48
#define __pyx_tuple__49 __pyx_mstate_global->__pyx_tuple__49
#define __pyx_tuple__50 __pyx_mstate_global->__pyx_tuple__50
#define __pyx_tuple__51 __pyx_mstate_global->__pyx_tuple__51
#define __pyx_tuple__52 __pyx_mstate_global->__pyx_tuple__52
#define __pyx_tuple__53 __pyx_mstate_global->__pyx_tuple__53
#define __pyx_tuple__54 __pyx_mstate_global->__pyx_tuple__54
#define __pyx_tuple__55 __pyx_mstate_global->__pyx_tuple__55
#define __pyx_tuple__56 __pyx_mstate_global->__pyx_tuple__56
#define __pyx_tuple__57 __pyx_mstate_global->__pyx_tuple__57
#define __pyx_tuple__58 __pyx_mstate_global->__pyx_tuple__58
#define __pyx_tuple__59 __pyx_mstate_global->__pyx_tuple__59
#define __pyx_tuple__60 __pyx_mstate_global->__pyx_tuple__60
#define __pyx_tuple__62 __pyx_mstate_global->__pyx_tuple__62
#define __pyx_tuple__64 __pyx_mstate_global->__pyx_tuple__64
#define __pyx_tuple__66 __pyx_mstate_global->__pyx_tuple__66
#define __pyx_tuple__67 __pyx_mstate_global->__pyx_tuple__67
#define __pyx_tuple__69 __pyx_mstate_global->__pyx_tuple__69
#define __pyx_tuple__71 __pyx_mstate_global->__pyx_tuple__71
#define __pyx_tuple__73 __pyx_mstate_global->__pyx_tuple__73
#define __pyx_tuple__75 __pyx_mstate_global->__pyx_tuple__75
#define __pyx_tuple__77 __pyx_mstate_global->__pyx_tuple__77
#define __pyx_tuple__78 __pyx_mstate_global->__pyx_tuple__78
#define __pyx_tuple__80 __pyx_mstate_global->__pyx_tuple__80
#define __pyx_tuple__82 __pyx_mstate_global->__pyx_tuple__82
#define __pyx_tuple__85 __pyx_mstate_global->__pyx_tuple__85
#define __pyx_tuple__88 __pyx_mstate_global->__pyx_tuple__88
#define __pyx_tuple__90 __pyx_mstate_global->__pyx_tuple__90
#define __pyx_tuple__92 __pyx_mstate_global->__pyx_tuple__92
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_tuple__95 __pyx_mstate_global->__pyx_tuple__95
#define __pyx_tuple__97 __pyx_mstate_global->__pyx_tuple__97
#define __pyx_tuple__99 __pyx_mstate_global->__pyx_tuple__99
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__102 __pyx_mstate_global->__pyx_tuple__102
#define __pyx_tuple__104 __pyx_mstate_global->__pyx_tuple__104
#define __pyx_tuple__106 __pyx_mstate_global->__pyx_tuple__106
#define __pyx_tuple__107 __pyx_mstate_global->__pyx_tuple__107
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_tuple__111 __pyx_mstate_global->__pyx_tuple__111
#define __pyx_tuple__113 __pyx_mstate_global->__pyx_tuple__113
#define __pyx_tuple__115 __pyx_mstate_global->__pyx_tuple__115
#define __pyx_tuple__117 __pyx_mstate_global->__pyx_tuple__117
#define __pyx_tuple__119 __pyx_mstate_global->__pyx_tuple__119
#define __pyx_tuple__121 __pyx_mstate_global->__pyx_tuple__121
#define __pyx_tuple__123 __pyx_mstate_global->__pyx_tuple__123
#define __pyx_tuple__125 __pyx_mstate_global->__pyx_tuple__125
#define __pyx_tuple__127 __pyx_mstate_global->__pyx_tuple__127
#define __pyx_tuple__129 __pyx_mstate_global->__pyx_tuple__129
#define __pyx_tuple__131 __pyx_mstate_global->__pyx_tuple__131
#define __pyx_tuple__133 __pyx_mstate_global->__pyx_tuple__133
#define __pyx_tuple__135 __pyx_mstate_global->__pyx_tuple__135
#define __pyx_tuple__138 __pyx_mstate_global->__pyx_tuple__138
#define __pyx_tuple__140 __pyx_mstate_global->__pyx_tuple__140
#define __pyx_tuple__141 __pyx_mstate_global->__pyx_tuple__141
#define __pyx_tuple__143 __pyx_mstate_global->__pyx_tuple__143
#define __pyx_tuple__145 __pyx_mstate_global->__pyx_tuple__145
#define __pyx_tuple__147 __pyx_mstate_global->__pyx_tuple__147
#define __pyx_tuple__149 __pyx_mstate_global->__pyx_tuple__149
#define __pyx_tuple__151 __pyx_mstate_global->__pyx_tuple__151
#define __pyx_tuple__156 __pyx_mstate_global->__pyx_tuple__156
#define __pyx_tuple__169 __pyx_mstate_global->__pyx_tuple__169
#define __pyx_tuple__172 __pyx_mstate_global->__pyx_tuple__172
#define __pyx_tuple__177 __pyx_mstate_global->__pyx_tuple__177
#define __pyx_tuple__179 __pyx_mstate_global->__pyx_tuple__179
#define __pyx_tuple__181 __pyx_mstate_global->__pyx_tuple__181
#define __pyx_tuple__183 __pyx_mstate_global->__pyx_tuple__183
#define __pyx_tuple__185 __pyx_mstate_global->__pyx_tuple__185
#define __pyx_tuple__187 __pyx_mstate_global->__pyx_tuple__187
#define __pyx_tuple__190 __pyx_mstate_global->__pyx_tuple__190
#define __pyx_tuple__192 __pyx_mstate_global->__pyx_tuple__192
#define __pyx_tuple__194 __pyx_mstate_global->__pyx_tuple__194
#define __pyx_tuple__196 __pyx_mstate_global->__pyx_tuple__196
#define __pyx_tuple__198 __pyx_mstate_global->__pyx_tuple__198
#define __pyx_tuple__202 __pyx_mstate_global->__pyx_tuple__202
#define __pyx_tuple__204 __pyx_mstate_global->__pyx_tuple__204
#define __pyx_tuple__206 __pyx_mstate_global->__pyx_tuple__206
#define __pyx_tuple__209 __pyx_mstate_global->__pyx_tuple__209
#define __pyx_tuple__211 __pyx_mstate_global->__pyx_tuple__211
#define __pyx_tuple__213 __pyx_mstate_global->__pyx_tuple__213
#define __pyx_tuple__217 __pyx_mstate_global->__pyx_tuple__217
#define __pyx_tuple__220 __pyx_mstate_global->__pyx_tuple__220
#define __pyx_tuple__227 __pyx_mstate_global->__pyx_tuple__227
#define __pyx_tuple__229 __pyx_mstate_global->__pyx_tuple__229
#define __pyx_tuple__261 __pyx_mstate_global->__pyx_tuple__261
#define __pyx_tuple__263 __pyx_mstate_global->__pyx_tuple__263
#define __pyx_tuple__265 __pyx_mstate_global->__pyx_tuple__265
#define __pyx_tuple__267 __pyx_mstate_global->__pyx_tuple__267
#define __pyx_tuple__269 __pyx_mstate_global->__pyx_tuple__269
#define __pyx_tuple__271 __pyx_mstate_global->__pyx_tuple__271
#define __pyx_tuple__273 __pyx_mstate_global->__pyx_tuple__273
#define __pyx_tuple__275 __pyx_mstate_global->__pyx_tuple__275
#define __pyx_tuple__277 __pyx_mstate_global->__pyx_tuple__277
#define __pyx_tuple__279 __pyx_mstate_global->__pyx_tuple__279
#define __pyx_tuple__283 __pyx_mstate_global->__pyx_tuple__283
#define __pyx_tuple__285 __pyx_mstate_global->__pyx_tuple__285
#define __pyx_tuple__290 __pyx_mstate_global->__pyx_tuple__290
#define __pyx_tuple__292 __pyx_mstate_global->__pyx_tuple__292
#define __pyx_tuple__295 __pyx_mstate_global->__pyx_tuple__295
#define __pyx_tuple__317 __pyx_mstate_global->__pyx_tuple__317
#define __pyx_tuple__320 __pyx_mstate_global->__pyx_tuple__320
#define __pyx_tuple__324 __pyx_mstate_global->__pyx_tuple__324
#define __pyx_tuple__326 __pyx_mstate_global->__pyx_tuple__326
#define __pyx_tuple__328 __pyx_mstate_global->__pyx_tuple__328
#define __pyx_tuple__330 __pyx_mstate_global->__pyx_tuple__330
#define __pyx_tuple__332 __pyx_mstate_global->__pyx_tuple__332
#define __pyx_tuple__335 __pyx_mstate_global->__pyx_tuple__335
#define __pyx_tuple__340 __pyx_mstate_global->__pyx_tuple__340
#define __pyx_tuple__342 __pyx_mstate_global->__pyx_tuple__342
#define __pyx_tuple__343 __pyx_mstate_global->__pyx_tuple__343
#define __pyx_tuple__345 __pyx_mstate_global->__pyx_tuple__345
#define __pyx_tuple__348 __pyx_mstate_global->__pyx_tuple__348
#define __pyx_tuple__350 __pyx_mstate_global->__pyx_tuple__350
#define __pyx_tuple__352 __pyx_mstate_global->__pyx_tuple__352
#define __pyx_tuple__354 __pyx_mstate_global->__pyx_tuple__354
#define __pyx_tuple__356 __pyx_mstate_global->__pyx_tuple__356
#define __pyx_tuple__358 __pyx_mstate_global->__pyx_tuple__358
#define __pyx_tuple__365 __pyx_mstate_global->__pyx_tuple__365
#define __pyx_tuple__374 __pyx_mstate_global->__pyx_tuple__374
#define __pyx_tuple__376 __pyx_mstate_global->__pyx_tuple__376
#define __pyx_tuple__378 __pyx_mstate_global->__pyx_tuple__378
#define __pyx_tuple__381 __pyx_mstate_global->__pyx_tuple__381
#define __pyx_tuple__383 __pyx_mstate_global->__pyx_tuple__383
#define __pyx_tuple__385 __pyx_mstate_global->__pyx_tuple__385
#define __pyx_tuple__387 __pyx_mstate_global->__pyx_tuple__387
#define __pyx_tuple__388 __pyx_mstate_global->__pyx_tuple__388
#define __pyx_tuple__393 __pyx_mstate_global->__pyx_tuple__393
#define __pyx_tuple__395 __pyx_mstate_global->__pyx_tuple__395
#define __pyx_tuple__396 __pyx_mstate_global->__pyx_tuple__396
#define __pyx_tuple__398 __pyx_mstate_global->__pyx_tuple__398
#define __pyx_tuple__399 __pyx_mstate_global->__pyx_tuple__399
#define __pyx_tuple__401 __pyx_mstate_global->__pyx_tuple__401
#define __pyx_tuple__402 __pyx_mstate_global->__pyx_tuple__402
#define __pyx_tuple__405 __pyx_mstate_global->__pyx_tuple__405
#define __pyx_tuple__407 __pyx_mstate_global->__pyx_tuple__407
#define __pyx_tuple__409 __pyx_mstate_global->__pyx_tuple__409
#define __pyx_tuple__410 __pyx_mstate_global->__pyx_tuple__410
#define __pyx_tuple__412 __pyx_mstate_global->__pyx_tuple__412
#define __pyx_tuple__414 __pyx_mstate_global->__pyx_tuple__414
#define __pyx_tuple__416 __pyx_mstate_global->__pyx_tuple__416
#define __pyx_tuple__417 __pyx_mstate_global->__pyx_tuple__417
#define __pyx_tuple__420 __pyx_mstate_global->__pyx_tuple__420
#define __pyx_tuple__422 __pyx_mstate_global->__pyx_tuple__422
#define __pyx_tuple__424 __pyx_mstate_global->__pyx_tuple__424
#define __pyx_tuple__427 __pyx_mstate_global->__pyx_tuple__427
#define __pyx_tuple__429 __pyx_mstate_global->__pyx_tuple__429
#define __pyx_tuple__433 __pyx_mstate_global->__pyx_tuple__433
#define __pyx_tuple__435 __pyx_mstate_global->__pyx_tuple__435
#define __pyx_tuple__437 __pyx_mstate_global->__pyx_tuple__437
#define __pyx_tuple__440 __pyx_mstate_global->__pyx_tuple__440
#define __pyx_tuple__444 __pyx_mstate_global->__pyx_tuple__444
#define __pyx_tuple__456 __pyx_mstate_global->__pyx_tuple__456
#define __pyx_tuple__458 __pyx_mstate_global->__pyx_tuple__458
#define __pyx_tuple__462 __pyx_mstate_global->__pyx_tuple__462
#define __pyx_tuple__464 __pyx_mstate_global->__pyx_tuple__464
#define __pyx_tuple__468 __pyx_mstate_global->__pyx_tuple__468
#define __pyx_tuple__470 __pyx_mstate_global->__pyx_tuple__470
#define __pyx_tuple__472 __pyx_mstate_global->__pyx_tuple__472
#define __pyx_tuple__474 __pyx_mstate_global->__pyx_tuple__474
#define __pyx_tuple__476 __pyx_mstate_global->__pyx_tuple__476
#define __pyx_tuple__478 __pyx_mstate_global->__pyx_tuple__478
#define __pyx_tuple__480 __pyx_mstate_global->__pyx_tuple__480
#define __pyx_tuple__482 __pyx_mstate_global->__pyx_tuple__482
#define __pyx_tuple__483 __pyx_mstate_global->__pyx_tuple__483
#define __pyx_tuple__486 __pyx_mstate_global->__pyx_tuple__486
#define __pyx_tuple__493 __pyx_mstate_global->__pyx_tuple__493
#define __pyx_tuple__497 __pyx_mstate_global->__pyx_tuple__497
#define __pyx_tuple__499 __pyx_mstate_global->__pyx_tuple__499
#define __pyx_tuple__504 __pyx_mstate_global->__pyx_tuple__504
#define __pyx_tuple__506 __pyx_mstate_global->__pyx_tuple__506
#define __pyx_tuple__507 __pyx_mstate_global->__pyx_tuple__507
#define __pyx_tuple__509 __pyx_mstate_global->__pyx_tuple__509
#define __pyx_tuple__511 __pyx_mstate_global->__pyx_tuple__511
#define __pyx_tuple__513 __pyx_mstate_global->__pyx_tuple__513
#define __pyx_tuple__516 __pyx_mstate_global->__pyx_tuple__516
#define __pyx_tuple__518 __pyx_mstate_global->__pyx_tuple__518
#define __pyx_tuple__519 __pyx_mstate_global->__pyx_tuple__519
#define __pyx_tuple__521 __pyx_mstate_global->__pyx_tuple__521
#define __pyx_tuple__524 __pyx_mstate_global->__pyx_tuple__524
#define __pyx_tuple__527 __pyx_mstate_global->__pyx_tuple__527
#define __pyx_tuple__530 __pyx_mstate_global->__pyx_tuple__530
#define __pyx_tuple__533 __pyx_mstate_global->__pyx_tuple__533
#define __pyx_tuple__536 __pyx_mstate_global->__pyx_tuple__536
#define __pyx_tuple__539 __pyx_mstate_global->__pyx_tuple__539
#define __pyx_tuple__542 __pyx_mstate_global->__pyx_tuple__542
#define __pyx_tuple__552 __pyx_mstate_global->__pyx_tuple__552
#define __pyx_codeobj__17 __pyx_mstate_global->__pyx_codeobj__17
#define __pyx_codeobj__32 __pyx_mstate_global->__pyx_codeobj__32
#define __pyx_codeobj__35 __pyx_mstate_global->__pyx_codeobj__35
#define __pyx_codeobj__36 __pyx_mstate_global->__pyx_codeobj__36
#define __pyx_codeobj__37 __pyx_mstate_global->__pyx_codeobj__37
#define __pyx_codeobj__39 __pyx_mstate_global->__pyx_codeobj__39
#define __pyx_codeobj__41 __pyx_mstate_global->__pyx_codeobj__41
#define __pyx_codeobj__61 __pyx_mstate_global->__pyx_codeobj__61
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__65 __pyx_mstate_global->__pyx_codeobj__65
#define __pyx_codeobj__68 __pyx_mstate_global->__pyx_codeobj__68
#define __pyx_codeobj__70 __pyx_mstate_global->__pyx_codeobj__70
#define __pyx_codeobj__72 __pyx_mstate_global->__pyx_codeobj__72
#define __pyx_codeobj__74 __pyx_mstate_global->__pyx_codeobj__74
#define __pyx_codeobj__76 __pyx_mstate_global->__pyx_codeobj__76
#define __pyx_codeobj__79 __pyx_mstate_global->__pyx_codeobj__79
#define __pyx_codeobj__81 __pyx_mstate_global->__pyx_codeobj__81
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__84 __pyx_mstate_global->__pyx_codeobj__84
#define __pyx_codeobj__86 __pyx_mstate_global->__pyx_codeobj__86
#define __pyx_codeobj__87 __pyx_mstate_global->__pyx_codeobj__87
#define __pyx_codeobj__89 __pyx_mstate_global->__pyx_codeobj__89
#define __pyx_codeobj__91 __pyx_mstate_global->__pyx_codeobj__91
#define __pyx_codeobj__94 __pyx_mstate_global->__pyx_codeobj__94
#define __pyx_codeobj__96 __pyx_mstate_global->__pyx_codeobj__96
#define __pyx_codeobj__98 __pyx_mstate_global->__pyx_codeobj__98
#define __pyx_codeobj__100 __pyx_mstate_global->__pyx_codeobj__100
#define __pyx_codeobj__103 __pyx_mstate_global->__pyx_codeobj__103
#define __pyx_codeobj__105 __pyx_mstate_global->__pyx_codeobj__105
#define __pyx_codeobj__108 __pyx_mstate_global->__pyx_codeobj__108
#define __pyx_codeobj__110 __pyx_mstate_global->__pyx_codeobj__110
#define __pyx_codeobj__112 __pyx_mstate_global->__pyx_codeobj__112
#define __pyx_codeobj__114 __pyx_mstate_global->__pyx_codeobj__114
#define __pyx_codeobj__116 __pyx_mstate_global->__pyx_codeobj__116
#define __pyx_codeobj__118 __pyx_mstate_global->__pyx_codeobj__118
#define __pyx_codeobj__120 __pyx_mstate_global->__pyx_codeobj__120
#define __pyx_codeobj__122 __pyx_mstate_global->__pyx_codeobj__122
#define __pyx_codeobj__124 __pyx_mstate_global->__pyx_codeobj__124
#define __pyx_codeobj__126 __pyx_mstate_global->__pyx_codeobj__126
#define __pyx_codeobj__128 __pyx_mstate_global->__pyx_codeobj__128
#define __pyx_codeobj__130 __pyx_mstate_global->__pyx_codeobj__130
#define __pyx_codeobj__132 __pyx_mstate_global->__pyx_codeobj__132
#define __pyx_codeobj__134 __pyx_mstate_global->__pyx_codeobj__134
#define __pyx_codeobj__136 __pyx_mstate_global->__pyx_codeobj__136
#define __pyx_codeobj__137 __pyx_mstate_global->__pyx_codeobj__137
#define __pyx_codeobj__139 __pyx_mstate_global->__pyx_codeobj__139
#define __pyx_codeobj__142 __pyx_mstate_global->__pyx_codeobj__142
#define __pyx_codeobj__144 __pyx_mstate_global->__pyx_codeobj__144
#define __pyx_codeobj__146 __pyx_mstate_global->__pyx_codeobj__146
#define __pyx_codeobj__148 __pyx_mstate_global->__pyx_codeobj__148
#define __pyx_codeobj__150 __pyx_mstate_global->__pyx_codeobj__150
#define __pyx_codeobj__152 __pyx_mstate_global->__pyx_codeobj__152
#define __pyx_codeobj__153 __pyx_mstate_global->__pyx_codeobj__153
#define __pyx_codeobj__154 __pyx_mstate_global->__pyx_codeobj__154
#define __pyx_codeobj__155 __pyx_mstate_global->__pyx_codeobj__155
#define __pyx_codeobj__157 __pyx_mstate_global->__pyx_codeobj__157
#define __pyx_codeobj__158 __pyx_mstate_global->__pyx_codeobj__158
#define __pyx_codeobj__159 __pyx_mstate_global->__pyx_codeobj__159
#define __pyx_codeobj__160 __pyx_mstate_global->__pyx_codeobj__160
#define __pyx_codeobj__161 __pyx_mstate_global->__pyx_codeobj__161
#define __pyx_codeobj__162 __pyx_mstate_global->__pyx_codeobj__162
#define __pyx_codeobj__163 __pyx_mstate_global->__pyx_codeobj__163
#define __pyx_codeobj__164 __pyx_mstate_global->__pyx_codeobj__164
#define __pyx_codeobj__165 __pyx_mstate_global->__pyx_codeobj__165
#define __pyx_codeobj__166 __pyx_mstate_global->__pyx_codeobj__166
#define __pyx_codeobj__167 __pyx_mstate_global->__pyx_codeobj__167
#define __pyx_codeobj__168 __pyx_mstate_global->__pyx_codeobj__168
#define __pyx_codeobj__170 __pyx_mstate_global->__pyx_codeobj__170
#define __pyx_codeobj__171 __pyx_mstate_global->__pyx_codeobj__171
#define __pyx_codeobj__173 __pyx_mstate_global->__pyx_codeobj__173
#define __pyx_codeobj__174 __pyx_mstate_global->__pyx_codeobj__174
#define __pyx_codeobj__175 __pyx_mstate_global->__pyx_codeobj__175
#define __pyx_codeobj__176 __pyx_mstate_global->__pyx_codeobj__176
#define __pyx_codeobj__178 __pyx_mstate_global->__pyx_codeobj__178
#define __pyx_codeobj__180 __pyx_mstate_global->__pyx_codeobj__180
#define __pyx_codeobj__182 __pyx_mstate_global->__pyx_codeobj__182
#define __pyx_codeobj__184 __pyx_mstate_global->__pyx_codeobj__184
#define __pyx_codeobj__186 __pyx_mstate_global->__pyx_codeobj__186
#define __pyx_codeobj__188 __pyx_mstate_global->__pyx_codeobj__188
#define __pyx_codeobj__189 __pyx_mstate_global->__pyx_codeobj__189
#define __pyx_codeobj__191 __pyx_mstate_global->__pyx_codeobj__191
#define __pyx_codeobj__193 __pyx_mstate_global->__pyx_codeobj__193
#define __pyx_codeobj__195 __pyx_mstate_global->__pyx_codeobj__195
#define __pyx_codeobj__197 __pyx_mstate_global->__pyx_codeobj__197
#define __pyx_codeobj__199 __pyx_mstate_global->__pyx_codeobj__199
#define __pyx_codeobj__200 __pyx_mstate_global->__pyx_codeobj__200
#define __pyx_codeobj__201 __pyx_mstate_global->__pyx_codeobj__201
#define __pyx_codeobj__203 __pyx_mstate_global->__pyx_codeobj__203
#define __pyx_codeobj__205 __pyx_mstate_global->__pyx_codeobj__205
#define __pyx_codeobj__207 __pyx_mstate_global->__pyx_codeobj__207
#define __pyx_codeobj__208 __pyx_mstate_global->__pyx_codeobj__208
#define __pyx_codeobj__210 __pyx_mstate_global->__pyx_codeobj__210
#define __pyx_codeobj__212 __pyx_mstate_global->__pyx_codeobj__212
#define __pyx_codeobj__214 __pyx_mstate_global->__pyx_codeobj__214
#define __pyx_codeobj__215 __pyx_mstate_global->__pyx_codeobj__215
#define __pyx_codeobj__216 __pyx_mstate_global->__pyx_codeobj__216
#define __pyx_codeobj__218 __pyx_mstate_global->__pyx_codeobj__218
#define __pyx_codeobj__219 __pyx_mstate_global->__pyx_codeobj__219
#define __pyx_codeobj__221 __pyx_mstate_global->__pyx_codeobj__221
#define __pyx_codeobj__222 __pyx_mstate_global->__pyx_codeobj__222
#define __pyx_codeobj__223 __pyx_mstate_global->__pyx_codeobj__223
#define __pyx_codeobj__224 __pyx_mstate_global->__pyx_codeobj__224
#define __pyx_codeobj__225 __pyx_mstate_global->__pyx_codeobj__225
#define __pyx_codeobj__226 __pyx_mstate_global->__pyx_codeobj__226
#define __pyx_codeobj__228 __pyx_mstate_global->__pyx_codeobj__228
#define __pyx_codeobj__230 __pyx_mstate_global->__pyx_codeobj__230
#define __pyx_codeobj__231 __pyx_mstate_global->__pyx_codeobj__231
#define __pyx_codeobj__232 __pyx_mstate_global->__pyx_codeobj__232
#define __pyx_codeobj__233 __pyx_mstate_global->__pyx_codeobj__233
#define __pyx_codeobj__234 __pyx_mstate_global->__pyx_codeobj__234
#define __pyx_codeobj__235 __pyx_mstate_global->__pyx_codeobj__235
#define __pyx_codeobj__236 __pyx_mstate_global->__pyx_codeobj__236
#define __pyx_codeobj__237 __pyx_mstate_global->__pyx_codeobj__237
#define __pyx_codeobj__238 __pyx_mstate_global->__pyx_codeobj__238
#define __pyx_codeobj__239 __pyx_mstate_global->__pyx_codeobj__239
#define __pyx_codeobj__240 __pyx_mstate_global->__pyx_codeobj__240
#define __pyx_codeobj__241 __pyx_mstate_global->__pyx_codeobj__241
#define __pyx_codeobj__242 __pyx_mstate_global->__pyx_codeobj__242
#define __pyx_codeobj__243 __pyx_mstate_global->__pyx_codeobj__243
#define __pyx_codeobj__244 __pyx_mstate_global->__pyx_codeobj__244
#define __pyx_codeobj__245 __pyx_mstate_global->__pyx_codeobj__245
#define __pyx_codeobj__246 __pyx_mstate_global->__pyx_codeobj__246
#define __pyx_codeobj__247 __pyx_mstate_global->__pyx_codeobj__247
#define __pyx_codeobj__248 __pyx_mstate_global->__pyx_codeobj__248
#define __pyx_codeobj__249 __pyx_mstate_global->__pyx_codeobj__249
#define __pyx_codeobj__250 __pyx_mstate_global->__pyx_codeobj__250
#define __pyx_codeobj__251 __pyx_mstate_global->__pyx_codeobj__251
#define __pyx_codeobj__252 __pyx_mstate_global->__pyx_codeobj__252
#define __pyx_codeobj__253 __pyx_mstate_global->__pyx_codeobj__253
#define __pyx_codeobj__254 __pyx_mstate_global->__pyx_codeobj__254
#define __pyx_codeobj__255 __pyx_mstate_global->__pyx_codeobj__255
#define __pyx_codeobj__256 __pyx_mstate_global->__pyx_codeobj__256
#define __pyx_codeobj__257 __pyx_mstate_global->__pyx_codeobj__257
#define __pyx_codeobj__258 __pyx_mstate_global->__pyx_codeobj__258
#define __pyx_codeobj__259 __pyx_mstate_global->__pyx_codeobj__259
#define __pyx_codeobj__260 __pyx_mstate_global->__pyx_codeobj__260
#define __pyx_codeobj__262 __pyx_mstate_global->__pyx_codeobj__262
#define __pyx_codeobj__264 __pyx_mstate_global->__pyx_codeobj__264
#define __pyx_codeobj__266 __pyx_mstate_global->__pyx_codeobj__266
#define __pyx_codeobj__268 __pyx_mstate_global->__pyx_codeobj__268
#define __pyx_codeobj__270 __pyx_mstate_global->__pyx_codeobj__270
#define __pyx_codeobj__272 __pyx_mstate_global->__pyx_codeobj__272
#define __pyx_codeobj__274 __pyx_mstate_global->__pyx_codeobj__274
#define __pyx_codeobj__276 __pyx_mstate_global->__pyx_codeobj__276
#define __pyx_codeobj__278 __pyx_mstate_global->__pyx_codeobj__278
#define __pyx_codeobj__280 __pyx_mstate_global->__pyx_codeobj__280
#define __pyx_codeobj__281 __pyx_mstate_global->__pyx_codeobj__281
#define __pyx_codeobj__282 __pyx_mstate_global->__pyx_codeobj__282
#define __pyx_codeobj__284 __pyx_mstate_global->__pyx_codeobj__284
#define __pyx_codeobj__286 __pyx_mstate_global->__pyx_codeobj__286
#define __pyx_codeobj__287 __pyx_mstate_global->__pyx_codeobj__287
#define __pyx_codeobj__288 __pyx_mstate_global->__pyx_codeobj__288
#define __pyx_codeobj__289 __pyx_mstate_global->__pyx_codeobj__289
#define __pyx_codeobj__291 __pyx_mstate_global->__pyx_codeobj__291
#define __pyx_codeobj__293 __pyx_mstate_global->__pyx_codeobj__293
#define __pyx_codeobj__294 __pyx_mstate_global->__pyx_codeobj__294
#define __pyx_codeobj__296 __pyx_mstate_global->__pyx_codeobj__296
#define __pyx_codeobj__297 __pyx_mstate_global->__pyx_codeobj__297
#define __pyx_codeobj__298 __pyx_mstate_global->__pyx_codeobj__298
#define __pyx_codeobj__299 __pyx_mstate_global->__pyx_codeobj__299
#define __pyx_codeobj__300 __pyx_mstate_global->__pyx_codeobj__300
#define __pyx_codeobj__301 __pyx_mstate_global->__pyx_codeobj__301
#define __pyx_codeobj__302 __pyx_mstate_global->__pyx_codeobj__302
#define __pyx_codeobj__303 __pyx_mstate_global->__pyx_codeobj__303
#define __pyx_codeobj__304 __pyx_mstate_global->__pyx_codeobj__304
#define __pyx_codeobj__305 __pyx_mstate_global->__pyx_codeobj__305
#define __pyx_codeobj__306 __pyx_mstate_global->__pyx_codeobj__306
#define __pyx_codeobj__307 __pyx_mstate_global->__pyx_codeobj__307
#define __pyx_codeobj__308 __pyx_mstate_global->__pyx_codeobj__308
#define __pyx_codeobj__309 __pyx_mstate_global->__pyx_codeobj__309
#define __pyx_codeobj__310 __pyx_mstate_global->__pyx_codeobj__310
#define __pyx_codeobj__311 __pyx_mstate_global->__pyx_codeobj__311
#define __pyx_codeobj__312 __pyx_mstate_global->__pyx_codeobj__312
#define __pyx_codeobj__313 __pyx_mstate_global->__pyx_codeobj__313
#define __pyx_codeobj__314 __pyx_mstate_global->__pyx_codeobj__314
#define __pyx_codeobj__315 __pyx_mstate_global->__pyx_codeobj__315
#define __pyx_codeobj__316 __pyx_mstate_global->__pyx_codeobj__316
#define __pyx_codeobj__318 __pyx_mstate_global->__pyx_codeobj__318
#define __pyx_codeobj__319 __pyx_mstate_global->__pyx_codeobj__319
#define __pyx_codeobj__321 __pyx_mstate_global->__pyx_codeobj__321
#define __pyx_codeobj__322 __pyx_mstate_global->__pyx_codeobj__322
#define __pyx_codeobj__323 __pyx_mstate_global->__pyx_codeobj__323
#define __pyx_codeobj__325 __pyx_mstate_global->__pyx_codeobj__325
#define __pyx_codeobj__327 __pyx_mstate_global->__pyx_codeobj__327
#define __pyx_codeobj__329 __pyx_mstate_global->__pyx_codeobj__329
#define __pyx_codeobj__331 __pyx_mstate_global->__pyx_codeobj__331
#define __pyx_codeobj__333 __pyx_mstate_global->__pyx_codeobj__333
#define __pyx_codeobj__334 __pyx_mstate_global->__pyx_codeobj__334
#define __pyx_codeobj__336 __pyx_mstate_global->__pyx_codeobj__336
#define __pyx_codeobj__337 __pyx_mstate_global->__pyx_codeobj__337
#define __pyx_codeobj__338 __pyx_mstate_global->__pyx_codeobj__338
#define __pyx_codeobj__339 __pyx_mstate_global->__pyx_codeobj__339
#define __pyx_codeobj__341 __pyx_mstate_global->__pyx_codeobj__341
#define __pyx_codeobj__344 __pyx_mstate_global->__pyx_codeobj__344
#define __pyx_codeobj__346 __pyx_mstate_global->__pyx_codeobj__346
#define __pyx_codeobj__347 __pyx_mstate_global->__pyx_codeobj__347
#define __pyx_codeobj__349 __pyx_mstate_global->__pyx_codeobj__349
#define __pyx_codeobj__351 __pyx_mstate_global->__pyx_codeobj__351
#define __pyx_codeobj__353 __pyx_mstate_global->__pyx_codeobj__353
#define __pyx_codeobj__355 __pyx_mstate_global->__pyx_codeobj__355
#define __pyx_codeobj__357 __pyx_mstate_global->__pyx_codeobj__357
#define __pyx_codeobj__359 __pyx_mstate_global->__pyx_codeobj__359
#define __pyx_codeobj__360 __pyx_mstate_global->__pyx_codeobj__360
#define __pyx_codeobj__361 __pyx_mstate_global->__pyx_codeobj__361
#define __pyx_codeobj__362 __pyx_mstate_global->__pyx_codeobj__362
#define __pyx_codeobj__363 __pyx_mstate_global->__pyx_codeobj__363
#define __pyx_codeobj__364 __pyx_mstate_global->__pyx_codeobj__364
#define __pyx_codeobj__366 __pyx_mstate_global->__pyx_codeobj__366
#define __pyx_codeobj__367 __pyx_mstate_global->__pyx_codeobj__367
#define __pyx_codeobj__368 __pyx_mstate_global->__pyx_codeobj__368
#define __pyx_codeobj__369 __pyx_mstate_global->__pyx_codeobj__369
#define __pyx_codeobj__370 __pyx_mstate_global->__pyx_codeobj__370
#define __pyx_codeobj__371 __pyx_mstate_global->__pyx_codeobj__371
#define __pyx_codeobj__372 __pyx_mstate_global->__pyx_codeobj__372
#define __pyx_codeobj__373 __pyx_mstate_global->__pyx_codeobj__373
#define __pyx_codeobj__375 __pyx_mstate_global->__pyx_codeobj__375
#define __pyx_codeobj__377 __pyx_mstate_global->__pyx_codeobj__377
#define __pyx_codeobj__379 __pyx_mstate_global->__pyx_codeobj__379
#define __pyx_codeobj__380 __pyx_mstate_global->__pyx_codeobj__380
#define __pyx_codeobj__382 __pyx_mstate_global->__pyx_codeobj__382
#define __pyx_codeobj__384 __pyx_mstate_global->__pyx_codeobj__384
#define __pyx_codeobj__386 __pyx_mstate_global->__pyx_codeobj__386
#define __pyx_codeobj__389 __pyx_mstate_global->__pyx_codeobj__389
#define __pyx_codeobj__390 __pyx_mstate_global->__pyx_codeobj__390
#define __pyx_codeobj__391 __pyx_mstate_global->__pyx_codeobj__391
#define __pyx_codeobj__392 __pyx_mstate_global->__pyx_codeobj__392
#define __pyx_codeobj__394 __pyx_mstate_global->__pyx_codeobj__394
#define __pyx_codeobj__397 __pyx_mstate_global->__pyx_codeobj__397
#define __pyx_codeobj__400 __pyx_mstate_global->__pyx_codeobj__400
#define __pyx_codeobj__403 __pyx_mstate_global->__pyx_codeobj__403
#define __pyx_codeobj__404 __pyx_mstate_global->__pyx_codeobj__404
#define __pyx_codeobj__406 __pyx_mstate_global->__pyx_codeobj__406
#define __pyx_codeobj__408 __pyx_mstate_global->__pyx_codeobj__408
#define __pyx_codeobj__411 __pyx_mstate_global->__pyx_codeobj__411
#define __pyx_codeobj__413 __pyx_mstate_global->__pyx_codeobj__413
#define __pyx_codeobj__415 __pyx_mstate_global->__pyx_codeobj__415
#define __pyx_codeobj__418 __pyx_mstate_global->__pyx_codeobj__418
#define __pyx_codeobj__419 __pyx_mstate_global->__pyx_codeobj__419
#define __pyx_codeobj__421 __pyx_mstate_global->__pyx_codeobj__421
#define __pyx_codeobj__423 __pyx_mstate_global->__pyx_codeobj__423
#define __pyx_codeobj__425 __pyx_mstate_global->__pyx_codeobj__425
#define __pyx_codeobj__426 __pyx_mstate_global->__pyx_codeobj__426
#define __pyx_codeobj__428 __pyx_mstate_global->__pyx_codeobj__428
#define __pyx_codeobj__430 __pyx_mstate_global->__pyx_codeobj__430
#define __pyx_codeobj__431 __pyx_mstate_global->__pyx_codeobj__431
#define __pyx_codeobj__432 __pyx_mstate_global->__pyx_codeobj__432
#define __pyx_codeobj__434 __pyx_mstate_global->__pyx_codeobj__434
#define __pyx_codeobj__436 __pyx_mstate_global->__pyx_codeobj__436
#define __pyx_codeobj__438 __pyx_mstate_global->__pyx_codeobj__438
#define __pyx_codeobj__439 __pyx_mstate_global->__pyx_codeobj__439
#define __pyx_codeobj__441 __pyx_mstate_global->__pyx_codeobj__441
#define __pyx_codeobj__442 __pyx_mstate_global->__pyx_codeobj__442
#define __pyx_codeobj__443 __pyx_mstate_global->__pyx_codeobj__443
#define __pyx_codeobj__445 __pyx_mstate_global->__pyx_codeobj__445
#define __pyx_codeobj__446 __pyx_mstate_global->__pyx_codeobj__446
#define __pyx_codeobj__447 __pyx_mstate_global->__pyx_codeobj__447
#define __pyx_codeobj__448 __pyx_mstate_global->__pyx_codeobj__448
#define __pyx_codeobj__449 __pyx_mstate_global->__pyx_codeobj__449
#define __pyx_codeobj__450 __pyx_mstate_global->__pyx_codeobj__450
#define __pyx_codeobj__451 __pyx_mstate_global->__pyx_codeobj__451
#define __pyx_codeobj__452 __pyx_mstate_global->__pyx_codeobj__452
#define __pyx_codeobj__453 __pyx_mstate_global->__pyx_codeobj__453
#define __pyx_codeobj__454 __pyx_mstate_global->__pyx_codeobj__454
#define __pyx_codeobj__455 __pyx_mstate_global->__pyx_codeobj__455
#define __pyx_codeobj__457 __pyx_mstate_global->__pyx_codeobj__457
#define __pyx_codeobj__459 __pyx_mstate_global->__pyx_codeobj__459
#define __pyx_codeobj__460 __pyx_mstate_global->__pyx_codeobj__460
#define __pyx_codeobj__461 __pyx_mstate_global->__pyx_codeobj__461
#define __pyx_codeobj__463 __pyx_mstate_global->__pyx_codeobj__463
#define __pyx_codeobj__465 __pyx_mstate_global->__pyx_codeobj__465
#define __pyx_codeobj__466 __pyx_mstate_global->__pyx_codeobj__466
#define __pyx_codeobj__467 __pyx_mstate_global->__pyx_codeobj__467
#define __pyx_codeobj__469 __pyx_mstate_global->__pyx_codeobj__469
#define __pyx_codeobj__471 __pyx_mstate_global->__pyx_codeobj__471
#define __pyx_codeobj__473 __pyx_mstate_global->__pyx_codeobj__473
#define __pyx_codeobj__475 __pyx_mstate_global->__pyx_codeobj__475
#define __pyx_codeobj__477 __pyx_mstate_global->__pyx_codeobj__477
#define __pyx_codeobj__479 __pyx_mstate_global->__pyx_codeobj__479
#define __pyx_codeobj__481 __pyx_mstate_global->__pyx_codeobj__481
#define __pyx_codeobj__484 __pyx_mstate_global->__pyx_codeobj__484
#define __pyx_codeobj__485 __pyx_mstate_global->__pyx_codeobj__485
#define __pyx_codeobj__487 __pyx_mstate_global->__pyx_codeobj__487
#define __pyx_codeobj__488 __pyx_mstate_global->__pyx_codeobj__488
#define __pyx_codeobj__489 __pyx_mstate_global->__pyx_codeobj__489
#define __pyx_codeobj__490 __pyx_mstate_global->__pyx_codeobj__490
#define __pyx_codeobj__491 __pyx_mstate_global->__pyx_codeobj__491
#define __pyx_codeobj__492 __pyx_mstate_global->__pyx_codeobj__492
#define __pyx_codeobj__494 __pyx_mstate_global->__pyx_codeobj__494
#define __pyx_codeobj__495 __pyx_mstate_global->__pyx_codeobj__495
#define __pyx_codeobj__496 __pyx_mstate_global->__pyx_codeobj__496
#define __pyx_codeobj__498 __pyx_mstate_global->__pyx_codeobj__498
#define __pyx_codeobj__500 __pyx_mstate_global->__pyx_codeobj__500
#define __pyx_codeobj__501 __pyx_mstate_global->__pyx_codeobj__501
#define __pyx_codeobj__502 __pyx_mstate_global->__pyx_codeobj__502
#define __pyx_codeobj__503 __pyx_mstate_global->__pyx_codeobj__503
#define __pyx_codeobj__505 __pyx_mstate_global->__pyx_codeobj__505
#define __pyx_codeobj__508 __pyx_mstate_global->__pyx_codeobj__508
#define __pyx_codeobj__510 __pyx_mstate_global->__pyx_codeobj__510
#define __pyx_codeobj__512 __pyx_mstate_global->__pyx_codeobj__512
#define __pyx_codeobj__514 __pyx_mstate_global->__pyx_codeobj__514
#define __pyx_codeobj__515 __pyx_mstate_global->__pyx_codeobj__515
#define __pyx_codeobj__517 __pyx_mstate_global->__pyx_codeobj__517
#define __pyx_codeobj__520 __pyx_mstate_global->__pyx_codeobj__520
#define __pyx_codeobj__522 __pyx_mstate_global->__pyx_codeobj__522
#define __pyx_codeobj__523 __pyx_mstate_global->__pyx_codeobj__523
#define __pyx_codeobj__525 __pyx_mstate_global->__pyx_codeobj__525
#define __pyx_codeobj__526 __pyx_mstate_global->__pyx_codeobj__526
#define __pyx_codeobj__528 __pyx_mstate_global->__pyx_codeobj__528
#define __pyx_codeobj__529 __pyx_mstate_global->__pyx_codeobj__529
#define __pyx_codeobj__531 __pyx_mstate_global->__pyx_codeobj__531
#define __pyx_codeobj__532 __pyx_mstate_global->__pyx_codeobj__532
#define __pyx_codeobj__534 __pyx_mstate_global->__pyx_codeobj__534
#define __pyx_codeobj__535 __pyx_mstate_global->__pyx_codeobj__535
#define __pyx_codeobj__537 __pyx_mstate_global->__pyx_codeobj__537
#define __pyx_codeobj__538 __pyx_mstate_global->__pyx_codeobj__538
#define __pyx_codeobj__540 __pyx_mstate_global->__pyx_codeobj__540
#define __pyx_codeobj__541 __pyx_mstate_global->__pyx_codeobj__541
#define __pyx_codeobj__543 __pyx_mstate_global->__pyx_codeobj__543
#define __pyx_codeobj__544 __pyx_mstate_global->__pyx_codeobj__544
#define __pyx_codeobj__545 __pyx_mstate_global->__pyx_codeobj__545
#define __pyx_codeobj__546 __pyx_mstate_global->__pyx_codeobj__546
#define __pyx_codeobj__547 __pyx_mstate_global->__pyx_codeobj__547
#define __pyx_codeobj__548 __pyx_mstate_global->__pyx_codeobj__548
#define __pyx_codeobj__549 __pyx_mstate_global->__pyx_codeobj__549
#define __pyx_codeobj__550 __pyx_mstate_global->__pyx_codeobj__550
#define __pyx_codeobj__551 __pyx_mstate_global->__pyx_codeobj__551
#define __pyx_codeobj__553 __pyx_mstate_global->__pyx_codeobj__553
/* #### Code section: module_code ### */

/* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

/* Python wrapper */
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_shape = 0;
  Py_ssize_t __pyx_v_itemsize;
  PyObject *__pyx_v_format = 0;
  PyObject *__pyx_v_mode = 0;
  int __pyx_v_allocate_buffer;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_shape,&__pyx_n_s_itemsize,&__pyx_n_s_format,&__pyx_n_s_mode,&__pyx_n_s_allocate_buffer,0};
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_s_c));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_shape)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_itemsize)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 1); __PYX_ERR(1, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_format)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 2); __PYX_ERR(1, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_allocate_buffer);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(1, 131, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_shape = ((PyObject*)values[0]);
    __pyx_v_itemsize = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_itemsize == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
    __pyx_v_format = values[2];
    __pyx_v_mode = values[3];
    if (values[4]) {
      __pyx_v_allocate_buffer = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_allocate_buffer == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 132, __pyx_L3_error)
    } else {

      /* "View.MemoryView":132
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,
 *                   mode="c", bint allocate_buffer=True):             # <<<<<<<<<<<<<<
 * 
 *         cdef int idx
 */
      __pyx_v_allocate_buffer = ((int)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, __pyx_nargs); __PYX_ERR(1, 131, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_shape), (&PyTuple_Type), 1, "shape", 1))) __PYX_ERR(1, 131, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_format) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "format"); __PYX_ERR(1, 131, __pyx_L1_error)
  }
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(((struct __pyx_array_obj *)__pyx_v_self), __pyx_v_shape, __pyx_v_itemsize, __pyx_v_format, __pyx_v_mode, __pyx_v_allocate_buffer);

  /* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_v_dim;
  char __pyx_v_order;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  char *__pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_UCS4 __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_INCREF(__pyx_v_format);

  /* "View.MemoryView":137
 *         cdef Py_ssize_t dim
 * 
 *         self.ndim = <int> len(shape)             # <<<<<<<<<<<<<<
 *         self.itemsize = itemsize
 * 
 */
  if (unlikely(__pyx_v_shape == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 137, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyTuple_GET_SIZE(__pyx_v_shape); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(1, 137, __pyx_L1_error)
  __pyx_v_self->ndim = ((int)__pyx_t_1);

  /* "View.MemoryView":138
 * 
 *         self.ndim = <int> len(shape)
 *         self.itemsize = itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not self.ndim:
 */
  __pyx_v_self->itemsize = __pyx_v_itemsize;

  /* "View.MemoryView":140
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->ndim != 0));
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":141
 * 
 *         if not self.ndim:
 *             raise ValueError, "Empty shape tuple for cython.array"             # <<<<<<<<<<<<<<
 * 
 *         if itemsize <= 0:
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Empty_shape_tuple_for_cython_arr, 0, 0);
    __PYX_ERR(1, 141, __pyx_L1_error)

    /* "View.MemoryView":140
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 */
  }

  /* "View.MemoryView":143
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 */
  __pyx_t_2 = (__pyx_v_itemsize <= 0);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":144
 * 
 *         if itemsize <= 0:
 *             raise ValueError, "itemsize <= 0 for cython.array"             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(format, bytes):
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_itemsize_0_for_cython_array, 0, 0);
    __PYX_ERR(1, 144, __pyx_L1_error)

    /* "View.MemoryView":143
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 */
  }

  /* "View.MemoryView":146
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  __pyx_t_2 = PyBytes_Check(__pyx_v_format); 
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "View.MemoryView":147
 * 
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')             # <<<<<<<<<<<<<<
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_format, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_s_ASCII};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_format, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "View.MemoryView":146
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  }

  /* "View.MemoryView":148
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string             # <<<<<<<<<<<<<<
 *         self.format = self._format
 * 
 */
  if (!(likely(PyBytes_CheckExact(__pyx_v_format))||((__pyx_v_format) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_v_format))) __PYX_ERR(1, 148, __pyx_L1_error)
  __pyx_t_4 = __pyx_v_format;
  __Pyx_INCREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->_format);
  __Pyx_DECREF(__pyx_v_self->_format);
  __pyx_v_self->_format = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "View.MemoryView":149
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_self->_format == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(1, 149, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyBytes_AsWritableString(__pyx_v_self->_format); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) __PYX_ERR(1, 149, __pyx_L1_error)
  __pyx_v_self->format = __pyx_t_8;

  /* "View.MemoryView":152
 * 
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)             # <<<<<<<<<<<<<<
 *         self._strides = self._shape + self.ndim
 * 
 */
  __pyx_v_self->_shape = ((Py_ssize_t *)PyObject_Malloc((((sizeof(Py_ssize_t)) * __pyx_v_self->ndim) * 2)));

  /* "View.MemoryView":153
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)
 *         self._strides = self._shape + self.ndim             # <<<<<<<<<<<<<<
 * 
 *         if not self._shape:
 */
  __pyx_v_self->_strides = (__pyx_v_self->_shape + __pyx_v_self->ndim);

  /* "View.MemoryView":155
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError, "unable to allocate shape and strides."
 * 
 */
  __pyx_t_3 = (!(__pyx_v_self->_shape != 0));
  if (unlikely(__pyx_t_3)) {

    /* "View.MemoryView":156
 * 
 *         if not self._shape:
 *             raise MemoryError, "unable to allocate shape and strides."             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_Raise(__pyx_builtin_MemoryError, __pyx_kp_s_unable_to_allocate_shape_and_str, 0, 0);
    __PYX_ERR(1, 156, __pyx_L1_error)

    /* "View.MemoryView":155
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError, "unable to allocate shape and strides."
 * 
 */
  }

  /* "View.MemoryView":159
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 */
  __pyx_t_9 = 0;
  __pyx_t_4 = __pyx_v_shape; __Pyx_INCREF(__pyx_t_4);
  __pyx_t_1 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 159, __pyx_L1_error)
      #endif
      if (__pyx_t_1 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely((0 < 0))) __PYX_ERR(1, 159, __pyx_L1_error)
    #else
    __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_t_5); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 159, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_10;
    __pyx_v_idx = __pyx_t_9;
    __pyx_t_9 = (__pyx_t_9 + 1);

    /* "View.MemoryView":160
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim
 */
    __pyx_t_3 = (__pyx_v_dim <= 0);
    if (unlikely(__pyx_t_3)) {

      /* "View.MemoryView":161
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."             # <<<<<<<<<<<<<<
 *             self._shape[idx] = dim
 * 
 */
      __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_10 = 0;
      __pyx_t_11 = 127;
      __Pyx_INCREF(__pyx_kp_u_Invalid_shape_in_axis);
      __pyx_t_10 += 22;
      __Pyx_GIVEREF(__pyx_kp_u_Invalid_shape_in_axis);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_Invalid_shape_in_axis);
      __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_idx, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u_);
      __pyx_t_10 += 2;
      __Pyx_GIVEREF(__pyx_kp_u_);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_);
      __pyx_t_6 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u__2);
      __pyx_t_10 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__2);
      PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_kp_u__2);
      __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, __pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_6, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(1, 161, __pyx_L1_error)

      /* "View.MemoryView":160
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim
 */
    }

    /* "View.MemoryView":162
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim             # <<<<<<<<<<<<<<
 * 
 *         cdef char order
 */
    (__pyx_v_self->_shape[__pyx_v_idx]) = __pyx_v_dim;

    /* "View.MemoryView":159
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "View.MemoryView":165
 * 
 *         cdef char order
 *         if mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_c, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(1, 165, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "View.MemoryView":166
 *         cdef char order
 *         if mode == 'c':
 *             order = b'C'             # <<<<<<<<<<<<<<
 *             self.mode = u'c'
 *         elif mode == 'fortran':
 */
    __pyx_v_order = 'C';

    /* "View.MemoryView":167
 *         if mode == 'c':
 *             order = b'C'
 *             self.mode = u'c'             # <<<<<<<<<<<<<<
 *         elif mode == 'fortran':
 *             order = b'F'
 */
    __Pyx_INCREF(__pyx_n_u_c);
    __Pyx_GIVEREF(__pyx_n_u_c);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_c;

    /* "View.MemoryView":165
 * 
 *         cdef char order
 *         if mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":168
 *             order = b'C'
 *             self.mode = u'c'
 *         elif mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_fortran, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(1, 168, __pyx_L1_error)
  if (likely(__pyx_t_3)) {

    /* "View.MemoryView":169
 *             self.mode = u'c'
 *         elif mode == 'fortran':
 *             order = b'F'             # <<<<<<<<<<<<<<
 *             self.mode = u'fortran'
 *         else:
 */
    __pyx_v_order = 'F';

    /* "View.MemoryView":170
 *         elif mode == 'fortran':
 *             order = b'F'
 *             self.mode = u'fortran'             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"
 */
    __Pyx_INCREF(__pyx_n_u_fortran);
    __Pyx_GIVEREF(__pyx_n_u_fortran);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_fortran;

    /* "View.MemoryView":168
 *             order = b'C'
 *             self.mode = u'c'
 *         elif mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":172
 *             self.mode = u'fortran'
 *         else:
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"             # <<<<<<<<<<<<<<
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_mode, __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Invalid_mode_expected_c_or_fortr, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_6, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(1, 172, __pyx_L1_error)
  }
  __pyx_L11:;

  /* "View.MemoryView":174
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)             # <<<<<<<<<<<<<<
 * 
 *         self.free_data = allocate_buffer
 */
  __pyx_v_self->len = __pyx_fill_contig_strides_array(__pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_itemsize, __pyx_v_self->ndim, __pyx_v_order);

  /* "View.MemoryView":176
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)
 * 
 *         self.free_data = allocate_buffer             # <<<<<<<<<<<<<<
 *         self.dtype_is_object = format == b'O'
 * 
 */
  __pyx_v_self->free_data = __pyx_v_allocate_buffer;

  /* "View.MemoryView":177
 * 
 *         self.free_data = allocate_buffer
 *         self.dtype_is_object = format == b'O'             # <<<<<<<<<<<<<<
 * 
 *         if allocate_buffer:
 */
  __pyx_t_6 = PyObject_RichCompare(__pyx_v_format, __pyx_n_b_O, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 177, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_self->dtype_is_object = __pyx_t_3;

  /* "View.MemoryView":179
 *         self.dtype_is_object = format == b'O'
 * 
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 *             _allocate_buffer(self)
 * 
 */
  if (__pyx_v_allocate_buffer) {

    /* "View.MemoryView":180
 * 
 *         if allocate_buffer:
 *             _allocate_buffer(self)             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    __pyx_t_9 = __pyx_array_allocate_buffer(__pyx_v_self); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(1, 180, __pyx_L1_error)

    /* "View.MemoryView":179
 *         self.dtype_is_object = format == b'O'
 * 
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 *             _allocate_buffer(self)
 * 
 */
  }

  /* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_format);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":182
 *             _allocate_buffer(self)
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 */

/* Python wrapper */
CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(((struct __pyx_array_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_bufmode;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  char *__pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (unlikely(__pyx_v_info == NULL)) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":184
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1             # <<<<<<<<<<<<<<
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":
 */
  __pyx_v_bufmode = -1;

  /* "View.MemoryView":185
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):             # <<<<<<<<<<<<<<
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
  __pyx_t_1 = ((__pyx_v_flags & ((PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS) | PyBUF_ANY_CONTIGUOUS)) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":186
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 */
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_c, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 186, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "View.MemoryView":187
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
      __pyx_v_bufmode = (PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

      /* "View.MemoryView":186
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 */
      goto __pyx_L4;
    }

    /* "View.MemoryView":188
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 */
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_fortran, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 188, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "View.MemoryView":189
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 */
      __pyx_v_bufmode = (PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

      /* "View.MemoryView":188
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 */
    }
    __pyx_L4:;

    /* "View.MemoryView":190
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 */
    __pyx_t_1 = (!((__pyx_v_flags & __pyx_v_bufmode) != 0));
    if (unlikely(__pyx_t_1)) {

      /* "View.MemoryView":191
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."             # <<<<<<<<<<<<<<
 *         info.buf = self.data
 *         info.len = self.len
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Can_only_create_a_buffer_that_is, 0, 0);
      __PYX_ERR(1, 191, __pyx_L1_error)

      /* "View.MemoryView":190
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 */
    }

    /* "View.MemoryView":185
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):             # <<<<<<<<<<<<<<
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
  }

  /* "View.MemoryView":192
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data             # <<<<<<<<<<<<<<
 *         info.len = self.len
 * 
 */
  __pyx_t_2 = __pyx_v_self->data;
  __pyx_v_info->buf = __pyx_t_2;

  /* "View.MemoryView":193
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 *         info.len = self.len             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_STRIDES:
 */
  __pyx_t_3 = __pyx_v_self->len;
  __pyx_v_info->len = __pyx_t_3;

  /* "View.MemoryView":195
 *         info.len = self.len
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_STRIDES) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":196
 * 
 *         if flags & PyBUF_STRIDES:
 *             info.ndim = self.ndim             # <<<<<<<<<<<<<<
 *             info.shape = self._shape
 *             info.strides = self._strides
 */
    __pyx_t_4 = __pyx_v_self->ndim;
    __pyx_v_info->ndim = __pyx_t_4;

    /* "View.MemoryView":197
 *         if flags & PyBUF_STRIDES:
 *             info.ndim = self.ndim
 *             info.shape = self._shape             # <<<<<<<<<<<<<<
 *             info.strides = self._strides
 *         else:
 */
    __pyx_t_5 = __pyx_v_self->_shape;
    __pyx_v_info->shape = __pyx_t_5;

    /* "View.MemoryView":198
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 *             info.strides = self._strides             # <<<<<<<<<<<<<<
 *         else:
 *             info.ndim = 1
 */
    __pyx_t_5 = __pyx_v_self->_strides;
    __pyx_v_info->strides = __pyx_t_5;

    /* "View.MemoryView":195
 *         info.len = self.len
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 */
    goto __pyx_L6;
  }

  /* "View.MemoryView":200
 *             info.strides = self._strides
 *         else:
 *             info.ndim = 1             # <<<<<<<<<<<<<<
 *             info.shape = &self.len if flags & PyBUF_ND else NULL
 *             info.strides = NULL
 */
  /*else*/ {
    __pyx_v_info->ndim = 1;

    /* "View.MemoryView":201
 *         else:
 *             info.ndim = 1
 *             info.shape = &self.len if flags & PyBUF_ND else NULL             # <<<<<<<<<<<<<<
 *             info.strides = NULL
 * 
 */
    __pyx_t_1 = ((__pyx_v_flags & PyBUF_ND) != 0);
    if (__pyx_t_1) {
      __pyx_t_5 = (&__pyx_v_self->len);
    } else {
      __pyx_t_5 = NULL;
    }
    __pyx_v_info->shape = __pyx_t_5;

    /* "View.MemoryView":202
 *             info.ndim = 1
 *             info.shape = &self.len if flags & PyBUF_ND else NULL
 *             info.strides = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.suboffsets = NULL
 */
    __pyx_v_info->strides = NULL;
  }
  __pyx_L6:;

  /* "View.MemoryView":204
 *             info.strides = NULL
 * 
 *         info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *         info.itemsize = self.itemsize
 *         info.readonly = 0
 */
  __pyx_v_info->suboffsets = NULL;

  /* "View.MemoryView":205
 * 
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize             # <<<<<<<<<<<<<<
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 */
  __pyx_t_3 = __pyx_v_self->itemsize;
  __pyx_v_info->itemsize = __pyx_t_3;

  /* "View.MemoryView":206
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize
 *         info.readonly = 0             # <<<<<<<<<<<<<<
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 *         info.obj = self
 */
  __pyx_v_info->readonly = 0;

  /* "View.MemoryView":207
 *         info.itemsize = self.itemsize
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL             # <<<<<<<<<<<<<<
 *         info.obj = self
 * 
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {
    __pyx_t_2 = __pyx_v_self->format;
  } else {
    __pyx_t_2 = NULL;
  }
  __pyx_v_info->format = __pyx_t_2;

  /* "View.MemoryView":208
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(array self):
 */
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":182
 *             _allocate_buffer(self)
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":210
 *         info.obj = self
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

/* Python wrapper */
static void __pyx_array___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_array___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self) {
  int __pyx_t_1;
  int __pyx_t_2;

  /* "View.MemoryView":211
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 */
  __pyx_t_1 = (__pyx_v_self->callback_free_data != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":212
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)             # <<<<<<<<<<<<<<
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:
 */
    __pyx_v_self->callback_free_data(__pyx_v_self->data);

    /* "View.MemoryView":211
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":213
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 */
  if (__pyx_v_self->free_data) {
  } else {
    __pyx_t_1 = __pyx_v_self->free_data;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->data != NULL);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "View.MemoryView":214
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 */
    if (__pyx_v_self->dtype_is_object) {

      /* "View.MemoryView":215
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)             # <<<<<<<<<<<<<<
 *             free(self.data)
 *         PyObject_Free(self._shape)
 */
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_self->data, __pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_self->ndim, 0);

      /* "View.MemoryView":214
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 */
    }

    /* "View.MemoryView":216
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)             # <<<<<<<<<<<<<<
 *         PyObject_Free(self._shape)
 * 
 */
    free(__pyx_v_self->data);

    /* "View.MemoryView":213
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":217
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 *         PyObject_Free(self._shape)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  PyObject_Free(__pyx_v_self->_shape);

  /* "View.MemoryView":210
 *         info.obj = self
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

  /* function exit code */
}

/* "View.MemoryView":219
 *         PyObject_Free(self._shape)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def memview(self):
 *         return self.get_memview()
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_5array_7memview___get__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":221
 *     @property
 *     def memview(self):
 *         return self.get_memview()             # <<<<<<<<<<<<<<
 * 
 *     @cname('get_memview')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_array *)__pyx_v_self->__pyx_vtab)->get_memview(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":219
 *         PyObject_Free(self._shape)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def memview(self):
 *         return self.get_memview()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.memview.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":224
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self) {
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_memview", 1);

  /* "View.MemoryView":225
 *     @cname('get_memview')
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE             # <<<<<<<<<<<<<<
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 */
  __pyx_v_flags = ((PyBUF_ANY_CONTIGUOUS | PyBUF_FORMAT) | PyBUF_WRITABLE);

  /* "View.MemoryView":226
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(1, 226, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 226, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(1, 226, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":224
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.array.get_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":228
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "View.MemoryView":229
 * 
 *     def __len__(self):
 *         return self._shape[0]             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, attr):
 */
  __pyx_r = (__pyx_v_self->_shape[0]);
  goto __pyx_L0;

  /* "View.MemoryView":228
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":231
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr); /*proto*/
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_attr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 1);

  /* "View.MemoryView":232
 * 
 *     def __getattr__(self, attr):
 *         return getattr(self.memview, attr)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, item):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr(__pyx_t_1, __pyx_v_attr); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":231
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":234
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 1);

  /* "View.MemoryView":235
 * 
 *     def __getitem__(self, item):
 *         return self.memview[item]             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, item, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_item); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":234
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":237
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

/* Python wrapper */
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /*proto*/
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 1);

  /* "View.MemoryView":238
 * 
 *     def __setitem__(self, item, value):
 *         self.memview[item] = value             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_item, __pyx_v_value) < 0))) __PYX_ERR(1, 238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "View.MemoryView":237
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_array___reduce_cython__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.array.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_array_2__setstate_cython__(((struct __pyx_array_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":248
 * 
 * @cname("__pyx_array_allocate_buffer")
 * cdef int _allocate_buffer(array self) except -1:             # <<<<<<<<<<<<<<
 * 
 * 
 */

static int __pyx_array_allocate_buffer(struct __pyx_array_obj *__pyx_v_self) {
  Py_ssize_t __pyx_v_i;
  PyObject **__pyx_v_p;
  int __pyx_r;
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":254
 *     cdef PyObject **p
 * 
 *     self.free_data = True             # <<<<<<<<<<<<<<
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:
 */
  __pyx_v_self->free_data = 1;

  /* "View.MemoryView":255
 * 
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)             # <<<<<<<<<<<<<<
 *     if not self.data:
 *         raise MemoryError, "unable to allocate array data."
 */
  __pyx_v_self->data = ((char *)malloc(__pyx_v_self->len));

  /* "View.MemoryView":256
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:             # <<<<<<<<<<<<<<
 *         raise MemoryError, "unable to allocate array data."
 * 
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":257
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:
 *         raise MemoryError, "unable to allocate array data."             # <<<<<<<<<<<<<<
 * 
 *     if self.dtype_is_object:
 */
    __Pyx_Raise(__pyx_builtin_MemoryError, __pyx_kp_s_unable_to_allocate_array_data, 0, 0);
    __PYX_ERR(1, 257, __pyx_L1_error)

    /* "View.MemoryView":256
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:             # <<<<<<<<<<<<<<
 *         raise MemoryError, "unable to allocate array data."
 * 
 */
  }

  /* "View.MemoryView":259
 *         raise MemoryError, "unable to allocate array data."
 * 
 *     if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 */
  if (__pyx_v_self->dtype_is_object) {

    /* "View.MemoryView":260
 * 
 *     if self.dtype_is_object:
 *         p = <PyObject **> self.data             # <<<<<<<<<<<<<<
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None
 */
    __pyx_v_p = ((PyObject **)__pyx_v_self->data);

    /* "View.MemoryView":261
 *     if self.dtype_is_object:
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):             # <<<<<<<<<<<<<<
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)
 */
    if (unlikely(__pyx_v_self->itemsize == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(1, 261, __pyx_L1_error)
    }
    else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_self->itemsize == (Py_ssize_t)-1)  && unlikely(__Pyx_UNARY_NEG_WOULD_OVERFLOW(__pyx_v_self->len))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(1, 261, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_div_Py_ssize_t(__pyx_v_self->len, __pyx_v_self->itemsize);
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":262
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None             # <<<<<<<<<<<<<<
 *             Py_INCREF(Py_None)
 *     return 0
 */
      (__pyx_v_p[__pyx_v_i]) = Py_None;

      /* "View.MemoryView":263
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
      Py_INCREF(Py_None);
    }

    /* "View.MemoryView":259
 *         raise MemoryError, "unable to allocate array data."
 * 
 *     if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 */
  }

  /* "View.MemoryView":264
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":248
 * 
 * @cname("__pyx_array_allocate_buffer")
 * cdef int _allocate_buffer(array self) except -1:             # <<<<<<<<<<<<<<
 * 
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._allocate_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":268
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):             # <<<<<<<<<<<<<<
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 */

static struct __pyx_array_obj *__pyx_array_new(PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, char *__pyx_v_format, char *__pyx_v_c_mode, char *__pyx_v_buf) {
  struct __pyx_array_obj *__pyx_v_result = 0;
  PyObject *__pyx_v_mode = 0;
  struct __pyx_array_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("array_cwrapper", 1);

  /* "View.MemoryView":270
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.             # <<<<<<<<<<<<<<
 * 
 *     if buf is NULL:
 */
  __pyx_t_2 = ((__pyx_v_c_mode[0]) == 'f');
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_n_s_fortran);
    __pyx_t_1 = __pyx_n_s_fortran;
  } else {
    __Pyx_INCREF(__pyx_n_s_c);
    __pyx_t_1 = __pyx_n_s_c;
  }
  __pyx_v_mode = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":272
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 * 
 *     if buf is NULL:             # <<<<<<<<<<<<<<
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_buf == NULL);
  if (__pyx_t_2) {

    /* "View.MemoryView":273
 * 
 *     if buf is NULL:
 *         result = array.__new__(array, shape, itemsize, format, mode)             # <<<<<<<<<<<<<<
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)
 */
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape)) __PYX_ERR(1, 273, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 273, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_mode);
    __Pyx_GIVEREF(__pyx_v_mode);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_v_mode)) __PYX_ERR(1, 273, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = ((PyObject *)__pyx_tp_new_array(((PyTypeObject *)__pyx_array_type), __pyx_t_4, NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":272
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 * 
 *     if buf is NULL:             # <<<<<<<<<<<<<<
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":275
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)             # <<<<<<<<<<<<<<
 *         result.data = buf
 * 
 */
  /*else*/ {
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape)) __PYX_ERR(1, 275, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(1, 275, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4)) __PYX_ERR(1, 275, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_mode);
    __Pyx_GIVEREF(__pyx_v_mode);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_mode)) __PYX_ERR(1, 275, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_allocate_buffer, Py_False) < 0) __PYX_ERR(1, 275, __pyx_L1_error)
    __pyx_t_3 = ((PyObject *)__pyx_tp_new_array(((PyTypeObject *)__pyx_array_type), __pyx_t_1, __pyx_t_4)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":276
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)
 *         result.data = buf             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
    __pyx_v_result->data = __pyx_v_buf;
  }
  __pyx_L3:;

  /* "View.MemoryView":278
 *         result.data = buf
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":268
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):             # <<<<<<<<<<<<<<
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.array_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_mode);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":304
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

/* Python wrapper */
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 304, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(1, 304, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_name = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 304, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.Enum.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), __pyx_v_name);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "View.MemoryView":305
 *     cdef object name
 *     def __init__(self, name):
 *         self.name = name             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return self.name
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_name;

  /* "View.MemoryView":304
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":306
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "View.MemoryView":307
 *         self.name = name
 *     def __repr__(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* "View.MemoryView":306
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_MemviewEnum___reduce_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.name,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->name)) __PYX_ERR(1, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.name is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->name != Py_None);
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_136983863);
    __Pyx_GIVEREF(__pyx_int_136983863);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_136983863)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_136983863);
    __Pyx_GIVEREF(__pyx_int_136983863);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_136983863)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.Enum.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.Enum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_MemviewEnum_2__setstate_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_unpickle_Enum__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.Enum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":349
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

/* Python wrapper */
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_obj = 0;
  int __pyx_v_flags;
  int __pyx_v_dtype_is_object;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,&__pyx_n_s_flags,&__pyx_n_s_dtype_is_object,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flags)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(1, 349, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtype_is_object);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(1, 349, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_obj = values[0];
    __pyx_v_flags = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_dtype_is_object = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_dtype_is_object == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
    } else {
      __pyx_v_dtype_is_object = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, __pyx_nargs); __PYX_ERR(1, 349, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_obj, __pyx_v_flags, __pyx_v_dtype_is_object);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_intptr_t __pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "View.MemoryView":350
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj             # <<<<<<<<<<<<<<
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 */
  __Pyx_INCREF(__pyx_v_obj);
  __Pyx_GIVEREF(__pyx_v_obj);
  __Pyx_GOTREF(__pyx_v_self->obj);
  __Pyx_DECREF(__pyx_v_self->obj);
  __pyx_v_self->obj = __pyx_v_obj;

  /* "View.MemoryView":351
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj
 *         self.flags = flags             # <<<<<<<<<<<<<<
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 */
  __pyx_v_self->flags = __pyx_v_flags;

  /* "View.MemoryView":352
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  __pyx_t_2 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_memoryview_type));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_obj != Py_None);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "View.MemoryView":353
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)             # <<<<<<<<<<<<<<
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 */
    __pyx_t_3 = __Pyx_GetBuffer(__pyx_v_obj, (&__pyx_v_self->view), __pyx_v_flags); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 353, __pyx_L1_error)

    /* "View.MemoryView":354
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->view.obj) == NULL);
    if (__pyx_t_1) {

      /* "View.MemoryView":355
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None             # <<<<<<<<<<<<<<
 *                 Py_INCREF(Py_None)
 * 
 */
      ((Py_buffer *)(&__pyx_v_self->view))->obj = Py_None;

      /* "View.MemoryView":356
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 */
      Py_INCREF(Py_None);

      /* "View.MemoryView":354
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    }

    /* "View.MemoryView":352
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  }

  /* "View.MemoryView":358
 *                 Py_INCREF(Py_None)
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():             # <<<<<<<<<<<<<<
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 */
  __pyx_t_1 = (!__PYX_CYTHON_ATOMICS_ENABLED());
  if (__pyx_t_1) {

    /* "View.MemoryView":360
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:             # <<<<<<<<<<<<<<
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 */
    __pyx_t_1 = (__pyx_memoryview_thread_locks_used < 8);
    if (__pyx_t_1) {

      /* "View.MemoryView":361
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]             # <<<<<<<<<<<<<<
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:
 */
      __pyx_v_self->lock = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);

      /* "View.MemoryView":362
 *             if __pyx_memoryview_thread_locks_used < 8:
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1             # <<<<<<<<<<<<<<
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 */
      __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used + 1);

      /* "View.MemoryView":360
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:             # <<<<<<<<<<<<<<
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 */
    }

    /* "View.MemoryView":363
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 */
    __pyx_t_1 = (__pyx_v_self->lock == NULL);
    if (__pyx_t_1) {

      /* "View.MemoryView":364
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()             # <<<<<<<<<<<<<<
 *                 if self.lock is NULL:
 *                     raise MemoryError
 */
      __pyx_v_self->lock = PyThread_allocate_lock();

      /* "View.MemoryView":365
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 * 
 */
      __pyx_t_1 = (__pyx_v_self->lock == NULL);
      if (unlikely(__pyx_t_1)) {

        /* "View.MemoryView":366
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
        PyErr_NoMemory(); __PYX_ERR(1, 366, __pyx_L1_error)

        /* "View.MemoryView":365
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 * 
 */
      }

      /* "View.MemoryView":363
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 */
    }

    /* "View.MemoryView":358
 *                 Py_INCREF(Py_None)
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():             # <<<<<<<<<<<<<<
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 */
  }

  /* "View.MemoryView":368
 *                     raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":369
 * 
 *         if flags & PyBUF_FORMAT:
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')             # <<<<<<<<<<<<<<
 *         else:
 *             self.dtype_is_object = dtype_is_object
 */
    __pyx_t_2 = ((__pyx_v_self->view.format[0]) == 'O');
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_2 = ((__pyx_v_self->view.format[1]) == '\x00');
    __pyx_t_1 = __pyx_t_2;
    __pyx_L12_bool_binop_done:;
    __pyx_v_self->dtype_is_object = __pyx_t_1;

    /* "View.MemoryView":368
 *                     raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":371
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 *             self.dtype_is_object = dtype_is_object             # <<<<<<<<<<<<<<
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0
 */
  /*else*/ {
    __pyx_v_self->dtype_is_object = __pyx_v_dtype_is_object;
  }
  __pyx_L11:;

  /* "View.MemoryView":373
 *             self.dtype_is_object = dtype_is_object
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0             # <<<<<<<<<<<<<<
 *         self.typeinfo = NULL
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_4 = ((Py_intptr_t)((void *)(&__pyx_v_self->acquisition_count)));
    __pyx_t_5 = (sizeof(__pyx_atomic_int_type));
    if (unlikely(__pyx_t_5 == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(1, 373, __pyx_L1_error)
    }
    __pyx_t_1 = ((__pyx_t_4 % __pyx_t_5) == 0);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(1, 373, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(1, 373, __pyx_L1_error)
  #endif

  /* "View.MemoryView":374
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0
 *         self.typeinfo = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(memoryview self):
 */
  __pyx_v_self->typeinfo = NULL;

  /* "View.MemoryView":349
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":376
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

/* Python wrapper */
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self) {
  int __pyx_v_i;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyThread_type_lock __pyx_t_5;
  PyThread_type_lock __pyx_t_6;

  /* "View.MemoryView":377
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
  __pyx_t_1 = (__pyx_v_self->obj != Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":378
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)             # <<<<<<<<<<<<<<
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 */
    __Pyx_ReleaseBuffer((&__pyx_v_self->view));

    /* "View.MemoryView":377
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":379
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  __pyx_t_1 = (((Py_buffer *)(&__pyx_v_self->view))->obj == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":381
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL             # <<<<<<<<<<<<<<
 *             Py_DECREF(Py_None)
 * 
 */
    ((Py_buffer *)(&__pyx_v_self->view))->obj = NULL;

    /* "View.MemoryView":382
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 *             Py_DECREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         cdef int i
 */
    Py_DECREF(Py_None);

    /* "View.MemoryView":379
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":386
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  __pyx_t_1 = (__pyx_v_self->lock != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":387
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):             # <<<<<<<<<<<<<<
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 */
    __pyx_t_2 = __pyx_memoryview_thread_locks_used;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":388
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      __pyx_t_1 = ((__pyx_memoryview_thread_locks[__pyx_v_i]) == __pyx_v_self->lock);
      if (__pyx_t_1) {

        /* "View.MemoryView":389
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1             # <<<<<<<<<<<<<<
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 */
        __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used - 1);

        /* "View.MemoryView":390
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        __pyx_t_1 = (__pyx_v_i != __pyx_memoryview_thread_locks_used);
        if (__pyx_t_1) {

          /* "View.MemoryView":392
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])             # <<<<<<<<<<<<<<
 *                     break
 *             else:
 */
          __pyx_t_5 = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);
          __pyx_t_6 = (__pyx_memoryview_thread_locks[__pyx_v_i]);

          /* "View.MemoryView":391
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (             # <<<<<<<<<<<<<<
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break
 */
          (__pyx_memoryview_thread_locks[__pyx_v_i]) = __pyx_t_5;
          (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]) = __pyx_t_6;

          /* "View.MemoryView":390
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        }

        /* "View.MemoryView":393
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break             # <<<<<<<<<<<<<<
 *             else:
 *                 PyThread_free_lock(self.lock)
 */
        goto __pyx_L6_break;

        /* "View.MemoryView":388
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      }
    }
    /*else*/ {

      /* "View.MemoryView":395
 *                     break
 *             else:
 *                 PyThread_free_lock(self.lock)             # <<<<<<<<<<<<<<
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 */
      PyThread_free_lock(__pyx_v_self->lock);
    }
    __pyx_L6_break:;

    /* "View.MemoryView":386
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  }

  /* "View.MemoryView":376
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

  /* function exit code */
}

/* "View.MemoryView":397
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  Py_ssize_t __pyx_v_dim;
  char *__pyx_v_itemp;
  PyObject *__pyx_v_idx = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item_pointer", 1);

  /* "View.MemoryView":399
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf             # <<<<<<<<<<<<<<
 * 
 *         for dim, idx in enumerate(index):
 */
  __pyx_v_itemp = ((char *)__pyx_v_self->view.buf);

  /* "View.MemoryView":401
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_v_index)) || PyTuple_CheckExact(__pyx_v_index)) {
    __pyx_t_2 = __pyx_v_index; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 401, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 401, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_idx, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_1;
    __pyx_t_1 = (__pyx_t_1 + 1);

    /* "View.MemoryView":402
 * 
 *         for dim, idx in enumerate(index):
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)             # <<<<<<<<<<<<<<
 * 
 *         return itemp
 */
    __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_v_idx); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 402, __pyx_L1_error)
    __pyx_t_7 = __pyx_pybuffer_index((&__pyx_v_self->view), __pyx_v_itemp, __pyx_t_6, __pyx_v_dim); if (unlikely(__pyx_t_7 == ((char *)NULL))) __PYX_ERR(1, 402, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_7;

    /* "View.MemoryView":401
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":404
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 *         return itemp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_itemp;
  goto __pyx_L0;

  /* "View.MemoryView":397
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.get_item_pointer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":407
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_indices = NULL;
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 1);

  /* "View.MemoryView":408
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  __pyx_t_1 = (__pyx_v_index == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "View.MemoryView":409
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:
 *             return self             # <<<<<<<<<<<<<<
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_self);
    __pyx_r = ((PyObject *)__pyx_v_self);
    goto __pyx_L0;

    /* "View.MemoryView":408
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  }

  /* "View.MemoryView":411
 *             return self
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *itemp
 */
  __pyx_t_2 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(__pyx_t_2 != Py_None)) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(1, 411, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(1, 411, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_indices = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "View.MemoryView":414
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 414, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "View.MemoryView":415
 *         cdef char *itemp
 *         if have_slices:
 *             return memview_slice(self, indices)             # <<<<<<<<<<<<<<
 *         else:
 *             itemp = self.get_item_pointer(indices)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_memview_slice(__pyx_v_self, __pyx_v_indices)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":414
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  }

  /* "View.MemoryView":417
 *             return memview_slice(self, indices)
 *         else:
 *             itemp = self.get_item_pointer(indices)             # <<<<<<<<<<<<<<
 *             return self.convert_item_to_object(itemp)
 * 
 */
  /*else*/ {
    __pyx_t_5 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_indices); if (unlikely(__pyx_t_5 == ((char *)NULL))) __PYX_ERR(1, 417, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_5;

    /* "View.MemoryView":418
 *         else:
 *             itemp = self.get_item_pointer(indices)
 *             return self.convert_item_to_object(itemp)             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(memoryview self, object index, object value):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->convert_item_to_object(__pyx_v_self, __pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":407
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_indices);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":420
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"
 */

/* Python wrapper */
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /*proto*/
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_obj = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);
  __Pyx_INCREF(__pyx_v_index);

  /* "View.MemoryView":421
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 */
  if (unlikely(__pyx_v_self->view.readonly)) {

    /* "View.MemoryView":422
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"             # <<<<<<<<<<<<<<
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 */
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_Cannot_assign_to_read_only_memor, 0, 0);
    __PYX_ERR(1, 422, __pyx_L1_error)

    /* "View.MemoryView":421
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 */
  }

  /* "View.MemoryView":424
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         if have_slices:
 */
  __pyx_t_1 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(1, 424, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(1, 424, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_2;
  __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "View.MemoryView":426
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj is not None:
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(1, 426, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "View.MemoryView":427
 * 
 *         if have_slices:
 *             obj = self.is_slice(value)             # <<<<<<<<<<<<<<
 *             if obj is not None:
 *                 self.setitem_slice_assignment(self[index], obj)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->is_slice(__pyx_v_self, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_obj = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "View.MemoryView":428
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj is not None:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
    __pyx_t_4 = (__pyx_v_obj != Py_None);
    if (__pyx_t_4) {

      /* "View.MemoryView":429
 *             obj = self.is_slice(value)
 *             if obj is not None:
 *                 self.setitem_slice_assignment(self[index], obj)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)
 */
      __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assignment(__pyx_v_self, __pyx_t_1, __pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "View.MemoryView":428
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj is not None:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":431
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)             # <<<<<<<<<<<<<<
 *         else:
 *             self.setitem_indexed(index, value)
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_memoryview_type))))) __PYX_ERR(1, 431, __pyx_L1_error)
      __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assign_scalar(__pyx_v_self, ((struct __pyx_memoryview_obj *)__pyx_t_3), __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "View.MemoryView":426
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj is not None:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":433
 *                 self.setitem_slice_assign_scalar(self[index], value)
 *         else:
 *             self.setitem_indexed(index, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef is_slice(self, obj):
 */
  /*else*/ {
    __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_indexed(__pyx_v_self, __pyx_v_index, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "View.MemoryView":420
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":435
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_slice", 0);
  __Pyx_INCREF(__pyx_v_obj);

  /* "View.MemoryView":436
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_memoryview_type); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "View.MemoryView":438
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_6 = __Pyx_PyInt_From_int(((__pyx_v_self->flags & (~PyBUF_WRITABLE)) | PyBUF_ANY_CONTIGUOUS)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);

        /* "View.MemoryView":439
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 return None
 */
        __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 439, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "View.MemoryView":438
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_obj)) __PYX_ERR(1, 438, __pyx_L4_error);
        __Pyx_GIVEREF(__pyx_t_6);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_6)) __PYX_ERR(1, 438, __pyx_L4_error);
        __Pyx_GIVEREF(__pyx_t_7);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_7)) __PYX_ERR(1, 438, __pyx_L4_error);
        __pyx_t_6 = 0;
        __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "View.MemoryView":440
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 return None
 * 
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_6) < 0) __PYX_ERR(1, 440, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);

        /* "View.MemoryView":441
 *                                  self.dtype_is_object)
 *             except TypeError:
 *                 return None             # <<<<<<<<<<<<<<
 * 
 *         return obj
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_except_return;
      }
      goto __pyx_L6_except_error;

      /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L7_except_return:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L0;
      __pyx_L9_try_end:;
    }

    /* "View.MemoryView":436
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  }

  /* "View.MemoryView":443
 *                 return None
 * 
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assignment(self, dst, src):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "View.MemoryView":435
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":445
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src) {
  __Pyx_memviewslice __pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_src_slice;
  __Pyx_memviewslice __pyx_v_msrc;
  __Pyx_memviewslice __pyx_v_mdst;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assignment", 1);

  /* "View.MemoryView":448
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 *         cdef __Pyx_memviewslice msrc = get_slice_from_memview(src, &src_slice)[0]             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]
 * 
 */
  if (!(likely(((__pyx_v_src) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_src, __pyx_memoryview_type))))) __PYX_ERR(1, 448, __pyx_L1_error)
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_src), (&__pyx_v_src_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 448, __pyx_L1_error)
  __pyx_v_msrc = (__pyx_t_1[0]);

  /* "View.MemoryView":449
 *         cdef __Pyx_memviewslice src_slice
 *         cdef __Pyx_memviewslice msrc = get_slice_from_memview(src, &src_slice)[0]
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]             # <<<<<<<<<<<<<<
 * 
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 */
  if (!(likely(((__pyx_v_dst) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_dst, __pyx_memoryview_type))))) __PYX_ERR(1, 449, __pyx_L1_error)
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_dst), (&__pyx_v_dst_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 449, __pyx_L1_error)
  __pyx_v_mdst = (__pyx_t_1[0]);

  /* "View.MemoryView":451
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]
 * 
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_src, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_dst, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_memoryview_copy_contents(__pyx_v_msrc, __pyx_v_mdst, __pyx_t_3, __pyx_t_4, __pyx_v_self->dtype_is_object); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 451, __pyx_L1_error)

  /* "View.MemoryView":445
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":453
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value) {
  int __pyx_v_array[0x80];
  void *__pyx_v_tmp;
  void *__pyx_v_item;
  __Pyx_memviewslice *__pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_tmp_slice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  char const *__pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assign_scalar", 1);

  /* "View.MemoryView":455
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 *         cdef int array[128]
 *         cdef void *tmp = NULL             # <<<<<<<<<<<<<<
 *         cdef void *item
 * 
 */
  __pyx_v_tmp = NULL;

  /* "View.MemoryView":460
 *         cdef __Pyx_memviewslice *dst_slice
 *         cdef __Pyx_memviewslice tmp_slice
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)             # <<<<<<<<<<<<<<
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_dst, (&__pyx_v_tmp_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 460, __pyx_L1_error)
  __pyx_v_dst_slice = __pyx_t_1;

  /* "View.MemoryView":462
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
  __pyx_t_2 = (((size_t)__pyx_v_self->view.itemsize) > (sizeof(__pyx_v_array)));
  if (__pyx_t_2) {

    /* "View.MemoryView":463
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)             # <<<<<<<<<<<<<<
 *             if tmp == NULL:
 *                 raise MemoryError
 */
    __pyx_v_tmp = PyMem_Malloc(__pyx_v_self->view.itemsize);

    /* "View.MemoryView":464
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    __pyx_t_2 = (__pyx_v_tmp == NULL);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":465
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             item = tmp
 *         else:
 */
      PyErr_NoMemory(); __PYX_ERR(1, 465, __pyx_L1_error)

      /* "View.MemoryView":464
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    }

    /* "View.MemoryView":466
 *             if tmp == NULL:
 *                 raise MemoryError
 *             item = tmp             # <<<<<<<<<<<<<<
 *         else:
 *             item = <void *> array
 */
    __pyx_v_item = __pyx_v_tmp;

    /* "View.MemoryView":462
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":468
 *             item = tmp
 *         else:
 *             item = <void *> array             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  /*else*/ {
    __pyx_v_item = ((void *)__pyx_v_array);
  }
  __pyx_L3:;

  /* "View.MemoryView":470
 *             item = <void *> array
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value
 */
  /*try:*/ {

    /* "View.MemoryView":471
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
    if (__pyx_v_self->dtype_is_object) {

      /* "View.MemoryView":472
 *         try:
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value             # <<<<<<<<<<<<<<
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)
 */
      (((PyObject **)__pyx_v_item)[0]) = ((PyObject *)__pyx_v_value);

      /* "View.MemoryView":471
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
      goto __pyx_L8;
    }

    /* "View.MemoryView":474
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, ((char *)__pyx_v_item), __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 474, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L8:;

    /* "View.MemoryView":478
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    __pyx_t_2 = (__pyx_v_self->view.suboffsets != NULL);
    if (__pyx_t_2) {

      /* "View.MemoryView":479
 * 
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)             # <<<<<<<<<<<<<<
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 *                                 item, self.dtype_is_object)
 */
      __pyx_t_4 = assert_direct_dimensions(__pyx_v_self->view.suboffsets, __pyx_v_self->view.ndim); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 479, __pyx_L6_error)

      /* "View.MemoryView":478
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    }

    /* "View.MemoryView":480
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,             # <<<<<<<<<<<<<<
 *                                 item, self.dtype_is_object)
 *         finally:
 */
    __pyx_memoryview_slice_assign_scalar(__pyx_v_dst_slice, __pyx_v_dst->view.ndim, __pyx_v_self->view.itemsize, __pyx_v_item, __pyx_v_self->dtype_is_object);
  }

  /* "View.MemoryView":483
 *                                 item, self.dtype_is_object)
 *         finally:
 *             PyMem_Free(tmp)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_indexed(self, index, value):
 */
  /*finally:*/ {
    /*normal exit:*/{
      PyMem_Free(__pyx_v_tmp);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __pyx_t_4 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_6 = __pyx_filename;
      {
        PyMem_Free(__pyx_v_tmp);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_6;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "View.MemoryView":453
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assign_scalar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":485
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_indexed", 1);

  /* "View.MemoryView":486
 * 
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)             # <<<<<<<<<<<<<<
 *         self.assign_item_from_object(itemp, value)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_index); if (unlikely(__pyx_t_1 == ((char *)NULL))) __PYX_ERR(1, 486, __pyx_L1_error)
  __pyx_v_itemp = __pyx_t_1;

  /* "View.MemoryView":487
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":485
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_indexed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":489
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_v_struct = NULL;
  PyObject *__pyx_v_bytesitem = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 1);

  /* "View.MemoryView":492
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef bytes bytesitem
 * 
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_struct, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":495
 *         cdef bytes bytesitem
 * 
 *         bytesitem = itemp[:self.view.itemsize]             # <<<<<<<<<<<<<<
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 */
  __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_itemp + 0, __pyx_v_self->view.itemsize - 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bytesitem = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "View.MemoryView":497
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)             # <<<<<<<<<<<<<<
 *         except struct.error:
 *             raise ValueError, "Unable to convert item to object"
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_unpack); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 497, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 497, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_6, __pyx_v_bytesitem};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 497, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    }

    /* "View.MemoryView":501
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
    /*else:*/ {
      __pyx_t_9 = __Pyx_ssize_strlen(__pyx_v_self->view.format); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(1, 501, __pyx_L5_except_error)
      __pyx_t_10 = (__pyx_t_9 == 1);
      if (__pyx_t_10) {

        /* "View.MemoryView":502
 *         else:
 *             if len(self.view.format) == 1:
 *                 return result[0]             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_result, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 502, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_r = __pyx_t_1;
        __pyx_t_1 = 0;
        goto __pyx_L6_except_return;

        /* "View.MemoryView":501
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
      }

      /* "View.MemoryView":503
 *             if len(self.view.format) == 1:
 *                 return result[0]
 *             return result             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_result);
      __pyx_r = __pyx_v_result;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":498
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 */
    __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_error); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 498, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_11 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_ErrRestore(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    __pyx_t_1 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0;
    if (__pyx_t_11) {
      __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(1, 498, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "View.MemoryView":499
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 *             raise ValueError, "Unable to convert item to object"             # <<<<<<<<<<<<<<
 *         else:
 *             if len(self.view.format) == 1:
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Unable_to_convert_item_to_object, 0, 0);
      __PYX_ERR(1, 499, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "View.MemoryView":489
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesitem);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":505
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_struct = NULL;
  char __pyx_v_c;
  PyObject *__pyx_v_bytesvalue = 0;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  char *__pyx_t_10;
  char *__pyx_t_11;
  char *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 1);

  /* "View.MemoryView":508
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef char c
 *         cdef bytes bytesvalue
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_struct, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":513
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_value); 
  if (__pyx_t_2) {

    /* "View.MemoryView":514
 * 
 *         if isinstance(value, tuple):
 *             bytesvalue = struct.pack(self.view.format, *value)             # <<<<<<<<<<<<<<
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(1, 514, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":513
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":516
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)             # <<<<<<<<<<<<<<
 * 
 *         for i, c in enumerate(bytesvalue):
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_1, __pyx_v_value};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(1, 516, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":518
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
  __pyx_t_7 = 0;
  if (unlikely(__pyx_v_bytesvalue == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' is not iterable");
    __PYX_ERR(1, 518, __pyx_L1_error)
  }
  __Pyx_INCREF(__pyx_v_bytesvalue);
  __pyx_t_8 = __pyx_v_bytesvalue;
  __pyx_t_10 = PyBytes_AS_STRING(__pyx_t_8);
  __pyx_t_11 = (__pyx_t_10 + PyBytes_GET_SIZE(__pyx_t_8));
  for (__pyx_t_12 = __pyx_t_10; __pyx_t_12 < __pyx_t_11; __pyx_t_12++) {
    __pyx_t_9 = __pyx_t_12;
    __pyx_v_c = (__pyx_t_9[0]);

    /* "View.MemoryView":519
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    __pyx_v_i = __pyx_t_7;

    /* "View.MemoryView":518
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
    __pyx_t_7 = (__pyx_t_7 + 1);

    /* "View.MemoryView":519
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    (__pyx_v_itemp[__pyx_v_i]) = __pyx_v_c;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "View.MemoryView":505
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memoryview.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":521
 *             itemp[i] = c
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 */

/* Python wrapper */
CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  char *__pyx_t_4;
  void *__pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (unlikely(__pyx_v_info == NULL)) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":523
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 */
  __pyx_t_2 = ((__pyx_v_flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __pyx_v_self->view.readonly;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":524
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_ND:
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Cannot_create_writable_memory_vi, 0, 0);
    __PYX_ERR(1, 524, __pyx_L1_error)

    /* "View.MemoryView":523
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 */
  }

  /* "View.MemoryView":526
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_ND) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":527
 * 
 *         if flags & PyBUF_ND:
 *             info.shape = self.view.shape             # <<<<<<<<<<<<<<
 *         else:
 *             info.shape = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.shape;
    __pyx_v_info->shape = __pyx_t_3;

    /* "View.MemoryView":526
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
    goto __pyx_L6;
  }

  /* "View.MemoryView":529
 *             info.shape = self.view.shape
 *         else:
 *             info.shape = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_STRIDES:
 */
  /*else*/ {
    __pyx_v_info->shape = NULL;
  }
  __pyx_L6:;

  /* "View.MemoryView":531
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_STRIDES) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":532
 * 
 *         if flags & PyBUF_STRIDES:
 *             info.strides = self.view.strides             # <<<<<<<<<<<<<<
 *         else:
 *             info.strides = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.strides;
    __pyx_v_info->strides = __pyx_t_3;

    /* "View.MemoryView":531
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
    goto __pyx_L7;
  }

  /* "View.MemoryView":534
 *             info.strides = self.view.strides
 *         else:
 *             info.strides = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_INDIRECT:
 */
  /*else*/ {
    __pyx_v_info->strides = NULL;
  }
  __pyx_L7:;

  /* "View.MemoryView":536
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_INDIRECT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":537
 * 
 *         if flags & PyBUF_INDIRECT:
 *             info.suboffsets = self.view.suboffsets             # <<<<<<<<<<<<<<
 *         else:
 *             info.suboffsets = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.suboffsets;
    __pyx_v_info->suboffsets = __pyx_t_3;

    /* "View.MemoryView":536
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
    goto __pyx_L8;
  }

  /* "View.MemoryView":539
 *             info.suboffsets = self.view.suboffsets
 *         else:
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
  /*else*/ {
    __pyx_v_info->suboffsets = NULL;
  }
  __pyx_L8:;

  /* "View.MemoryView":541
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":542
 * 
 *         if flags & PyBUF_FORMAT:
 *             info.format = self.view.format             # <<<<<<<<<<<<<<
 *         else:
 *             info.format = NULL
 */
    __pyx_t_4 = __pyx_v_self->view.format;
    __pyx_v_info->format = __pyx_t_4;

    /* "View.MemoryView":541
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":544
 *             info.format = self.view.format
 *         else:
 *             info.format = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.buf = self.view.buf
 */
  /*else*/ {
    __pyx_v_info->format = NULL;
  }
  __pyx_L9:;

  /* "View.MemoryView":546
 *             info.format = NULL
 * 
 *         info.buf = self.view.buf             # <<<<<<<<<<<<<<
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 */
  __pyx_t_5 = __pyx_v_self->view.buf;
  __pyx_v_info->buf = __pyx_t_5;

  /* "View.MemoryView":547
 * 
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim             # <<<<<<<<<<<<<<
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 */
  __pyx_t_6 = __pyx_v_self->view.ndim;
  __pyx_v_info->ndim = __pyx_t_6;

  /* "View.MemoryView":548
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize             # <<<<<<<<<<<<<<
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 */
  __pyx_t_7 = __pyx_v_self->view.itemsize;
  __pyx_v_info->itemsize = __pyx_t_7;

  /* "View.MemoryView":549
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len             # <<<<<<<<<<<<<<
 *         info.readonly = self.view.readonly
 *         info.obj = self
 */
  __pyx_t_7 = __pyx_v_self->view.len;
  __pyx_v_info->len = __pyx_t_7;

  /* "View.MemoryView":550
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly             # <<<<<<<<<<<<<<
 *         info.obj = self
 * 
 */
  __pyx_t_1 = __pyx_v_self->view.readonly;
  __pyx_v_info->readonly = __pyx_t_1;

  /* "View.MemoryView":551
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":521
 *             itemp[i] = c
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":554
 * 
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":556
 *     @property
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&result.from_slice)
 *         return result
 */
  __pyx_t_1 = __pyx_memoryview_copy_object(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_memoryviewslice_type))))) __PYX_ERR(1, 556, __pyx_L1_error)
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":557
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_2 = __pyx_memslice_transpose((&__pyx_v_result->from_slice)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(1, 557, __pyx_L1_error)

  /* "View.MemoryView":558
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":554
 * 
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.T.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":560
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         return self._get_base()
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":562
 *     @property
 *     def base(self):
 *         return self._get_base()             # <<<<<<<<<<<<<<
 * 
 *     cdef _get_base(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->_get_base(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":560
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         return self._get_base()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.base.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":564
 *         return self._get_base()
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

static PyObject *__pyx_memoryview__get_base(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_base", 1);

  /* "View.MemoryView":565
 * 
 *     cdef _get_base(self):
 *         return self.obj             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->obj);
  __pyx_r = __pyx_v_self->obj;
  goto __pyx_L0;

  /* "View.MemoryView":564
 *         return self._get_base()
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":567
 *         return self.obj
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_7genexpr__pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":569
 *     @property
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
    for (__pyx_t_4 = __pyx_v_self->view.shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
      __pyx_t_2 = __pyx_t_4;
      __pyx_7genexpr__pyx_v_length = (__pyx_t_2[0]);
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_7genexpr__pyx_v_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(1, 569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  } /* exit inner scope */
  __pyx_t_5 = PyList_AsTuple(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":567
 *         return self.obj
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.shape.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":571
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def strides(self):
 *         if self.view.strides == NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_8genexpr1__pyx_v_stride;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":573
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError, "Buffer view does not expose strides"
 */
  __pyx_t_1 = (__pyx_v_self->view.strides == NULL);
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":575
 *         if self.view.strides == NULL:
 * 
 *             raise ValueError, "Buffer view does not expose strides"             # <<<<<<<<<<<<<<
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Buffer_view_does_not_expose_stri, 0, 0);
    __PYX_ERR(1, 575, __pyx_L1_error)

    /* "View.MemoryView":573
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError, "Buffer view does not expose strides"
 */
  }

  /* "View.MemoryView":577
 *             raise ValueError, "Buffer view does not expose strides"
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__pyx_v_self->view.strides + __pyx_v_self->view.ndim);
    for (__pyx_t_5 = __pyx_v_self->view.strides; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
      __pyx_t_3 = __pyx_t_5;
      __pyx_8genexpr1__pyx_v_stride = (__pyx_t_3[0]);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_8genexpr1__pyx_v_stride); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(1, 577, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  } /* exit inner scope */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":571
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def strides(self):
 *         if self.view.strides == NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.strides.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":579
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_8genexpr2__pyx_v_suboffset;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":581
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  __pyx_t_1 = (__pyx_v_self->view.suboffsets == NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":582
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PySequence_Multiply(__pyx_tuple__4, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":581
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  }

  /* "View.MemoryView":584
 *             return (-1,) * self.view.ndim
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__pyx_v_self->view.suboffsets + __pyx_v_self->view.ndim);
    for (__pyx_t_5 = __pyx_v_self->view.suboffsets; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
      __pyx_t_3 = __pyx_t_5;
      __pyx_8genexpr2__pyx_v_suboffset = (__pyx_t_3[0]);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_8genexpr2__pyx_v_suboffset); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(1, 584, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  } /* exit inner scope */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":579
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.suboffsets.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":586
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ndim(self):
 *         return self.view.ndim
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":588
 *     @property
 *     def ndim(self):
 *         return self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->view.ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":586
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ndim(self):
 *         return self.view.ndim
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.ndim.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":590
 *         return self.view.ndim
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def itemsize(self):
 *         return self.view.itemsize
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":592
 *     @property
 *     def itemsize(self):
 *         return self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":590
 *         return self.view.ndim
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def itemsize(self):
 *         return self.view.itemsize
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.itemsize.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":594
 *         return self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nbytes(self):
 *         return self.size * self.view.itemsize
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":596
 *     @property
 *     def nbytes(self):
 *         return self.size * self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":594
 *         return self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nbytes(self):
 *         return self.size * self.view.itemsize
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.nbytes.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":598
 *         return self.size * self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def size(self):
 *         if self._size is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":600
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_size == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":601
 *     def size(self):
 *         if self._size is None:
 *             result = 1             # <<<<<<<<<<<<<<
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 */
    __Pyx_INCREF(__pyx_int_1);
    __pyx_v_result = __pyx_int_1;

    /* "View.MemoryView":603
 *             result = 1
 * 
 *             for length in self.view.shape[:self.view.ndim]:             # <<<<<<<<<<<<<<
 *                 result *= length
 * 
 */
    __pyx_t_3 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
    for (__pyx_t_4 = __pyx_v_self->view.shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
      __pyx_t_2 = __pyx_t_4;
      __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_2[0])); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "View.MemoryView":604
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 *                 result *= length             # <<<<<<<<<<<<<<
 * 
 *             self._size = result
 */
      __pyx_t_5 = PyNumber_InPlaceMultiply(__pyx_v_result, __pyx_v_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_5);
      __pyx_t_5 = 0;
    }

    /* "View.MemoryView":606
 *                 result *= length
 * 
 *             self._size = result             # <<<<<<<<<<<<<<
 * 
 *         return self._size
 */
    __Pyx_INCREF(__pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    __Pyx_GOTREF(__pyx_v_self->_size);
    __Pyx_DECREF(__pyx_v_self->_size);
    __pyx_v_self->_size = __pyx_v_result;

    /* "View.MemoryView":600
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  }

  /* "View.MemoryView":608
 *             self._size = result
 * 
 *         return self._size             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_size);
  __pyx_r = __pyx_v_self->_size;
  goto __pyx_L0;

  /* "View.MemoryView":598
 *         return self.size * self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def size(self):
 *         if self._size is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":610
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

/* Python wrapper */
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  int __pyx_t_1;

  /* "View.MemoryView":611
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  __pyx_t_1 = (__pyx_v_self->view.ndim >= 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":612
 *     def __len__(self):
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_r = (__pyx_v_self->view.shape[0]);
    goto __pyx_L0;

    /* "View.MemoryView":611
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  }

  /* "View.MemoryView":614
 *             return self.view.shape[0]
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":610
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":616
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "View.MemoryView":617
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":618
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "View.MemoryView":617
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(1, 617, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2)) __PYX_ERR(1, 617, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":616
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":620
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "View.MemoryView":621
 * 
 *     def __str__(self):
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_object, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":620
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":624
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_c_contig (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_c_contig", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_c_contig", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_c_contig", 1);

  /* "View.MemoryView":627
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 627, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":628
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def is_f_contig(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'C', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":624
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_c_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":630
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_f_contig (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_f_contig", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_f_contig", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_f_contig", 1);

  /* "View.MemoryView":633
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 633, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":634
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'F', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":630
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_f_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":636
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("copy", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_mslice;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "View.MemoryView":638
 *     def copy(self):
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &mslice)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_F_CONTIGUOUS));

  /* "View.MemoryView":640
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 * 
 *         slice_copy(self, &mslice)             # <<<<<<<<<<<<<<
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,
 *                                    self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_mslice));

  /* "View.MemoryView":641
 * 
 *         slice_copy(self, &mslice)
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                    self.view.itemsize,
 *                                    flags|PyBUF_C_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_mslice), ((char *)"c"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_C_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 641, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":646
 *                                    self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &mslice)             # <<<<<<<<<<<<<<
 * 
 *     def copy_fortran(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_mslice)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":636
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":648
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy_fortran (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("copy_fortran", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy_fortran", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_fortran", 1);

  /* "View.MemoryView":650
 *     def copy_fortran(self):
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &src)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_C_CONTIGUOUS));

  /* "View.MemoryView":652
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 * 
 *         slice_copy(self, &src)             # <<<<<<<<<<<<<<
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,
 *                                 self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_src));

  /* "View.MemoryView":653
 * 
 *         slice_copy(self, &src)
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                 self.view.itemsize,
 *                                 flags|PyBUF_F_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_src), ((char *)"fortran"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_F_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 653, __pyx_L1_error)
  __pyx_v_dst = __pyx_t_1;

  /* "View.MemoryView":658
 *                                 self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &dst)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_dst)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":648
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy_fortran", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_memoryview___reduce_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_memoryview_2__setstate_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":662
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

static PyObject *__pyx_memoryview_new(PyObject *__pyx_v_o, int __pyx_v_flags, int __pyx_v_dtype_is_object, __Pyx_TypeInfo *__pyx_v_typeinfo) {
  struct __pyx_memoryview_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_cwrapper", 1);

  /* "View.MemoryView":663
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)             # <<<<<<<<<<<<<<
 *     result.typeinfo = typeinfo
 *     return result
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o)) __PYX_ERR(1, 663, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 663, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(1, 663, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryview_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":664
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
  __pyx_v_result->typeinfo = __pyx_v_typeinfo;

  /* "View.MemoryView":665
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_check')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":662
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":668
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

static CYTHON_INLINE int __pyx_memoryview_check(PyObject *__pyx_v_o) {
  int __pyx_r;
  int __pyx_t_1;

  /* "View.MemoryView":669
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:
 *     return isinstance(o, memoryview)             # <<<<<<<<<<<<<<
 * 
 * cdef tuple _unellipsify(object index, int ndim):
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_o, __pyx_memoryview_type); 
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "View.MemoryView":668
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":671
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

static PyObject *_unellipsify(PyObject *__pyx_v_index, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_idx;
  PyObject *__pyx_v_tup = NULL;
  PyObject *__pyx_v_result = NULL;
  int __pyx_v_have_slices;
  int __pyx_v_seen_ellipsis;
  PyObject *__pyx_v_item = NULL;
  Py_ssize_t __pyx_v_nslices;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unellipsify", 1);

  /* "View.MemoryView":677
 *     """
 *     cdef Py_ssize_t idx
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)             # <<<<<<<<<<<<<<
 * 
 *     result = [slice(None)] * ndim
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_index); 
  if (__pyx_t_2) {
    __Pyx_INCREF(((PyObject*)__pyx_v_index));
    __pyx_t_1 = __pyx_v_index;
  } else {
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_index);
    __Pyx_GIVEREF(__pyx_v_index);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_index)) __PYX_ERR(1, 677, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_v_tup = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":679
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)
 * 
 *     result = [slice(None)] * ndim             # <<<<<<<<<<<<<<
 *     have_slices = False
 *     seen_ellipsis = False
 */
  __pyx_t_1 = PyList_New(1 * ((__pyx_v_ndim<0) ? 0:__pyx_v_ndim)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  { Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < __pyx_v_ndim; __pyx_temp++) {
      __Pyx_INCREF(__pyx_slice__5);
      __Pyx_GIVEREF(__pyx_slice__5);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, __pyx_temp, __pyx_slice__5)) __PYX_ERR(1, 679, __pyx_L1_error);
    }
  }
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":680
 * 
 *     result = [slice(None)] * ndim
 *     have_slices = False             # <<<<<<<<<<<<<<
 *     seen_ellipsis = False
 *     idx = 0
 */
  __pyx_v_have_slices = 0;

  /* "View.MemoryView":681
 *     result = [slice(None)] * ndim
 *     have_slices = False
 *     seen_ellipsis = False             # <<<<<<<<<<<<<<
 *     idx = 0
 *     for item in tup:
 */
  __pyx_v_seen_ellipsis = 0;

  /* "View.MemoryView":682
 *     have_slices = False
 *     seen_ellipsis = False
 *     idx = 0             # <<<<<<<<<<<<<<
 *     for item in tup:
 *         if item is Ellipsis:
 */
  __pyx_v_idx = 0;

  /* "View.MemoryView":683
 *     seen_ellipsis = False
 *     idx = 0
 *     for item in tup:             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  if (unlikely(__pyx_v_tup == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(1, 683, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_tup; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 683, __pyx_L1_error)
      #endif
      if (__pyx_t_4 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(1, 683, __pyx_L1_error)
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":684
 *     idx = 0
 *     for item in tup:
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 */
    __pyx_t_2 = (__pyx_v_item == __pyx_builtin_Ellipsis);
    if (__pyx_t_2) {

      /* "View.MemoryView":685
 *     for item in tup:
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 */
      __pyx_t_2 = (!__pyx_v_seen_ellipsis);
      if (__pyx_t_2) {

        /* "View.MemoryView":686
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)             # <<<<<<<<<<<<<<
 *                 seen_ellipsis = True
 *             have_slices = True
 */
        if (unlikely(__pyx_v_tup == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(1, 686, __pyx_L1_error)
        }
        __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(__pyx_v_tup); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(1, 686, __pyx_L1_error)
        __pyx_v_idx = (__pyx_v_idx + (__pyx_v_ndim - __pyx_t_5));

        /* "View.MemoryView":687
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True             # <<<<<<<<<<<<<<
 *             have_slices = True
 *         else:
 */
        __pyx_v_seen_ellipsis = 1;

        /* "View.MemoryView":685
 *     for item in tup:
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 */
      }

      /* "View.MemoryView":688
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 *             have_slices = True             # <<<<<<<<<<<<<<
 *         else:
 *             if isinstance(item, slice):
 */
      __pyx_v_have_slices = 1;

      /* "View.MemoryView":684
 *     idx = 0
 *     for item in tup:
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":690
 *             have_slices = True
 *         else:
 *             if isinstance(item, slice):             # <<<<<<<<<<<<<<
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 */
    /*else*/ {
      __pyx_t_2 = PySlice_Check(__pyx_v_item); 
      if (__pyx_t_2) {

        /* "View.MemoryView":691
 *         else:
 *             if isinstance(item, slice):
 *                 have_slices = True             # <<<<<<<<<<<<<<
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 */
        __pyx_v_have_slices = 1;

        /* "View.MemoryView":690
 *             have_slices = True
 *         else:
 *             if isinstance(item, slice):             # <<<<<<<<<<<<<<
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":692
 *             if isinstance(item, slice):
 *                 have_slices = True
 *             elif not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 */
      __pyx_t_2 = (!(PyIndex_Check(__pyx_v_item) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "View.MemoryView":693
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"             # <<<<<<<<<<<<<<
 *             result[idx] = item
 *         idx += 1
 */
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = 0;
        __pyx_t_6 = 127;
        __Pyx_INCREF(__pyx_kp_u_Cannot_index_with_type);
        __pyx_t_5 += 24;
        __Pyx_GIVEREF(__pyx_kp_u_Cannot_index_with_type);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Cannot_index_with_type);
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_item)), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_6;
        __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_INCREF(__pyx_kp_u__6);
        __pyx_t_5 += 1;
        __Pyx_GIVEREF(__pyx_kp_u__6);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__6);
        __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_builtin_TypeError, __pyx_t_7, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __PYX_ERR(1, 693, __pyx_L1_error)

        /* "View.MemoryView":692
 *             if isinstance(item, slice):
 *                 have_slices = True
 *             elif not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 */
      }
      __pyx_L7:;

      /* "View.MemoryView":694
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item             # <<<<<<<<<<<<<<
 *         idx += 1
 * 
 */
      if (unlikely((__Pyx_SetItemInt(__pyx_v_result, __pyx_v_idx, __pyx_v_item, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1) < 0))) __PYX_ERR(1, 694, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "View.MemoryView":695
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 *         idx += 1             # <<<<<<<<<<<<<<
 * 
 *     nslices = ndim - idx
 */
    __pyx_v_idx = (__pyx_v_idx + 1);

    /* "View.MemoryView":683
 *     seen_ellipsis = False
 *     idx = 0
 *     for item in tup:             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "View.MemoryView":697
 *         idx += 1
 * 
 *     nslices = ndim - idx             # <<<<<<<<<<<<<<
 *     return have_slices or nslices, tuple(result)
 * 
 */
  __pyx_v_nslices = (__pyx_v_ndim - __pyx_v_idx);

  /* "View.MemoryView":698
 * 
 *     nslices = ndim - idx
 *     return have_slices or nslices, tuple(result)             # <<<<<<<<<<<<<<
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 */
  __Pyx_XDECREF(__pyx_r);
  if (!__pyx_v_have_slices) {
  } else {
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_have_slices); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_7 = PyInt_FromSsize_t(__pyx_v_nslices); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __pyx_t_7;
  __pyx_t_7 = 0;
  __pyx_L9_bool_binop_done:;
  __pyx_t_7 = PyList_AsTuple(__pyx_v_result); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(1, 698, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":671
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView._unellipsify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tup);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

static int assert_direct_dimensions(Py_ssize_t *__pyx_v_suboffsets, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_suboffset;
  int __pyx_r;
  Py_ssize_t *__pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":701
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"
 */
  __pyx_t_2 = (__pyx_v_suboffsets + __pyx_v_ndim);
  for (__pyx_t_3 = __pyx_v_suboffsets; __pyx_t_3 < __pyx_t_2; __pyx_t_3++) {
    __pyx_t_1 = __pyx_t_3;
    __pyx_v_suboffset = (__pyx_t_1[0]);

    /* "View.MemoryView":702
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag
 */
    __pyx_t_4 = (__pyx_v_suboffset >= 0);
    if (unlikely(__pyx_t_4)) {

      /* "View.MemoryView":703
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"             # <<<<<<<<<<<<<<
 *     return 0  # return type just used as an error flag
 * 
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Indirect_dimensions_not_supporte, 0, 0);
      __PYX_ERR(1, 703, __pyx_L1_error)

      /* "View.MemoryView":702
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag
 */
    }
  }

  /* "View.MemoryView":704
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.assert_direct_dimensions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":711
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *__pyx_v_memview, PyObject *__pyx_v_indices) {
  int __pyx_v_new_ndim;
  int __pyx_v_suboffset_dim;
  int __pyx_v_dim;
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  __Pyx_memviewslice *__pyx_v_p_src;
  struct __pyx_memoryviewslice_obj *__pyx_v_memviewsliceobj = 0;
  __Pyx_memviewslice *__pyx_v_p_dst;
  int *__pyx_v_p_suboffset_dim;
  Py_ssize_t __pyx_v_start;
  Py_ssize_t __pyx_v_stop;
  Py_ssize_t __pyx_v_step;
  Py_ssize_t __pyx_v_cindex;
  int __pyx_v_have_start;
  int __pyx_v_have_stop;
  int __pyx_v_have_step;
  PyObject *__pyx_v_index = NULL;
  struct __pyx_memoryview_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_memoryview_obj *__pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memview_slice", 1);

  /* "View.MemoryView":712
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim             # <<<<<<<<<<<<<<
 *     cdef bint negative_step
 *     cdef __Pyx_memviewslice src, dst
 */
  __pyx_v_new_ndim = 0;
  __pyx_v_suboffset_dim = -1;

  /* "View.MemoryView":719
 * 
 * 
 *     memset(&dst, 0, sizeof(dst))             # <<<<<<<<<<<<<<
 * 
 *     cdef _memoryviewslice memviewsliceobj
 */
  (void)(memset((&__pyx_v_dst), 0, (sizeof(__pyx_v_dst))));

  /* "View.MemoryView":723
 *     cdef _memoryviewslice memviewsliceobj
 * 
 *     assert memview.view.ndim > 0             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__pyx_v_memview->view.ndim > 0);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(1, 723, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(1, 723, __pyx_L1_error)
  #endif

  /* "View.MemoryView":725
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":726
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview             # <<<<<<<<<<<<<<
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(1, 726, __pyx_L1_error)
    __pyx_t_2 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_memviewsliceobj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":727
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, &src)
 */
    __pyx_v_p_src = (&__pyx_v_memviewsliceobj->from_slice);

    /* "View.MemoryView":725
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":729
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 *         slice_copy(memview, &src)             # <<<<<<<<<<<<<<
 *         p_src = &src
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_src));

    /* "View.MemoryView":730
 *     else:
 *         slice_copy(memview, &src)
 *         p_src = &src             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_p_src = (&__pyx_v_src);
  }
  __pyx_L3:;

  /* "View.MemoryView":736
 * 
 * 
 *     dst.memview = p_src.memview             # <<<<<<<<<<<<<<
 *     dst.data = p_src.data
 * 
 */
  __pyx_t_3 = __pyx_v_p_src->memview;
  __pyx_v_dst.memview = __pyx_t_3;

  /* "View.MemoryView":737
 * 
 *     dst.memview = p_src.memview
 *     dst.data = p_src.data             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_v_p_src->data;
  __pyx_v_dst.data = __pyx_t_4;

  /* "View.MemoryView":742
 * 
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst             # <<<<<<<<<<<<<<
 *     cdef int *p_suboffset_dim = &suboffset_dim
 *     cdef Py_ssize_t start, stop, step, cindex
 */
  __pyx_v_p_dst = (&__pyx_v_dst);

  /* "View.MemoryView":743
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst
 *     cdef int *p_suboffset_dim = &suboffset_dim             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t start, stop, step, cindex
 *     cdef bint have_start, have_stop, have_step
 */
  __pyx_v_p_suboffset_dim = (&__pyx_v_suboffset_dim);

  /* "View.MemoryView":747
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             cindex = index
 */
  __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_v_indices)) || PyTuple_CheckExact(__pyx_v_indices)) {
    __pyx_t_2 = __pyx_v_indices; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_indices); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 747, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
        #else
        __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 747, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
        #else
        __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 747, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      }
    } else {
      __pyx_t_8 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_8)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 747, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_v_dim = __pyx_t_5;
    __pyx_t_5 = (__pyx_t_5 + 1);

    /* "View.MemoryView":748
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             cindex = index
 *             slice_memviewslice(
 */
    __pyx_t_1 = (PyIndex_Check(__pyx_v_index) != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":749
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):
 *             cindex = index             # <<<<<<<<<<<<<<
 *             slice_memviewslice(
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 */
      __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 749, __pyx_L1_error)
      __pyx_v_cindex = __pyx_t_9;

      /* "View.MemoryView":750
 *         if PyIndex_Check(index):
 *             cindex = index
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_10 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_v_cindex, 0, 0, 0, 0, 0, 0); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(1, 750, __pyx_L1_error)

      /* "View.MemoryView":748
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             cindex = index
 *             slice_memviewslice(
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":756
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
    __pyx_t_1 = (__pyx_v_index == Py_None);
    if (__pyx_t_1) {

      /* "View.MemoryView":757
 *                 False)
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1             # <<<<<<<<<<<<<<
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 */
      (__pyx_v_p_dst->shape[__pyx_v_new_ndim]) = 1;

      /* "View.MemoryView":758
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0             # <<<<<<<<<<<<<<
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1
 */
      (__pyx_v_p_dst->strides[__pyx_v_new_ndim]) = 0;

      /* "View.MemoryView":759
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1             # <<<<<<<<<<<<<<
 *             new_ndim += 1
 *         else:
 */
      (__pyx_v_p_dst->suboffsets[__pyx_v_new_ndim]) = -1L;

      /* "View.MemoryView":760
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 *         else:
 *             start = index.start or 0
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);

      /* "View.MemoryView":756
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":762
 *             new_ndim += 1
 *         else:
 *             start = index.start or 0             # <<<<<<<<<<<<<<
 *             stop = index.stop or 0
 *             step = index.step or 0
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 762, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 762, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L7_bool_binop_done:;
      __pyx_v_start = __pyx_t_9;

      /* "View.MemoryView":763
 *         else:
 *             start = index.start or 0
 *             stop = index.stop or 0             # <<<<<<<<<<<<<<
 *             step = index.step or 0
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 763, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 763, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L9_bool_binop_done:;
      __pyx_v_stop = __pyx_t_9;

      /* "View.MemoryView":764
 *             start = index.start or 0
 *             stop = index.stop or 0
 *             step = index.step or 0             # <<<<<<<<<<<<<<
 * 
 *             have_start = index.start is not None
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 764, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 764, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L11_bool_binop_done:;
      __pyx_v_step = __pyx_t_9;

      /* "View.MemoryView":766
 *             step = index.step or 0
 * 
 *             have_start = index.start is not None             # <<<<<<<<<<<<<<
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_start = __pyx_t_1;

      /* "View.MemoryView":767
 * 
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None             # <<<<<<<<<<<<<<
 *             have_step = index.step is not None
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 767, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_stop = __pyx_t_1;

      /* "View.MemoryView":768
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None             # <<<<<<<<<<<<<<
 * 
 *             slice_memviewslice(
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 768, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_step = __pyx_t_1;

      /* "View.MemoryView":770
 *             have_step = index.step is not None
 * 
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_10 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_v_start, __pyx_v_stop, __pyx_v_step, __pyx_v_have_start, __pyx_v_have_stop, __pyx_v_have_step, 1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(1, 770, __pyx_L1_error)

      /* "View.MemoryView":776
 *                 have_start, have_stop, have_step,
 *                 True)
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);
    }
    __pyx_L6:;

    /* "View.MemoryView":747
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             cindex = index
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":778
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":779
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);

    /* "View.MemoryView":780
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_dtype_func,
 *                                     memview.dtype_is_object)
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(1, 780, __pyx_L1_error) }

    /* "View.MemoryView":781
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 *     else:
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(1, 781, __pyx_L1_error) }

    /* "View.MemoryView":779
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, __pyx_v_memviewsliceobj->to_object_func, __pyx_v_memviewsliceobj->to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_memoryview_type))))) __PYX_ERR(1, 779, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":778
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  }

  /* "View.MemoryView":784
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
  /*else*/ {
    __Pyx_XDECREF((PyObject *)__pyx_r);

    /* "View.MemoryView":785
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,
 *                                     memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, NULL, NULL, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "View.MemoryView":784
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_memoryview_type))))) __PYX_ERR(1, 784, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":711
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memview_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_memviewsliceobj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":793
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *__pyx_v_dst, Py_ssize_t __pyx_v_shape, Py_ssize_t __pyx_v_stride, Py_ssize_t __pyx_v_suboffset, int __pyx_v_dim, int __pyx_v_new_ndim, int *__pyx_v_suboffset_dim, Py_ssize_t __pyx_v_start, Py_ssize_t __pyx_v_stop, Py_ssize_t __pyx_v_step, int __pyx_v_have_start, int __pyx_v_have_stop, int __pyx_v_have_step, int __pyx_v_is_slice) {
  Py_ssize_t __pyx_v_new_shape;
  int __pyx_v_negative_step;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":813
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
  __pyx_t_1 = (!__pyx_v_is_slice);
  if (__pyx_t_1) {

    /* "View.MemoryView":815
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    __pyx_t_1 = (__pyx_v_start < 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":816
 * 
 *         if start < 0:
 *             start += shape             # <<<<<<<<<<<<<<
 *         if not 0 <= start < shape:
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 */
      __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

      /* "View.MemoryView":815
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    }

    /* "View.MemoryView":817
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    __pyx_t_1 = (0 <= __pyx_v_start);
    if (__pyx_t_1) {
      __pyx_t_1 = (__pyx_v_start < __pyx_v_shape);
    }
    __pyx_t_2 = (!__pyx_t_1);
    if (__pyx_t_2) {

      /* "View.MemoryView":818
 *             start += shape
 *         if not 0 <= start < shape:
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)             # <<<<<<<<<<<<<<
 *     else:
 * 
 */
      __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_IndexError, __pyx_kp_s_Index_out_of_bounds_axis_d, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 818, __pyx_L1_error)

      /* "View.MemoryView":817
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    }

    /* "View.MemoryView":813
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":821
 *     else:
 * 
 *         if have_step:             # <<<<<<<<<<<<<<
 *             negative_step = step < 0
 *             if step == 0:
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_have_step != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":822
 * 
 *         if have_step:
 *             negative_step = step < 0             # <<<<<<<<<<<<<<
 *             if step == 0:
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 */
      __pyx_v_negative_step = (__pyx_v_step < 0);

      /* "View.MemoryView":823
 *         if have_step:
 *             negative_step = step < 0
 *             if step == 0:             # <<<<<<<<<<<<<<
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 */
      __pyx_t_2 = (__pyx_v_step == 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":824
 *             negative_step = step < 0
 *             if step == 0:
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)             # <<<<<<<<<<<<<<
 *         else:
 *             negative_step = False
 */
        __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_ValueError, __pyx_kp_s_Step_may_not_be_zero_axis_d, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 824, __pyx_L1_error)

        /* "View.MemoryView":823
 *         if have_step:
 *             negative_step = step < 0
 *             if step == 0:             # <<<<<<<<<<<<<<
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 */
      }

      /* "View.MemoryView":821
 *     else:
 * 
 *         if have_step:             # <<<<<<<<<<<<<<
 *             negative_step = step < 0
 *             if step == 0:
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":826
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 *             negative_step = False             # <<<<<<<<<<<<<<
 *             step = 1
 * 
 */
    /*else*/ {
      __pyx_v_negative_step = 0;

      /* "View.MemoryView":827
 *         else:
 *             negative_step = False
 *             step = 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_step = 1;
    }
    __pyx_L6:;

    /* "View.MemoryView":830
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
    __pyx_t_2 = (__pyx_v_have_start != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":831
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
      __pyx_t_2 = (__pyx_v_start < 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":832
 *         if have_start:
 *             if start < 0:
 *                 start += shape             # <<<<<<<<<<<<<<
 *                 if start < 0:
 *                     start = 0
 */
        __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

        /* "View.MemoryView":833
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        __pyx_t_2 = (__pyx_v_start < 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":834
 *                 start += shape
 *                 if start < 0:
 *                     start = 0             # <<<<<<<<<<<<<<
 *             elif start >= shape:
 *                 if negative_step:
 */
          __pyx_v_start = 0;

          /* "View.MemoryView":833
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        }

        /* "View.MemoryView":831
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
        goto __pyx_L9;
      }

      /* "View.MemoryView":835
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      __pyx_t_2 = (__pyx_v_start >= __pyx_v_shape);
      if (__pyx_t_2) {

        /* "View.MemoryView":836
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
        if (__pyx_v_negative_step) {

          /* "View.MemoryView":837
 *             elif start >= shape:
 *                 if negative_step:
 *                     start = shape - 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     start = shape
 */
          __pyx_v_start = (__pyx_v_shape - 1);

          /* "View.MemoryView":836
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
          goto __pyx_L11;
        }

        /* "View.MemoryView":839
 *                     start = shape - 1
 *                 else:
 *                     start = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        /*else*/ {
          __pyx_v_start = __pyx_v_shape;
        }
        __pyx_L11:;

        /* "View.MemoryView":835
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      }
      __pyx_L9:;

      /* "View.MemoryView":830
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
      goto __pyx_L8;
    }

    /* "View.MemoryView":841
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
    /*else*/ {
      if (__pyx_v_negative_step) {

        /* "View.MemoryView":842
 *         else:
 *             if negative_step:
 *                 start = shape - 1             # <<<<<<<<<<<<<<
 *             else:
 *                 start = 0
 */
        __pyx_v_start = (__pyx_v_shape - 1);

        /* "View.MemoryView":841
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
        goto __pyx_L12;
      }

      /* "View.MemoryView":844
 *                 start = shape - 1
 *             else:
 *                 start = 0             # <<<<<<<<<<<<<<
 * 
 *         if have_stop:
 */
      /*else*/ {
        __pyx_v_start = 0;
      }
      __pyx_L12:;
    }
    __pyx_L8:;

    /* "View.MemoryView":846
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
    __pyx_t_2 = (__pyx_v_have_stop != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":847
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
      __pyx_t_2 = (__pyx_v_stop < 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":848
 *         if have_stop:
 *             if stop < 0:
 *                 stop += shape             # <<<<<<<<<<<<<<
 *                 if stop < 0:
 *                     stop = 0
 */
        __pyx_v_stop = (__pyx_v_stop + __pyx_v_shape);

        /* "View.MemoryView":849
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        __pyx_t_2 = (__pyx_v_stop < 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":850
 *                 stop += shape
 *                 if stop < 0:
 *                     stop = 0             # <<<<<<<<<<<<<<
 *             elif stop > shape:
 *                 stop = shape
 */
          __pyx_v_stop = 0;

          /* "View.MemoryView":849
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        }

        /* "View.MemoryView":847
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
        goto __pyx_L14;
      }

      /* "View.MemoryView":851
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      __pyx_t_2 = (__pyx_v_stop > __pyx_v_shape);
      if (__pyx_t_2) {

        /* "View.MemoryView":852
 *                     stop = 0
 *             elif stop > shape:
 *                 stop = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        __pyx_v_stop = __pyx_v_shape;

        /* "View.MemoryView":851
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      }
      __pyx_L14:;

      /* "View.MemoryView":846
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
      goto __pyx_L13;
    }

    /* "View.MemoryView":854
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
    /*else*/ {
      if (__pyx_v_negative_step) {

        /* "View.MemoryView":855
 *         else:
 *             if negative_step:
 *                 stop = -1             # <<<<<<<<<<<<<<
 *             else:
 *                 stop = shape
 */
        __pyx_v_stop = -1L;

        /* "View.MemoryView":854
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
        goto __pyx_L16;
      }

      /* "View.MemoryView":857
 *                 stop = -1
 *             else:
 *                 stop = shape             # <<<<<<<<<<<<<<
 * 
 * 
 */
      /*else*/ {
        __pyx_v_stop = __pyx_v_shape;
      }
      __pyx_L16:;
    }
    __pyx_L13:;

    /* "View.MemoryView":861
 * 
 *         with cython.cdivision(True):
 *             new_shape = (stop - start) // step             # <<<<<<<<<<<<<<
 * 
 *             if (stop - start) - step * new_shape:
 */
    __pyx_v_new_shape = ((__pyx_v_stop - __pyx_v_start) / __pyx_v_step);

    /* "View.MemoryView":863
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    __pyx_t_2 = (((__pyx_v_stop - __pyx_v_start) - (__pyx_v_step * __pyx_v_new_shape)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":864
 * 
 *             if (stop - start) - step * new_shape:
 *                 new_shape += 1             # <<<<<<<<<<<<<<
 * 
 *         if new_shape < 0:
 */
      __pyx_v_new_shape = (__pyx_v_new_shape + 1);

      /* "View.MemoryView":863
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    }

    /* "View.MemoryView":866
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    __pyx_t_2 = (__pyx_v_new_shape < 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":867
 * 
 *         if new_shape < 0:
 *             new_shape = 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_new_shape = 0;

      /* "View.MemoryView":866
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    }

    /* "View.MemoryView":870
 * 
 * 
 *         dst.strides[new_ndim] = stride * step             # <<<<<<<<<<<<<<
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset
 */
    (__pyx_v_dst->strides[__pyx_v_new_ndim]) = (__pyx_v_stride * __pyx_v_step);

    /* "View.MemoryView":871
 * 
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape             # <<<<<<<<<<<<<<
 *         dst.suboffsets[new_ndim] = suboffset
 * 
 */
    (__pyx_v_dst->shape[__pyx_v_new_ndim]) = __pyx_v_new_shape;

    /* "View.MemoryView":872
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_dst->suboffsets[__pyx_v_new_ndim]) = __pyx_v_suboffset;
  }
  __pyx_L3:;

  /* "View.MemoryView":875
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_suboffset_dim[0]) < 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":876
 * 
 *     if suboffset_dim[0] < 0:
 *         dst.data += start * stride             # <<<<<<<<<<<<<<
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 */
    __pyx_v_dst->data = (__pyx_v_dst->data + (__pyx_v_start * __pyx_v_stride));

    /* "View.MemoryView":875
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
    goto __pyx_L19;
  }

  /* "View.MemoryView":878
 *         dst.data += start * stride
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride             # <<<<<<<<<<<<<<
 * 
 *     if suboffset >= 0:
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_suboffset_dim[0]);
    (__pyx_v_dst->suboffsets[__pyx_t_3]) = ((__pyx_v_dst->suboffsets[__pyx_t_3]) + (__pyx_v_start * __pyx_v_stride));
  }
  __pyx_L19:;

  /* "View.MemoryView":880
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  __pyx_t_2 = (__pyx_v_suboffset >= 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":881
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
    __pyx_t_2 = (!__pyx_v_is_slice);
    if (__pyx_t_2) {

      /* "View.MemoryView":882
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
      __pyx_t_2 = (__pyx_v_new_ndim == 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":883
 *         if not is_slice:
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "
 */
        __pyx_v_dst->data = ((((char **)__pyx_v_dst->data)[0]) + __pyx_v_suboffset);

        /* "View.MemoryView":882
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
        goto __pyx_L22;
      }

      /* "View.MemoryView":885
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "             # <<<<<<<<<<<<<<
 *                                      "must be indexed and not sliced", dim)
 *         else:
 */
      /*else*/ {

        /* "View.MemoryView":886
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "
 *                                      "must be indexed and not sliced", dim)             # <<<<<<<<<<<<<<
 *         else:
 *             suboffset_dim[0] = new_ndim
 */
        __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_IndexError, __pyx_kp_s_All_dimensions_preceding_dimensi, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 885, __pyx_L1_error)
      }
      __pyx_L22:;

      /* "View.MemoryView":881
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
      goto __pyx_L21;
    }

    /* "View.MemoryView":888
 *                                      "must be indexed and not sliced", dim)
 *         else:
 *             suboffset_dim[0] = new_ndim             # <<<<<<<<<<<<<<
 * 
 *     return 0
 */
    /*else*/ {
      (__pyx_v_suboffset_dim[0]) = __pyx_v_new_ndim;
    }
    __pyx_L21:;

    /* "View.MemoryView":880
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  }

  /* "View.MemoryView":890
 *             suboffset_dim[0] = new_ndim
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":793
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.slice_memviewslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":896
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

static char *__pyx_pybuffer_index(Py_buffer *__pyx_v_view, char *__pyx_v_bufp, Py_ssize_t __pyx_v_index, Py_ssize_t __pyx_v_dim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_suboffset;
  Py_ssize_t __pyx_v_itemsize;
  char *__pyx_v_resultp;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pybuffer_index", 1);

  /* "View.MemoryView":898
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t itemsize = view.itemsize
 *     cdef char *resultp
 */
  __pyx_v_suboffset = -1L;

  /* "View.MemoryView":899
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 *     cdef Py_ssize_t itemsize = view.itemsize             # <<<<<<<<<<<<<<
 *     cdef char *resultp
 * 
 */
  __pyx_t_1 = __pyx_v_view->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":902
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len // itemsize
 *         stride = itemsize
 */
  __pyx_t_2 = (__pyx_v_view->ndim == 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":903
 * 
 *     if view.ndim == 0:
 *         shape = view.len // itemsize             # <<<<<<<<<<<<<<
 *         stride = itemsize
 *     else:
 */
    if (unlikely(__pyx_v_itemsize == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(1, 903, __pyx_L1_error)
    }
    else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_itemsize == (Py_ssize_t)-1)  && unlikely(__Pyx_UNARY_NEG_WOULD_OVERFLOW(__pyx_v_view->len))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(1, 903, __pyx_L1_error)
    }
    __pyx_v_shape = __Pyx_div_Py_ssize_t(__pyx_v_view->len, __pyx_v_itemsize);

    /* "View.MemoryView":904
 *     if view.ndim == 0:
 *         shape = view.len // itemsize
 *         stride = itemsize             # <<<<<<<<<<<<<<
 *     else:
 *         shape = view.shape[dim]
 */
    __pyx_v_stride = __pyx_v_itemsize;

    /* "View.MemoryView":902
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len // itemsize
 *         stride = itemsize
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":906
 *         stride = itemsize
 *     else:
 *         shape = view.shape[dim]             # <<<<<<<<<<<<<<
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 */
  /*else*/ {
    __pyx_v_shape = (__pyx_v_view->shape[__pyx_v_dim]);

    /* "View.MemoryView":907
 *     else:
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]             # <<<<<<<<<<<<<<
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]
 */
    __pyx_v_stride = (__pyx_v_view->strides[__pyx_v_dim]);

    /* "View.MemoryView":908
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    __pyx_t_2 = (__pyx_v_view->suboffsets != NULL);
    if (__pyx_t_2) {

      /* "View.MemoryView":909
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]             # <<<<<<<<<<<<<<
 * 
 *     if index < 0:
 */
      __pyx_v_suboffset = (__pyx_v_view->suboffsets[__pyx_v_dim]);

      /* "View.MemoryView":908
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":911
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  __pyx_t_2 = (__pyx_v_index < 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":912
 * 
 *     if index < 0:
 *         index += view.shape[dim]             # <<<<<<<<<<<<<<
 *         if index < 0:
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 */
    __pyx_v_index = (__pyx_v_index + (__pyx_v_view->shape[__pyx_v_dim]));

    /* "View.MemoryView":913
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
    __pyx_t_2 = (__pyx_v_index < 0);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":914
 *         index += view.shape[dim]
 *         if index < 0:
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"             # <<<<<<<<<<<<<<
 * 
 *     if index >= shape:
 */
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = 0;
      __pyx_t_4 = 127;
      __Pyx_INCREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      __pyx_t_1 += 37;
      __Pyx_GIVEREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      __pyx_t_5 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_kp_u__7);
      __pyx_t_1 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__7);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__7);
      __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_builtin_IndexError, __pyx_t_5, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(1, 914, __pyx_L1_error)

      /* "View.MemoryView":913
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
    }

    /* "View.MemoryView":911
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  }

  /* "View.MemoryView":916
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
  __pyx_t_2 = (__pyx_v_index >= __pyx_v_shape);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":917
 * 
 *     if index >= shape:
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"             # <<<<<<<<<<<<<<
 * 
 *     resultp = bufp + index * stride
 */
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = 0;
    __pyx_t_4 = 127;
    __Pyx_INCREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    __pyx_t_1 += 37;
    __Pyx_GIVEREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    __pyx_t_3 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u__7);
    __pyx_t_1 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__7);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u__7);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_5, 3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_builtin_IndexError, __pyx_t_3, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 917, __pyx_L1_error)

    /* "View.MemoryView":916
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
  }

  /* "View.MemoryView":919
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     resultp = bufp + index * stride             # <<<<<<<<<<<<<<
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset
 */
  __pyx_v_resultp = (__pyx_v_bufp + (__pyx_v_index * __pyx_v_stride));

  /* "View.MemoryView":920
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  __pyx_t_2 = (__pyx_v_suboffset >= 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":921
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset             # <<<<<<<<<<<<<<
 * 
 *     return resultp
 */
    __pyx_v_resultp = ((((char **)__pyx_v_resultp)[0]) + __pyx_v_suboffset);

    /* "View.MemoryView":920
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  }

  /* "View.MemoryView":923
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 *     return resultp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_resultp;
  goto __pyx_L0;

  /* "View.MemoryView":896
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.pybuffer_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":929
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

static int __pyx_memslice_transpose(__Pyx_memviewslice *__pyx_v_memslice) {
  int __pyx_v_ndim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_r;
  int __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":930
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:
 *     cdef int ndim = memslice.memview.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 */
  __pyx_t_1 = __pyx_v_memslice->memview->view.ndim;
  __pyx_v_ndim = __pyx_t_1;

  /* "View.MemoryView":932
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 *     cdef Py_ssize_t *shape = memslice.shape             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t *strides = memslice.strides
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->shape;
  __pyx_v_shape = __pyx_t_2;

  /* "View.MemoryView":933
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 *     cdef Py_ssize_t *strides = memslice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->strides;
  __pyx_v_strides = __pyx_t_2;

  /* "View.MemoryView":937
 * 
 *     cdef int i, j
 *     for i in range(ndim // 2):             # <<<<<<<<<<<<<<
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 */
  __pyx_t_3 = __Pyx_div_long(__pyx_v_ndim, 2);
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_4; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":938
 *     cdef int i, j
 *     for i in range(ndim // 2):
 *         j = ndim - 1 - i             # <<<<<<<<<<<<<<
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]
 */
    __pyx_v_j = ((__pyx_v_ndim - 1) - __pyx_v_i);

    /* "View.MemoryView":939
 *     for i in range(ndim // 2):
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]             # <<<<<<<<<<<<<<
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 */
    __pyx_t_5 = (__pyx_v_strides[__pyx_v_j]);
    __pyx_t_6 = (__pyx_v_strides[__pyx_v_i]);
    (__pyx_v_strides[__pyx_v_i]) = __pyx_t_5;
    (__pyx_v_strides[__pyx_v_j]) = __pyx_t_6;

    /* "View.MemoryView":940
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]             # <<<<<<<<<<<<<<
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 */
    __pyx_t_6 = (__pyx_v_shape[__pyx_v_j]);
    __pyx_t_5 = (__pyx_v_shape[__pyx_v_i]);
    (__pyx_v_shape[__pyx_v_i]) = __pyx_t_6;
    (__pyx_v_shape[__pyx_v_j]) = __pyx_t_5;

    /* "View.MemoryView":942
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    __pyx_t_8 = ((__pyx_v_memslice->suboffsets[__pyx_v_i]) >= 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_8 = ((__pyx_v_memslice->suboffsets[__pyx_v_j]) >= 0);
    __pyx_t_7 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_7) {

      /* "View.MemoryView":943
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")             # <<<<<<<<<<<<<<
 * 
 *     return 0
 */
      __pyx_t_9 = __pyx_memoryview_err(PyExc_ValueError, __pyx_kp_s_Cannot_transpose_memoryview_with); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(1, 943, __pyx_L1_error)

      /* "View.MemoryView":942
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    }
  }

  /* "View.MemoryView":945
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":929
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.transpose_memslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":963
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 */

/* Python wrapper */
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self) {

  /* "View.MemoryView":964
 * 
 *     def __dealloc__(self):
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __PYX_XCLEAR_MEMVIEW((&__pyx_v_self->from_slice), 1);

  /* "View.MemoryView":963
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 */

  /* function exit code */
}

/* "View.MemoryView":966
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 1);

  /* "View.MemoryView":967
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->to_object_func != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":968
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)             # <<<<<<<<<<<<<<
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_self->to_object_func(__pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":967
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  }

  /* "View.MemoryView":970
 *             return self.to_object_func(itemp)
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_memoryview_convert_item_to_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":966
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":972
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 1);

  /* "View.MemoryView":973
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->to_dtype_func != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":974
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)             # <<<<<<<<<<<<<<
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)
 */
    __pyx_t_2 = __pyx_v_self->to_dtype_func(__pyx_v_itemp, __pyx_v_value); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(1, 974, __pyx_L1_error)

    /* "View.MemoryView":973
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":976
 *             self.to_dtype_func(itemp, value)
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef _get_base(self):
 */
  /*else*/ {
    __pyx_t_3 = __pyx_memoryview_assign_item_from_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":972
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":978
 *             memoryview.assign_item_from_object(self, itemp, value)
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

static PyObject *__pyx_memoryviewslice__get_base(struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_base", 1);

  /* "View.MemoryView":979
 * 
 *     cdef _get_base(self):
 *         return self.from_object             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->from_object);
  __pyx_r = __pyx_v_self->from_object;
  goto __pyx_L0;

  /* "View.MemoryView":978
 *             memoryview.assign_item_from_object(self, itemp, value)
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_memoryviewslice___reduce_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_memoryviewslice_2__setstate_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice __pyx_v_memviewslice, int __pyx_v_ndim, PyObject *(*__pyx_v_to_object_func)(char *), int (*__pyx_v_to_dtype_func)(char *, PyObject *), int __pyx_v_dtype_is_object) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  Py_ssize_t __pyx_v_suboffset;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_TypeInfo *__pyx_t_4;
  Py_buffer __pyx_t_5;
  Py_ssize_t *__pyx_t_6;
  Py_ssize_t *__pyx_t_7;
  Py_ssize_t *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_fromslice", 1);

  /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_memviewslice.memview) == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":1008
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  }

  /* "View.MemoryView":1013
 * 
 * 
 *     result = _memoryviewslice.__new__(_memoryviewslice, None, 0, dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     result.from_slice = memviewslice
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, Py_None)) __PYX_ERR(1, 1013, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0)) __PYX_ERR(1, 1013, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(1, 1013, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_tp_new__memoryviewslice(((PyTypeObject *)__pyx_memoryviewslice_type), __pyx_t_3, NULL)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1013, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":1015
 *     result = _memoryviewslice.__new__(_memoryviewslice, None, 0, dtype_is_object)
 * 
 *     result.from_slice = memviewslice             # <<<<<<<<<<<<<<
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 */
  __pyx_v_result->from_slice = __pyx_v_memviewslice;

  /* "View.MemoryView":1016
 * 
 *     result.from_slice = memviewslice
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)             # <<<<<<<<<<<<<<
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()
 */
  __PYX_INC_MEMVIEW((&__pyx_v_memviewslice), 1);

  /* "View.MemoryView":1018
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()             # <<<<<<<<<<<<<<
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)->__pyx_vtab)->_get_base(((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_result->from_object);
  __Pyx_DECREF(__pyx_v_result->from_object);
  __pyx_v_result->from_object = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "View.MemoryView":1019
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()
 *     result.typeinfo = memviewslice.memview.typeinfo             # <<<<<<<<<<<<<<
 * 
 *     result.view = memviewslice.memview.view
 */
  __pyx_t_4 = __pyx_v_memviewslice.memview->typeinfo;
  __pyx_v_result->__pyx_base.typeinfo = __pyx_t_4;

  /* "View.MemoryView":1021
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 *     result.view = memviewslice.memview.view             # <<<<<<<<<<<<<<
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 */
  __pyx_t_5 = __pyx_v_memviewslice.memview->view;
  __pyx_v_result->__pyx_base.view = __pyx_t_5;

  /* "View.MemoryView":1022
 * 
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data             # <<<<<<<<<<<<<<
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 */
  __pyx_v_result->__pyx_base.view.buf = ((void *)__pyx_v_memviewslice.data);

  /* "View.MemoryView":1023
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim             # <<<<<<<<<<<<<<
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)
 */
  __pyx_v_result->__pyx_base.view.ndim = __pyx_v_ndim;

  /* "View.MemoryView":1024
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None             # <<<<<<<<<<<<<<
 *     Py_INCREF(Py_None)
 * 
 */
  ((Py_buffer *)(&__pyx_v_result->__pyx_base.view))->obj = Py_None;

  /* "View.MemoryView":1025
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 */
  Py_INCREF(Py_None);

  /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
  __pyx_t_1 = ((((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)->flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1028
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 *         result.flags = PyBUF_RECORDS             # <<<<<<<<<<<<<<
 *     else:
 *         result.flags = PyBUF_RECORDS_RO
 */
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS;

    /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":1030
 *         result.flags = PyBUF_RECORDS
 *     else:
 *         result.flags = PyBUF_RECORDS_RO             # <<<<<<<<<<<<<<
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 */
  /*else*/ {
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS_RO;
  }
  __pyx_L4:;

  /* "View.MemoryView":1032
 *         result.flags = PyBUF_RECORDS_RO
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape             # <<<<<<<<<<<<<<
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides
 * 
 */
  __pyx_v_result->__pyx_base.view.shape = ((Py_ssize_t *)__pyx_v_result->from_slice.shape);

  /* "View.MemoryView":1033
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_result->__pyx_base.view.strides = ((Py_ssize_t *)__pyx_v_result->from_slice.strides);

  /* "View.MemoryView":1036
 * 
 * 
 *     result.view.suboffsets = NULL             # <<<<<<<<<<<<<<
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 */
  __pyx_v_result->__pyx_base.view.suboffsets = NULL;

  /* "View.MemoryView":1037
 * 
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 */
  __pyx_t_7 = (__pyx_v_result->from_slice.suboffsets + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->from_slice.suboffsets; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_v_suboffset = (__pyx_t_6[0]);

    /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    __pyx_t_1 = (__pyx_v_suboffset >= 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":1039
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_result->__pyx_base.view.suboffsets = ((Py_ssize_t *)__pyx_v_result->from_slice.suboffsets);

      /* "View.MemoryView":1040
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break             # <<<<<<<<<<<<<<
 * 
 *     result.view.len = result.view.itemsize
 */
      goto __pyx_L6_break;

      /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    }
  }
  __pyx_L6_break:;

  /* "View.MemoryView":1042
 *             break
 * 
 *     result.view.len = result.view.itemsize             # <<<<<<<<<<<<<<
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length
 */
  __pyx_t_9 = __pyx_v_result->__pyx_base.view.itemsize;
  __pyx_v_result->__pyx_base.view.len = __pyx_t_9;

  /* "View.MemoryView":1043
 * 
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         result.view.len *= length
 * 
 */
  __pyx_t_7 = (__pyx_v_result->__pyx_base.view.shape + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->__pyx_base.view.shape; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_t_2 = PyInt_FromSsize_t((__pyx_t_6[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":1044
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length             # <<<<<<<<<<<<<<
 * 
 *     result.to_object_func = to_object_func
 */
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_result->__pyx_base.view.len); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_InPlaceMultiply(__pyx_t_2, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 1044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_result->__pyx_base.view.len = __pyx_t_9;
  }

  /* "View.MemoryView":1046
 *         result.view.len *= length
 * 
 *     result.to_object_func = to_object_func             # <<<<<<<<<<<<<<
 *     result.to_dtype_func = to_dtype_func
 * 
 */
  __pyx_v_result->to_object_func = __pyx_v_to_object_func;

  /* "View.MemoryView":1047
 * 
 *     result.to_object_func = to_object_func
 *     result.to_dtype_func = to_dtype_func             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  __pyx_v_result->to_dtype_func = __pyx_v_to_dtype_func;

  /* "View.MemoryView":1049
 *     result.to_dtype_func = to_dtype_func
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_fromslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_mslice) {
  struct __pyx_memoryviewslice_obj *__pyx_v_obj = 0;
  __Pyx_memviewslice *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_slice_from_memview", 1);

  /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":1056
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview             # <<<<<<<<<<<<<<
 *         return &obj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(1, 1056, __pyx_L1_error)
    __pyx_t_2 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_obj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":1057
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview
 *         return &obj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, mslice)
 */
    __pyx_r = (&__pyx_v_obj->from_slice);
    goto __pyx_L0;

    /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  }

  /* "View.MemoryView":1059
 *         return &obj.from_slice
 *     else:
 *         slice_copy(memview, mslice)             # <<<<<<<<<<<<<<
 *         return mslice
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, __pyx_v_mslice);

    /* "View.MemoryView":1060
 *     else:
 *         slice_copy(memview, mslice)
 *         return mslice             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_slice_copy')
 */
    __pyx_r = __pyx_v_mslice;
    goto __pyx_L0;
  }

  /* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.get_slice_from_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_obj);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst) noexcept:             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_dst) {
  int __pyx_v_dim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  Py_ssize_t *__pyx_v_suboffsets;
  Py_ssize_t *__pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;

  /* "View.MemoryView":1067
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 * 
 *     shape = memview.view.shape             # <<<<<<<<<<<<<<
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets
 */
  __pyx_t_1 = __pyx_v_memview->view.shape;
  __pyx_v_shape = __pyx_t_1;

  /* "View.MemoryView":1068
 * 
 *     shape = memview.view.shape
 *     strides = memview.view.strides             # <<<<<<<<<<<<<<
 *     suboffsets = memview.view.suboffsets
 * 
 */
  __pyx_t_1 = __pyx_v_memview->view.strides;
  __pyx_v_strides = __pyx_t_1;

  /* "View.MemoryView":1069
 *     shape = memview.view.shape
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets             # <<<<<<<<<<<<<<
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 */
  __pyx_t_1 = __pyx_v_memview->view.suboffsets;
  __pyx_v_suboffsets = __pyx_t_1;

  /* "View.MemoryView":1071
 *     suboffsets = memview.view.suboffsets
 * 
 *     dst.memview = <__pyx_memoryview *> memview             # <<<<<<<<<<<<<<
 *     dst.data = <char *> memview.view.buf
 * 
 */
  __pyx_v_dst->memview = ((struct __pyx_memoryview_obj *)__pyx_v_memview);

  /* "View.MemoryView":1072
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 *     dst.data = <char *> memview.view.buf             # <<<<<<<<<<<<<<
 * 
 *     for dim in range(memview.view.ndim):
 */
  __pyx_v_dst->data = ((char *)__pyx_v_memview->view.buf);

  /* "View.MemoryView":1074
 *     dst.data = <char *> memview.view.buf
 * 
 *     for dim in range(memview.view.ndim):             # <<<<<<<<<<<<<<
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 */
  __pyx_t_2 = __pyx_v_memview->view.ndim;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_dim = __pyx_t_4;

    /* "View.MemoryView":1075
 * 
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]             # <<<<<<<<<<<<<<
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 */
    (__pyx_v_dst->shape[__pyx_v_dim]) = (__pyx_v_shape[__pyx_v_dim]);

    /* "View.MemoryView":1076
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]             # <<<<<<<<<<<<<<
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 * 
 */
    (__pyx_v_dst->strides[__pyx_v_dim]) = (__pyx_v_strides[__pyx_v_dim]);

    /* "View.MemoryView":1077
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object')
 */
    __pyx_t_6 = (__pyx_v_suboffsets != 0);
    if (__pyx_t_6) {
      __pyx_t_5 = (__pyx_v_suboffsets[__pyx_v_dim]);
    } else {
      __pyx_t_5 = -1L;
    }
    (__pyx_v_dst->suboffsets[__pyx_v_dim]) = __pyx_t_5;
  }

  /* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst) noexcept:             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

  /* function exit code */
}

/* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *__pyx_v_memview) {
  __Pyx_memviewslice __pyx_v_memviewslice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy", 1);

  /* "View.MemoryView":1083
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)             # <<<<<<<<<<<<<<
 *     return memoryview_copy_from_slice(memview, &memviewslice)
 * 
 */
  __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_memviewslice));

  /* "View.MemoryView":1084
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)
 *     return memoryview_copy_from_slice(memview, &memviewslice)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_copy_object_from_slice(__pyx_v_memview, (&__pyx_v_memviewslice)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_memviewslice) {
  PyObject *(*__pyx_v_to_object_func)(char *);
  int (*__pyx_v_to_dtype_func)(char *, PyObject *);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *(*__pyx_t_2)(char *);
  int (*__pyx_t_3)(char *, PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy_from_slice", 1);

  /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":1095
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func             # <<<<<<<<<<<<<<
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 */
    __pyx_t_2 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_object_func;
    __pyx_v_to_object_func = __pyx_t_2;

    /* "View.MemoryView":1096
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func             # <<<<<<<<<<<<<<
 *     else:
 *         to_object_func = NULL
 */
    __pyx_t_3 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_dtype_func;
    __pyx_v_to_dtype_func = __pyx_t_3;

    /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1098
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 *         to_object_func = NULL             # <<<<<<<<<<<<<<
 *         to_dtype_func = NULL
 * 
 */
  /*else*/ {
    __pyx_v_to_object_func = NULL;

    /* "View.MemoryView":1099
 *     else:
 *         to_object_func = NULL
 *         to_dtype_func = NULL             # <<<<<<<<<<<<<<
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 */
    __pyx_v_to_dtype_func = NULL;
  }
  __pyx_L3:;

  /* "View.MemoryView":1101
 *         to_dtype_func = NULL
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,             # <<<<<<<<<<<<<<
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)
 */
  __Pyx_XDECREF(__pyx_r);

  /* "View.MemoryView":1103
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_memoryview_fromslice((__pyx_v_memviewslice[0]), __pyx_v_memview->view.ndim, __pyx_v_to_object_func, __pyx_v_to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy_from_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:             # <<<<<<<<<<<<<<
 *     return -arg if arg < 0 else arg
 * 
 */

static Py_ssize_t abs_py_ssize_t(Py_ssize_t __pyx_v_arg) {
  Py_ssize_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;

  /* "View.MemoryView":1110
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:
 *     return -arg if arg < 0 else arg             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_get_best_slice_order')
 */
  __pyx_t_2 = (__pyx_v_arg < 0);
  if (__pyx_t_2) {
    __pyx_t_1 = (-__pyx_v_arg);
  } else {
    __pyx_t_1 = __pyx_v_arg;
  }
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:             # <<<<<<<<<<<<<<
 *     return -arg if arg < 0 else arg
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1113
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

static char __pyx_get_best_slice_order(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim) {
  int __pyx_v_i;
  Py_ssize_t __pyx_v_c_stride;
  Py_ssize_t __pyx_v_f_stride;
  char __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1118
 *     """
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t f_stride = 0
 * 
 */
  __pyx_v_c_stride = 0;

  /* "View.MemoryView":1119
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0
 *     cdef Py_ssize_t f_stride = 0             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_f_stride = 0;

  /* "View.MemoryView":1121
 *     cdef Py_ssize_t f_stride = 0
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1122
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = ((__pyx_v_mslice->shape[__pyx_v_i]) > 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1123
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_c_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1124
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
      goto __pyx_L4_break;

      /* "View.MemoryView":1122
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L4_break:;

  /* "View.MemoryView":1126
 *             break
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 */
  __pyx_t_1 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_1;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1127
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = ((__pyx_v_mslice->shape[__pyx_v_i]) > 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1128
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_f_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1129
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 */
      goto __pyx_L7_break;

      /* "View.MemoryView":1127
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L7_break:;

  /* "View.MemoryView":1131
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  __pyx_t_2 = (abs_py_ssize_t(__pyx_v_c_stride) <= abs_py_ssize_t(__pyx_v_f_stride));
  if (__pyx_t_2) {

    /* "View.MemoryView":1132
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 *         return 'C'             # <<<<<<<<<<<<<<
 *     else:
 *         return 'F'
 */
    __pyx_r = 'C';
    goto __pyx_L0;

    /* "View.MemoryView":1131
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  }

  /* "View.MemoryView":1134
 *         return 'C'
 *     else:
 *         return 'F'             # <<<<<<<<<<<<<<
 * 
 * @cython.cdivision(True)
 */
  /*else*/ {
    __pyx_r = 'F';
    goto __pyx_L0;
  }

  /* "View.MemoryView":1113
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1137
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

static void _copy_strided_to_strided(char *__pyx_v_src_data, Py_ssize_t *__pyx_v_src_strides, char *__pyx_v_dst_data, Py_ssize_t *__pyx_v_dst_strides, Py_ssize_t *__pyx_v_src_shape, Py_ssize_t *__pyx_v_dst_shape, int __pyx_v_ndim, size_t __pyx_v_itemsize) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  CYTHON_UNUSED Py_ssize_t __pyx_v_src_extent;
  Py_ssize_t __pyx_v_dst_extent;
  Py_ssize_t __pyx_v_src_stride;
  Py_ssize_t __pyx_v_dst_stride;
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;

  /* "View.MemoryView":1144
 * 
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 */
  __pyx_v_src_extent = (__pyx_v_src_shape[0]);

  /* "View.MemoryView":1145
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 */
  __pyx_v_dst_extent = (__pyx_v_dst_shape[0]);

  /* "View.MemoryView":1146
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 */
  __pyx_v_src_stride = (__pyx_v_src_strides[0]);

  /* "View.MemoryView":1147
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_dst_stride = (__pyx_v_dst_strides[0]);

  /* "View.MemoryView":1149
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
  __pyx_t_1 = (__pyx_v_ndim == 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    __pyx_t_2 = (__pyx_v_src_stride > 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_dst_stride > 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }

    /* "View.MemoryView":1151
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):             # <<<<<<<<<<<<<<
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 *         else:
 */
    __pyx_t_2 = (((size_t)__pyx_v_src_stride) == __pyx_v_itemsize);
    if (__pyx_t_2) {
      __pyx_t_2 = (__pyx_v_itemsize == ((size_t)__pyx_v_dst_stride));
    }
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;

    /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    if (__pyx_t_1) {

      /* "View.MemoryView":1152
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)             # <<<<<<<<<<<<<<
 *         else:
 *             for i in range(dst_extent):
 */
      (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, (__pyx_v_itemsize * __pyx_v_dst_extent)));

      /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
      goto __pyx_L4;
    }

    /* "View.MemoryView":1154
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 *         else:
 *             for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride
 */
    /*else*/ {
      __pyx_t_3 = __pyx_v_dst_extent;
      __pyx_t_4 = __pyx_t_3;
      for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
        __pyx_v_i = __pyx_t_5;

        /* "View.MemoryView":1155
 *         else:
 *             for i in range(dst_extent):
 *                 memcpy(dst_data, src_data, itemsize)             # <<<<<<<<<<<<<<
 *                 src_data += src_stride
 *                 dst_data += dst_stride
 */
        (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, __pyx_v_itemsize));

        /* "View.MemoryView":1156
 *             for i in range(dst_extent):
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride             # <<<<<<<<<<<<<<
 *                 dst_data += dst_stride
 *     else:
 */
        __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

        /* "View.MemoryView":1157
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride
 *                 dst_data += dst_stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(dst_extent):
 */
        __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
      }
    }
    __pyx_L4:;

    /* "View.MemoryView":1149
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1159
 *                 dst_data += dst_stride
 *     else:
 *         for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *             _copy_strided_to_strided(src_data, src_strides + 1,
 *                                      dst_data, dst_strides + 1,
 */
  /*else*/ {
    __pyx_t_3 = __pyx_v_dst_extent;
    __pyx_t_4 = __pyx_t_3;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_i = __pyx_t_5;

      /* "View.MemoryView":1160
 *     else:
 *         for i in range(dst_extent):
 *             _copy_strided_to_strided(src_data, src_strides + 1,             # <<<<<<<<<<<<<<
 *                                      dst_data, dst_strides + 1,
 *                                      src_shape + 1, dst_shape + 1,
 */
      _copy_strided_to_strided(__pyx_v_src_data, (__pyx_v_src_strides + 1), __pyx_v_dst_data, (__pyx_v_dst_strides + 1), (__pyx_v_src_shape + 1), (__pyx_v_dst_shape + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize);

      /* "View.MemoryView":1164
 *                                      src_shape + 1, dst_shape + 1,
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride             # <<<<<<<<<<<<<<
 *             dst_data += dst_stride
 * 
 */
      __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

      /* "View.MemoryView":1165
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride
 *             dst_data += dst_stride             # <<<<<<<<<<<<<<
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,
 */
      __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1137
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

  /* function exit code */
}

/* "View.MemoryView":1167
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 */

static void copy_strided_to_strided(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize) {

  /* "View.MemoryView":1170
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 *     _copy_strided_to_strided(src.data, src.strides, dst.data, dst.strides,             # <<<<<<<<<<<<<<
 *                              src.shape, dst.shape, ndim, itemsize)
 * 
 */
  _copy_strided_to_strided(__pyx_v_src->data, __pyx_v_src->strides, __pyx_v_dst->data, __pyx_v_dst->strides, __pyx_v_src->shape, __pyx_v_dst->shape, __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1167
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1174
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *__pyx_v_src, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_size;
  Py_ssize_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;

  /* "View.MemoryView":1176
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     for shape in src.shape[:ndim]:
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_size = __pyx_t_1;

  /* "View.MemoryView":1178
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 * 
 *     for shape in src.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         size *= shape
 * 
 */
  __pyx_t_3 = (__pyx_v_src->shape + __pyx_v_ndim);
  for (__pyx_t_4 = __pyx_v_src->shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
    __pyx_t_2 = __pyx_t_4;
    __pyx_v_shape = (__pyx_t_2[0]);

    /* "View.MemoryView":1179
 * 
 *     for shape in src.shape[:ndim]:
 *         size *= shape             # <<<<<<<<<<<<<<
 * 
 *     return size
 */
    __pyx_v_size = (__pyx_v_size * __pyx_v_shape);
  }

  /* "View.MemoryView":1181
 *         size *= shape
 * 
 *     return size             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_fill_contig_strides_array')
 */
  __pyx_r = __pyx_v_size;
  goto __pyx_L0;

  /* "View.MemoryView":1174
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1184
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) noexcept nogil:
 */

static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, Py_ssize_t __pyx_v_stride, int __pyx_v_ndim, char __pyx_v_order) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1193
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
  __pyx_t_1 = (__pyx_v_order == 'F');
  if (__pyx_t_1) {

    /* "View.MemoryView":1194
 * 
 *     if order == 'F':
 *         for idx in range(ndim):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
    __pyx_t_2 = __pyx_v_ndim;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_idx = __pyx_t_4;

      /* "View.MemoryView":1195
 *     if order == 'F':
 *         for idx in range(ndim):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 *     else:
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1196
 *         for idx in range(ndim):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }

    /* "View.MemoryView":1193
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1198
 *             stride *= shape[idx]
 *     else:
 *         for idx in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
  /*else*/ {
    for (__pyx_t_2 = (__pyx_v_ndim - 1); __pyx_t_2 > -1; __pyx_t_2-=1) {
      __pyx_v_idx = __pyx_t_2;

      /* "View.MemoryView":1199
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 * 
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1200
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 * 
 *     return stride
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1202
 *             stride *= shape[idx]
 * 
 *     return stride             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 */
  __pyx_r = __pyx_v_stride;
  goto __pyx_L0;

  /* "View.MemoryView":1184
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) noexcept nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1205
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_tmpslice, char __pyx_v_order, int __pyx_v_ndim) {
  int __pyx_v_i;
  void *__pyx_v_result;
  size_t __pyx_v_itemsize;
  size_t __pyx_v_size;
  void *__pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  struct __pyx_memoryview_obj *__pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":1216
 *     cdef void *result
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1217
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef size_t size = slice_get_size(src, ndim)             # <<<<<<<<<<<<<<
 * 
 *     result = malloc(size)
 */
  __pyx_v_size = __pyx_memoryview_slice_get_size(__pyx_v_src, __pyx_v_ndim);

  /* "View.MemoryView":1219
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 *     result = malloc(size)             # <<<<<<<<<<<<<<
 *     if not result:
 *         _err_no_memory()
 */
  __pyx_v_result = malloc(__pyx_v_size);

  /* "View.MemoryView":1220
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err_no_memory()
 * 
 */
  __pyx_t_2 = (!(__pyx_v_result != 0));
  if (__pyx_t_2) {

    /* "View.MemoryView":1221
 *     result = malloc(size)
 *     if not result:
 *         _err_no_memory()             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __pyx_memoryview_err_no_memory(); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 1221, __pyx_L1_error)

    /* "View.MemoryView":1220
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err_no_memory()
 * 
 */
  }

  /* "View.MemoryView":1224
 * 
 * 
 *     tmpslice.data = <char *> result             # <<<<<<<<<<<<<<
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 */
  __pyx_v_tmpslice->data = ((char *)__pyx_v_result);

  /* "View.MemoryView":1225
 * 
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview             # <<<<<<<<<<<<<<
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 */
  __pyx_t_4 = __pyx_v_src->memview;
  __pyx_v_tmpslice->memview = __pyx_t_4;

  /* "View.MemoryView":1226
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1227
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]             # <<<<<<<<<<<<<<
 *         tmpslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_tmpslice->shape[__pyx_v_i]) = (__pyx_v_src->shape[__pyx_v_i]);

    /* "View.MemoryView":1228
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize, ndim, order)
 */
    (__pyx_v_tmpslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1230
 *         tmpslice.suboffsets[i] = -1
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize, ndim, order)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  (void)(__pyx_fill_contig_strides_array((&(__pyx_v_tmpslice->shape[0])), (&(__pyx_v_tmpslice->strides[0])), __pyx_v_itemsize, __pyx_v_ndim, __pyx_v_order));

  /* "View.MemoryView":1233
 * 
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1234
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    __pyx_t_2 = ((__pyx_v_tmpslice->shape[__pyx_v_i]) == 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1235
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     if slice_is_contig(src[0], order, ndim):
 */
      (__pyx_v_tmpslice->strides[__pyx_v_i]) = 0;

      /* "View.MemoryView":1234
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    }
  }

  /* "View.MemoryView":1237
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
  __pyx_t_2 = __pyx_memviewslice_is_contig((__pyx_v_src[0]), __pyx_v_order, __pyx_v_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1238
 * 
 *     if slice_is_contig(src[0], order, ndim):
 *         memcpy(result, src.data, size)             # <<<<<<<<<<<<<<
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 */
    (void)(memcpy(__pyx_v_result, __pyx_v_src->data, __pyx_v_size));

    /* "View.MemoryView":1237
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":1240
 *         memcpy(result, src.data, size)
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  /*else*/ {
    copy_strided_to_strided(__pyx_v_src, __pyx_v_tmpslice, __pyx_v_ndim, __pyx_v_itemsize);
  }
  __pyx_L9:;

  /* "View.MemoryView":1242
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":1205
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.copy_data_to_temp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1247
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"
 */

static int __pyx_memoryview_err_extents(int __pyx_v_i, Py_ssize_t __pyx_v_extent1, Py_ssize_t __pyx_v_extent2) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_extents", 0);

  /* "View.MemoryView":1249
 * cdef int _err_extents(int i, Py_ssize_t extent1,
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err_dim')
 */
  __pyx_t_1 = PyTuple_New(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u_got_differing_extents_in_dimensi);
  __pyx_t_2 += 35;
  __Pyx_GIVEREF(__pyx_kp_u_got_differing_extents_in_dimensi);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_got_differing_extents_in_dimensi);
  __pyx_t_4 = __Pyx_PyUnicode_From_int(__pyx_v_i, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_got);
  __pyx_t_2 += 6;
  __Pyx_GIVEREF(__pyx_kp_u_got);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_got);
  __pyx_t_4 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_extent1, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_and);
  __pyx_t_2 += 5;
  __Pyx_GIVEREF(__pyx_kp_u_and);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u_and);
  __pyx_t_4 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_extent2, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__7);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__7);
  PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_kp_u__7);
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 7, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_4, 0, 0);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(1, 1249, __pyx_L1_error)

  /* "View.MemoryView":1247
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView._err_extents", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1252
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg % dim
 * 
 */

static int __pyx_memoryview_err_dim(PyObject *__pyx_v_error, PyObject *__pyx_v_msg, int __pyx_v_dim) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_dim", 0);
  __Pyx_INCREF(__pyx_v_msg);

  /* "View.MemoryView":1253
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:
 *     raise <object>error, msg % dim             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err')
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_dim); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyString_FormatSafe(__pyx_v_msg, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(((PyObject *)__pyx_v_error), __pyx_t_2, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(1, 1253, __pyx_L1_error)

  /* "View.MemoryView":1252
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg % dim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView._err_dim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1256
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg
 * 
 */

static int __pyx_memoryview_err(PyObject *__pyx_v_error, PyObject *__pyx_v_msg) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err", 0);
  __Pyx_INCREF(__pyx_v_msg);

  /* "View.MemoryView":1257
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:
 *     raise <object>error, msg             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 */
  __Pyx_Raise(((PyObject *)__pyx_v_error), __pyx_v_msg, 0, 0);
  __PYX_ERR(1, 1257, __pyx_L1_error)

  /* "View.MemoryView":1256
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._err", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1260
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise MemoryError
 * 
 */

static int __pyx_memoryview_err_no_memory(void) {
  int __pyx_r;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif

  /* "View.MemoryView":1261
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:
 *     raise MemoryError             # <<<<<<<<<<<<<<
 * 
 * 
 */
  PyErr_NoMemory(); __PYX_ERR(1, 1261, __pyx_L1_error)

  /* "View.MemoryView":1260
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise MemoryError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._err_no_memory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1265
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

static int __pyx_memoryview_copy_contents(__Pyx_memviewslice __pyx_v_src, __Pyx_memviewslice __pyx_v_dst, int __pyx_v_src_ndim, int __pyx_v_dst_ndim, int __pyx_v_dtype_is_object) {
  void *__pyx_v_tmpdata;
  size_t __pyx_v_itemsize;
  int __pyx_v_i;
  char __pyx_v_order;
  int __pyx_v_broadcasting;
  int __pyx_v_direct_copy;
  __Pyx_memviewslice __pyx_v_tmp;
  int __pyx_v_ndim;
  int __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  void *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":1273
 *     Check for overlapping memory and verify the shapes.
 *     """
 *     cdef void *tmpdata = NULL             # <<<<<<<<<<<<<<
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 */
  __pyx_v_tmpdata = NULL;

  /* "View.MemoryView":1274
 *     """
 *     cdef void *tmpdata = NULL
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 */
  __pyx_t_1 = __pyx_v_src.memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1276
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)             # <<<<<<<<<<<<<<
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False
 */
  __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_src), __pyx_v_src_ndim);

  /* "View.MemoryView":1277
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False             # <<<<<<<<<<<<<<
 *     cdef bint direct_copy = False
 *     cdef __Pyx_memviewslice tmp
 */
  __pyx_v_broadcasting = 0;

  /* "View.MemoryView":1278
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False             # <<<<<<<<<<<<<<
 *     cdef __Pyx_memviewslice tmp
 * 
 */
  __pyx_v_direct_copy = 0;

  /* "View.MemoryView":1281
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
  __pyx_t_2 = (__pyx_v_src_ndim < __pyx_v_dst_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1282
 * 
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_src), __pyx_v_src_ndim, __pyx_v_dst_ndim);

    /* "View.MemoryView":1281
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1283
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  __pyx_t_2 = (__pyx_v_dst_ndim < __pyx_v_src_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1284
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)             # <<<<<<<<<<<<<<
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_dst), __pyx_v_dst_ndim, __pyx_v_src_ndim);

    /* "View.MemoryView":1283
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":1286
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
  __pyx_t_3 = __pyx_v_dst_ndim;
  __pyx_t_4 = __pyx_v_src_ndim;
  __pyx_t_2 = (__pyx_t_3 > __pyx_t_4);
  if (__pyx_t_2) {
    __pyx_t_5 = __pyx_t_3;
  } else {
    __pyx_t_5 = __pyx_t_4;
  }
  __pyx_v_ndim = __pyx_t_5;

  /* "View.MemoryView":1288
 *     cdef int ndim = max(src_ndim, dst_ndim)
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 */
  __pyx_t_5 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_5;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1289
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    __pyx_t_2 = ((__pyx_v_src.shape[__pyx_v_i]) != (__pyx_v_dst.shape[__pyx_v_i]));
    if (__pyx_t_2) {

      /* "View.MemoryView":1290
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
      __pyx_t_2 = ((__pyx_v_src.shape[__pyx_v_i]) == 1);
      if (__pyx_t_2) {

        /* "View.MemoryView":1291
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 *                 broadcasting = True             # <<<<<<<<<<<<<<
 *                 src.strides[i] = 0
 *             else:
 */
        __pyx_v_broadcasting = 1;

        /* "View.MemoryView":1292
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 *                 src.strides[i] = 0             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 */
        (__pyx_v_src.strides[__pyx_v_i]) = 0;

        /* "View.MemoryView":1290
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":1294
 *                 src.strides[i] = 0
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])             # <<<<<<<<<<<<<<
 * 
 *         if src.suboffsets[i] >= 0:
 */
      /*else*/ {
        __pyx_t_6 = __pyx_memoryview_err_extents(__pyx_v_i, (__pyx_v_dst.shape[__pyx_v_i]), (__pyx_v_src.shape[__pyx_v_i])); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(1, 1294, __pyx_L1_error)
      }
      __pyx_L7:;

      /* "View.MemoryView":1289
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    }

    /* "View.MemoryView":1296
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 */
    __pyx_t_2 = ((__pyx_v_src.suboffsets[__pyx_v_i]) >= 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1297
 * 
 *         if src.suboffsets[i] >= 0:
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)             # <<<<<<<<<<<<<<
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 */
      __pyx_t_6 = __pyx_memoryview_err_dim(PyExc_ValueError, __pyx_kp_s_Dimension_d_is_not_direct, __pyx_v_i); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(1, 1297, __pyx_L1_error)

      /* "View.MemoryView":1296
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 */
    }
  }

  /* "View.MemoryView":1299
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  __pyx_t_2 = __pyx_slices_overlap((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize);
  if (__pyx_t_2) {

    /* "View.MemoryView":1301
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    __pyx_t_2 = (!__pyx_memviewslice_is_contig(__pyx_v_src, __pyx_v_order, __pyx_v_ndim));
    if (__pyx_t_2) {

      /* "View.MemoryView":1302
 * 
 *         if not slice_is_contig(src, order, ndim):
 *             order = get_best_order(&dst, ndim)             # <<<<<<<<<<<<<<
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 */
      __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim);

      /* "View.MemoryView":1301
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    }

    /* "View.MemoryView":1304
 *             order = get_best_order(&dst, ndim)
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)             # <<<<<<<<<<<<<<
 *         src = tmp
 * 
 */
    __pyx_t_7 = __pyx_memoryview_copy_data_to_temp((&__pyx_v_src), (&__pyx_v_tmp), __pyx_v_order, __pyx_v_ndim); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(1, 1304, __pyx_L1_error)
    __pyx_v_tmpdata = __pyx_t_7;

    /* "View.MemoryView":1305
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 *         src = tmp             # <<<<<<<<<<<<<<
 * 
 *     if not broadcasting:
 */
    __pyx_v_src = __pyx_v_tmp;

    /* "View.MemoryView":1299
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  }

  /* "View.MemoryView":1307
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (!__pyx_v_broadcasting);
  if (__pyx_t_2) {

    /* "View.MemoryView":1310
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
    __pyx_t_2 = __pyx_memviewslice_is_contig(__pyx_v_src, 'C', __pyx_v_ndim);
    if (__pyx_t_2) {

      /* "View.MemoryView":1311
 * 
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)             # <<<<<<<<<<<<<<
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'C', __pyx_v_ndim);

      /* "View.MemoryView":1310
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
      goto __pyx_L12;
    }

    /* "View.MemoryView":1312
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    __pyx_t_2 = __pyx_memviewslice_is_contig(__pyx_v_src, 'F', __pyx_v_ndim);
    if (__pyx_t_2) {

      /* "View.MemoryView":1313
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)             # <<<<<<<<<<<<<<
 * 
 *         if direct_copy:
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'F', __pyx_v_ndim);

      /* "View.MemoryView":1312
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    }
    __pyx_L12:;

    /* "View.MemoryView":1315
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    if (__pyx_v_direct_copy) {

      /* "View.MemoryView":1317
 *         if direct_copy:
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

      /* "View.MemoryView":1318
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))             # <<<<<<<<<<<<<<
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)
 */
      (void)(memcpy(__pyx_v_dst.data, __pyx_v_src.data, __pyx_memoryview_slice_get_size((&__pyx_v_src), __pyx_v_ndim)));

      /* "View.MemoryView":1319
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 *             free(tmpdata)
 *             return 0
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

      /* "View.MemoryView":1320
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
      free(__pyx_v_tmpdata);

      /* "View.MemoryView":1321
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "View.MemoryView":1315
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    }

    /* "View.MemoryView":1307
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1323
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (__pyx_v_order == 'F');
  if (__pyx_t_2) {
    __pyx_t_2 = ('F' == __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim));
  }
  if (__pyx_t_2) {

    /* "View.MemoryView":1326
 * 
 * 
 *         transpose_memslice(&src)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&dst)
 * 
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_src)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 1326, __pyx_L1_error)

    /* "View.MemoryView":1327
 * 
 *         transpose_memslice(&src)
 *         transpose_memslice(&dst)             # <<<<<<<<<<<<<<
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_dst)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 1327, __pyx_L1_error)

    /* "View.MemoryView":1323
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1329
 *         transpose_memslice(&dst)
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1330
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)             # <<<<<<<<<<<<<<
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 * 
 */
  copy_strided_to_strided((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1331
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 * 
 *     free(tmpdata)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1333
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 * 
 *     free(tmpdata)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
  free(__pyx_v_tmpdata);

  /* "View.MemoryView":1334
 * 
 *     free(tmpdata)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1265
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy_contents", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1337
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) noexcept nogil:
 */

static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim, int __pyx_v_ndim_other) {
  int __pyx_v_i;
  int __pyx_v_offset;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "View.MemoryView":1341
 *                             int ndim_other) noexcept nogil:
 *     cdef int i
 *     cdef int offset = ndim_other - ndim             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_offset = (__pyx_v_ndim_other - __pyx_v_ndim);

  /* "View.MemoryView":1343
 *     cdef int offset = ndim_other - ndim
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1344
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]             # <<<<<<<<<<<<<<
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 */
    (__pyx_v_mslice->shape[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->shape[__pyx_v_i]);

    /* "View.MemoryView":1345
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 */
    (__pyx_v_mslice->strides[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->strides[__pyx_v_i]);

    /* "View.MemoryView":1346
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(offset):
 */
    (__pyx_v_mslice->suboffsets[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->suboffsets[__pyx_v_i]);
  }

  /* "View.MemoryView":1348
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 *     for i in range(offset):             # <<<<<<<<<<<<<<
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 */
  __pyx_t_1 = __pyx_v_offset;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1349
 * 
 *     for i in range(offset):
 *         mslice.shape[i] = 1             # <<<<<<<<<<<<<<
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1
 */
    (__pyx_v_mslice->shape[__pyx_v_i]) = 1;

    /* "View.MemoryView":1350
 *     for i in range(offset):
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_mslice->strides[__pyx_v_i]) = (__pyx_v_mslice->strides[0]);

    /* "View.MemoryView":1351
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_mslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1337
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1359
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:             # <<<<<<<<<<<<<<
 * 
 *     if dtype_is_object:
 */

static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_dtype_is_object, int __pyx_v_ndim, int __pyx_v_inc) {

  /* "View.MemoryView":1361
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)
 * 
 */
  if (__pyx_v_dtype_is_object) {

    /* "View.MemoryView":1362
 * 
 *     if dtype_is_object:
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 */
    __pyx_memoryview_refcount_objects_in_slice_with_gil(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_inc);

    /* "View.MemoryView":1361
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)
 * 
 */
  }

  /* "View.MemoryView":1359
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:             # <<<<<<<<<<<<<<
 * 
 *     if dtype_is_object:
 */

  /* function exit code */
}

/* "View.MemoryView":1365
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 */

static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif

  /* "View.MemoryView":1368
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 *     refcount_objects_in_slice(data, shape, strides, ndim, inc)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 */
  __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, __pyx_v_shape, __pyx_v_strides, __pyx_v_ndim, __pyx_v_inc);

  /* "View.MemoryView":1365
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 */

  /* function exit code */
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 */

static void __pyx_memoryview_refcount_objects_in_slice(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1374
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(shape[0]):
 */
  __pyx_v_stride = (__pyx_v_strides[0]);

  /* "View.MemoryView":1376
 *     cdef Py_ssize_t stride = strides[0]
 * 
 *     for i in range(shape[0]):             # <<<<<<<<<<<<<<
 *         if ndim == 1:
 *             if inc:
 */
  __pyx_t_1 = (__pyx_v_shape[0]);
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1377
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
    __pyx_t_4 = (__pyx_v_ndim == 1);
    if (__pyx_t_4) {

      /* "View.MemoryView":1378
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
      if (__pyx_v_inc) {

        /* "View.MemoryView":1379
 *         if ndim == 1:
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])
 */
        Py_INCREF((((PyObject **)__pyx_v_data)[0]));

        /* "View.MemoryView":1378
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
        goto __pyx_L6;
      }

      /* "View.MemoryView":1381
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)
 */
      /*else*/ {
        Py_DECREF((((PyObject **)__pyx_v_data)[0]));
      }
      __pyx_L6:;

      /* "View.MemoryView":1377
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":1383
 *                 Py_DECREF((<PyObject **> data)[0])
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)             # <<<<<<<<<<<<<<
 * 
 *         data += stride
 */
    /*else*/ {
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_inc);
    }
    __pyx_L5:;

    /* "View.MemoryView":1385
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)
 * 
 *         data += stride             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
  }

  /* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 */

  /* function exit code */
}

/* "View.MemoryView":1391
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 */

static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item, int __pyx_v_dtype_is_object) {

  /* "View.MemoryView":1394
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1395
 *                               bint dtype_is_object) noexcept nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)             # <<<<<<<<<<<<<<
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)
 * 
 */
  __pyx_memoryview__slice_assign_scalar(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_itemsize, __pyx_v_item);

  /* "View.MemoryView":1396
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1391
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1400
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) noexcept nogil:
 */

static void __pyx_memoryview__slice_assign_scalar(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_extent;
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;

  /* "View.MemoryView":1404
 *                               size_t itemsize, void *item) noexcept nogil:
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t extent = shape[0]
 * 
 */
  __pyx_v_stride = (__pyx_v_strides[0]);

  /* "View.MemoryView":1405
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]
 *     cdef Py_ssize_t extent = shape[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_extent = (__pyx_v_shape[0]);

  /* "View.MemoryView":1407
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
  __pyx_t_1 = (__pyx_v_ndim == 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":1408
 * 
 *     if ndim == 1:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             memcpy(data, item, itemsize)
 *             data += stride
 */
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1409
 *     if ndim == 1:
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)             # <<<<<<<<<<<<<<
 *             data += stride
 *     else:
 */
      (void)(memcpy(__pyx_v_data, __pyx_v_item, __pyx_v_itemsize));

      /* "View.MemoryView":1410
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 *             data += stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(extent):
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }

    /* "View.MemoryView":1407
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1412
 *             data += stride
 *     else:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)
 *             data += stride
 */
  /*else*/ {
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1413
 *     else:
 *         for i in range(extent):
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)             # <<<<<<<<<<<<<<
 *             data += stride
 * 
 */
      __pyx_memoryview__slice_assign_scalar(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize, __pyx_v_item);

      /* "View.MemoryView":1414
 *         for i in range(extent):
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)
 *             data += stride             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1400
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) noexcept nogil:
 */

  /* function exit code */
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum = {"__pyx_unpickle_Enum", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_Enum") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum", 1);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__8, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_MemviewEnum_type), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_unpickle_Enum__set_state(((struct __pyx_MemviewEnum_obj *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum__set_state", 1);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->name);
  __Pyx_DECREF(__pyx_v___pyx_result->name);
  __pyx_v___pyx_result->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 > 1);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "BufferFormatFromTypeInfo":1450
 * 
 * @cname('__pyx_format_from_typeinfo')
 * cdef bytes format_from_typeinfo(__Pyx_TypeInfo *type):             # <<<<<<<<<<<<<<
 *     cdef __Pyx_StructField *field
 *     cdef __pyx_typeinfo_string fmt
 */

static PyObject *__pyx_format_from_typeinfo(__Pyx_TypeInfo *__pyx_v_type) {
  __Pyx_StructField *__pyx_v_field;
  struct __pyx_typeinfo_string __pyx_v_fmt;
  PyObject *__pyx_v_part = 0;
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_alignment = NULL;
  PyObject *__pyx_v_parts = NULL;
  PyObject *__pyx_v_extents = NULL;
  Py_ssize_t __pyx_7genexpr__pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_StructField *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_UCS4 __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("format_from_typeinfo", 1);

  /* "BufferFormatFromTypeInfo":1456
 *     cdef Py_ssize_t i
 * 
 *     if type.typegroup == 'S':             # <<<<<<<<<<<<<<
 *         assert type.fields != NULL
 *         assert type.fields.type != NULL
 */
  __pyx_t_1 = (__pyx_v_type->typegroup == 'S');
  if (__pyx_t_1) {

    /* "BufferFormatFromTypeInfo":1457
 * 
 *     if type.typegroup == 'S':
 *         assert type.fields != NULL             # <<<<<<<<<<<<<<
 *         assert type.fields.type != NULL
 * 
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_1 = (__pyx_v_type->fields != NULL);
      if (unlikely(!__pyx_t_1)) {
        __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
        __PYX_ERR(1, 1457, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(1, 1457, __pyx_L1_error)
    #endif

    /* "BufferFormatFromTypeInfo":1458
 *     if type.typegroup == 'S':
 *         assert type.fields != NULL
 *         assert type.fields.type != NULL             # <<<<<<<<<<<<<<
 * 
 *         if type.flags & __PYX_BUF_FLAGS_PACKED_STRUCT:
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_1 = (__pyx_v_type->fields->type != NULL);
      if (unlikely(!__pyx_t_1)) {
        __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
        __PYX_ERR(1, 1458, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(1, 1458, __pyx_L1_error)
    #endif

    /* "BufferFormatFromTypeInfo":1460
 *         assert type.fields.type != NULL
 * 
 *         if type.flags & __PYX_BUF_FLAGS_PACKED_STRUCT:             # <<<<<<<<<<<<<<
 *             alignment = b'^'
 *         else:
 */
    __pyx_t_1 = ((__pyx_v_type->flags & __PYX_BUF_FLAGS_PACKED_STRUCT) != 0);
    if (__pyx_t_1) {

      /* "BufferFormatFromTypeInfo":1461
 * 
 *         if type.flags & __PYX_BUF_FLAGS_PACKED_STRUCT:
 *             alignment = b'^'             # <<<<<<<<<<<<<<
 *         else:
 *             alignment = b''
 */
      __Pyx_INCREF(__pyx_kp_b__9);
      __pyx_v_alignment = __pyx_kp_b__9;

      /* "BufferFormatFromTypeInfo":1460
 *         assert type.fields.type != NULL
 * 
 *         if type.flags & __PYX_BUF_FLAGS_PACKED_STRUCT:             # <<<<<<<<<<<<<<
 *             alignment = b'^'
 *         else:
 */
      goto __pyx_L4;
    }

    /* "BufferFormatFromTypeInfo":1463
 *             alignment = b'^'
 *         else:
 *             alignment = b''             # <<<<<<<<<<<<<<
 * 
 *         parts = [b"T{"]
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_kp_b__10);
      __pyx_v_alignment = __pyx_kp_b__10;
    }
    __pyx_L4:;

    /* "BufferFormatFromTypeInfo":1465
 *             alignment = b''
 * 
 *         parts = [b"T{"]             # <<<<<<<<<<<<<<
 *         field = type.fields
 * 
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1465, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_kp_b_T);
    __Pyx_GIVEREF(__pyx_kp_b_T);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_kp_b_T)) __PYX_ERR(1, 1465, __pyx_L1_error);
    __pyx_v_parts = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "BufferFormatFromTypeInfo":1466
 * 
 *         parts = [b"T{"]
 *         field = type.fields             # <<<<<<<<<<<<<<
 * 
 *         while field.type:
 */
    __pyx_t_3 = __pyx_v_type->fields;
    __pyx_v_field = __pyx_t_3;

    /* "BufferFormatFromTypeInfo":1468
 *         field = type.fields
 * 
 *         while field.type:             # <<<<<<<<<<<<<<
 *             part = format_from_typeinfo(field.type)
 *             parts.append(part + b':' + field.name + b':')
 */
    while (1) {
      __pyx_t_1 = (__pyx_v_field->type != 0);
      if (!__pyx_t_1) break;

      /* "BufferFormatFromTypeInfo":1469
 * 
 *         while field.type:
 *             part = format_from_typeinfo(field.type)             # <<<<<<<<<<<<<<
 *             parts.append(part + b':' + field.name + b':')
 *             field += 1
 */
      __pyx_t_2 = __pyx_format_from_typeinfo(__pyx_v_field->type); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_part, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "BufferFormatFromTypeInfo":1470
 *         while field.type:
 *             part = format_from_typeinfo(field.type)
 *             parts.append(part + b':' + field.name + b':')             # <<<<<<<<<<<<<<
 *             field += 1
 * 
 */
      __pyx_t_2 = PyNumber_Add(__pyx_v_part, __pyx_kp_b__11); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_field->name); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_kp_b__11); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_parts, __pyx_t_4); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(1, 1470, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "BufferFormatFromTypeInfo":1471
 *             part = format_from_typeinfo(field.type)
 *             parts.append(part + b':' + field.name + b':')
 *             field += 1             # <<<<<<<<<<<<<<
 * 
 *         result = alignment.join(parts) + b'}'
 */
      __pyx_v_field = (__pyx_v_field + 1);
    }

    /* "BufferFormatFromTypeInfo":1473
 *             field += 1
 * 
 *         result = alignment.join(parts) + b'}'             # <<<<<<<<<<<<<<
 *     else:
 *         fmt = __Pyx_TypeInfoToFormat(type)
 */
    __pyx_t_4 = __Pyx_PyBytes_Join(__pyx_v_alignment, __pyx_v_parts); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_kp_b__12); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_5))) __PYX_ERR(1, 1473, __pyx_L1_error)
    __pyx_v_result = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "BufferFormatFromTypeInfo":1456
 *     cdef Py_ssize_t i
 * 
 *     if type.typegroup == 'S':             # <<<<<<<<<<<<<<
 *         assert type.fields != NULL
 *         assert type.fields.type != NULL
 */
    goto __pyx_L3;
  }

  /* "BufferFormatFromTypeInfo":1475
 *         result = alignment.join(parts) + b'}'
 *     else:
 *         fmt = __Pyx_TypeInfoToFormat(type)             # <<<<<<<<<<<<<<
 *         result = fmt.string
 *         if type.arraysize[0]:
 */
  /*else*/ {
    __pyx_v_fmt = __Pyx_TypeInfoToFormat(__pyx_v_type);

    /* "BufferFormatFromTypeInfo":1476
 *     else:
 *         fmt = __Pyx_TypeInfoToFormat(type)
 *         result = fmt.string             # <<<<<<<<<<<<<<
 *         if type.arraysize[0]:
 *             extents = [f"{type.arraysize[i]}" for i in range(type.ndim)]
 */
    __pyx_t_5 = __Pyx_PyObject_FromString(__pyx_v_fmt.string); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_result = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "BufferFormatFromTypeInfo":1477
 *         fmt = __Pyx_TypeInfoToFormat(type)
 *         result = fmt.string
 *         if type.arraysize[0]:             # <<<<<<<<<<<<<<
 *             extents = [f"{type.arraysize[i]}" for i in range(type.ndim)]
 *             result = f"({u','.join(extents)})".encode('ascii') + result
 */
    __pyx_t_1 = ((__pyx_v_type->arraysize[0]) != 0);
    if (__pyx_t_1) {

      /* "BufferFormatFromTypeInfo":1478
 *         result = fmt.string
 *         if type.arraysize[0]:
 *             extents = [f"{type.arraysize[i]}" for i in range(type.ndim)]             # <<<<<<<<<<<<<<
 *             result = f"({u','.join(extents)})".encode('ascii') + result
 * 
 */
      { /* enter inner scope */
        __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1478, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = __pyx_v_type->ndim;
        __pyx_t_8 = __pyx_t_7;
        for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
          __pyx_7genexpr__pyx_v_i = __pyx_t_9;
          __pyx_t_4 = __Pyx_PyUnicode_From_size_t((__pyx_v_type->arraysize[__pyx_7genexpr__pyx_v_i]), 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1478, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(__Pyx_ListComp_Append(__pyx_t_5, (PyObject*)__pyx_t_4))) __PYX_ERR(1, 1478, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      } /* exit inner scope */
      __pyx_v_extents = ((PyObject*)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "BufferFormatFromTypeInfo":1479
 *         if type.arraysize[0]:
 *             extents = [f"{type.arraysize[i]}" for i in range(type.ndim)]
 *             result = f"({u','.join(extents)})".encode('ascii') + result             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
      __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = 0;
      __pyx_t_10 = 127;
      __Pyx_INCREF(__pyx_kp_u__13);
      __pyx_t_9 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__13);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u__13);
      __pyx_t_4 = PyUnicode_Join(__pyx_kp_u__14, __pyx_v_extents); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_10;
      __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_kp_u__7);
      __pyx_t_9 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__7);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u__7);
      __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_5, 3, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyUnicode_AsASCIIString(((PyObject*)__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Add(__pyx_t_5, __pyx_v_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (!(likely(PyBytes_CheckExact(__pyx_t_4)) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_4))) __PYX_ERR(1, 1479, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "BufferFormatFromTypeInfo":1477
 *         fmt = __Pyx_TypeInfoToFormat(type)
 *         result = fmt.string
 *         if type.arraysize[0]:             # <<<<<<<<<<<<<<
 *             extents = [f"{type.arraysize[i]}" for i in range(type.ndim)]
 *             result = f"({u','.join(extents)})".encode('ascii') + result
 */
    }
  }
  __pyx_L3:;

  /* "BufferFormatFromTypeInfo":1481
 *             result = f"({u','.join(extents)})".encode('ascii') + result
 * 
 *     return result             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "BufferFormatFromTypeInfo":1450
 * 
 * @cname('__pyx_format_from_typeinfo')
 * cdef bytes format_from_typeinfo(__Pyx_TypeInfo *type):             # <<<<<<<<<<<<<<
 *     cdef __Pyx_StructField *field
 *     cdef __pyx_typeinfo_string fmt
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("BufferFormatFromTypeInfo.format_from_typeinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_alignment);
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XDECREF(__pyx_v_extents);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":286
 * 
 *         @property
 *         cdef inline npy_intp itemsize(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             return PyDataType_ELSIZE(self)
 * 
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_5dtype_8itemsize_itemsize(PyArray_Descr *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":287
 *         @property
 *         cdef inline npy_intp itemsize(self) noexcept nogil:
 *             return PyDataType_ELSIZE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDataType_ELSIZE(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":286
 * 
 *         @property
 *         cdef inline npy_intp itemsize(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             return PyDataType_ELSIZE(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":290
 * 
 *         @property
 *         cdef inline npy_intp alignment(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             return PyDataType_ALIGNMENT(self)
 * 
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_5dtype_9alignment_alignment(PyArray_Descr *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":291
 *         @property
 *         cdef inline npy_intp alignment(self) noexcept nogil:
 *             return PyDataType_ALIGNMENT(self)             # <<<<<<<<<<<<<<
 * 
 *         # Use fields/names with care as they may be NULL.  You must check
 */
  __pyx_r = PyDataType_ALIGNMENT(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":290
 * 
 *         @property
 *         cdef inline npy_intp alignment(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             return PyDataType_ALIGNMENT(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":296
 *         # for this using PyDataType_HASFIELDS.
 *         @property
 *         cdef inline object fields(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDataType_FIELDS(self)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_5dtype_6fields_fields(PyArray_Descr *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("fields", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":297
 *         @property
 *         cdef inline object fields(self):
 *             return <object>PyDataType_FIELDS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDataType_FIELDS(__pyx_v_self);
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":296
 *         # for this using PyDataType_HASFIELDS.
 *         @property
 *         cdef inline object fields(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDataType_FIELDS(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":300
 * 
 *         @property
 *         cdef inline tuple names(self):             # <<<<<<<<<<<<<<
 *             return <tuple>PyDataType_NAMES(self)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_5dtype_5names_names(PyArray_Descr *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("names", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":301
 *         @property
 *         cdef inline tuple names(self):
 *             return <tuple>PyDataType_NAMES(self)             # <<<<<<<<<<<<<<
 * 
 *         # Use PyDataType_HASSUBARRAY to test whether this field is
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDataType_NAMES(__pyx_v_self);
  __Pyx_INCREF(((PyObject*)__pyx_t_1));
  __pyx_r = ((PyObject*)__pyx_t_1);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":300
 * 
 *         @property
 *         cdef inline tuple names(self):             # <<<<<<<<<<<<<<
 *             return <tuple>PyDataType_NAMES(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":307
 *         # this field via the inline helper method PyDataType_SHAPE.
 *         @property
 *         cdef inline PyArray_ArrayDescr* subarray(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             return PyDataType_SUBARRAY(self)
 * 
 */

static CYTHON_INLINE PyArray_ArrayDescr *__pyx_f_5numpy_5dtype_8subarray_subarray(PyArray_Descr *__pyx_v_self) {
  PyArray_ArrayDescr *__pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":308
 *         @property
 *         cdef inline PyArray_ArrayDescr* subarray(self) noexcept nogil:
 *             return PyDataType_SUBARRAY(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDataType_SUBARRAY(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":307
 *         # this field via the inline helper method PyDataType_SHAPE.
 *         @property
 *         cdef inline PyArray_ArrayDescr* subarray(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             return PyDataType_SUBARRAY(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":311
 * 
 *         @property
 *         cdef inline npy_uint64 flags(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The data types flags."""
 *             return PyDataType_FLAGS(self)
 */

static CYTHON_INLINE npy_uint64 __pyx_f_5numpy_5dtype_5flags_flags(PyArray_Descr *__pyx_v_self) {
  npy_uint64 __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":313
 *         cdef inline npy_uint64 flags(self) noexcept nogil:
 *             """The data types flags."""
 *             return PyDataType_FLAGS(self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyDataType_FLAGS(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":311
 * 
 *         @property
 *         cdef inline npy_uint64 flags(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The data types flags."""
 *             return PyDataType_FLAGS(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":323
 * 
 *         @property
 *         cdef inline int numiter(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The number of arrays that need to be broadcast to the same shape."""
 *             return PyArray_MultiIter_NUMITER(self)
 */

static CYTHON_INLINE int __pyx_f_5numpy_9broadcast_7numiter_numiter(PyArrayMultiIterObject *__pyx_v_self) {
  int __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":325
 *         cdef inline int numiter(self) noexcept nogil:
 *             """The number of arrays that need to be broadcast to the same shape."""
 *             return PyArray_MultiIter_NUMITER(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_MultiIter_NUMITER(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":323
 * 
 *         @property
 *         cdef inline int numiter(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The number of arrays that need to be broadcast to the same shape."""
 *             return PyArray_MultiIter_NUMITER(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":328
 * 
 *         @property
 *         cdef inline npy_intp size(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The total broadcasted size."""
 *             return PyArray_MultiIter_SIZE(self)
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_9broadcast_4size_size(PyArrayMultiIterObject *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":330
 *         cdef inline npy_intp size(self) noexcept nogil:
 *             """The total broadcasted size."""
 *             return PyArray_MultiIter_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_MultiIter_SIZE(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":328
 * 
 *         @property
 *         cdef inline npy_intp size(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The total broadcasted size."""
 *             return PyArray_MultiIter_SIZE(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":333
 * 
 *         @property
 *         cdef inline npy_intp index(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The current (1-d) index into the broadcasted result."""
 *             return PyArray_MultiIter_INDEX(self)
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_9broadcast_5index_index(PyArrayMultiIterObject *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":335
 *         cdef inline npy_intp index(self) noexcept nogil:
 *             """The current (1-d) index into the broadcasted result."""
 *             return PyArray_MultiIter_INDEX(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_MultiIter_INDEX(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":333
 * 
 *         @property
 *         cdef inline npy_intp index(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The current (1-d) index into the broadcasted result."""
 *             return PyArray_MultiIter_INDEX(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":338
 * 
 *         @property
 *         cdef inline int nd(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The number of dimensions in the broadcasted result."""
 *             return PyArray_MultiIter_NDIM(self)
 */

static CYTHON_INLINE int __pyx_f_5numpy_9broadcast_2nd_nd(PyArrayMultiIterObject *__pyx_v_self) {
  int __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":340
 *         cdef inline int nd(self) noexcept nogil:
 *             """The number of dimensions in the broadcasted result."""
 *             return PyArray_MultiIter_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_MultiIter_NDIM(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":338
 * 
 *         @property
 *         cdef inline int nd(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The number of dimensions in the broadcasted result."""
 *             return PyArray_MultiIter_NDIM(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":343
 * 
 *         @property
 *         cdef inline npy_intp* dimensions(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The shape of the broadcasted result."""
 *             return PyArray_MultiIter_DIMS(self)
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_9broadcast_10dimensions_dimensions(PyArrayMultiIterObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":345
 *         cdef inline npy_intp* dimensions(self) noexcept nogil:
 *             """The shape of the broadcasted result."""
 *             return PyArray_MultiIter_DIMS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_MultiIter_DIMS(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":343
 * 
 *         @property
 *         cdef inline npy_intp* dimensions(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The shape of the broadcasted result."""
 *             return PyArray_MultiIter_DIMS(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":348
 * 
 *         @property
 *         cdef inline void** iters(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """An array of iterator objects that holds the iterators for the arrays to be broadcast together.
 *             On return, the iterators are adjusted for broadcasting."""
 */

static CYTHON_INLINE void **__pyx_f_5numpy_9broadcast_5iters_iters(PyArrayMultiIterObject *__pyx_v_self) {
  void **__pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":351
 *             """An array of iterator objects that holds the iterators for the arrays to be broadcast together.
 *             On return, the iterators are adjusted for broadcasting."""
 *             return PyArray_MultiIter_ITERS(self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyArray_MultiIter_ITERS(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":348
 * 
 *         @property
 *         cdef inline void** iters(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """An array of iterator objects that holds the iterators for the arrays to be broadcast together.
 *             On return, the iterators are adjusted for broadcasting."""
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":366
 * 
 *         @property
 *         cdef inline PyObject* base(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self) {
  PyObject *__pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":369
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 *             return PyArray_BASE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_BASE(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":366
 * 
 *         @property
 *         cdef inline PyObject* base(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":372
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self) {
  PyArray_Descr *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyArray_Descr *__pyx_t_1;
  __Pyx_RefNannySetupContext("descr", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":375
 *             """Returns an owned reference to the dtype of the array.
 *             """
 *             return <dtype>PyArray_DESCR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = PyArray_DESCR(__pyx_v_self);
  __Pyx_INCREF((PyObject *)((PyArray_Descr *)__pyx_t_1));
  __pyx_r = ((PyArray_Descr *)__pyx_t_1);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":372
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":378
 * 
 *         @property
 *         cdef inline int ndim(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self) {
  int __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":381
 *             """Returns the number of dimensions in the array.
 *             """
 *             return PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_NDIM(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":378
 * 
 *         @property
 *         cdef inline int ndim(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":384
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":389
 *             Can return NULL for 0-dimensional arrays.
 *             """
 *             return PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_DIMS(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":384
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":392
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":396
 *             The number of elements matches the number of dimensions of the array (ndim).
 *             """
 *             return PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_STRIDES(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":392
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":399
 * 
 *         @property
 *         cdef inline npy_intp size(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":402
 *             """Returns the total size (in number of elements) of the array.
 *             """
 *             return PyArray_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_SIZE(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":399
 * 
 *         @property
 *         cdef inline npy_intp size(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":405
 * 
 *         @property
 *         cdef inline char* data(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self) {
  char *__pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":411
 *             of `PyArray_DATA()` instead, which returns a 'void*'.
 *             """
 *             return PyArray_BYTES(self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyArray_BYTES(__pyx_v_self);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":405
 * 
 *         @property
 *         cdef inline char* data(self) noexcept nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":807
 * ctypedef long double complex clongdouble_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":808
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":807
 * ctypedef long double complex clongdouble_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":810
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":811
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":810
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":813
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":814
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":813
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":816
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":817
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":816
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":819
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":820
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":819
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":822
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":823
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = PyDataType_HASSUBARRAY(__pyx_v_d);
  if (__pyx_t_1) {

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":824
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_5numpy_5dtype_8subarray_subarray(__pyx_v_d)->shape;
    __Pyx_INCREF(((PyObject*)__pyx_t_2));
    __pyx_r = ((PyObject*)__pyx_t_2);
    goto __pyx_L0;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":823
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":826
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":822
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1010
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base) except *:             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1011
 * 
 * cdef inline void set_array_base(ndarray arr, object base) except *:
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1012
 * cdef inline void set_array_base(ndarray arr, object base) except *:
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_t_1 = PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 1012, __pyx_L1_error)

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1010
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base) except *:             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("numpy.set_array_base", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1014
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1015
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1016
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = (__pyx_v_base == NULL);
  if (__pyx_t_1) {

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1017
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1016
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1018
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1014
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1022
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_array", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1023
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1024
 * cdef inline int import_array() except -1:
 *     try:
 *         __pyx_import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy._core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1024, __pyx_L3_error)

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1023
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1025
 *     try:
 *         __pyx_import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy._core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1025, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1026
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy._core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1026, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1026, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1023
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1022
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1028
 *         raise ImportError("numpy._core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_umath", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1029
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1030
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy._core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1030, __pyx_L3_error)

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1029
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1031
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy._core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1031, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1032
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy._core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1032, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1032, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1029
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1028
 *         raise ImportError("numpy._core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1034
 *         raise ImportError("numpy._core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_ufunc", 1);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1035
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1036
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy._core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1036, __pyx_L3_error)

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1035
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1037
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy._core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1037, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1038
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy._core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1038, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1038, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1035
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1034
 *         raise ImportError("numpy._core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1041
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj) noexcept:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1053
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1041
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj) noexcept:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1056
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj) noexcept:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1068
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1056
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj) noexcept:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1071
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

static CYTHON_INLINE npy_datetime __pyx_f_5numpy_get_datetime64_value(PyObject *__pyx_v_obj) {
  npy_datetime __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1078
 *     also needed.  That can be found using `get_datetime64_unit`.
 *     """
 *     return (<PyDatetimeScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyDatetimeScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1071
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1081
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

static CYTHON_INLINE npy_timedelta __pyx_f_5numpy_get_timedelta64_value(PyObject *__pyx_v_obj) {
  npy_timedelta __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1085
 *     returns the int64 value underlying scalar numpy timedelta64 object
 *     """
 *     return (<PyTimedeltaScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyTimedeltaScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1081
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1088
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

static CYTHON_INLINE NPY_DATETIMEUNIT __pyx_f_5numpy_get_datetime64_unit(PyObject *__pyx_v_obj) {
  NPY_DATETIMEUNIT __pyx_r;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1092
 *     returns the unit part of the dtype for a numpy datetime64 object.
 *     """
 *     return <NPY_DATETIMEUNIT>(<PyDatetimeScalarObject*>obj).obmeta.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((NPY_DATETIMEUNIT)((PyDatetimeScalarObject *)__pyx_v_obj)->obmeta.base);
  goto __pyx_L0;

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1088
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":36
 * import logging
 * 
 * def configure_logging(level=logging.INFO):             # <<<<<<<<<<<<<<
 *     logging.basicConfig(
 *         format='%(levelname)s - %(message)s',
 */

static PyObject *__pyx_pf_9classy_sz_15__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_level);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_level);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_level)) __PYX_ERR(0, 36, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 36, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 36, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_1configure_logging(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_1configure_logging = {"configure_logging", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_1configure_logging, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_1configure_logging(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_level = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("configure_logging (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_level,0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);
    values[0] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_level);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_level);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 36, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "configure_logging") < 0)) __PYX_ERR(0, 36, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_level = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("configure_logging", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 36, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.configure_logging", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_configure_logging(__pyx_self, __pyx_v_level);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_configure_logging(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_level) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("configure_logging", 1);

  /* "class-sz/python/classy.pyx":37
 * 
 * def configure_logging(level=logging.INFO):
 *     logging.basicConfig(             # <<<<<<<<<<<<<<
 *         format='%(levelname)s - %(message)s',
 *         level=level
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_logging); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_basicConfig); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":38
 * def configure_logging(level=logging.INFO):
 *     logging.basicConfig(
 *         format='%(levelname)s - %(message)s',             # <<<<<<<<<<<<<<
 *         level=level
 *     )
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_format, __pyx_kp_u_levelname_s_message_s) < 0) __PYX_ERR(0, 38, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":39
 *     logging.basicConfig(
 *         format='%(levelname)s - %(message)s',
 *         level=level             # <<<<<<<<<<<<<<
 *     )
 * 
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_level, __pyx_v_level) < 0) __PYX_ERR(0, 38, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":37
 * 
 * def configure_logging(level=logging.INFO):
 *     logging.basicConfig(             # <<<<<<<<<<<<<<
 *         format='%(levelname)s - %(message)s',
 *         level=level
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":36
 * import logging
 * 
 * def configure_logging(level=logging.INFO):             # <<<<<<<<<<<<<<
 *     logging.basicConfig(
 *         format='%(levelname)s - %(message)s',
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.configure_logging", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":42
 *     )
 * 
 * def set_verbosity(verbosity):             # <<<<<<<<<<<<<<
 *     levels = {
 *         'none': logging.CRITICAL,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_3set_verbosity(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_3set_verbosity = {"set_verbosity", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_3set_verbosity, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_3set_verbosity(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_verbosity = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_verbosity (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_verbosity,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_verbosity)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 42, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_verbosity") < 0)) __PYX_ERR(0, 42, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_verbosity = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_verbosity", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 42, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.set_verbosity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_2set_verbosity(__pyx_self, __pyx_v_verbosity);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_2set_verbosity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_verbosity) {
  PyObject *__pyx_v_levels = NULL;
  PyObject *__pyx_v_level = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_verbosity", 1);

  /* "class-sz/python/classy.pyx":44
 * def set_verbosity(verbosity):
 *     levels = {
 *         'none': logging.CRITICAL,             # <<<<<<<<<<<<<<
 *         'minimal': logging.INFO,
 *         'extensive': logging.DEBUG
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logging); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_CRITICAL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_none, __pyx_t_3) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":45
 *     levels = {
 *         'none': logging.CRITICAL,
 *         'minimal': logging.INFO,             # <<<<<<<<<<<<<<
 *         'extensive': logging.DEBUG
 *     }
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_logging); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_INFO); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_minimal, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":46
 *         'none': logging.CRITICAL,
 *         'minimal': logging.INFO,
 *         'extensive': logging.DEBUG             # <<<<<<<<<<<<<<
 *     }
 *     # print(f'Setting verbosity to {verbosity}')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logging); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DEBUG); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_extensive, __pyx_t_3) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_levels = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":49
 *     }
 *     # print(f'Setting verbosity to {verbosity}')
 *     level = levels.get(verbosity, logging.INFO)             # <<<<<<<<<<<<<<
 *     configure_logging(level)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_logging); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_INFO); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_GetItemDefault(__pyx_v_levels, __pyx_v_verbosity, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_level = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":50
 *     # print(f'Setting verbosity to {verbosity}')
 *     level = levels.get(verbosity, logging.INFO)
 *     configure_logging(level)             # <<<<<<<<<<<<<<
 * 
 * @contextmanager
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_configure_logging); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_level};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":42
 *     )
 * 
 * def set_verbosity(verbosity):             # <<<<<<<<<<<<<<
 *     levels = {
 *         'none': logging.CRITICAL,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.set_verbosity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_levels);
  __Pyx_XDECREF(__pyx_v_level);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9classy_sz_6generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "class-sz/python/classy.pyx":52
 *     configure_logging(level)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def suppress_warnings():
 *     warnings.filterwarnings("ignore")
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5suppress_warnings(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5suppress_warnings = {"suppress_warnings", (PyCFunction)__pyx_pw_9classy_sz_5suppress_warnings, METH_NOARGS, 0};
static PyObject *__pyx_pw_9classy_sz_5suppress_warnings(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress_warnings (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9classy_sz_4suppress_warnings(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_4suppress_warnings(CYTHON_UNUSED PyObject *__pyx_self) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("suppress_warnings", 0);
  __pyx_cur_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings *)__pyx_tp_new_9classy_sz___pyx_scope_struct__suppress_warnings(__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 52, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9classy_sz_6generator, __pyx_codeobj__17, (PyObject *) __pyx_cur_scope, __pyx_n_s_suppress_warnings, __pyx_n_s_suppress_warnings, __pyx_n_s_classy_sz); if (unlikely(!gen)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("classy_sz.suppress_warnings", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9classy_sz_6generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  char const *__pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("suppress_warnings", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":54
 * @contextmanager
 * def suppress_warnings():
 *     warnings.filterwarnings("ignore")             # <<<<<<<<<<<<<<
 *     try:
 *         yield
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_filterwarnings); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_ignore};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":55
 * def suppress_warnings():
 *     warnings.filterwarnings("ignore")
 *     try:             # <<<<<<<<<<<<<<
 *         yield
 *     finally:
 */
  /*try:*/ {

    /* "class-sz/python/classy.pyx":56
 *     warnings.filterwarnings("ignore")
 *     try:
 *         yield             # <<<<<<<<<<<<<<
 *     finally:
 *         warnings.resetwarnings()
 */
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L7_resume_from_yield:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 56, __pyx_L5_error)
  }

  /* "class-sz/python/classy.pyx":58
 *         yield
 *     finally:
 *         warnings.resetwarnings()             # <<<<<<<<<<<<<<
 * 
 * with suppress_warnings():
 */
  /*finally:*/ {
    /*normal exit:*/{
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_warnings); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 58, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_resetwarnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 58, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_assign
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __pyx_t_5 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_7 = __pyx_filename;
      {
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_resetwarnings); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 58, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 58, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      }
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ErrRestore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_7;
      goto __pyx_L1_error;
      __pyx_L9_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "class-sz/python/classy.pyx":52
 *     configure_logging(level)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def suppress_warnings():
 *     warnings.filterwarnings("ignore")
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("suppress_warnings", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":67
 * 
 * 
 * def class_sz_in_dict_output(d):             # <<<<<<<<<<<<<<
 *     # Define the allowed keys
 *     non_class_sz_keys = {"mPk", "tCl", "lCl", "pCl"}
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_8class_sz_in_dict_output(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_8class_sz_in_dict_output = {"class_sz_in_dict_output", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_8class_sz_in_dict_output, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_8class_sz_in_dict_output(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_d = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("class_sz_in_dict_output (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_d,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_d)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 67, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "class_sz_in_dict_output") < 0)) __PYX_ERR(0, 67, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_d = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("class_sz_in_dict_output", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 67, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.class_sz_in_dict_output", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_7class_sz_in_dict_output(__pyx_self, __pyx_v_d);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_7class_sz_in_dict_output(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_v_non_class_sz_keys = NULL;
  PyObject *__pyx_v_output_string = NULL;
  PyObject *__pyx_v_output_keys = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_7genexpr__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("class_sz_in_dict_output", 1);

  /* "class-sz/python/classy.pyx":69
 * def class_sz_in_dict_output(d):
 *     # Define the allowed keys
 *     non_class_sz_keys = {"mPk", "tCl", "lCl", "pCl"}             # <<<<<<<<<<<<<<
 * 
 *     # Extract the string from dict["output"]
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PySet_Add(__pyx_t_1, __pyx_n_u_mPk) < 0) __PYX_ERR(0, 69, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_tCl) < 0) __PYX_ERR(0, 69, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_lCl) < 0) __PYX_ERR(0, 69, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_pCl) < 0) __PYX_ERR(0, 69, __pyx_L1_error)
  __pyx_v_non_class_sz_keys = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":72
 * 
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_output_string = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":76
 * 
 *     # Split the string into individual keys using a regular expression to handle commas and spaces
 *     output_keys = {key.strip() for key in re.split(r'[,\s]+', output_string) if key.strip()}             # <<<<<<<<<<<<<<
 * 
 * 
 */
  { /* enter inner scope */
    __pyx_t_2 = PySet_New(NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_split); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 76, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_kp_u_s, __pyx_v_output_string};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 76, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 76, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 76, __pyx_L5_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 76, __pyx_L5_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 76, __pyx_L5_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 76, __pyx_L5_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_7(__pyx_t_4);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 76, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_key, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_key, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 76, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_9) {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_7genexpr__pyx_v_key, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (unlikely(PySet_Add(__pyx_t_2, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 76, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_key); __pyx_7genexpr__pyx_v_key = 0;
    goto __pyx_L10_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_key); __pyx_7genexpr__pyx_v_key = 0;
    goto __pyx_L1_error;
    __pyx_L10_exit_scope:;
  } /* exit inner scope */
  __pyx_v_output_keys = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":80
 * 
 *     # Check if all keys are within the allowed keys
 *     for key in output_keys:             # <<<<<<<<<<<<<<
 * 
 *         if key not in non_class_sz_keys:
 */
  __pyx_t_6 = 0;
  __pyx_t_4 = __Pyx_set_iterator(__pyx_v_output_keys, 1, (&__pyx_t_10), (&__pyx_t_11)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_2);
  __pyx_t_2 = __pyx_t_4;
  __pyx_t_4 = 0;
  while (1) {
    __pyx_t_12 = __Pyx_set_iter_next(__pyx_t_2, __pyx_t_10, &__pyx_t_6, &__pyx_t_4, __pyx_t_11);
    if (unlikely(__pyx_t_12 == 0)) break;
    if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":82
 *     for key in output_keys:
 * 
 *         if key not in non_class_sz_keys:             # <<<<<<<<<<<<<<
 * 
 *             return True
 */
    __pyx_t_9 = (__Pyx_PySet_ContainsTF(__pyx_v_key, __pyx_v_non_class_sz_keys, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 82, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "class-sz/python/classy.pyx":84
 *         if key not in non_class_sz_keys:
 * 
 *             return True             # <<<<<<<<<<<<<<
 * 
 *     return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":82
 *     for key in output_keys:
 * 
 *         if key not in non_class_sz_keys:             # <<<<<<<<<<<<<<
 * 
 *             return True
 */
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":86
 *             return True
 * 
 *     return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":67
 * 
 * 
 * def class_sz_in_dict_output(d):             # <<<<<<<<<<<<<<
 *     # Define the allowed keys
 *     non_class_sz_keys = {"mPk", "tCl", "lCl", "pCl"}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.class_sz_in_dict_output", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_non_class_sz_keys);
  __Pyx_XDECREF(__pyx_v_output_string);
  __Pyx_XDECREF(__pyx_v_output_keys);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":89
 * 
 * 
 * def contains_specific_keys(d,specific_keys = {"tCl", "lCl", "pCl", "mPk"}):             # <<<<<<<<<<<<<<
 *     # Define the specific keys to check
 * 
 */

static PyObject *__pyx_pf_9classy_sz_17__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_specific_keys);
  __Pyx_GIVEREF(__Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_specific_keys);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self)->__pyx_arg_specific_keys)) __PYX_ERR(0, 89, __pyx_L1_error);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 89, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, Py_None)) __PYX_ERR(0, 89, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_10contains_specific_keys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_10contains_specific_keys = {"contains_specific_keys", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_10contains_specific_keys, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_10contains_specific_keys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_d = 0;
  PyObject *__pyx_v_specific_keys = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("contains_specific_keys (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_d,&__pyx_n_s_specific_keys,0};
    __pyx_defaults1 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self);
    values[1] = __Pyx_Arg_NewRef_FASTCALL(__pyx_dynamic_args->__pyx_arg_specific_keys);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_d)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 89, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_specific_keys);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 89, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "contains_specific_keys") < 0)) __PYX_ERR(0, 89, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_d = values[0];
    __pyx_v_specific_keys = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("contains_specific_keys", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 89, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.contains_specific_keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_9contains_specific_keys(__pyx_self, __pyx_v_d, __pyx_v_specific_keys);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_9contains_specific_keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d, PyObject *__pyx_v_specific_keys) {
  PyObject *__pyx_v_output_string = NULL;
  PyObject *__pyx_v_output_keys = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_8genexpr1__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("contains_specific_keys", 1);

  /* "class-sz/python/classy.pyx":94
 * 
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")             # <<<<<<<<<<<<<<
 * 
 *     # Split the string into individual keys
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_output_string = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":97
 * 
 *     # Split the string into individual keys
 *     output_keys = {key.strip() for key in re.split(r'[,\s]+', output_string)  if key.strip()}             # <<<<<<<<<<<<<<
 * 
 *     # Check if any of the specific keys are in output_keys
 */
  { /* enter inner scope */
    __pyx_t_2 = PySet_New(NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 97, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 97, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_split); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 97, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_kp_u_s, __pyx_v_output_string};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 97, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 97, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 97, __pyx_L5_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 97, __pyx_L5_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 97, __pyx_L5_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 97, __pyx_L5_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_7(__pyx_t_4);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 97, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr1__pyx_v_key, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr1__pyx_v_key, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 97, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 97, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_9) {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr1__pyx_v_key, __pyx_n_s_strip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 97, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 97, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (unlikely(PySet_Add(__pyx_t_2, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 97, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
    goto __pyx_L10_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key); __pyx_8genexpr1__pyx_v_key = 0;
    goto __pyx_L1_error;
    __pyx_L10_exit_scope:;
  } /* exit inner scope */
  __pyx_v_output_keys = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":100
 * 
 *     # Check if any of the specific keys are in output_keys
 *     for key in specific_keys:             # <<<<<<<<<<<<<<
 *         if key in output_keys:
 *             return True
 */
  if (likely(PyList_CheckExact(__pyx_v_specific_keys)) || PyTuple_CheckExact(__pyx_v_specific_keys)) {
    __pyx_t_2 = __pyx_v_specific_keys; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_specific_keys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 100, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 100, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 100, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 100, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 100, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 100, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 100, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 100, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":101
 *     # Check if any of the specific keys are in output_keys
 *     for key in specific_keys:
 *         if key in output_keys:             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
    __pyx_t_9 = (__Pyx_PySet_ContainsTF(__pyx_v_key, __pyx_v_output_keys, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 101, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "class-sz/python/classy.pyx":102
 *     for key in specific_keys:
 *         if key in output_keys:
 *             return True             # <<<<<<<<<<<<<<
 * 
 *     return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":101
 *     # Check if any of the specific keys are in output_keys
 *     for key in specific_keys:
 *         if key in output_keys:             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
    }

    /* "class-sz/python/classy.pyx":100
 * 
 *     # Check if any of the specific keys are in output_keys
 *     for key in specific_keys:             # <<<<<<<<<<<<<<
 *         if key in output_keys:
 *             return True
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":104
 *             return True
 * 
 *     return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":89
 * 
 * 
 * def contains_specific_keys(d,specific_keys = {"tCl", "lCl", "pCl", "mPk"}):             # <<<<<<<<<<<<<<
 *     # Define the specific keys to check
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.contains_specific_keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_output_string);
  __Pyx_XDECREF(__pyx_v_output_keys);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_8genexpr1__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":109
 * 
 * 
 * def contains_specific_pattern_or_keys(d):             # <<<<<<<<<<<<<<
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_12contains_specific_pattern_or_keys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_12contains_specific_pattern_or_keys = {"contains_specific_pattern_or_keys", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_12contains_specific_pattern_or_keys, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_12contains_specific_pattern_or_keys(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_d = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("contains_specific_pattern_or_keys (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_d,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_d)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 109, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "contains_specific_pattern_or_keys") < 0)) __PYX_ERR(0, 109, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_d = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("contains_specific_pattern_or_keys", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 109, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.contains_specific_pattern_or_keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_11contains_specific_pattern_or_keys(__pyx_self, __pyx_v_d);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_11contains_specific_pattern_or_keys(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_v_output_string = NULL;
  PyObject *__pyx_v_output_keys = NULL;
  PyObject *__pyx_v_pattern1 = NULL;
  PyObject *__pyx_v_pattern2 = NULL;
  PyObject *__pyx_v_pattern3 = NULL;
  PyObject *__pyx_v_other_class_sz_keys = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_8genexpr2__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("contains_specific_pattern_or_keys", 1);

  /* "class-sz/python/classy.pyx":111
 * def contains_specific_pattern_or_keys(d):
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")             # <<<<<<<<<<<<<<
 * 
 *     # Split the string into individual keys
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_output_string = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":114
 * 
 *     # Split the string into individual keys
 *     output_keys = {key.strip() for key in output_string.split(",") if key.strip()}             # <<<<<<<<<<<<<<
 * 
 *     # Define the regular expression pattern
 */
  { /* enter inner scope */
    __pyx_t_2 = PySet_New(NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 114, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_output_string, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 114, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u__14};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 114, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 114, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 114, __pyx_L5_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 114, __pyx_L5_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 114, __pyx_L5_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 114, __pyx_L5_error)
          #else
          __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_7(__pyx_t_3);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 114, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_key, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr2__pyx_v_key, __pyx_n_s_strip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 114, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 114, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_9) {
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_8genexpr2__pyx_v_key, __pyx_n_s_strip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 114, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        if (unlikely(PySet_Add(__pyx_t_2, (PyObject*)__pyx_t_1))) __PYX_ERR(0, 114, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_key); __pyx_8genexpr2__pyx_v_key = 0;
    goto __pyx_L10_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_key); __pyx_8genexpr2__pyx_v_key = 0;
    goto __pyx_L1_error;
    __pyx_L10_exit_scope:;
  } /* exit inner scope */
  __pyx_v_output_keys = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":117
 * 
 *     # Define the regular expression pattern
 *     pattern1 = re.compile(r'^[^,]+_(1h|2h|hf|3h|covmat|lensing_term|hsv)$')             # <<<<<<<<<<<<<<
 *     pattern2 = re.compile(r'^m\d+[a-zA-Z]*_to_m\d+[a-zA-Z]*$')
 *     pattern3 = re.compile(r'^\((1h|2h|3h)\)$')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_compile); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_1h_2h_hf_3h_covmat_lensing_te};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_pattern1 = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":118
 *     # Define the regular expression pattern
 *     pattern1 = re.compile(r'^[^,]+_(1h|2h|hf|3h|covmat|lensing_term|hsv)$')
 *     pattern2 = re.compile(r'^m\d+[a-zA-Z]*_to_m\d+[a-zA-Z]*$')             # <<<<<<<<<<<<<<
 *     pattern3 = re.compile(r'^\((1h|2h|3h)\)$')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_re); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_compile); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_kp_u_m_d_a_zA_Z__to_m_d_a_zA_Z};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_pattern2 = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":119
 *     pattern1 = re.compile(r'^[^,]+_(1h|2h|hf|3h|covmat|lensing_term|hsv)$')
 *     pattern2 = re.compile(r'^m\d+[a-zA-Z]*_to_m\d+[a-zA-Z]*$')
 *     pattern3 = re.compile(r'^\((1h|2h|3h)\)$')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_re); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_compile); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_1h_2h_3h};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_pattern3 = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":122
 * 
 * 
 *     other_class_sz_keys = {"tabulate_rhob_xout_at_m_and_z",             # <<<<<<<<<<<<<<
 *                             "scale_dependent_bias",
 *                             "n5k",
 */
  __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PySet_Add(__pyx_t_2, __pyx_n_u_tabulate_rhob_xout_at_m_and_z) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_scale_dependent_bias) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_n5k) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_sz_unbinned_cluster_counts) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_sz_cluster_counts_fft) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_dndM) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_dndm) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_dndlnM) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_dndlnm) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_sz_cluster_counts) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_isw_auto) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_isw_tsz) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_isw_lens) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_vrms2) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_hmf) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_kp_u_cov_N_N) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_te_y_y) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_dydz) < 0) __PYX_ERR(0, 122, __pyx_L1_error)
  __pyx_v_other_class_sz_keys = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":140
 * 
 *     # Check if any key matches the patterns
 *     for key in output_keys:             # <<<<<<<<<<<<<<
 *         if pattern1.match(key) or pattern2.match(key) or pattern3.match(key):
 *             return True
 */
  __pyx_t_6 = 0;
  __pyx_t_1 = __Pyx_set_iterator(__pyx_v_output_keys, 1, (&__pyx_t_10), (&__pyx_t_11)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __pyx_t_2 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_12 = __Pyx_set_iter_next(__pyx_t_2, __pyx_t_10, &__pyx_t_6, &__pyx_t_1, __pyx_t_11);
    if (unlikely(__pyx_t_12 == 0)) break;
    if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":141
 *     # Check if any key matches the patterns
 *     for key in output_keys:
 *         if pattern1.match(key) or pattern2.match(key) or pattern3.match(key):             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_pattern1, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_key};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_13) {
    } else {
      __pyx_t_9 = __pyx_t_13;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_pattern2, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_key};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_13) {
    } else {
      __pyx_t_9 = __pyx_t_13;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_pattern3, __pyx_n_s_match); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_key};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 141, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_9 = __pyx_t_13;
    __pyx_L14_bool_binop_done:;
    if (__pyx_t_9) {

      /* "class-sz/python/classy.pyx":142
 *     for key in output_keys:
 *         if pattern1.match(key) or pattern2.match(key) or pattern3.match(key):
 *             return True             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":141
 *     # Check if any key matches the patterns
 *     for key in output_keys:
 *         if pattern1.match(key) or pattern2.match(key) or pattern3.match(key):             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
    }

    /* "class-sz/python/classy.pyx":145
 * 
 * 
 *         if key in other_class_sz_keys:             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
    __pyx_t_9 = (__Pyx_PySet_ContainsTF(__pyx_v_key, __pyx_v_other_class_sz_keys, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 145, __pyx_L1_error)
    if (__pyx_t_9) {

      /* "class-sz/python/classy.pyx":146
 * 
 *         if key in other_class_sz_keys:
 *             return True             # <<<<<<<<<<<<<<
 * 
 *     return False
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":145
 * 
 * 
 *         if key in other_class_sz_keys:             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":148
 *             return True
 * 
 *     return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":109
 * 
 * 
 * def contains_specific_pattern_or_keys(d):             # <<<<<<<<<<<<<<
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.contains_specific_pattern_or_keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_output_string);
  __Pyx_XDECREF(__pyx_v_output_keys);
  __Pyx_XDECREF(__pyx_v_pattern1);
  __Pyx_XDECREF(__pyx_v_pattern2);
  __Pyx_XDECREF(__pyx_v_pattern3);
  __Pyx_XDECREF(__pyx_v_other_class_sz_keys);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":157
 * # Nils : Added for python 3.x and python 2.x compatibility
 * import sys
 * def viewdictitems(d):             # <<<<<<<<<<<<<<
 *     if sys.version_info >= (3,0):
 *         return d.items()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_14viewdictitems(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_14viewdictitems = {"viewdictitems", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_14viewdictitems, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_14viewdictitems(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_d = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("viewdictitems (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_d,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_d)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 157, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "viewdictitems") < 0)) __PYX_ERR(0, 157, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_d = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("viewdictitems", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 157, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.viewdictitems", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_13viewdictitems(__pyx_self, __pyx_v_d);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_13viewdictitems(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("viewdictitems", 1);

  /* "class-sz/python/classy.pyx":158
 * import sys
 * def viewdictitems(d):
 *     if sys.version_info >= (3,0):             # <<<<<<<<<<<<<<
 *         return d.items()
 *     else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_version_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_tuple__19, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":159
 * def viewdictitems(d):
 *     if sys.version_info >= (3,0):
 *         return d.items()             # <<<<<<<<<<<<<<
 *     else:
 *         return d.viewitems()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_items); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":158
 * import sys
 * def viewdictitems(d):
 *     if sys.version_info >= (3,0):             # <<<<<<<<<<<<<<
 *         return d.items()
 *     else:
 */
  }

  /* "class-sz/python/classy.pyx":161
 *         return d.items()
 *     else:
 *         return d.viewitems()             # <<<<<<<<<<<<<<
 * 
 * ctypedef np.float_t DTYPE_t
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_viewitems); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":157
 * # Nils : Added for python 3.x and python 2.x compatibility
 * import sys
 * def viewdictitems(d):             # <<<<<<<<<<<<<<
 *     if sys.version_info >= (3,0):
 *         return d.items()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.viewdictitems", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":180
 * # MontePython to handle things differently.
 * class CosmoError(Exception):
 *     def __init__(self, message=""):             # <<<<<<<<<<<<<<
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_10CosmoError_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_10CosmoError_1__init__ = {"__init__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_10CosmoError_1__init__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_10CosmoError_1__init__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_message = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_message,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)((PyObject*)__pyx_kp_u__10)));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 180, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_message);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 180, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 180, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_message = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 180, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.CosmoError.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_10CosmoError___init__(__pyx_self, __pyx_v_self, __pyx_v_message);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_10CosmoError___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_message) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "class-sz/python/classy.pyx":181
 * class CosmoError(Exception):
 *     def __init__(self, message=""):
 *         self.message = message.decode() if isinstance(message,bytes) else message             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_2 = PyBytes_Check(__pyx_v_message); 
  if (__pyx_t_2) {
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_message, __pyx_n_s_decode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 181, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(__pyx_v_message);
    __pyx_t_1 = __pyx_v_message;
  }
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_message, __pyx_t_1) < 0) __PYX_ERR(0, 181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":180
 * # MontePython to handle things differently.
 * class CosmoError(Exception):
 *     def __init__(self, message=""):             # <<<<<<<<<<<<<<
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.CosmoError.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":183
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '\n\nError in Class: ' + self.message
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_10CosmoError_3__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_10CosmoError_3__str__ = {"__str__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_10CosmoError_3__str__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_10CosmoError_3__str__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 183, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__str__") < 0)) __PYX_ERR(0, 183, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_self = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__str__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 183, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.CosmoError.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_10CosmoError_2__str__(__pyx_self, __pyx_v_self);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_10CosmoError_2__str__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "class-sz/python/classy.pyx":184
 * 
 *     def __str__(self):
 *         return '\n\nError in Class: ' + self.message             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_message); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Add(__pyx_kp_u_Error_in_Class, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":183
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '\n\nError in Class: ' + self.message
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.CosmoError.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":257
 *     # call it (see _T_cmb method, at the very bottom).
 *     property pars:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._pars
 *     property state:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_4pars_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9classy_sz_5Class_4pars_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9classy_sz_5Class_4pars___get__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_4pars___get__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "class-sz/python/classy.pyx":258
 *     property pars:
 *         def __get__(self):
 *             return self._pars             # <<<<<<<<<<<<<<
 *     property state:
 *         def __get__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_pars);
  __pyx_r = __pyx_v_self->_pars;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":257
 *     # call it (see _T_cmb method, at the very bottom).
 *     property pars:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._pars
 *     property state:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":260
 *             return self._pars
 *     property state:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return True
 *     property Omega_nu:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_5state_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9classy_sz_5Class_5state_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9classy_sz_5Class_5state___get__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_5state___get__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "class-sz/python/classy.pyx":261
 *     property state:
 *         def __get__(self):
 *             return True             # <<<<<<<<<<<<<<
 *     property Omega_nu:
 *         def __get__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":260
 *             return self._pars
 *     property state:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return True
 *     property Omega_nu:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":263
 *             return True
 *     property Omega_nu:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.ba.Omega0_ncdm_tot
 *     property nonlinear_method:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_8Omega_nu_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9classy_sz_5Class_8Omega_nu_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9classy_sz_5Class_8Omega_nu___get__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_8Omega_nu___get__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "class-sz/python/classy.pyx":264
 *     property Omega_nu:
 *         def __get__(self):
 *             return self.ba.Omega0_ncdm_tot             # <<<<<<<<<<<<<<
 *     property nonlinear_method:
 *         def __get__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_ncdm_tot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":263
 *             return True
 *     property Omega_nu:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.ba.Omega0_ncdm_tot
 *     property nonlinear_method:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega_nu.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":266
 *             return self.ba.Omega0_ncdm_tot
 *     property nonlinear_method:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.nl.method
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_16nonlinear_method_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9classy_sz_5Class_16nonlinear_method_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9classy_sz_5Class_16nonlinear_method___get__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_16nonlinear_method___get__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "class-sz/python/classy.pyx":267
 *     property nonlinear_method:
 *         def __get__(self):
 *             return self.nl.method             # <<<<<<<<<<<<<<
 * 
 *     property PATH_TO_CLASS_SZ_DATA:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->nl.method); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":266
 *             return self.ba.Omega0_ncdm_tot
 *     property nonlinear_method:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self.nl.method
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_method.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":270
 * 
 *     property PATH_TO_CLASS_SZ_DATA:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return classy_szfast.path_to_cosmopower_organization + '/class_sz/class-sz/'
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_21PATH_TO_CLASS_SZ_DATA_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9classy_sz_5Class_21PATH_TO_CLASS_SZ_DATA_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9classy_sz_5Class_21PATH_TO_CLASS_SZ_DATA___get__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_21PATH_TO_CLASS_SZ_DATA___get__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "class-sz/python/classy.pyx":271
 *     property PATH_TO_CLASS_SZ_DATA:
 *         def __get__(self):
 *             return classy_szfast.path_to_cosmopower_organization + '/class_sz/class-sz/'             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_classy_szfast); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path_to_cosmopower_organization); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_class_sz_class_sz); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":270
 * 
 *     property PATH_TO_CLASS_SZ_DATA:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return classy_szfast.path_to_cosmopower_organization + '/class_sz/class-sz/'
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.PATH_TO_CLASS_SZ_DATA.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":276
 * 
 * # BB: modified for class_sz
 *     def set_default(self):             # <<<<<<<<<<<<<<
 *         # print('setting default')
 *         _pars = {
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_1set_default(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_1set_default = {"set_default", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_1set_default, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_1set_default(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_default (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("set_default", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set_default", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_set_default(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_set_default(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v__pars = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_default", 1);

  /* "class-sz/python/classy.pyx":279
 *         # print('setting default')
 *         _pars = {
 *             "output":"tCl",             # <<<<<<<<<<<<<<
 *             'skip_input': 1,
 *             'skip_background_and_thermo': 1,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(35); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_output, __pyx_n_u_tCl) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_input, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_background_and_thermo, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_pknl, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_pkl, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_chi, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_hubble, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_class_sz, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_sigma8_at_z, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_sigma8_and_der, __pyx_int_0) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_skip_cmb, __pyx_int_0) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_cosmo_model, __pyx_int_6) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_N_ur, __pyx_float_0_00441) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_N_ncdm, __pyx_int_1) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_deg_ncdm, __pyx_int_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_m_ncdm, __pyx_float_0_02) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_classy_sz_verbose, __pyx_n_u_none) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_omega_b, __pyx_float_0_022383) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_s, __pyx_float_0_9665) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ndim_masses, __pyx_int_500) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ndim_redshifts, __pyx_int_100) < 0) __PYX_ERR(0, 279, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":314
 *             'ndim_redshifts': 100,
 * 
 *             'sBBN file': self.PATH_TO_CLASS_SZ_DATA + '/bbn/PRIMAT21_class_format.dat',             # <<<<<<<<<<<<<<
 * 
 *             'A10_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_A10.txt',
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_bbn_PRIMAT21_class_format_dat); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_kp_u_sBBN_file, __pyx_t_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":316
 *             'sBBN file': self.PATH_TO_CLASS_SZ_DATA + '/bbn/PRIMAT21_class_format.dat',
 * 
 *             'A10_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_A10.txt',             # <<<<<<<<<<<<<<
 *             'P13_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_P13.txt',
 *             'Tinker_et_al_10_alpha_consistency_msyriac_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/Tinker_et_al_10_alpha_consistency_msyriac.txt',
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_class_sz_auxiliary_files_includ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_A10_file, __pyx_t_2) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":317
 * 
 *             'A10_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_A10.txt',
 *             'P13_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_P13.txt',             # <<<<<<<<<<<<<<
 *             'Tinker_et_al_10_alpha_consistency_msyriac_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/Tinker_et_al_10_alpha_consistency_msyriac.txt',
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_class_sz_auxiliary_files_includ_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_P13_file, __pyx_t_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":318
 *             'A10_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_A10.txt',
 *             'P13_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/class_sz_lnIgnfw-and-d2lnIgnfw-vs-lnell-over-ell500_P13.txt',
 *             'Tinker_et_al_10_alpha_consistency_msyriac_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/Tinker_et_al_10_alpha_consistency_msyriac.txt',             # <<<<<<<<<<<<<<
 * 
 *             'full_path_to_dndz_gal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example1.txt',
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_class_sz_auxiliary_files_includ_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_Tinker_et_al_10_alpha_consistenc, __pyx_t_2) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":320
 *             'Tinker_et_al_10_alpha_consistency_msyriac_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/Tinker_et_al_10_alpha_consistency_msyriac.txt',
 * 
 *             'full_path_to_dndz_gal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example1.txt',             # <<<<<<<<<<<<<<
 *             'full_path_and_prefix_to_dndz_ngal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example',
 *             'full_path_to_source_dndz_gal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3.txt',
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_class_sz_auxiliary_files_includ_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_full_path_to_dndz_gal, __pyx_t_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":321
 * 
 *             'full_path_to_dndz_gal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example1.txt',
 *             'full_path_and_prefix_to_dndz_ngal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example',             # <<<<<<<<<<<<<<
 *             'full_path_to_source_dndz_gal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3.txt',
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_class_sz_auxiliary_files_includ_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_full_path_and_prefix_to_dndz_nga, __pyx_t_2) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":322
 *             'full_path_to_dndz_gal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example1.txt',
 *             'full_path_and_prefix_to_dndz_ngal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3_ngal_example',
 *             'full_path_to_source_dndz_gal': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/WISC_bin3.txt',             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_class_sz_auxiliary_files_includ_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_full_path_to_source_dndz_gal, __pyx_t_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":325
 * 
 * 
 *             'cib_Snu_file_snu': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_fine.txt',             # <<<<<<<<<<<<<<
 *             'cib_Snu_file_z': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_z_fine.txt',
 *             'cib_Snu_file_nu': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_nu_fine.txt',
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_class_sz_auxiliary_files_includ_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_cib_Snu_file_snu, __pyx_t_2) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":326
 * 
 *             'cib_Snu_file_snu': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_fine.txt',
 *             'cib_Snu_file_z': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_z_fine.txt',             # <<<<<<<<<<<<<<
 *             'cib_Snu_file_nu': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_nu_fine.txt',
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_class_sz_auxiliary_files_includ_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_cib_Snu_file_z, __pyx_t_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":327
 *             'cib_Snu_file_snu': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_fine.txt',
 *             'cib_Snu_file_z': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_z_fine.txt',
 *             'cib_Snu_file_nu': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_nu_fine.txt',             # <<<<<<<<<<<<<<
 * 
 *             'SZ_cat_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_cat.txt',
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_class_sz_auxiliary_files_includ_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_cib_Snu_file_nu, __pyx_t_2) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":329
 *             'cib_Snu_file_nu': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/filtered_snu_planck_nu_fine.txt',
 * 
 *             'SZ_cat_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_cat.txt',             # <<<<<<<<<<<<<<
 *             'sz_selection_function_thetas_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_thetas.txt',
 *             'sz_selection_function_skyfracs_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_skyfracs.txt',
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_class_sz_auxiliary_files_includ_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_SZ_cat_file, __pyx_t_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":330
 * 
 *             'SZ_cat_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_cat.txt',
 *             'sz_selection_function_thetas_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_thetas.txt',             # <<<<<<<<<<<<<<
 *             'sz_selection_function_skyfracs_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_skyfracs.txt',
 *             'sz_selection_function_ylims_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_ylims.txt',
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_class_sz_auxiliary_files_includ_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_sz_selection_function_thetas_fil, __pyx_t_2) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":331
 *             'SZ_cat_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_cat.txt',
 *             'sz_selection_function_thetas_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_thetas.txt',
 *             'sz_selection_function_skyfracs_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_skyfracs.txt',             # <<<<<<<<<<<<<<
 *             'sz_selection_function_ylims_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_ylims.txt',
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_kp_u_class_sz_auxiliary_files_includ_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_sz_selection_function_skyfracs_f, __pyx_t_3) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":332
 *             'sz_selection_function_thetas_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_thetas.txt',
 *             'sz_selection_function_skyfracs_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_skyfracs.txt',
 *             'sz_selection_function_ylims_file': self.PATH_TO_CLASS_SZ_DATA + '/class_sz_auxiliary_files/includes/SZ_ylims.txt',             # <<<<<<<<<<<<<<
 * 
 *             }
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_PATH_TO_CLASS_SZ_DATA); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_kp_u_class_sz_auxiliary_files_includ_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_sz_selection_function_ylims_file, __pyx_t_2) < 0) __PYX_ERR(0, 279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v__pars = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":346
 * 
 * 
 *         self.set(**_pars)             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, default=True):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyDict_Copy(__pyx_v__pars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":276
 * 
 * # BB: modified for class_sz
 *     def set_default(self):             # <<<<<<<<<<<<<<
 *         # print('setting default')
 *         _pars = {
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.set_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__pars);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":348
 *         self.set(**_pars)
 * 
 *     def __cinit__(self, default=True):             # <<<<<<<<<<<<<<
 *         cdef char* dumc
 *         self.allocated = False
 */

/* Python wrapper */
static int __pyx_pw_9classy_sz_5Class_3__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9classy_sz_5Class_3__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_default = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_default,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_default);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 348, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 348, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_default = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 348, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_2__cinit__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_default);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9classy_sz_5Class_2__cinit__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_default) {
  char *__pyx_v_dumc;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "class-sz/python/classy.pyx":350
 *     def __cinit__(self, default=True):
 *         cdef char* dumc
 *         self.allocated = False             # <<<<<<<<<<<<<<
 *         self.computed = False
 *         self.likelihood_mode = False
 */
  __pyx_v_self->allocated = 0;

  /* "class-sz/python/classy.pyx":351
 *         cdef char* dumc
 *         self.allocated = False
 *         self.computed = False             # <<<<<<<<<<<<<<
 *         self.likelihood_mode = False
 *         self._pars = {}
 */
  __pyx_v_self->computed = 0;

  /* "class-sz/python/classy.pyx":352
 *         self.allocated = False
 *         self.computed = False
 *         self.likelihood_mode = False             # <<<<<<<<<<<<<<
 *         self._pars = {}
 *         self.fc.size=0
 */
  __pyx_v_self->likelihood_mode = 0;

  /* "class-sz/python/classy.pyx":353
 *         self.computed = False
 *         self.likelihood_mode = False
 *         self._pars = {}             # <<<<<<<<<<<<<<
 *         self.fc.size=0
 *         self.fc.filename = <char*>malloc(sizeof(char)*30)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_pars);
  __Pyx_DECREF(__pyx_v_self->_pars);
  __pyx_v_self->_pars = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":354
 *         self.likelihood_mode = False
 *         self._pars = {}
 *         self.fc.size=0             # <<<<<<<<<<<<<<
 *         self.fc.filename = <char*>malloc(sizeof(char)*30)
 *         assert(self.fc.filename!=NULL)
 */
  __pyx_v_self->fc.size = 0;

  /* "class-sz/python/classy.pyx":355
 *         self._pars = {}
 *         self.fc.size=0
 *         self.fc.filename = <char*>malloc(sizeof(char)*30)             # <<<<<<<<<<<<<<
 *         assert(self.fc.filename!=NULL)
 *         dumc = "NOFILE"
 */
  __pyx_v_self->fc.filename = ((char *)malloc(((sizeof(char)) * 30)));

  /* "class-sz/python/classy.pyx":356
 *         self.fc.size=0
 *         self.fc.filename = <char*>malloc(sizeof(char)*30)
 *         assert(self.fc.filename!=NULL)             # <<<<<<<<<<<<<<
 *         dumc = "NOFILE"
 *         sprintf(self.fc.filename,"%s",dumc)
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_2 = (__pyx_v_self->fc.filename != NULL);
    if (unlikely(!__pyx_t_2)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 356, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 356, __pyx_L1_error)
  #endif

  /* "class-sz/python/classy.pyx":357
 *         self.fc.filename = <char*>malloc(sizeof(char)*30)
 *         assert(self.fc.filename!=NULL)
 *         dumc = "NOFILE"             # <<<<<<<<<<<<<<
 *         sprintf(self.fc.filename,"%s",dumc)
 *         self.ncp = set()
 */
  __pyx_v_dumc = ((char *)"NOFILE");

  /* "class-sz/python/classy.pyx":358
 *         assert(self.fc.filename!=NULL)
 *         dumc = "NOFILE"
 *         sprintf(self.fc.filename,"%s",dumc)             # <<<<<<<<<<<<<<
 *         self.ncp = set()
 *         if default: self.set_default()
 */
  (void)(sprintf(__pyx_v_self->fc.filename, ((char const *)"%s"), __pyx_v_dumc));

  /* "class-sz/python/classy.pyx":359
 *         dumc = "NOFILE"
 *         sprintf(self.fc.filename,"%s",dumc)
 *         self.ncp = set()             # <<<<<<<<<<<<<<
 *         if default: self.set_default()
 *         # print('PATH_TO_CLASS_SZ_DATA',classy_szfast.path_to_cosmopower_organization)
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->ncp);
  __Pyx_DECREF(__pyx_v_self->ncp);
  __pyx_v_self->ncp = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":360
 *         sprintf(self.fc.filename,"%s",dumc)
 *         self.ncp = set()
 *         if default: self.set_default()             # <<<<<<<<<<<<<<
 *         # print('PATH_TO_CLASS_SZ_DATA',classy_szfast.path_to_cosmopower_organization)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_default); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 360, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_default); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 360, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":348
 *         self.set(**_pars)
 * 
 *     def __cinit__(self, default=True):             # <<<<<<<<<<<<<<
 *         cdef char* dumc
 *         self.allocated = False
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":363
 *         # print('PATH_TO_CLASS_SZ_DATA',classy_szfast.path_to_cosmopower_organization)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.allocated:
 *           self.struct_cleanup()
 */

/* Python wrapper */
static void __pyx_pw_9classy_sz_5Class_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_9classy_sz_5Class_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_9classy_sz_5Class_4__dealloc__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_9classy_sz_5Class_4__dealloc__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 1);

  /* "class-sz/python/classy.pyx":364
 * 
 *     def __dealloc__(self):
 *         if self.allocated:             # <<<<<<<<<<<<<<
 *           self.struct_cleanup()
 *         self.empty()
 */
  __pyx_t_1 = (__pyx_v_self->allocated != 0);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":365
 *     def __dealloc__(self):
 *         if self.allocated:
 *           self.struct_cleanup()             # <<<<<<<<<<<<<<
 *         self.empty()
 *         # Reset all the fc to zero if its not already done
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 365, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 365, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":364
 * 
 *     def __dealloc__(self):
 *         if self.allocated:             # <<<<<<<<<<<<<<
 *           self.struct_cleanup()
 *         self.empty()
 */
  }

  /* "class-sz/python/classy.pyx":366
 *         if self.allocated:
 *           self.struct_cleanup()
 *         self.empty()             # <<<<<<<<<<<<<<
 *         # Reset all the fc to zero if its not already done
 *         if self.fc.size !=0:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 366, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":368
 *         self.empty()
 *         # Reset all the fc to zero if its not already done
 *         if self.fc.size !=0:             # <<<<<<<<<<<<<<
 *             self.fc.size=0
 *             free(self.fc.name)
 */
  __pyx_t_1 = (__pyx_v_self->fc.size != 0);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":369
 *         # Reset all the fc to zero if its not already done
 *         if self.fc.size !=0:
 *             self.fc.size=0             # <<<<<<<<<<<<<<
 *             free(self.fc.name)
 *             free(self.fc.value)
 */
    __pyx_v_self->fc.size = 0;

    /* "class-sz/python/classy.pyx":370
 *         if self.fc.size !=0:
 *             self.fc.size=0
 *             free(self.fc.name)             # <<<<<<<<<<<<<<
 *             free(self.fc.value)
 *             free(self.fc.read)
 */
    free(__pyx_v_self->fc.name);

    /* "class-sz/python/classy.pyx":371
 *             self.fc.size=0
 *             free(self.fc.name)
 *             free(self.fc.value)             # <<<<<<<<<<<<<<
 *             free(self.fc.read)
 *             free(self.fc.filename)
 */
    free(__pyx_v_self->fc.value);

    /* "class-sz/python/classy.pyx":372
 *             free(self.fc.name)
 *             free(self.fc.value)
 *             free(self.fc.read)             # <<<<<<<<<<<<<<
 *             free(self.fc.filename)
 * 
 */
    free(__pyx_v_self->fc.read);

    /* "class-sz/python/classy.pyx":373
 *             free(self.fc.value)
 *             free(self.fc.read)
 *             free(self.fc.filename)             # <<<<<<<<<<<<<<
 * 
 *     # Set up the dictionary
 */
    free(__pyx_v_self->fc.filename);

    /* "class-sz/python/classy.pyx":368
 *         self.empty()
 *         # Reset all the fc to zero if its not already done
 *         if self.fc.size !=0:             # <<<<<<<<<<<<<<
 *             self.fc.size=0
 *             free(self.fc.name)
 */
  }

  /* "class-sz/python/classy.pyx":363
 *         # print('PATH_TO_CLASS_SZ_DATA',classy_szfast.path_to_cosmopower_organization)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.allocated:
 *           self.struct_cleanup()
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("classy_sz.Class.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "class-sz/python/classy.pyx":376
 * 
 *     # Set up the dictionary
 *     def set(self,*pars,**kars):             # <<<<<<<<<<<<<<
 *         oldpars = self._pars.copy()
 *         if len(pars)==1:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_7set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_7set = {"set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9classy_sz_5Class_7set, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_7set(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_pars = 0;
  PyObject *__pyx_v_kars = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "set", 1))) return NULL;
  if (unlikely(__pyx_kwds)) {
    __pyx_v_kars = __Pyx_KwargsAsDict_VARARGS(__pyx_kwds, __pyx_kwvalues);
    if (unlikely(!__pyx_v_kars)) return NULL;
    __Pyx_GOTREF(__pyx_v_kars);
  } else {
    __pyx_v_kars = PyDict_New();
    if (unlikely(!__pyx_v_kars)) return NULL;
    __Pyx_GOTREF(__pyx_v_kars);
  }
  __Pyx_INCREF(__pyx_args);
  __pyx_v_pars = __pyx_args;
  __pyx_r = __pyx_pf_9classy_sz_5Class_6set(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_pars, __pyx_v_kars);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_pars);
  __Pyx_DECREF(__pyx_v_kars);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_6set(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_pars, PyObject *__pyx_v_kars) {
  PyObject *__pyx_v_oldpars = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 1);

  /* "class-sz/python/classy.pyx":377
 *     # Set up the dictionary
 *     def set(self,*pars,**kars):
 *         oldpars = self._pars.copy()             # <<<<<<<<<<<<<<
 *         if len(pars)==1:
 *             self._pars.update(dict(pars[0]))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_pars, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_oldpars = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":378
 *     def set(self,*pars,**kars):
 *         oldpars = self._pars.copy()
 *         if len(pars)==1:             # <<<<<<<<<<<<<<
 *             self._pars.update(dict(pars[0]))
 *         elif len(pars)!=0:
 */
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(__pyx_v_pars); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 378, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 == 1);
  if (__pyx_t_6) {

    /* "class-sz/python/classy.pyx":379
 *         oldpars = self._pars.copy()
 *         if len(pars)==1:
 *             self._pars.update(dict(pars[0]))             # <<<<<<<<<<<<<<
 *         elif len(pars)!=0:
 *             raise CosmoSevereError("bad call")
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_pars, __pyx_n_s_update); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_GetItemInt_Tuple(__pyx_v_pars, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyDict_Type)), __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":378
 *     def set(self,*pars,**kars):
 *         oldpars = self._pars.copy()
 *         if len(pars)==1:             # <<<<<<<<<<<<<<
 *             self._pars.update(dict(pars[0]))
 *         elif len(pars)!=0:
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":380
 *         if len(pars)==1:
 *             self._pars.update(dict(pars[0]))
 *         elif len(pars)!=0:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("bad call")
 *         self._pars.update(kars)
 */
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(__pyx_v_pars); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 380, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (unlikely(__pyx_t_6)) {

    /* "class-sz/python/classy.pyx":381
 *             self._pars.update(dict(pars[0]))
 *         elif len(pars)!=0:
 *             raise CosmoSevereError("bad call")             # <<<<<<<<<<<<<<
 *         self._pars.update(kars)
 *         if viewdictitems(self._pars) <= viewdictitems(oldpars):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 381, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_kp_u_bad_call};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 381, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 381, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":380
 *         if len(pars)==1:
 *             self._pars.update(dict(pars[0]))
 *         elif len(pars)!=0:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("bad call")
 *         self._pars.update(kars)
 */
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":382
 *         elif len(pars)!=0:
 *             raise CosmoSevereError("bad call")
 *         self._pars.update(kars)             # <<<<<<<<<<<<<<
 *         if viewdictitems(self._pars) <= viewdictitems(oldpars):
 *           return # Don't change the computed states, if the new dict was already contained in the previous dict
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_pars, __pyx_n_s_update); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_kars};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":383
 *             raise CosmoSevereError("bad call")
 *         self._pars.update(kars)
 *         if viewdictitems(self._pars) <= viewdictitems(oldpars):             # <<<<<<<<<<<<<<
 *           return # Don't change the computed states, if the new dict was already contained in the previous dict
 *         self.computed=False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_viewdictitems); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_self->_pars};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_viewdictitems); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_oldpars};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_LE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_6) {

    /* "class-sz/python/classy.pyx":384
 *         self._pars.update(kars)
 *         if viewdictitems(self._pars) <= viewdictitems(oldpars):
 *           return # Don't change the computed states, if the new dict was already contained in the previous dict             # <<<<<<<<<<<<<<
 *         self.computed=False
 *         set_verbosity(self._pars["classy_sz_verbose"])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":383
 *             raise CosmoSevereError("bad call")
 *         self._pars.update(kars)
 *         if viewdictitems(self._pars) <= viewdictitems(oldpars):             # <<<<<<<<<<<<<<
 *           return # Don't change the computed states, if the new dict was already contained in the previous dict
 *         self.computed=False
 */
  }

  /* "class-sz/python/classy.pyx":385
 *         if viewdictitems(self._pars) <= viewdictitems(oldpars):
 *           return # Don't change the computed states, if the new dict was already contained in the previous dict
 *         self.computed=False             # <<<<<<<<<<<<<<
 *         set_verbosity(self._pars["classy_sz_verbose"])
 *         self.logger = logging.getLogger(__name__)
 */
  __pyx_v_self->computed = 0;

  /* "class-sz/python/classy.pyx":386
 *           return # Don't change the computed states, if the new dict was already contained in the previous dict
 *         self.computed=False
 *         set_verbosity(self._pars["classy_sz_verbose"])             # <<<<<<<<<<<<<<
 *         self.logger = logging.getLogger(__name__)
 *         return True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_set_verbosity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_classy_sz_verbose); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_1};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":387
 *         self.computed=False
 *         set_verbosity(self._pars["classy_sz_verbose"])
 *         self.logger = logging.getLogger(__name__)             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_logging); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getLogger); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_7);
  __Pyx_GOTREF(__pyx_v_self->logger);
  __Pyx_DECREF(__pyx_v_self->logger);
  __pyx_v_self->logger = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":388
 *         set_verbosity(self._pars["classy_sz_verbose"])
 *         self.logger = logging.getLogger(__name__)
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def empty(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":376
 * 
 *     # Set up the dictionary
 *     def set(self,*pars,**kars):             # <<<<<<<<<<<<<<
 *         oldpars = self._pars.copy()
 *         if len(pars)==1:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_oldpars);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":390
 *         return True
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         self._pars = {}
 *         self.computed = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_9empty(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_9empty = {"empty", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_9empty, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_9empty(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("empty", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "empty", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_8empty(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_8empty(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty", 1);

  /* "class-sz/python/classy.pyx":391
 * 
 *     def empty(self):
 *         self._pars = {}             # <<<<<<<<<<<<<<
 *         self.computed = False
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_pars);
  __Pyx_DECREF(__pyx_v_self->_pars);
  __pyx_v_self->_pars = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":392
 *     def empty(self):
 *         self._pars = {}
 *         self.computed = False             # <<<<<<<<<<<<<<
 * 
 *     # Create an equivalent of the parameter file. Non specified values will be
 */
  __pyx_v_self->computed = 0;

  /* "class-sz/python/classy.pyx":390
 *         return True
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         self._pars = {}
 *         self.computed = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.empty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":396
 *     # Create an equivalent of the parameter file. Non specified values will be
 *     # taken at their default (in Class)
 *     def _fillparfile(self):             # <<<<<<<<<<<<<<
 *         cdef char* dumc
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_11_fillparfile(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_11_fillparfile = {"_fillparfile", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_11_fillparfile, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_11_fillparfile(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_fillparfile (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_fillparfile", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_fillparfile", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_10_fillparfile(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_10_fillparfile(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  char *__pyx_v_dumc;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_kk = NULL;
  PyObject *__pyx_v_dumcp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  char *__pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_fillparfile", 1);

  /* "class-sz/python/classy.pyx":399
 *         cdef char* dumc
 * 
 *         if self.fc.size!=0:             # <<<<<<<<<<<<<<
 *             free(self.fc.name)
 *             free(self.fc.value)
 */
  __pyx_t_1 = (__pyx_v_self->fc.size != 0);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":400
 * 
 *         if self.fc.size!=0:
 *             free(self.fc.name)             # <<<<<<<<<<<<<<
 *             free(self.fc.value)
 *             free(self.fc.read)
 */
    free(__pyx_v_self->fc.name);

    /* "class-sz/python/classy.pyx":401
 *         if self.fc.size!=0:
 *             free(self.fc.name)
 *             free(self.fc.value)             # <<<<<<<<<<<<<<
 *             free(self.fc.read)
 *         self.fc.size = len(self._pars)
 */
    free(__pyx_v_self->fc.value);

    /* "class-sz/python/classy.pyx":402
 *             free(self.fc.name)
 *             free(self.fc.value)
 *             free(self.fc.read)             # <<<<<<<<<<<<<<
 *         self.fc.size = len(self._pars)
 *         self.fc.name = <FileArg*> malloc(sizeof(FileArg)*len(self._pars))
 */
    free(__pyx_v_self->fc.read);

    /* "class-sz/python/classy.pyx":399
 *         cdef char* dumc
 * 
 *         if self.fc.size!=0:             # <<<<<<<<<<<<<<
 *             free(self.fc.name)
 *             free(self.fc.value)
 */
  }

  /* "class-sz/python/classy.pyx":403
 *             free(self.fc.value)
 *             free(self.fc.read)
 *         self.fc.size = len(self._pars)             # <<<<<<<<<<<<<<
 *         self.fc.name = <FileArg*> malloc(sizeof(FileArg)*len(self._pars))
 *         assert(self.fc.name!=NULL)
 */
  __pyx_t_2 = __pyx_v_self->_pars;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 403, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->fc.size = __pyx_t_3;

  /* "class-sz/python/classy.pyx":404
 *             free(self.fc.read)
 *         self.fc.size = len(self._pars)
 *         self.fc.name = <FileArg*> malloc(sizeof(FileArg)*len(self._pars))             # <<<<<<<<<<<<<<
 *         assert(self.fc.name!=NULL)
 * 
 */
  __pyx_t_2 = __pyx_v_self->_pars;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->fc.name = ((FileArg *)malloc(((sizeof(FileArg)) * __pyx_t_3)));

  /* "class-sz/python/classy.pyx":405
 *         self.fc.size = len(self._pars)
 *         self.fc.name = <FileArg*> malloc(sizeof(FileArg)*len(self._pars))
 *         assert(self.fc.name!=NULL)             # <<<<<<<<<<<<<<
 * 
 *         self.fc.value = <FileArg*> malloc(sizeof(FileArg)*len(self._pars))
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__pyx_v_self->fc.name != NULL);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 405, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 405, __pyx_L1_error)
  #endif

  /* "class-sz/python/classy.pyx":407
 *         assert(self.fc.name!=NULL)
 * 
 *         self.fc.value = <FileArg*> malloc(sizeof(FileArg)*len(self._pars))             # <<<<<<<<<<<<<<
 *         assert(self.fc.value!=NULL)
 * 
 */
  __pyx_t_2 = __pyx_v_self->_pars;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->fc.value = ((FileArg *)malloc(((sizeof(FileArg)) * __pyx_t_3)));

  /* "class-sz/python/classy.pyx":408
 * 
 *         self.fc.value = <FileArg*> malloc(sizeof(FileArg)*len(self._pars))
 *         assert(self.fc.value!=NULL)             # <<<<<<<<<<<<<<
 * 
 *         self.fc.read = <short*> malloc(sizeof(short)*len(self._pars))
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__pyx_v_self->fc.value != NULL);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 408, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 408, __pyx_L1_error)
  #endif

  /* "class-sz/python/classy.pyx":410
 *         assert(self.fc.value!=NULL)
 * 
 *         self.fc.read = <short*> malloc(sizeof(short)*len(self._pars))             # <<<<<<<<<<<<<<
 *         assert(self.fc.read!=NULL)
 * 
 */
  __pyx_t_2 = __pyx_v_self->_pars;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->fc.read = ((short *)malloc(((sizeof(short)) * __pyx_t_3)));

  /* "class-sz/python/classy.pyx":411
 * 
 *         self.fc.read = <short*> malloc(sizeof(short)*len(self._pars))
 *         assert(self.fc.read!=NULL)             # <<<<<<<<<<<<<<
 * 
 *         # fill parameter file
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__pyx_v_self->fc.read != NULL);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 411, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 411, __pyx_L1_error)
  #endif

  /* "class-sz/python/classy.pyx":414
 * 
 *         # fill parameter file
 *         i = 0             # <<<<<<<<<<<<<<
 *         for kk in self._pars:
 * 
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_i = __pyx_int_0;

  /* "class-sz/python/classy.pyx":415
 *         # fill parameter file
 *         i = 0
 *         for kk in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             dumcp = kk.encode()
 */
  if (likely(PyList_CheckExact(__pyx_v_self->_pars)) || PyTuple_CheckExact(__pyx_v_self->_pars)) {
    __pyx_t_2 = __pyx_v_self->_pars; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->_pars); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 415, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 415, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 415, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 415, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 415, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 415, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 415, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_kk, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":417
 *         for kk in self._pars:
 * 
 *             dumcp = kk.encode()             # <<<<<<<<<<<<<<
 *             dumc = dumcp
 *             sprintf(self.fc.name[i],"%s",dumc)
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_kk, __pyx_n_s_encode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 417, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_dumcp, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":418
 * 
 *             dumcp = kk.encode()
 *             dumc = dumcp             # <<<<<<<<<<<<<<
 *             sprintf(self.fc.name[i],"%s",dumc)
 *             dumcp = str(self._pars[kk]).encode()
 */
    __pyx_t_9 = __Pyx_PyObject_AsWritableString(__pyx_v_dumcp); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) __PYX_ERR(0, 418, __pyx_L1_error)
    __pyx_v_dumc = __pyx_t_9;

    /* "class-sz/python/classy.pyx":419
 *             dumcp = kk.encode()
 *             dumc = dumcp
 *             sprintf(self.fc.name[i],"%s",dumc)             # <<<<<<<<<<<<<<
 *             dumcp = str(self._pars[kk]).encode()
 *             dumc = dumcp
 */
    __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 419, __pyx_L1_error)
    (void)(sprintf((__pyx_v_self->fc.name[__pyx_t_10]), ((char const *)"%s"), __pyx_v_dumc));

    /* "class-sz/python/classy.pyx":420
 *             dumc = dumcp
 *             sprintf(self.fc.name[i],"%s",dumc)
 *             dumcp = str(self._pars[kk]).encode()             # <<<<<<<<<<<<<<
 *             dumc = dumcp
 *             sprintf(self.fc.value[i],"%s",dumc)
 */
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_self->_pars, __pyx_v_kk); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Unicode(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyUnicode_AsEncodedString(((PyObject*)__pyx_t_6), NULL, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_dumcp, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":421
 *             sprintf(self.fc.name[i],"%s",dumc)
 *             dumcp = str(self._pars[kk]).encode()
 *             dumc = dumcp             # <<<<<<<<<<<<<<
 *             sprintf(self.fc.value[i],"%s",dumc)
 *             self.fc.read[i] = _FALSE_
 */
    __pyx_t_9 = __Pyx_PyObject_AsWritableString(__pyx_v_dumcp); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) __PYX_ERR(0, 421, __pyx_L1_error)
    __pyx_v_dumc = __pyx_t_9;

    /* "class-sz/python/classy.pyx":422
 *             dumcp = str(self._pars[kk]).encode()
 *             dumc = dumcp
 *             sprintf(self.fc.value[i],"%s",dumc)             # <<<<<<<<<<<<<<
 *             self.fc.read[i] = _FALSE_
 *             i+=1
 */
    __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 422, __pyx_L1_error)
    (void)(sprintf((__pyx_v_self->fc.value[__pyx_t_10]), ((char const *)"%s"), __pyx_v_dumc));

    /* "class-sz/python/classy.pyx":423
 *             dumc = dumcp
 *             sprintf(self.fc.value[i],"%s",dumc)
 *             self.fc.read[i] = _FALSE_             # <<<<<<<<<<<<<<
 *             i+=1
 * 
 */
    __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 423, __pyx_L1_error)
    (__pyx_v_self->fc.read[__pyx_t_10]) = _FALSE_;

    /* "class-sz/python/classy.pyx":424
 *             sprintf(self.fc.value[i],"%s",dumc)
 *             self.fc.read[i] = _FALSE_
 *             i+=1             # <<<<<<<<<<<<<<
 * 
 *     # Called at the end of a run, to free memory
 */
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":415
 *         # fill parameter file
 *         i = 0
 *         for kk in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             dumcp = kk.encode()
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":396
 *     # Create an equivalent of the parameter file. Non specified values will be
 *     # taken at their default (in Class)
 *     def _fillparfile(self):             # <<<<<<<<<<<<<<
 *         cdef char* dumc
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class._fillparfile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_kk);
  __Pyx_XDECREF(__pyx_v_dumcp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":427
 * 
 *     # Called at the end of a run, to free memory
 *     def struct_cleanup(self):             # <<<<<<<<<<<<<<
 *         # print('cleaning up memoryyyy!!!')
 *         # print('level:',self.ncp)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_13struct_cleanup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_13struct_cleanup = {"struct_cleanup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_13struct_cleanup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_13struct_cleanup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("struct_cleanup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("struct_cleanup", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "struct_cleanup", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_12struct_cleanup(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_12struct_cleanup(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("struct_cleanup", 1);

  /* "class-sz/python/classy.pyx":430
 *         # print('cleaning up memoryyyy!!!')
 *         # print('level:',self.ncp)
 *         if(self.allocated != True):             # <<<<<<<<<<<<<<
 *           return
 *         if self.tsz.use_class_sz_fast_mode == 1 and self.tsz.skip_class_sz == 0:
 */
  __pyx_t_1 = (__pyx_v_self->allocated != 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":431
 *         # print('level:',self.ncp)
 *         if(self.allocated != True):
 *           return             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1 and self.tsz.skip_class_sz == 0:
 *             szcounts_free(&self.csz,&self.tsz)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":430
 *         # print('cleaning up memoryyyy!!!')
 *         # print('level:',self.ncp)
 *         if(self.allocated != True):             # <<<<<<<<<<<<<<
 *           return
 *         if self.tsz.use_class_sz_fast_mode == 1 and self.tsz.skip_class_sz == 0:
 */
  }

  /* "class-sz/python/classy.pyx":432
 *         if(self.allocated != True):
 *           return
 *         if self.tsz.use_class_sz_fast_mode == 1 and self.tsz.skip_class_sz == 0:             # <<<<<<<<<<<<<<
 *             szcounts_free(&self.csz,&self.tsz)
 *             class_sz_free(&self.tsz)
 */
  __pyx_t_2 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->tsz.skip_class_sz == 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":433
 *           return
 *         if self.tsz.use_class_sz_fast_mode == 1 and self.tsz.skip_class_sz == 0:
 *             szcounts_free(&self.csz,&self.tsz)             # <<<<<<<<<<<<<<
 *             class_sz_free(&self.tsz)
 *         if "szcount" in self.ncp: #BB: added for class_sz
 */
    szcounts_free((&__pyx_v_self->csz), (&__pyx_v_self->tsz));

    /* "class-sz/python/classy.pyx":434
 *         if self.tsz.use_class_sz_fast_mode == 1 and self.tsz.skip_class_sz == 0:
 *             szcounts_free(&self.csz,&self.tsz)
 *             class_sz_free(&self.tsz)             # <<<<<<<<<<<<<<
 *         if "szcount" in self.ncp: #BB: added for class_sz
 *             szcounts_free(&self.csz,&self.tsz)
 */
    class_sz_free((&__pyx_v_self->tsz));

    /* "class-sz/python/classy.pyx":432
 *         if(self.allocated != True):
 *           return
 *         if self.tsz.use_class_sz_fast_mode == 1 and self.tsz.skip_class_sz == 0:             # <<<<<<<<<<<<<<
 *             szcounts_free(&self.csz,&self.tsz)
 *             class_sz_free(&self.tsz)
 */
  }

  /* "class-sz/python/classy.pyx":435
 *             szcounts_free(&self.csz,&self.tsz)
 *             class_sz_free(&self.tsz)
 *         if "szcount" in self.ncp: #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             szcounts_free(&self.csz,&self.tsz)
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_szcount, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 435, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":436
 *             class_sz_free(&self.tsz)
 *         if "szcount" in self.ncp: #BB: added for class_sz
 *             szcounts_free(&self.csz,&self.tsz)             # <<<<<<<<<<<<<<
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz
 *             class_sz_free(&self.tsz)
 */
    szcounts_free((&__pyx_v_self->csz), (&__pyx_v_self->tsz));

    /* "class-sz/python/classy.pyx":435
 *             szcounts_free(&self.csz,&self.tsz)
 *             class_sz_free(&self.tsz)
 *         if "szcount" in self.ncp: #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             szcounts_free(&self.csz,&self.tsz)
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz
 */
  }

  /* "class-sz/python/classy.pyx":437
 *         if "szcount" in self.ncp: #BB: added for class_sz
 *             szcounts_free(&self.csz,&self.tsz)
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             class_sz_free(&self.tsz)
 *         if "lensing" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_integrate, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 437, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":438
 *             szcounts_free(&self.csz,&self.tsz)
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz
 *             class_sz_free(&self.tsz)             # <<<<<<<<<<<<<<
 *         if "lensing" in self.ncp:
 *             lensing_free(&self.le)
 */
    class_sz_free((&__pyx_v_self->tsz));

    /* "class-sz/python/classy.pyx":437
 *         if "szcount" in self.ncp: #BB: added for class_sz
 *             szcounts_free(&self.csz,&self.tsz)
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             class_sz_free(&self.tsz)
 *         if "lensing" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":439
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz
 *             class_sz_free(&self.tsz)
 *         if "lensing" in self.ncp:             # <<<<<<<<<<<<<<
 *             lensing_free(&self.le)
 *         if "spectra" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_lensing, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 439, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":440
 *             class_sz_free(&self.tsz)
 *         if "lensing" in self.ncp:
 *             lensing_free(&self.le)             # <<<<<<<<<<<<<<
 *         if "spectra" in self.ncp:
 *             spectra_free(&self.sp)
 */
    lensing_free((&__pyx_v_self->le));

    /* "class-sz/python/classy.pyx":439
 *         if "class_sz_integrate" in self.ncp:  #BB: added for class_sz
 *             class_sz_free(&self.tsz)
 *         if "lensing" in self.ncp:             # <<<<<<<<<<<<<<
 *             lensing_free(&self.le)
 *         if "spectra" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":441
 *         if "lensing" in self.ncp:
 *             lensing_free(&self.le)
 *         if "spectra" in self.ncp:             # <<<<<<<<<<<<<<
 *             spectra_free(&self.sp)
 *         if "transfer" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_spectra, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 441, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":442
 *             lensing_free(&self.le)
 *         if "spectra" in self.ncp:
 *             spectra_free(&self.sp)             # <<<<<<<<<<<<<<
 *         if "transfer" in self.ncp:
 *             transfer_free(&self.tr)
 */
    spectra_free((&__pyx_v_self->sp));

    /* "class-sz/python/classy.pyx":441
 *         if "lensing" in self.ncp:
 *             lensing_free(&self.le)
 *         if "spectra" in self.ncp:             # <<<<<<<<<<<<<<
 *             spectra_free(&self.sp)
 *         if "transfer" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":443
 *         if "spectra" in self.ncp:
 *             spectra_free(&self.sp)
 *         if "transfer" in self.ncp:             # <<<<<<<<<<<<<<
 *             transfer_free(&self.tr)
 *         if "nonlinear" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_transfer, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 443, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":444
 *             spectra_free(&self.sp)
 *         if "transfer" in self.ncp:
 *             transfer_free(&self.tr)             # <<<<<<<<<<<<<<
 *         if "nonlinear" in self.ncp:
 *             nonlinear_free(&self.nl)
 */
    transfer_free((&__pyx_v_self->tr));

    /* "class-sz/python/classy.pyx":443
 *         if "spectra" in self.ncp:
 *             spectra_free(&self.sp)
 *         if "transfer" in self.ncp:             # <<<<<<<<<<<<<<
 *             transfer_free(&self.tr)
 *         if "nonlinear" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":445
 *         if "transfer" in self.ncp:
 *             transfer_free(&self.tr)
 *         if "nonlinear" in self.ncp:             # <<<<<<<<<<<<<<
 *             nonlinear_free(&self.nl)
 *         if "primordial" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_nonlinear, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 445, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":446
 *             transfer_free(&self.tr)
 *         if "nonlinear" in self.ncp:
 *             nonlinear_free(&self.nl)             # <<<<<<<<<<<<<<
 *         if "primordial" in self.ncp:
 *             primordial_free(&self.pm)
 */
    nonlinear_free((&__pyx_v_self->nl));

    /* "class-sz/python/classy.pyx":445
 *         if "transfer" in self.ncp:
 *             transfer_free(&self.tr)
 *         if "nonlinear" in self.ncp:             # <<<<<<<<<<<<<<
 *             nonlinear_free(&self.nl)
 *         if "primordial" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":447
 *         if "nonlinear" in self.ncp:
 *             nonlinear_free(&self.nl)
 *         if "primordial" in self.ncp:             # <<<<<<<<<<<<<<
 *             primordial_free(&self.pm)
 *         if "perturb" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_primordial, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 447, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":448
 *             nonlinear_free(&self.nl)
 *         if "primordial" in self.ncp:
 *             primordial_free(&self.pm)             # <<<<<<<<<<<<<<
 *         if "perturb" in self.ncp:
 *             perturb_free(&self.pt)
 */
    primordial_free((&__pyx_v_self->pm));

    /* "class-sz/python/classy.pyx":447
 *         if "nonlinear" in self.ncp:
 *             nonlinear_free(&self.nl)
 *         if "primordial" in self.ncp:             # <<<<<<<<<<<<<<
 *             primordial_free(&self.pm)
 *         if "perturb" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":449
 *         if "primordial" in self.ncp:
 *             primordial_free(&self.pm)
 *         if "perturb" in self.ncp:             # <<<<<<<<<<<<<<
 *             perturb_free(&self.pt)
 *         if "thermodynamics" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_perturb, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 449, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":450
 *             primordial_free(&self.pm)
 *         if "perturb" in self.ncp:
 *             perturb_free(&self.pt)             # <<<<<<<<<<<<<<
 *         if "thermodynamics" in self.ncp:
 *             thermodynamics_free(&self.th)
 */
    perturb_free((&__pyx_v_self->pt));

    /* "class-sz/python/classy.pyx":449
 *         if "primordial" in self.ncp:
 *             primordial_free(&self.pm)
 *         if "perturb" in self.ncp:             # <<<<<<<<<<<<<<
 *             perturb_free(&self.pt)
 *         if "thermodynamics" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":451
 *         if "perturb" in self.ncp:
 *             perturb_free(&self.pt)
 *         if "thermodynamics" in self.ncp:             # <<<<<<<<<<<<<<
 *             thermodynamics_free(&self.th)
 *         if "background" in self.ncp:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_thermodynamics, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 451, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":452
 *             perturb_free(&self.pt)
 *         if "thermodynamics" in self.ncp:
 *             thermodynamics_free(&self.th)             # <<<<<<<<<<<<<<
 *         if "background" in self.ncp:
 *             background_free(&self.ba)
 */
    thermodynamics_free((&__pyx_v_self->th));

    /* "class-sz/python/classy.pyx":451
 *         if "perturb" in self.ncp:
 *             perturb_free(&self.pt)
 *         if "thermodynamics" in self.ncp:             # <<<<<<<<<<<<<<
 *             thermodynamics_free(&self.th)
 *         if "background" in self.ncp:
 */
  }

  /* "class-sz/python/classy.pyx":453
 *         if "thermodynamics" in self.ncp:
 *             thermodynamics_free(&self.th)
 *         if "background" in self.ncp:             # <<<<<<<<<<<<<<
 *             background_free(&self.ba)
 *         self.allocated = False
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_background, __pyx_v_self->ncp, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 453, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":454
 *             thermodynamics_free(&self.th)
 *         if "background" in self.ncp:
 *             background_free(&self.ba)             # <<<<<<<<<<<<<<
 *         self.allocated = False
 *         self.computed = False
 */
    background_free((&__pyx_v_self->ba));

    /* "class-sz/python/classy.pyx":453
 *         if "thermodynamics" in self.ncp:
 *             thermodynamics_free(&self.th)
 *         if "background" in self.ncp:             # <<<<<<<<<<<<<<
 *             background_free(&self.ba)
 *         self.allocated = False
 */
  }

  /* "class-sz/python/classy.pyx":455
 *         if "background" in self.ncp:
 *             background_free(&self.ba)
 *         self.allocated = False             # <<<<<<<<<<<<<<
 *         self.computed = False
 * 
 */
  __pyx_v_self->allocated = 0;

  /* "class-sz/python/classy.pyx":456
 *             background_free(&self.ba)
 *         self.allocated = False
 *         self.computed = False             # <<<<<<<<<<<<<<
 * 
 *     def _check_task_dependency(self, level):
 */
  __pyx_v_self->computed = 0;

  /* "class-sz/python/classy.pyx":427
 * 
 *     # Called at the end of a run, to free memory
 *     def struct_cleanup(self):             # <<<<<<<<<<<<<<
 *         # print('cleaning up memoryyyy!!!')
 *         # print('level:',self.ncp)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("classy_sz.Class.struct_cleanup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":458
 *         self.computed = False
 * 
 *     def _check_task_dependency(self, level):             # <<<<<<<<<<<<<<
 *         """
 *         Fill the level list with all the needed modules
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_15_check_task_dependency(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_14_check_task_dependency, "\n        Fill the level list with all the needed modules\n\n        .. warning::\n\n            the ordering of modules is obviously dependent on CLASS module order\n            in the main.c file. This has to be updated in case of a change to\n            this file.\n\n        Parameters\n        ----------\n\n        level : list\n            list of strings, containing initially only the last module required.\n            For instance, to recover all the modules, the input should be\n            ['lensing']\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_15_check_task_dependency = {"_check_task_dependency", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_15_check_task_dependency, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_14_check_task_dependency};
static PyObject *__pyx_pw_9classy_sz_5Class_15_check_task_dependency(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_level = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_check_task_dependency (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_level,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_level)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 458, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_check_task_dependency") < 0)) __PYX_ERR(0, 458, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_level = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_check_task_dependency", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 458, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class._check_task_dependency", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_14_check_task_dependency(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_level);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_14_check_task_dependency(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_level) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_check_task_dependency", 1);

  /* "class-sz/python/classy.pyx":477
 * 
 *         """
 *         if "szcount" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "class_sz_integrate" not in level:
 *               level.append("class_sz_integrate")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_szcount, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 477, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":478
 *         """
 *         if "szcount" in level:  #BB: added for class_sz
 *             if "class_sz_integrate" not in level:             # <<<<<<<<<<<<<<
 *               level.append("class_sz_integrate")
 *         if "class_sz_integrate" in level:  #BB: added for class_sz
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_integrate, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 478, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":479
 *         if "szcount" in level:  #BB: added for class_sz
 *             if "class_sz_integrate" not in level:
 *               level.append("class_sz_integrate")             # <<<<<<<<<<<<<<
 *         if "class_sz_integrate" in level:  #BB: added for class_sz
 *             if "class_sz_tabulate" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_class_sz_integrate); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 479, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":478
 *         """
 *         if "szcount" in level:  #BB: added for class_sz
 *             if "class_sz_integrate" not in level:             # <<<<<<<<<<<<<<
 *               level.append("class_sz_integrate")
 *         if "class_sz_integrate" in level:  #BB: added for class_sz
 */
    }

    /* "class-sz/python/classy.pyx":477
 * 
 *         """
 *         if "szcount" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "class_sz_integrate" not in level:
 *               level.append("class_sz_integrate")
 */
  }

  /* "class-sz/python/classy.pyx":480
 *             if "class_sz_integrate" not in level:
 *               level.append("class_sz_integrate")
 *         if "class_sz_integrate" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "class_sz_tabulate" not in level:
 *               level.append("class_sz_tabulate")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_integrate, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 480, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":481
 *               level.append("class_sz_integrate")
 *         if "class_sz_integrate" in level:  #BB: added for class_sz
 *             if "class_sz_tabulate" not in level:             # <<<<<<<<<<<<<<
 *               level.append("class_sz_tabulate")
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_tabulate, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 481, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":482
 *         if "class_sz_integrate" in level:  #BB: added for class_sz
 *             if "class_sz_tabulate" not in level:
 *               level.append("class_sz_tabulate")             # <<<<<<<<<<<<<<
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz
 *             if "class_sz_cosmo" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_class_sz_tabulate); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 482, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":481
 *               level.append("class_sz_integrate")
 *         if "class_sz_integrate" in level:  #BB: added for class_sz
 *             if "class_sz_tabulate" not in level:             # <<<<<<<<<<<<<<
 *               level.append("class_sz_tabulate")
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz
 */
    }

    /* "class-sz/python/classy.pyx":480
 *             if "class_sz_integrate" not in level:
 *               level.append("class_sz_integrate")
 *         if "class_sz_integrate" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "class_sz_tabulate" not in level:
 *               level.append("class_sz_tabulate")
 */
  }

  /* "class-sz/python/classy.pyx":483
 *             if "class_sz_tabulate" not in level:
 *               level.append("class_sz_tabulate")
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "class_sz_cosmo" not in level:
 *               level.append("class_sz_cosmo")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_tabulate, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 483, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":484
 *               level.append("class_sz_tabulate")
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz
 *             if "class_sz_cosmo" not in level:             # <<<<<<<<<<<<<<
 *               level.append("class_sz_cosmo")
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_cosmo, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 484, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":485
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz
 *             if "class_sz_cosmo" not in level:
 *               level.append("class_sz_cosmo")             # <<<<<<<<<<<<<<
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz
 *             if "lensing" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_class_sz_cosmo); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 485, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":484
 *               level.append("class_sz_tabulate")
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz
 *             if "class_sz_cosmo" not in level:             # <<<<<<<<<<<<<<
 *               level.append("class_sz_cosmo")
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz
 */
    }

    /* "class-sz/python/classy.pyx":483
 *             if "class_sz_tabulate" not in level:
 *               level.append("class_sz_tabulate")
 *         if "class_sz_tabulate" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "class_sz_cosmo" not in level:
 *               level.append("class_sz_cosmo")
 */
  }

  /* "class-sz/python/classy.pyx":486
 *             if "class_sz_cosmo" not in level:
 *               level.append("class_sz_cosmo")
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "lensing" not in level:
 *               level.append("lensing")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_cosmo, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 486, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":487
 *               level.append("class_sz_cosmo")
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz
 *             if "lensing" not in level:             # <<<<<<<<<<<<<<
 *               level.append("lensing")
 *         #if "distortions" in level:
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_lensing, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 487, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":488
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz
 *             if "lensing" not in level:
 *               level.append("lensing")             # <<<<<<<<<<<<<<
 *         #if "distortions" in level:
 *         #    if "lensing" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_lensing); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 488, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":487
 *               level.append("class_sz_cosmo")
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz
 *             if "lensing" not in level:             # <<<<<<<<<<<<<<
 *               level.append("lensing")
 *         #if "distortions" in level:
 */
    }

    /* "class-sz/python/classy.pyx":486
 *             if "class_sz_cosmo" not in level:
 *               level.append("class_sz_cosmo")
 *         if "class_sz_cosmo" in level:  #BB: added for class_sz             # <<<<<<<<<<<<<<
 *             if "lensing" not in level:
 *               level.append("lensing")
 */
  }

  /* "class-sz/python/classy.pyx":492
 *         #    if "lensing" not in level:
 *         #        level.append("lensing")
 *         if "lensing" in level:             # <<<<<<<<<<<<<<
 *             if "spectra" not in level:
 *                 level.append("spectra")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_lensing, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 492, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":493
 *         #        level.append("lensing")
 *         if "lensing" in level:
 *             if "spectra" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("spectra")
 *         if "spectra" in level:
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_spectra, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 493, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":494
 *         if "lensing" in level:
 *             if "spectra" not in level:
 *                 level.append("spectra")             # <<<<<<<<<<<<<<
 *         if "spectra" in level:
 *             if "transfer" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_spectra); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 494, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":493
 *         #        level.append("lensing")
 *         if "lensing" in level:
 *             if "spectra" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("spectra")
 *         if "spectra" in level:
 */
    }

    /* "class-sz/python/classy.pyx":492
 *         #    if "lensing" not in level:
 *         #        level.append("lensing")
 *         if "lensing" in level:             # <<<<<<<<<<<<<<
 *             if "spectra" not in level:
 *                 level.append("spectra")
 */
  }

  /* "class-sz/python/classy.pyx":495
 *             if "spectra" not in level:
 *                 level.append("spectra")
 *         if "spectra" in level:             # <<<<<<<<<<<<<<
 *             if "transfer" not in level:
 *                 level.append("transfer")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_spectra, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 495, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":496
 *                 level.append("spectra")
 *         if "spectra" in level:
 *             if "transfer" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("transfer")
 *         if "transfer" in level:
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_transfer, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 496, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":497
 *         if "spectra" in level:
 *             if "transfer" not in level:
 *                 level.append("transfer")             # <<<<<<<<<<<<<<
 *         if "transfer" in level:
 *             if "nonlinear" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_transfer); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 497, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":496
 *                 level.append("spectra")
 *         if "spectra" in level:
 *             if "transfer" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("transfer")
 *         if "transfer" in level:
 */
    }

    /* "class-sz/python/classy.pyx":495
 *             if "spectra" not in level:
 *                 level.append("spectra")
 *         if "spectra" in level:             # <<<<<<<<<<<<<<
 *             if "transfer" not in level:
 *                 level.append("transfer")
 */
  }

  /* "class-sz/python/classy.pyx":498
 *             if "transfer" not in level:
 *                 level.append("transfer")
 *         if "transfer" in level:             # <<<<<<<<<<<<<<
 *             if "nonlinear" not in level:
 *                 level.append("nonlinear")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_transfer, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 498, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":499
 *                 level.append("transfer")
 *         if "transfer" in level:
 *             if "nonlinear" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("nonlinear")
 *         if "nonlinear" in level:
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_nonlinear, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 499, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":500
 *         if "transfer" in level:
 *             if "nonlinear" not in level:
 *                 level.append("nonlinear")             # <<<<<<<<<<<<<<
 *         if "nonlinear" in level:
 *             if "primordial" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_nonlinear); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 500, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":499
 *                 level.append("transfer")
 *         if "transfer" in level:
 *             if "nonlinear" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("nonlinear")
 *         if "nonlinear" in level:
 */
    }

    /* "class-sz/python/classy.pyx":498
 *             if "transfer" not in level:
 *                 level.append("transfer")
 *         if "transfer" in level:             # <<<<<<<<<<<<<<
 *             if "nonlinear" not in level:
 *                 level.append("nonlinear")
 */
  }

  /* "class-sz/python/classy.pyx":501
 *             if "nonlinear" not in level:
 *                 level.append("nonlinear")
 *         if "nonlinear" in level:             # <<<<<<<<<<<<<<
 *             if "primordial" not in level:
 *                 level.append("primordial")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_nonlinear, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 501, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":502
 *                 level.append("nonlinear")
 *         if "nonlinear" in level:
 *             if "primordial" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("primordial")
 *         if "primordial" in level:
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_primordial, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 502, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":503
 *         if "nonlinear" in level:
 *             if "primordial" not in level:
 *                 level.append("primordial")             # <<<<<<<<<<<<<<
 *         if "primordial" in level:
 *             if "perturb" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_primordial); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 503, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":502
 *                 level.append("nonlinear")
 *         if "nonlinear" in level:
 *             if "primordial" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("primordial")
 *         if "primordial" in level:
 */
    }

    /* "class-sz/python/classy.pyx":501
 *             if "nonlinear" not in level:
 *                 level.append("nonlinear")
 *         if "nonlinear" in level:             # <<<<<<<<<<<<<<
 *             if "primordial" not in level:
 *                 level.append("primordial")
 */
  }

  /* "class-sz/python/classy.pyx":504
 *             if "primordial" not in level:
 *                 level.append("primordial")
 *         if "primordial" in level:             # <<<<<<<<<<<<<<
 *             if "perturb" not in level:
 *                 level.append("perturb")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_primordial, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 504, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":505
 *                 level.append("primordial")
 *         if "primordial" in level:
 *             if "perturb" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("perturb")
 *         if "perturb" in level:
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_perturb, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 505, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":506
 *         if "primordial" in level:
 *             if "perturb" not in level:
 *                 level.append("perturb")             # <<<<<<<<<<<<<<
 *         if "perturb" in level:
 *             if "thermodynamics" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_perturb); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 506, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":505
 *                 level.append("primordial")
 *         if "primordial" in level:
 *             if "perturb" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("perturb")
 *         if "perturb" in level:
 */
    }

    /* "class-sz/python/classy.pyx":504
 *             if "primordial" not in level:
 *                 level.append("primordial")
 *         if "primordial" in level:             # <<<<<<<<<<<<<<
 *             if "perturb" not in level:
 *                 level.append("perturb")
 */
  }

  /* "class-sz/python/classy.pyx":507
 *             if "perturb" not in level:
 *                 level.append("perturb")
 *         if "perturb" in level:             # <<<<<<<<<<<<<<
 *             if "thermodynamics" not in level:
 *                 level.append("thermodynamics")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_perturb, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 507, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":508
 *                 level.append("perturb")
 *         if "perturb" in level:
 *             if "thermodynamics" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("thermodynamics")
 *         if "thermodynamics" in level:
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_thermodynamics, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 508, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":509
 *         if "perturb" in level:
 *             if "thermodynamics" not in level:
 *                 level.append("thermodynamics")             # <<<<<<<<<<<<<<
 *         if "thermodynamics" in level:
 *             if "background" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_thermodynamics); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 509, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":508
 *                 level.append("perturb")
 *         if "perturb" in level:
 *             if "thermodynamics" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("thermodynamics")
 *         if "thermodynamics" in level:
 */
    }

    /* "class-sz/python/classy.pyx":507
 *             if "perturb" not in level:
 *                 level.append("perturb")
 *         if "perturb" in level:             # <<<<<<<<<<<<<<
 *             if "thermodynamics" not in level:
 *                 level.append("thermodynamics")
 */
  }

  /* "class-sz/python/classy.pyx":510
 *             if "thermodynamics" not in level:
 *                 level.append("thermodynamics")
 *         if "thermodynamics" in level:             # <<<<<<<<<<<<<<
 *             if "background" not in level:
 *                 level.append("background")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_thermodynamics, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 510, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":511
 *                 level.append("thermodynamics")
 *         if "thermodynamics" in level:
 *             if "background" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("background")
 *         if len(level)!=0 :
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_background, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 511, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":512
 *         if "thermodynamics" in level:
 *             if "background" not in level:
 *                 level.append("background")             # <<<<<<<<<<<<<<
 *         if len(level)!=0 :
 *             if "input" not in level:
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_background); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 512, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":511
 *                 level.append("thermodynamics")
 *         if "thermodynamics" in level:
 *             if "background" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("background")
 *         if len(level)!=0 :
 */
    }

    /* "class-sz/python/classy.pyx":510
 *             if "thermodynamics" not in level:
 *                 level.append("thermodynamics")
 *         if "thermodynamics" in level:             # <<<<<<<<<<<<<<
 *             if "background" not in level:
 *                 level.append("background")
 */
  }

  /* "class-sz/python/classy.pyx":513
 *             if "background" not in level:
 *                 level.append("background")
 *         if len(level)!=0 :             # <<<<<<<<<<<<<<
 *             if "input" not in level:
 *                 level.append("input")
 */
  __pyx_t_3 = PyObject_Length(__pyx_v_level); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 513, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_3 != 0);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":514
 *                 level.append("background")
 *         if len(level)!=0 :
 *             if "input" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("input")
 *         return level
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_input, __pyx_v_level, Py_NE)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 514, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":515
 *         if len(level)!=0 :
 *             if "input" not in level:
 *                 level.append("input")             # <<<<<<<<<<<<<<
 *         return level
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_level, __pyx_n_u_input); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 515, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":514
 *                 level.append("background")
 *         if len(level)!=0 :
 *             if "input" not in level:             # <<<<<<<<<<<<<<
 *                 level.append("input")
 *         return level
 */
    }

    /* "class-sz/python/classy.pyx":513
 *             if "background" not in level:
 *                 level.append("background")
 *         if len(level)!=0 :             # <<<<<<<<<<<<<<
 *             if "input" not in level:
 *                 level.append("input")
 */
  }

  /* "class-sz/python/classy.pyx":516
 *             if "input" not in level:
 *                 level.append("input")
 *         return level             # <<<<<<<<<<<<<<
 * 
 *     def _pars_check(self, key, value, contains=False, add=""):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_level);
  __pyx_r = __pyx_v_level;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":458
 *         self.computed = False
 * 
 *     def _check_task_dependency(self, level):             # <<<<<<<<<<<<<<
 *         """
 *         Fill the level list with all the needed modules
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("classy_sz.Class._check_task_dependency", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":518
 *         return level
 * 
 *     def _pars_check(self, key, value, contains=False, add=""):             # <<<<<<<<<<<<<<
 *         val = ""
 *         if key in self._pars:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_17_pars_check(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_17_pars_check = {"_pars_check", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_17_pars_check, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_17_pars_check(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_v_value = 0;
  PyObject *__pyx_v_contains = 0;
  PyObject *__pyx_v_add = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_pars_check (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_value,&__pyx_n_s_contains,&__pyx_n_s_add,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_kp_u__10));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 518, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 518, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_pars_check", 0, 2, 4, 1); __PYX_ERR(0, 518, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_contains);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 518, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_add);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 518, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_pars_check") < 0)) __PYX_ERR(0, 518, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_key = values[0];
    __pyx_v_value = values[1];
    __pyx_v_contains = values[2];
    __pyx_v_add = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_pars_check", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 518, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class._pars_check", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_16_pars_check(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_key, __pyx_v_value, __pyx_v_contains, __pyx_v_add);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_16_pars_check(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_key, PyObject *__pyx_v_value, PyObject *__pyx_v_contains, PyObject *__pyx_v_add) {
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_v_sep = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_pars_check", 1);

  /* "class-sz/python/classy.pyx":519
 * 
 *     def _pars_check(self, key, value, contains=False, add=""):
 *         val = ""             # <<<<<<<<<<<<<<
 *         if key in self._pars:
 *             val = self._pars[key]
 */
  __Pyx_INCREF(__pyx_kp_u__10);
  __pyx_v_val = __pyx_kp_u__10;

  /* "class-sz/python/classy.pyx":520
 *     def _pars_check(self, key, value, contains=False, add=""):
 *         val = ""
 *         if key in self._pars:             # <<<<<<<<<<<<<<
 *             val = self._pars[key]
 *             if contains:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_key, __pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 520, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":521
 *         val = ""
 *         if key in self._pars:
 *             val = self._pars[key]             # <<<<<<<<<<<<<<
 *             if contains:
 *                 if value in val:
 */
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_self->_pars, __pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_val, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":522
 *         if key in self._pars:
 *             val = self._pars[key]
 *             if contains:             # <<<<<<<<<<<<<<
 *                 if value in val:
 *                     return True
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_contains); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 522, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":523
 *             val = self._pars[key]
 *             if contains:
 *                 if value in val:             # <<<<<<<<<<<<<<
 *                     return True
 *             else:
 */
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_value, __pyx_v_val, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 523, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":524
 *             if contains:
 *                 if value in val:
 *                     return True             # <<<<<<<<<<<<<<
 *             else:
 *                 if value==val:
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_True);
        __pyx_r = Py_True;
        goto __pyx_L0;

        /* "class-sz/python/classy.pyx":523
 *             val = self._pars[key]
 *             if contains:
 *                 if value in val:             # <<<<<<<<<<<<<<
 *                     return True
 *             else:
 */
      }

      /* "class-sz/python/classy.pyx":522
 *         if key in self._pars:
 *             val = self._pars[key]
 *             if contains:             # <<<<<<<<<<<<<<
 *                 if value in val:
 *                     return True
 */
      goto __pyx_L4;
    }

    /* "class-sz/python/classy.pyx":526
 *                     return True
 *             else:
 *                 if value==val:             # <<<<<<<<<<<<<<
 *                     return True
 *         if add:
 */
    /*else*/ {
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_value, __pyx_v_val, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 526, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 526, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":527
 *             else:
 *                 if value==val:
 *                     return True             # <<<<<<<<<<<<<<
 *         if add:
 *             sep = " "
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_True);
        __pyx_r = Py_True;
        goto __pyx_L0;

        /* "class-sz/python/classy.pyx":526
 *                     return True
 *             else:
 *                 if value==val:             # <<<<<<<<<<<<<<
 *                     return True
 *         if add:
 */
      }
    }
    __pyx_L4:;

    /* "class-sz/python/classy.pyx":520
 *     def _pars_check(self, key, value, contains=False, add=""):
 *         val = ""
 *         if key in self._pars:             # <<<<<<<<<<<<<<
 *             val = self._pars[key]
 *             if contains:
 */
  }

  /* "class-sz/python/classy.pyx":528
 *                 if value==val:
 *                     return True
 *         if add:             # <<<<<<<<<<<<<<
 *             sep = " "
 *             if isinstance(add,str):
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_add); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 528, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":529
 *                     return True
 *         if add:
 *             sep = " "             # <<<<<<<<<<<<<<
 *             if isinstance(add,str):
 *                 sep = add
 */
    __Pyx_INCREF(__pyx_kp_u__20);
    __pyx_v_sep = __pyx_kp_u__20;

    /* "class-sz/python/classy.pyx":530
 *         if add:
 *             sep = " "
 *             if isinstance(add,str):             # <<<<<<<<<<<<<<
 *                 sep = add
 * 
 */
    __pyx_t_1 = PyUnicode_Check(__pyx_v_add); 
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":531
 *             sep = " "
 *             if isinstance(add,str):
 *                 sep = add             # <<<<<<<<<<<<<<
 * 
 *             if contains and val:
 */
      __Pyx_INCREF(__pyx_v_add);
      __Pyx_DECREF_SET(__pyx_v_sep, __pyx_v_add);

      /* "class-sz/python/classy.pyx":530
 *         if add:
 *             sep = " "
 *             if isinstance(add,str):             # <<<<<<<<<<<<<<
 *                 sep = add
 * 
 */
    }

    /* "class-sz/python/classy.pyx":533
 *                 sep = add
 * 
 *             if contains and val:             # <<<<<<<<<<<<<<
 *                     self.set({key:val+sep+value})
 *             else:
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_contains); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 533, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_1 = __pyx_t_3;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_val); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 533, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_3;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":534
 * 
 *             if contains and val:
 *                     self.set({key:val+sep+value})             # <<<<<<<<<<<<<<
 *             else:
 *                 self.set({key:value})
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyNumber_Add(__pyx_v_val, __pyx_v_sep); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_v_value); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PyDict_SetItem(__pyx_t_5, __pyx_v_key, __pyx_t_7) < 0) __PYX_ERR(0, 534, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 534, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":533
 *                 sep = add
 * 
 *             if contains and val:             # <<<<<<<<<<<<<<
 *                     self.set({key:val+sep+value})
 *             else:
 */
      goto __pyx_L9;
    }

    /* "class-sz/python/classy.pyx":536
 *                     self.set({key:val+sep+value})
 *             else:
 *                 self.set({key:value})             # <<<<<<<<<<<<<<
 *             return True
 *         return False
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_v_key, __pyx_v_value) < 0) __PYX_ERR(0, 536, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 536, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L9:;

    /* "class-sz/python/classy.pyx":537
 *             else:
 *                 self.set({key:value})
 *             return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":528
 *                 if value==val:
 *                     return True
 *         if add:             # <<<<<<<<<<<<<<
 *             sep = " "
 *             if isinstance(add,str):
 */
  }

  /* "class-sz/python/classy.pyx":538
 *                 self.set({key:value})
 *             return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def compute(self, level=["szcount"]):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":518
 *         return level
 * 
 *     def _pars_check(self, key, value, contains=False, add=""):             # <<<<<<<<<<<<<<
 *         val = ""
 *         if key in self._pars:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class._pars_check", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_sep);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":540
 *         return False
 * 
 *     def compute(self, level=["szcount"]):             # <<<<<<<<<<<<<<
 *         """
 *         #compute(level=["lensing"])
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_19compute(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_18compute, "\n        #compute(level=[\"lensing\"])\n        compute(level=[\"szcount\"])\n\n        Main function, execute all the _init methods for all desired modules.\n        This is called in MontePython, and this ensures that the Class instance\n        of this class contains all the relevant quantities. Then, one can deduce\n        Pk, Cl, etc...\n\n        Parameters\n        ----------\n        level : list\n                list of the last module desired. The internal function\n                _check_task_dependency will then add to this list all the\n                necessary modules to compute in order to initialize this last\n                one. The default last module is \"lensing\".\n\n        .. warning::\n\n            level default value should be left as an array (it was creating\n            problem when casting as a set later on, in _check_task_dependency)\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_19compute = {"compute", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_19compute, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_18compute};
static PyObject *__pyx_pw_9classy_sz_5Class_19compute(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_level = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("compute (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_level,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(__pyx_k__21);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_level);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 540, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "compute") < 0)) __PYX_ERR(0, 540, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_level = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("compute", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 540, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.compute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_18compute(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_level);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_18compute(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_level) {
  ErrorMsg __pyx_v_errmsg;
  int __pyx_v_problem_flag;
  PyObject *__pyx_v_problematic_parameters = NULL;
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  char *__pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("compute", 0);
  __Pyx_INCREF(__pyx_v_level);

  /* "class-sz/python/classy.pyx":567
 * 
 *         # Append to the list level all the modules necessary to compute.
 *         level = self._check_task_dependency(level)             # <<<<<<<<<<<<<<
 * 
 *         # Check if this function ran before (self.computed should be true), and
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_check_task_dependency); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_level};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_level, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":573
 *         # equivalent to) level. If it is the case, simply stop the execution of
 *         # the function.
 *         if self.computed and self.ncp.issuperset(level):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_6 = (__pyx_v_self->computed != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_issuperset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_level};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":574
 *         # the function.
 *         if self.computed and self.ncp.issuperset(level):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         # Check if already allocated to prevent memory leaks
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":573
 *         # equivalent to) level. If it is the case, simply stop the execution of
 *         # the function.
 *         if self.computed and self.ncp.issuperset(level):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "class-sz/python/classy.pyx":577
 * 
 *         # Check if already allocated to prevent memory leaks
 *         if self.allocated:             # <<<<<<<<<<<<<<
 *             self.struct_cleanup()
 * 
 */
  __pyx_t_5 = (__pyx_v_self->allocated != 0);
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":578
 *         # Check if already allocated to prevent memory leaks
 *         if self.allocated:
 *             self.struct_cleanup()             # <<<<<<<<<<<<<<
 * 
 *         # Otherwise, proceed with the normal computation.
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 578, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 578, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":577
 * 
 *         # Check if already allocated to prevent memory leaks
 *         if self.allocated:             # <<<<<<<<<<<<<<
 *             self.struct_cleanup()
 * 
 */
  }

  /* "class-sz/python/classy.pyx":581
 * 
 *         # Otherwise, proceed with the normal computation.
 *         self.computed = False             # <<<<<<<<<<<<<<
 * 
 *         # Equivalent of writing a parameter file
 */
  __pyx_v_self->computed = 0;

  /* "class-sz/python/classy.pyx":584
 * 
 *         # Equivalent of writing a parameter file
 *         self._fillparfile()             # <<<<<<<<<<<<<<
 * 
 *         # self.ncp will contain the list of computed modules (under the form of
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_fillparfile); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":588
 *         # self.ncp will contain the list of computed modules (under the form of
 *         # a set, instead of a python list)
 *         self.ncp=set()             # <<<<<<<<<<<<<<
 *         # Up until the empty set, all modules are allocated
 *         # (And then we successively keep track of the ones we allocate additionally)
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->ncp);
  __Pyx_DECREF(__pyx_v_self->ncp);
  __pyx_v_self->ncp = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":591
 *         # Up until the empty set, all modules are allocated
 *         # (And then we successively keep track of the ones we allocate additionally)
 *         self.allocated = True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->allocated = 1;

  /* "class-sz/python/classy.pyx":601
 *         # non-understood parameters asked to the wrapper is a problematic
 *         # situation.
 *         if "input" in level:             # <<<<<<<<<<<<<<
 *             if input_init(&self.fc, &self.pr, &self.ba, &self.th,
 *                           &self.pt, &self.tr, &self.pm, &self.sp,
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_input, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 601, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":604
 *             if input_init(&self.fc, &self.pr, &self.ba, &self.th,
 *                           &self.pt, &self.tr, &self.pm, &self.sp,
 *                           &self.nl, &self.le, &self.tsz, &self.csz, &self.op, errmsg) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(errmsg)
 *             self.ncp.add("input")
 */
    __pyx_t_5 = (input_init((&__pyx_v_self->fc), (&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->tr), (&__pyx_v_self->pm), (&__pyx_v_self->sp), (&__pyx_v_self->nl), (&__pyx_v_self->le), (&__pyx_v_self->tsz), (&__pyx_v_self->csz), (&__pyx_v_self->op), __pyx_v_errmsg) == _FAILURE_);

    /* "class-sz/python/classy.pyx":602
 *         # situation.
 *         if "input" in level:
 *             if input_init(&self.fc, &self.pr, &self.ba, &self.th,             # <<<<<<<<<<<<<<
 *                           &self.pt, &self.tr, &self.pm, &self.sp,
 *                           &self.nl, &self.le, &self.tsz, &self.csz, &self.op, errmsg) == _FAILURE_:
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":605
 *                           &self.pt, &self.tr, &self.pm, &self.sp,
 *                           &self.nl, &self.le, &self.tsz, &self.csz, &self.op, errmsg) == _FAILURE_:
 *                 raise CosmoSevereError(errmsg)             # <<<<<<<<<<<<<<
 *             self.ncp.add("input")
 *             # This part is done to list all the unread parameters, for debugging
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_errmsg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 605, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 605, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":602
 *         # situation.
 *         if "input" in level:
 *             if input_init(&self.fc, &self.pr, &self.ba, &self.th,             # <<<<<<<<<<<<<<
 *                           &self.pt, &self.tr, &self.pm, &self.sp,
 *                           &self.nl, &self.le, &self.tsz, &self.csz, &self.op, errmsg) == _FAILURE_:
 */
    }

    /* "class-sz/python/classy.pyx":606
 *                           &self.nl, &self.le, &self.tsz, &self.csz, &self.op, errmsg) == _FAILURE_:
 *                 raise CosmoSevereError(errmsg)
 *             self.ncp.add("input")             # <<<<<<<<<<<<<<
 *             # This part is done to list all the unread parameters, for debugging
 *             problem_flag = False
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_input};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":608
 *             self.ncp.add("input")
 *             # This part is done to list all the unread parameters, for debugging
 *             problem_flag = False             # <<<<<<<<<<<<<<
 *             problematic_parameters = []
 *             for i in range(self.fc.size):
 */
    __pyx_v_problem_flag = 0;

    /* "class-sz/python/classy.pyx":609
 *             # This part is done to list all the unread parameters, for debugging
 *             problem_flag = False
 *             problematic_parameters = []             # <<<<<<<<<<<<<<
 *             for i in range(self.fc.size):
 *                 if self.fc.read[i] == _FALSE_:
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 609, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_problematic_parameters = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":610
 *             problem_flag = False
 *             problematic_parameters = []
 *             for i in range(self.fc.size):             # <<<<<<<<<<<<<<
 *                 if self.fc.read[i] == _FALSE_:
 *                     problem_flag = True
 */
    __pyx_t_8 = __pyx_v_self->fc.size;
    __pyx_t_9 = __pyx_t_8;
    for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
      __pyx_v_i = __pyx_t_10;

      /* "class-sz/python/classy.pyx":611
 *             problematic_parameters = []
 *             for i in range(self.fc.size):
 *                 if self.fc.read[i] == _FALSE_:             # <<<<<<<<<<<<<<
 *                     problem_flag = True
 *                     problematic_parameters.append(self.fc.name[i].decode())
 */
      __pyx_t_5 = ((__pyx_v_self->fc.read[__pyx_v_i]) == _FALSE_);
      if (__pyx_t_5) {

        /* "class-sz/python/classy.pyx":612
 *             for i in range(self.fc.size):
 *                 if self.fc.read[i] == _FALSE_:
 *                     problem_flag = True             # <<<<<<<<<<<<<<
 *                     problematic_parameters.append(self.fc.name[i].decode())
 *             if problem_flag:
 */
        __pyx_v_problem_flag = 1;

        /* "class-sz/python/classy.pyx":613
 *                 if self.fc.read[i] == _FALSE_:
 *                     problem_flag = True
 *                     problematic_parameters.append(self.fc.name[i].decode())             # <<<<<<<<<<<<<<
 *             if problem_flag:
 *                 raise CosmoSevereError(
 */
        __pyx_t_11 = (__pyx_v_self->fc.name[__pyx_v_i]);
        __pyx_t_12 = __Pyx_ssize_strlen(__pyx_t_11); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(0, 613, __pyx_L1_error)
        __pyx_t_1 = __Pyx_decode_c_string(__pyx_t_11, 0, __pyx_t_12, NULL, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_problematic_parameters, __pyx_t_1); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 613, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "class-sz/python/classy.pyx":611
 *             problematic_parameters = []
 *             for i in range(self.fc.size):
 *                 if self.fc.read[i] == _FALSE_:             # <<<<<<<<<<<<<<
 *                     problem_flag = True
 *                     problematic_parameters.append(self.fc.name[i].decode())
 */
      }
    }

    /* "class-sz/python/classy.pyx":614
 *                     problem_flag = True
 *                     problematic_parameters.append(self.fc.name[i].decode())
 *             if problem_flag:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(
 *                     "Class did not read input parameter(s): %s\n" % ', '.join(
 */
    if (unlikely(__pyx_v_problem_flag)) {

      /* "class-sz/python/classy.pyx":615
 *                     problematic_parameters.append(self.fc.name[i].decode())
 *             if problem_flag:
 *                 raise CosmoSevereError(             # <<<<<<<<<<<<<<
 *                     "Class did not read input parameter(s): %s\n" % ', '.join(
 *                     problematic_parameters))
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 615, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "class-sz/python/classy.pyx":616
 *             if problem_flag:
 *                 raise CosmoSevereError(
 *                     "Class did not read input parameter(s): %s\n" % ', '.join(             # <<<<<<<<<<<<<<
 *                     problematic_parameters))
 * 
 */
      __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__22, __pyx_v_problematic_parameters); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 616, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = PyUnicode_Format(__pyx_kp_u_Class_did_not_read_input_paramet, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 616, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 615, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":614
 *                     problem_flag = True
 *                     problematic_parameters.append(self.fc.name[i].decode())
 *             if problem_flag:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(
 *                     "Class did not read input parameter(s): %s\n" % ', '.join(
 */
    }

    /* "class-sz/python/classy.pyx":601
 *         # non-understood parameters asked to the wrapper is a problematic
 *         # situation.
 *         if "input" in level:             # <<<<<<<<<<<<<<
 *             if input_init(&self.fc, &self.pr, &self.ba, &self.th,
 *                           &self.pt, &self.tr, &self.pm, &self.sp,
 */
  }

  /* "class-sz/python/classy.pyx":622
 *         # methods fail, call `struct_cleanup` and raise a CosmoComputationError
 *         # with the error message from the faulty module of CLASS.
 *         if "background" in level:             # <<<<<<<<<<<<<<
 *             if background_init(&(self.pr), &(self.ba)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_background, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 622, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":623
 *         # with the error message from the faulty module of CLASS.
 *         if "background" in level:
 *             if background_init(&(self.pr), &(self.ba)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.ba.error_message)
 */
    __pyx_t_5 = (background_init((&__pyx_v_self->pr), (&__pyx_v_self->ba)) == _FAILURE_);
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":624
 *         if "background" in level:
 *             if background_init(&(self.pr), &(self.ba)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.ba.error_message)
 *             self.ncp.add("background")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":625
 *             if background_init(&(self.pr), &(self.ba)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.ba.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("background")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 625, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 625, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 625, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":623
 *         # with the error message from the faulty module of CLASS.
 *         if "background" in level:
 *             if background_init(&(self.pr), &(self.ba)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.ba.error_message)
 */
    }

    /* "class-sz/python/classy.pyx":626
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.ba.error_message)
 *             self.ncp.add("background")             # <<<<<<<<<<<<<<
 * 
 *         if "thermodynamics" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_background};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":622
 *         # methods fail, call `struct_cleanup` and raise a CosmoComputationError
 *         # with the error message from the faulty module of CLASS.
 *         if "background" in level:             # <<<<<<<<<<<<<<
 *             if background_init(&(self.pr), &(self.ba)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
  }

  /* "class-sz/python/classy.pyx":628
 *             self.ncp.add("background")
 * 
 *         if "thermodynamics" in level:             # <<<<<<<<<<<<<<
 *             if thermodynamics_init(&(self.pr), &(self.ba),
 *                                    &(self.th)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_thermodynamics, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 628, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":630
 *         if "thermodynamics" in level:
 *             if thermodynamics_init(&(self.pr), &(self.ba),
 *                                    &(self.th)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.th.error_message)
 */
    __pyx_t_5 = (thermodynamics_init((&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->th)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":629
 * 
 *         if "thermodynamics" in level:
 *             if thermodynamics_init(&(self.pr), &(self.ba),             # <<<<<<<<<<<<<<
 *                                    &(self.th)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":631
 *             if thermodynamics_init(&(self.pr), &(self.ba),
 *                                    &(self.th)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.th.error_message)
 *             self.ncp.add("thermodynamics")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 631, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 631, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":632
 *                                    &(self.th)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.th.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("thermodynamics")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->th.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 632, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":629
 * 
 *         if "thermodynamics" in level:
 *             if thermodynamics_init(&(self.pr), &(self.ba),             # <<<<<<<<<<<<<<
 *                                    &(self.th)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":633
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.th.error_message)
 *             self.ncp.add("thermodynamics")             # <<<<<<<<<<<<<<
 * 
 *         if "perturb" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_thermodynamics};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":628
 *             self.ncp.add("background")
 * 
 *         if "thermodynamics" in level:             # <<<<<<<<<<<<<<
 *             if thermodynamics_init(&(self.pr), &(self.ba),
 *                                    &(self.th)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":635
 *             self.ncp.add("thermodynamics")
 * 
 *         if "perturb" in level:             # <<<<<<<<<<<<<<
 *             if perturb_init(&(self.pr), &(self.ba),
 *                             &(self.th), &(self.pt)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_perturb, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 635, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":637
 *         if "perturb" in level:
 *             if perturb_init(&(self.pr), &(self.ba),
 *                             &(self.th), &(self.pt)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.pt.error_message)
 */
    __pyx_t_5 = (perturb_init((&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":636
 * 
 *         if "perturb" in level:
 *             if perturb_init(&(self.pr), &(self.ba),             # <<<<<<<<<<<<<<
 *                             &(self.th), &(self.pt)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":638
 *             if perturb_init(&(self.pr), &(self.ba),
 *                             &(self.th), &(self.pt)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.pt.error_message)
 *             self.ncp.add("perturb")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 638, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":639
 *                             &(self.th), &(self.pt)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.pt.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("perturb")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->pt.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 639, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 639, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":636
 * 
 *         if "perturb" in level:
 *             if perturb_init(&(self.pr), &(self.ba),             # <<<<<<<<<<<<<<
 *                             &(self.th), &(self.pt)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":640
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.pt.error_message)
 *             self.ncp.add("perturb")             # <<<<<<<<<<<<<<
 * 
 *         if "primordial" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_perturb};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":635
 *             self.ncp.add("thermodynamics")
 * 
 *         if "perturb" in level:             # <<<<<<<<<<<<<<
 *             if perturb_init(&(self.pr), &(self.ba),
 *                             &(self.th), &(self.pt)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":642
 *             self.ncp.add("perturb")
 * 
 *         if "primordial" in level:             # <<<<<<<<<<<<<<
 *             if primordial_init(&(self.pr), &(self.pt),
 *                                &(self.pm)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_primordial, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 642, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":644
 *         if "primordial" in level:
 *             if primordial_init(&(self.pr), &(self.pt),
 *                                &(self.pm)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.pm.error_message)
 */
    __pyx_t_5 = (primordial_init((&__pyx_v_self->pr), (&__pyx_v_self->pt), (&__pyx_v_self->pm)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":643
 * 
 *         if "primordial" in level:
 *             if primordial_init(&(self.pr), &(self.pt),             # <<<<<<<<<<<<<<
 *                                &(self.pm)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":645
 *             if primordial_init(&(self.pr), &(self.pt),
 *                                &(self.pm)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.pm.error_message)
 *             self.ncp.add("primordial")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":646
 *                                &(self.pm)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.pm.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("primordial")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->pm.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 646, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 646, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":643
 * 
 *         if "primordial" in level:
 *             if primordial_init(&(self.pr), &(self.pt),             # <<<<<<<<<<<<<<
 *                                &(self.pm)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":647
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.pm.error_message)
 *             self.ncp.add("primordial")             # <<<<<<<<<<<<<<
 * 
 *         if "nonlinear" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_primordial};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":642
 *             self.ncp.add("perturb")
 * 
 *         if "primordial" in level:             # <<<<<<<<<<<<<<
 *             if primordial_init(&(self.pr), &(self.pt),
 *                                &(self.pm)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":649
 *             self.ncp.add("primordial")
 * 
 *         if "nonlinear" in level:             # <<<<<<<<<<<<<<
 *             if nonlinear_init(&self.pr, &self.ba, &self.th,
 *                               &self.pt, &self.pm, &self.nl) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_nonlinear, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 649, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":651
 *         if "nonlinear" in level:
 *             if nonlinear_init(&self.pr, &self.ba, &self.th,
 *                               &self.pt, &self.pm, &self.nl) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.nl.error_message)
 */
    __pyx_t_5 = (nonlinear_init((&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->pm), (&__pyx_v_self->nl)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":650
 * 
 *         if "nonlinear" in level:
 *             if nonlinear_init(&self.pr, &self.ba, &self.th,             # <<<<<<<<<<<<<<
 *                               &self.pt, &self.pm, &self.nl) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":652
 *             if nonlinear_init(&self.pr, &self.ba, &self.th,
 *                               &self.pt, &self.pm, &self.nl) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.nl.error_message)
 *             self.ncp.add("nonlinear")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 652, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":653
 *                               &self.pt, &self.pm, &self.nl) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.nl.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("nonlinear")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 653, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 653, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 653, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":650
 * 
 *         if "nonlinear" in level:
 *             if nonlinear_init(&self.pr, &self.ba, &self.th,             # <<<<<<<<<<<<<<
 *                               &self.pt, &self.pm, &self.nl) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":654
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.nl.error_message)
 *             self.ncp.add("nonlinear")             # <<<<<<<<<<<<<<
 * 
 *         if "transfer" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_nonlinear};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":649
 *             self.ncp.add("primordial")
 * 
 *         if "nonlinear" in level:             # <<<<<<<<<<<<<<
 *             if nonlinear_init(&self.pr, &self.ba, &self.th,
 *                               &self.pt, &self.pm, &self.nl) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":656
 *             self.ncp.add("nonlinear")
 * 
 *         if "transfer" in level:             # <<<<<<<<<<<<<<
 *             if transfer_init(&(self.pr), &(self.ba), &(self.th),
 *                              &(self.pt), &(self.nl), &(self.tr)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_transfer, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 656, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":658
 *         if "transfer" in level:
 *             if transfer_init(&(self.pr), &(self.ba), &(self.th),
 *                              &(self.pt), &(self.nl), &(self.tr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tr.error_message)
 */
    __pyx_t_5 = (transfer_init((&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->nl), (&__pyx_v_self->tr)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":657
 * 
 *         if "transfer" in level:
 *             if transfer_init(&(self.pr), &(self.ba), &(self.th),             # <<<<<<<<<<<<<<
 *                              &(self.pt), &(self.nl), &(self.tr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":659
 *             if transfer_init(&(self.pr), &(self.ba), &(self.th),
 *                              &(self.pt), &(self.nl), &(self.tr)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tr.error_message)
 *             self.ncp.add("transfer")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 659, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 659, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":660
 *                              &(self.pt), &(self.nl), &(self.tr)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tr.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("transfer")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->tr.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 660, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 660, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":657
 * 
 *         if "transfer" in level:
 *             if transfer_init(&(self.pr), &(self.ba), &(self.th),             # <<<<<<<<<<<<<<
 *                              &(self.pt), &(self.nl), &(self.tr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":661
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tr.error_message)
 *             self.ncp.add("transfer")             # <<<<<<<<<<<<<<
 * 
 *         if "spectra" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_transfer};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":656
 *             self.ncp.add("nonlinear")
 * 
 *         if "transfer" in level:             # <<<<<<<<<<<<<<
 *             if transfer_init(&(self.pr), &(self.ba), &(self.th),
 *                              &(self.pt), &(self.nl), &(self.tr)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":663
 *             self.ncp.add("transfer")
 * 
 *         if "spectra" in level:             # <<<<<<<<<<<<<<
 *             if spectra_init(&(self.pr), &(self.ba), &(self.pt),
 *                             &(self.pm), &(self.nl), &(self.tr),
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_spectra, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 663, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":666
 *             if spectra_init(&(self.pr), &(self.ba), &(self.pt),
 *                             &(self.pm), &(self.nl), &(self.tr),
 *                             &(self.sp), &(self.tsz), &(self.th), &(self.le)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.sp.error_message)
 */
    __pyx_t_5 = (spectra_init((&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->pt), (&__pyx_v_self->pm), (&__pyx_v_self->nl), (&__pyx_v_self->tr), (&__pyx_v_self->sp), (&__pyx_v_self->tsz), (&__pyx_v_self->th), (&__pyx_v_self->le)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":664
 * 
 *         if "spectra" in level:
 *             if spectra_init(&(self.pr), &(self.ba), &(self.pt),             # <<<<<<<<<<<<<<
 *                             &(self.pm), &(self.nl), &(self.tr),
 *                             &(self.sp), &(self.tsz), &(self.th), &(self.le)) == _FAILURE_:
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":667
 *                             &(self.pm), &(self.nl), &(self.tr),
 *                             &(self.sp), &(self.tsz), &(self.th), &(self.le)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.sp.error_message)
 *             self.ncp.add("spectra")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 667, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":668
 *                             &(self.sp), &(self.tsz), &(self.th), &(self.le)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.sp.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("spectra")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->sp.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 668, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":664
 * 
 *         if "spectra" in level:
 *             if spectra_init(&(self.pr), &(self.ba), &(self.pt),             # <<<<<<<<<<<<<<
 *                             &(self.pm), &(self.nl), &(self.tr),
 *                             &(self.sp), &(self.tsz), &(self.th), &(self.le)) == _FAILURE_:
 */
    }

    /* "class-sz/python/classy.pyx":669
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.sp.error_message)
 *             self.ncp.add("spectra")             # <<<<<<<<<<<<<<
 * 
 *         if "lensing" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_spectra};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":663
 *             self.ncp.add("transfer")
 * 
 *         if "spectra" in level:             # <<<<<<<<<<<<<<
 *             if spectra_init(&(self.pr), &(self.ba), &(self.pt),
 *                             &(self.pm), &(self.nl), &(self.tr),
 */
  }

  /* "class-sz/python/classy.pyx":671
 *             self.ncp.add("spectra")
 * 
 *         if "lensing" in level:             # <<<<<<<<<<<<<<
 *             if lensing_init(&(self.pr), &(self.pt), &(self.sp),
 *                             &(self.nl), &(self.le)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_lensing, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 671, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":673
 *         if "lensing" in level:
 *             if lensing_init(&(self.pr), &(self.pt), &(self.sp),
 *                             &(self.nl), &(self.le)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.le.error_message)
 */
    __pyx_t_5 = (lensing_init((&__pyx_v_self->pr), (&__pyx_v_self->pt), (&__pyx_v_self->sp), (&__pyx_v_self->nl), (&__pyx_v_self->le)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":672
 * 
 *         if "lensing" in level:
 *             if lensing_init(&(self.pr), &(self.pt), &(self.sp),             # <<<<<<<<<<<<<<
 *                             &(self.nl), &(self.le)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":674
 *             if lensing_init(&(self.pr), &(self.pt), &(self.sp),
 *                             &(self.nl), &(self.le)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.le.error_message)
 *             self.ncp.add("lensing")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 674, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":675
 *                             &(self.nl), &(self.le)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.le.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("lensing")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->le.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 675, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 675, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 675, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":672
 * 
 *         if "lensing" in level:
 *             if lensing_init(&(self.pr), &(self.pt), &(self.sp),             # <<<<<<<<<<<<<<
 *                             &(self.nl), &(self.le)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":676
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.le.error_message)
 *             self.ncp.add("lensing")             # <<<<<<<<<<<<<<
 * 
 *         if "class_sz_cosmo" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_lensing};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 676, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":671
 *             self.ncp.add("spectra")
 * 
 *         if "lensing" in level:             # <<<<<<<<<<<<<<
 *             if lensing_init(&(self.pr), &(self.pt), &(self.sp),
 *                             &(self.nl), &(self.le)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":678
 *             self.ncp.add("lensing")
 * 
 *         if "class_sz_cosmo" in level:             # <<<<<<<<<<<<<<
 *             if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_cosmo, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 678, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":680
 *         if "class_sz_cosmo" in level:
 *             if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
    __pyx_t_5 = (class_sz_cosmo_init((&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->nl), (&__pyx_v_self->pm), (&__pyx_v_self->sp), (&__pyx_v_self->le), (&__pyx_v_self->tsz), (&__pyx_v_self->pr)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":679
 * 
 *         if "class_sz_cosmo" in level:
 *             if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":681
 *             if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("class_sz_cosmo")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 681, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 681, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":682
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("class_sz_cosmo")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 682, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 682, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":679
 * 
 *         if "class_sz_cosmo" in level:
 *             if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":683
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("class_sz_cosmo")             # <<<<<<<<<<<<<<
 * 
 *         if "class_sz_tabulate" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_class_sz_cosmo};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":678
 *             self.ncp.add("lensing")
 * 
 *         if "class_sz_cosmo" in level:             # <<<<<<<<<<<<<<
 *             if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":685
 *             self.ncp.add("class_sz_cosmo")
 * 
 *         if "class_sz_tabulate" in level:             # <<<<<<<<<<<<<<
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_tabulate, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 685, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":687
 *         if "class_sz_tabulate" in level:
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
    __pyx_t_5 = (class_sz_tabulate_init((&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->nl), (&__pyx_v_self->pm), (&__pyx_v_self->sp), (&__pyx_v_self->le), (&__pyx_v_self->tsz), (&__pyx_v_self->pr)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":686
 * 
 *         if "class_sz_tabulate" in level:
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":688
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("class_sz_tabulate")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":689
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("class_sz_tabulate")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 689, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 689, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 689, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":686
 * 
 *         if "class_sz_tabulate" in level:
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":690
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("class_sz_tabulate")             # <<<<<<<<<<<<<<
 * 
 *         if "class_sz_integrate" in level:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_class_sz_tabulate};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":685
 *             self.ncp.add("class_sz_cosmo")
 * 
 *         if "class_sz_tabulate" in level:             # <<<<<<<<<<<<<<
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":692
 *             self.ncp.add("class_sz_tabulate")
 * 
 *         if "class_sz_integrate" in level:             # <<<<<<<<<<<<<<
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_class_sz_integrate, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 692, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":694
 *         if "class_sz_integrate" in level:
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
    __pyx_t_5 = (class_sz_integrate_init((&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->nl), (&__pyx_v_self->pm), (&__pyx_v_self->sp), (&__pyx_v_self->le), (&__pyx_v_self->tsz), (&__pyx_v_self->pr)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":693
 * 
 *         if "class_sz_integrate" in level:
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":695
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("class_sz_integrate")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 695, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":696
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("class_sz_integrate")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 696, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 696, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":693
 * 
 *         if "class_sz_integrate" in level:
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":697
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("class_sz_integrate")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_class_sz_integrate};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":692
 *             self.ncp.add("class_sz_tabulate")
 * 
 *         if "class_sz_integrate" in level:             # <<<<<<<<<<<<<<
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":700
 * 
 * 
 *         if "szcount" in level:             # <<<<<<<<<<<<<<
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_szcount, __pyx_v_level, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 700, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":702
 *         if "szcount" in level:
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 *             &(self.tsz),&(self.csz)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
    __pyx_t_5 = (szcount_init((&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->pm), (&__pyx_v_self->tsz), (&__pyx_v_self->csz)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":701
 * 
 *         if "szcount" in level:
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_5)) {

      /* "class-sz/python/classy.pyx":703
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("szcount")
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":704
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 *             self.ncp.add("szcount")
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 704, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 704, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":701
 * 
 *         if "szcount" in level:
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":705
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             self.ncp.add("szcount")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->ncp, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_szcount};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":700
 * 
 * 
 *         if "szcount" in level:             # <<<<<<<<<<<<<<
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":708
 * 
 * 
 *         self.computed = True             # <<<<<<<<<<<<<<
 * 
 *         # At this point, the cosmological instance contains everything needed. The
 */
  __pyx_v_self->computed = 1;

  /* "class-sz/python/classy.pyx":712
 *         # At this point, the cosmological instance contains everything needed. The
 *         # following functions are only to output the desired numbers
 *         return             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":540
 *         return False
 * 
 *     def compute(self, level=["szcount"]):             # <<<<<<<<<<<<<<
 *         """
 *         #compute(level=["lensing"])
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.compute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_problematic_parameters);
  __Pyx_XDECREF(__pyx_v_level);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":715
 * 
 * 
 *     def calculate_pkl_fftlog_alphas(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         cnew = self.class_szfast.calculate_pkl_fftlog_alphas(zpk=zpk,**params_settings)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_21calculate_pkl_fftlog_alphas(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_21calculate_pkl_fftlog_alphas = {"calculate_pkl_fftlog_alphas", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_21calculate_pkl_fftlog_alphas, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_21calculate_pkl_fftlog_alphas(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_zpk = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calculate_pkl_fftlog_alphas (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_zpk,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_zpk)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 715, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "calculate_pkl_fftlog_alphas") < 0)) __PYX_ERR(0, 715, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_zpk = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calculate_pkl_fftlog_alphas", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 715, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.calculate_pkl_fftlog_alphas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_20calculate_pkl_fftlog_alphas(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_zpk);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_20calculate_pkl_fftlog_alphas(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_zpk) {
  PyObject *__pyx_v_params_settings = NULL;
  PyObject *__pyx_v_cnew = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calculate_pkl_fftlog_alphas", 1);

  /* "class-sz/python/classy.pyx":716
 * 
 *     def calculate_pkl_fftlog_alphas(self,zpk):
 *         params_settings = self._pars             # <<<<<<<<<<<<<<
 *         cnew = self.class_szfast.calculate_pkl_fftlog_alphas(zpk=zpk,**params_settings)
 *         return self.class_szfast.cp_pkl_fftlog_alphas_nus[self.class_szfast.cosmo_model]['arr_0'],cnew
 */
  __pyx_t_1 = __pyx_v_self->_pars;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_params_settings = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":717
 *     def calculate_pkl_fftlog_alphas(self,zpk):
 *         params_settings = self._pars
 *         cnew = self.class_szfast.calculate_pkl_fftlog_alphas(zpk=zpk,**params_settings)             # <<<<<<<<<<<<<<
 *         return self.class_szfast.cp_pkl_fftlog_alphas_nus[self.class_szfast.cosmo_model]['arr_0'],cnew
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_calculate_pkl_fftlog_alphas); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_zpk, __pyx_v_zpk) < 0) __PYX_ERR(0, 717, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_t_3 = 0;
  if (unlikely(__pyx_v_params_settings == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 717, __pyx_L1_error)
  }
  if (__Pyx_MergeKeywords(__pyx_t_2, __pyx_v_params_settings) < 0) __PYX_ERR(0, 717, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_cnew = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":718
 *         params_settings = self._pars
 *         cnew = self.class_szfast.calculate_pkl_fftlog_alphas(zpk=zpk,**params_settings)
 *         return self.class_szfast.cp_pkl_fftlog_alphas_nus[self.class_szfast.cosmo_model]['arr_0'],cnew             # <<<<<<<<<<<<<<
 * 
 *     def get_pkl_reconstructed_from_fftlog(self,zpk):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cp_pkl_fftlog_alphas_nus); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cosmo_model); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_u_arr_0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_cnew);
  __Pyx_GIVEREF(__pyx_v_cnew);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_cnew)) __PYX_ERR(0, 718, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":715
 * 
 * 
 *     def calculate_pkl_fftlog_alphas(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         cnew = self.class_szfast.calculate_pkl_fftlog_alphas(zpk=zpk,**params_settings)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.calculate_pkl_fftlog_alphas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params_settings);
  __Pyx_XDECREF(__pyx_v_cnew);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":720
 *         return self.class_szfast.cp_pkl_fftlog_alphas_nus[self.class_szfast.cosmo_model]['arr_0'],cnew
 * 
 *     def get_pkl_reconstructed_from_fftlog(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         return self.class_szfast.get_pkl_reconstructed_from_fftlog(zpk=zpk,**params_settings)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_23get_pkl_reconstructed_from_fftlog(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_23get_pkl_reconstructed_from_fftlog = {"get_pkl_reconstructed_from_fftlog", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_23get_pkl_reconstructed_from_fftlog, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_23get_pkl_reconstructed_from_fftlog(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_zpk = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pkl_reconstructed_from_fftlog (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_zpk,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_zpk)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 720, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pkl_reconstructed_from_fftlog") < 0)) __PYX_ERR(0, 720, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_zpk = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pkl_reconstructed_from_fftlog", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 720, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pkl_reconstructed_from_fftlog", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_22get_pkl_reconstructed_from_fftlog(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_zpk);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_22get_pkl_reconstructed_from_fftlog(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_zpk) {
  PyObject *__pyx_v_params_settings = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pkl_reconstructed_from_fftlog", 1);

  /* "class-sz/python/classy.pyx":721
 * 
 *     def get_pkl_reconstructed_from_fftlog(self,zpk):
 *         params_settings = self._pars             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_pkl_reconstructed_from_fftlog(zpk=zpk,**params_settings)
 * 
 */
  __pyx_t_1 = __pyx_v_self->_pars;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_params_settings = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":722
 *     def get_pkl_reconstructed_from_fftlog(self,zpk):
 *         params_settings = self._pars
 *         return self.class_szfast.get_pkl_reconstructed_from_fftlog(zpk=zpk,**params_settings)             # <<<<<<<<<<<<<<
 * 
 *     # @cython.boundscheck(False)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pkl_reconstructed_from_fftlo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_zpk, __pyx_v_zpk) < 0) __PYX_ERR(0, 722, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_t_3 = 0;
  if (unlikely(__pyx_v_params_settings == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 722, __pyx_L1_error)
  }
  if (__Pyx_MergeKeywords(__pyx_t_2, __pyx_v_params_settings) < 0) __PYX_ERR(0, 722, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":720
 *         return self.class_szfast.cp_pkl_fftlog_alphas_nus[self.class_szfast.cosmo_model]['arr_0'],cnew
 * 
 *     def get_pkl_reconstructed_from_fftlog(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         return self.class_szfast.get_pkl_reconstructed_from_fftlog(zpk=zpk,**params_settings)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_pkl_reconstructed_from_fftlog", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params_settings);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":727
 *     # @cython.wraparound(False)
 *     # the likelihood_mode parameter is used to identify whether we run within cobaya
 *     def compute_class_szfast(self,likelihood_mode=False):             # <<<<<<<<<<<<<<
 * 
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_25compute_class_szfast(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_25compute_class_szfast = {"compute_class_szfast", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_25compute_class_szfast, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_25compute_class_szfast(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_likelihood_mode = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("compute_class_szfast (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_likelihood_mode,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_likelihood_mode);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 727, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "compute_class_szfast") < 0)) __PYX_ERR(0, 727, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_likelihood_mode = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("compute_class_szfast", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 727, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.compute_class_szfast", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_24compute_class_szfast(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_likelihood_mode);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9classy_sz_5Class_20compute_class_szfast_2generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "class-sz/python/classy.pyx":856
 *                 pknl_in_output = re.compile(r'^hf$').match(self._pars['output'])
 * 
 *                 pknl_key_value_checks = any(self._pars.get(key) == 1 for key in ['use_pknl_in_2hterms_IA_only', 'use_pknl_in_2hterms'])             # <<<<<<<<<<<<<<
 * 
 *                 non_linear_check = 'non_linear' in self._pars
 */

static PyObject *__pyx_pf_9classy_sz_5Class_20compute_class_szfast_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *)__pyx_tp_new_9classy_sz___pyx_scope_struct_2_genexpr(__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 856, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9classy_sz_5Class_20compute_class_szfast_2generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_compute_class_szfast_locals_gene, __pyx_n_s_classy_sz); if (unlikely(!gen)) __PYX_ERR(0, 856, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("classy_sz.Class.compute_class_szfast.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9classy_sz_5Class_20compute_class_szfast_2generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *__pyx_cur_scope = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 856, __pyx_L1_error)
  __pyx_t_1 = __pyx_tuple__23; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= 2) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 856, __pyx_L1_error)
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_key);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_key, ((PyObject*)__pyx_t_3));
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 856, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self->_pars, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_key};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_7 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 856, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_7) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":727
 *     # @cython.wraparound(False)
 *     # the likelihood_mode parameter is used to identify whether we run within cobaya
 *     def compute_class_szfast(self,likelihood_mode=False):             # <<<<<<<<<<<<<<
 * 
 * 
 */

static PyObject *__pyx_pf_9classy_sz_5Class_24compute_class_szfast(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_likelihood_mode) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *__pyx_cur_scope;
  PyObject *__pyx_v_non_linear_check = NULL;
  PyObject *__pyx_v_pknl_in_output = NULL;
  PyObject *__pyx_v_pknl_key_value_checks = NULL;
  PyObject *__pyx_v_skip_background_and_thermo = NULL;
  PyObject *__pyx_v_params_settings = NULL;
  PyObject *__pyx_v_cszfast = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_start = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_end = NULL;
  PyObject *__pyx_v_index_z_r = NULL;
  int __pyx_v_index_z;
  PyObject *__pyx_v_ln1pzc = NULL;
  int __pyx_v_index_r;
  PyObject *__pyx_v_z = NULL;
  PyObject *__pyx_v_index_m_z = NULL;
  int __pyx_v_index_m;
  PyObject *__pyx_v_m = NULL;
  int __pyx_v_index_x;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_gb_9classy_sz_5Class_20compute_class_szfast_2generator1 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  double __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("compute_class_szfast", 0);
  __pyx_cur_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *)__pyx_tp_new_9classy_sz___pyx_scope_struct_1_compute_class_szfast(__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 727, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

  /* "class-sz/python/classy.pyx":731
 * 
 *         ## deal with names
 *         if 'sigma_8' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['sigma8'] = self._pars.pop('sigma_8')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_sigma_8, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 731, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":733
 *         if 'sigma_8' in self._pars:
 * 
 *           self._pars['sigma8'] = self._pars.pop('sigma_8')             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 733, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_sigma_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 733, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_sigma8, __pyx_t_2) < 0))) __PYX_ERR(0, 733, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":731
 * 
 *         ## deal with names
 *         if 'sigma_8' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['sigma8'] = self._pars.pop('sigma_8')
 */
  }

  /* "class-sz/python/classy.pyx":736
 * 
 * 
 *         if 'ns' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['n_s'] = self._pars.pop('ns')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_ns, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 736, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":738
 *         if 'ns' in self._pars:
 * 
 *           self._pars['n_s'] = self._pars.pop('ns')             # <<<<<<<<<<<<<<
 * 
 *         if 'As' in self._pars:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_ns};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_n_s, __pyx_t_2) < 0))) __PYX_ERR(0, 738, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":736
 * 
 * 
 *         if 'ns' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['n_s'] = self._pars.pop('ns')
 */
  }

  /* "class-sz/python/classy.pyx":740
 *           self._pars['n_s'] = self._pars.pop('ns')
 * 
 *         if 'As' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('As'))
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_As, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 740, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":742
 *         if 'As' in self._pars:
 * 
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('As'))             # <<<<<<<<<<<<<<
 * 
 *         if 'A_s' in self._pars:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_log); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_As};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 742, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = PyNumber_Multiply(__pyx_int_10000000000, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 742, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 742, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_kp_u_ln10_10_A_s, __pyx_t_2) < 0))) __PYX_ERR(0, 742, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":740
 *           self._pars['n_s'] = self._pars.pop('ns')
 * 
 *         if 'As' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('As'))
 */
  }

  /* "class-sz/python/classy.pyx":744
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('As'))
 * 
 *         if 'A_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('A_s'))
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_A_s, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 744, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":746
 *         if 'A_s' in self._pars:
 * 
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('A_s'))             # <<<<<<<<<<<<<<
 * 
 *         if 'logA' in self._pars:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_log); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_A_s};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 746, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Multiply(__pyx_int_10000000000, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 746, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_kp_u_ln10_10_A_s, __pyx_t_2) < 0))) __PYX_ERR(0, 746, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":744
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('As'))
 * 
 *         if 'A_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('A_s'))
 */
  }

  /* "class-sz/python/classy.pyx":748
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('A_s'))
 * 
 *         if 'logA' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['ln10^{10}A_s'] = self._pars.pop('logA')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_logA, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 748, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":750
 *         if 'logA' in self._pars:
 * 
 *           self._pars['ln10^{10}A_s'] = self._pars.pop('logA')             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_logA};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_kp_u_ln10_10_A_s, __pyx_t_2) < 0))) __PYX_ERR(0, 750, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":748
 *           self._pars['ln10^{10}A_s'] = np.log(10**10*self._pars.pop('A_s'))
 * 
 *         if 'logA' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['ln10^{10}A_s'] = self._pars.pop('logA')
 */
  }

  /* "class-sz/python/classy.pyx":753
 * 
 * 
 *         if 'tau' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['tau_reio'] = self._pars.pop('tau')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_tau, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 753, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":755
 *         if 'tau' in self._pars:
 * 
 *           self._pars['tau_reio'] = self._pars.pop('tau')             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_tau};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 755, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_tau_reio, __pyx_t_2) < 0))) __PYX_ERR(0, 755, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":753
 * 
 * 
 *         if 'tau' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['tau_reio'] = self._pars.pop('tau')
 */
  }

  /* "class-sz/python/classy.pyx":758
 * 
 * 
 *         if 'mnu' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['m_ncdm'] = self._pars.pop('mnu')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_mnu, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 758, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":760
 *         if 'mnu' in self._pars:
 * 
 *           self._pars['m_ncdm'] = self._pars.pop('mnu')             # <<<<<<<<<<<<<<
 * 
 *         if 'omch2' in self._pars:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_mnu};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_m_ncdm, __pyx_t_2) < 0))) __PYX_ERR(0, 760, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":758
 * 
 * 
 *         if 'mnu' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['m_ncdm'] = self._pars.pop('mnu')
 */
  }

  /* "class-sz/python/classy.pyx":762
 *           self._pars['m_ncdm'] = self._pars.pop('mnu')
 * 
 *         if 'omch2' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('omch2')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_omch2, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 762, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":764
 *         if 'omch2' in self._pars:
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('omch2')             # <<<<<<<<<<<<<<
 * 
 *         if 'omega_c' in self._pars:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_omch2};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_cdm, __pyx_t_2) < 0))) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":762
 *           self._pars['m_ncdm'] = self._pars.pop('mnu')
 * 
 *         if 'omch2' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('omch2')
 */
  }

  /* "class-sz/python/classy.pyx":766
 *           self._pars['omega_cdm'] = self._pars.pop('omch2')
 * 
 *         if 'omega_c' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('omega_c')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_omega_c, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 766, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":768
 *         if 'omega_c' in self._pars:
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('omega_c')             # <<<<<<<<<<<<<<
 * 
 *         if 'ombh2' in self._pars:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 768, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_omega_c};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 768, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_cdm, __pyx_t_2) < 0))) __PYX_ERR(0, 768, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":766
 *           self._pars['omega_cdm'] = self._pars.pop('omch2')
 * 
 *         if 'omega_c' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('omega_c')
 */
  }

  /* "class-sz/python/classy.pyx":770
 *           self._pars['omega_cdm'] = self._pars.pop('omega_c')
 * 
 *         if 'ombh2' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_b'] = self._pars.pop('ombh2')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_ombh2, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 770, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":772
 *         if 'ombh2' in self._pars:
 * 
 *           self._pars['omega_b'] = self._pars.pop('ombh2')             # <<<<<<<<<<<<<<
 * 
 *         if 'h' in self._pars:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 772, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_ombh2};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 772, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_b, __pyx_t_2) < 0))) __PYX_ERR(0, 772, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":770
 *           self._pars['omega_cdm'] = self._pars.pop('omega_c')
 * 
 *         if 'ombh2' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_b'] = self._pars.pop('ombh2')
 */
  }

  /* "class-sz/python/classy.pyx":774
 *           self._pars['omega_b'] = self._pars.pop('ombh2')
 * 
 *         if 'h' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['H0'] = 100.*self._pars.pop('h')
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_h, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 774, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":776
 *         if 'h' in self._pars:
 * 
 *           self._pars['H0'] = 100.*self._pars.pop('h')             # <<<<<<<<<<<<<<
 * 
 *         if 'Omega_b' in self._pars:
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_h};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 776, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = PyNumber_Multiply(__pyx_float_100_, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 776, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_H0, __pyx_t_6) < 0))) __PYX_ERR(0, 776, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":774
 *           self._pars['omega_b'] = self._pars.pop('ombh2')
 * 
 *         if 'h' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['H0'] = 100.*self._pars.pop('h')
 */
  }

  /* "class-sz/python/classy.pyx":778
 *           self._pars['H0'] = 100.*self._pars.pop('h')
 * 
 *         if 'Omega_b' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_b'] = self._pars.pop('Omega_b')*(self._pars['H0']/100.)**2.
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_Omega_b, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 778, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":780
 *         if 'Omega_b' in self._pars:
 * 
 *           self._pars['omega_b'] = self._pars.pop('Omega_b')*(self._pars['H0']/100.)**2.             # <<<<<<<<<<<<<<
 * 
 *         if 'Omega_cdm' in self._pars:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_Omega_b};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 780, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_H0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_2, __pyx_float_100_, 100., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Power(__pyx_t_3, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_b, __pyx_t_3) < 0))) __PYX_ERR(0, 780, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":778
 *           self._pars['H0'] = 100.*self._pars.pop('h')
 * 
 *         if 'Omega_b' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_b'] = self._pars.pop('Omega_b')*(self._pars['H0']/100.)**2.
 */
  }

  /* "class-sz/python/classy.pyx":782
 *           self._pars['omega_b'] = self._pars.pop('Omega_b')*(self._pars['H0']/100.)**2.
 * 
 *         if 'Omega_cdm' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_cdm')*(self._pars['H0']/100.)**2.
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_Omega_cdm, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 782, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":784
 *         if 'Omega_cdm' in self._pars:
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_cdm')*(self._pars['H0']/100.)**2.             # <<<<<<<<<<<<<<
 * 
 *         if 'Omega_c' in self._pars:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_u_Omega_cdm};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 784, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_H0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_2, __pyx_float_100_, 100., 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Power(__pyx_t_6, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_cdm, __pyx_t_6) < 0))) __PYX_ERR(0, 784, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":782
 *           self._pars['omega_b'] = self._pars.pop('Omega_b')*(self._pars['H0']/100.)**2.
 * 
 *         if 'Omega_cdm' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_cdm')*(self._pars['H0']/100.)**2.
 */
  }

  /* "class-sz/python/classy.pyx":786
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_cdm')*(self._pars['H0']/100.)**2.
 * 
 *         if 'Omega_c' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_c')*(self._pars['H0']/100.)**2.
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_Omega_c, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 786, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":788
 *         if 'Omega_c' in self._pars:
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_c')*(self._pars['H0']/100.)**2.             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_Omega_c};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 788, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_H0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_2, __pyx_float_100_, 100., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Power(__pyx_t_3, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_cdm, __pyx_t_3) < 0))) __PYX_ERR(0, 788, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":786
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_cdm')*(self._pars['H0']/100.)**2.
 * 
 *         if 'Omega_c' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = self._pars.pop('Omega_c')*(self._pars['H0']/100.)**2.
 */
  }

  /* "class-sz/python/classy.pyx":791
 * 
 * 
 *         if 'Omega_m' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = (self._pars.pop('Omega_m')-self._pars['omega_b']*(self._pars['H0']/100.)**-2.)*(self._pars['H0']/100.)**2.
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_Omega_m, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 791, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":793
 *         if 'Omega_m' in self._pars:
 * 
 *           self._pars['omega_cdm'] = (self._pars.pop('Omega_m')-self._pars['omega_b']*(self._pars['H0']/100.)**-2.)*(self._pars['H0']/100.)**2.             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_u_Omega_m};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_b); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_H0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_6, __pyx_float_100_, 100., 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Power(__pyx_t_4, __pyx_float_neg_2_, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Subtract(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_H0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_4, __pyx_float_100_, 100., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Power(__pyx_t_3, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_omega_cdm, __pyx_t_3) < 0))) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":791
 * 
 * 
 *         if 'Omega_m' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           self._pars['omega_cdm'] = (self._pars.pop('Omega_m')-self._pars['omega_b']*(self._pars['H0']/100.)**-2.)*(self._pars['H0']/100.)**2.
 */
  }

  /* "class-sz/python/classy.pyx":797
 * 
 * 
 *         if "pressure_profile" in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             self._pars["pressure profile"] = self._pars.pop("pressure_profile")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_pressure_profile, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 797, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":799
 *         if "pressure_profile" in self._pars:
 * 
 *             self._pars["pressure profile"] = self._pars.pop("pressure_profile")             # <<<<<<<<<<<<<<
 * 
 *         if "mass_function" in self._pars:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_u_pressure_profile};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 799, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_kp_u_pressure_profile_2, __pyx_t_3) < 0))) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":797
 * 
 * 
 *         if "pressure_profile" in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             self._pars["pressure profile"] = self._pars.pop("pressure_profile")
 */
  }

  /* "class-sz/python/classy.pyx":801
 *             self._pars["pressure profile"] = self._pars.pop("pressure_profile")
 * 
 *         if "mass_function" in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             self._pars["mass function"] = self._pars.pop("mass_function")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_mass_function, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 801, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":803
 *         if "mass_function" in self._pars:
 * 
 *             self._pars["mass function"] = self._pars.pop("mass_function")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_u_mass_function};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_kp_u_mass_function_2, __pyx_t_3) < 0))) __PYX_ERR(0, 803, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":801
 *             self._pars["pressure profile"] = self._pars.pop("pressure_profile")
 * 
 *         if "mass_function" in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             self._pars["mass function"] = self._pars.pop("mass_function")
 */
  }

  /* "class-sz/python/classy.pyx":806
 * 
 * 
 *         if "concentration_parameter" in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             self._pars["concentration parameter"] = self._pars.pop("concentration_parameter")
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_concentration_parameter, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 806, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":808
 *         if "concentration_parameter" in self._pars:
 * 
 *             self._pars["concentration parameter"] = self._pars.pop("concentration_parameter")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_pop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 808, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_u_concentration_parameter};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 808, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_kp_u_concentration_parameter_2, __pyx_t_3) < 0))) __PYX_ERR(0, 808, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":806
 * 
 * 
 *         if "concentration_parameter" in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             self._pars["concentration parameter"] = self._pars.pop("concentration_parameter")
 */
  }

  /* "class-sz/python/classy.pyx":812
 * 
 * 
 *         if contains_specific_keys(self._pars,{"tCl", "lCl", "pCl"}):             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_cmb'] = 0
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_contains_specific_keys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_n_u_tCl) < 0) __PYX_ERR(0, 812, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_n_u_lCl) < 0) __PYX_ERR(0, 812, __pyx_L1_error)
  if (PySet_Add(__pyx_t_6, __pyx_n_u_pCl) < 0) __PYX_ERR(0, 812, __pyx_L1_error)
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_self->_pars, __pyx_t_6};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":814
 *         if contains_specific_keys(self._pars,{"tCl", "lCl", "pCl"}):
 * 
 *             self._pars['skip_cmb'] = 0             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_cmb, __pyx_int_0) < 0))) __PYX_ERR(0, 814, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":812
 * 
 * 
 *         if contains_specific_keys(self._pars,{"tCl", "lCl", "pCl"}):             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_cmb'] = 0
 */
    goto __pyx_L21;
  }

  /* "class-sz/python/classy.pyx":818
 *         else:
 * 
 *             self._pars['skip_cmb'] = 1             # <<<<<<<<<<<<<<
 * 
 *         ## when running in likelihood mode, we don't need to compute Pk
 */
  /*else*/ {
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_cmb, __pyx_int_1) < 0))) __PYX_ERR(0, 818, __pyx_L1_error)
  }
  __pyx_L21:;

  /* "class-sz/python/classy.pyx":822
 *         ## when running in likelihood mode, we don't need to compute Pk
 *         ## unless we are asked for it.
 *         if contains_specific_keys(self._pars,{"mPk"}) and (likelihood_mode == False):             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_pkl'] = 0
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_contains_specific_keys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PySet_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PySet_Add(__pyx_t_6, __pyx_n_u_mPk) < 0) __PYX_ERR(0, 822, __pyx_L1_error)
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_self->_pars, __pyx_t_6};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L23_bool_binop_done;
  }
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_likelihood_mode, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 822, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 822, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_8;
  __pyx_L23_bool_binop_done:;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":824
 *         if contains_specific_keys(self._pars,{"mPk"}) and (likelihood_mode == False):
 * 
 *             self._pars['skip_pkl'] = 0             # <<<<<<<<<<<<<<
 * 
 *         non_linear_check = 'non_linear' in self._pars
 */
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_pkl, __pyx_int_0) < 0))) __PYX_ERR(0, 824, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":822
 *         ## when running in likelihood mode, we don't need to compute Pk
 *         ## unless we are asked for it.
 *         if contains_specific_keys(self._pars,{"mPk"}) and (likelihood_mode == False):             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_pkl'] = 0
 */
  }

  /* "class-sz/python/classy.pyx":826
 *             self._pars['skip_pkl'] = 0
 * 
 *         non_linear_check = 'non_linear' in self._pars             # <<<<<<<<<<<<<<
 * 
 *         if non_linear_check:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_non_linear, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 826, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_non_linear_check = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":828
 *         non_linear_check = 'non_linear' in self._pars
 * 
 *         if non_linear_check:             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_pknl'] = 0
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_non_linear_check); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 828, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":830
 *         if non_linear_check:
 * 
 *             self._pars['skip_pknl'] = 0             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_pknl, __pyx_int_0) < 0))) __PYX_ERR(0, 830, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":828
 *         non_linear_check = 'non_linear' in self._pars
 * 
 *         if non_linear_check:             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_pknl'] = 0
 */
    goto __pyx_L25;
  }

  /* "class-sz/python/classy.pyx":834
 *         else:
 * 
 *             self._pars['skip_pknl'] = 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_pknl, __pyx_int_1) < 0))) __PYX_ERR(0, 834, __pyx_L1_error)
  }
  __pyx_L25:;

  /* "class-sz/python/classy.pyx":839
 *         # test is anything else than class quantities are requested.
 *         # if so make sure we run at least input.
 *         if class_sz_in_dict_output(self._pars):             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_input'] = 0
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_class_sz_in_dict_output); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_self->_pars};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":841
 *         if class_sz_in_dict_output(self._pars):
 * 
 *             self._pars['skip_input'] = 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
    if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_input, __pyx_int_0) < 0))) __PYX_ERR(0, 841, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":845
 * 
 * 
 *             if contains_specific_pattern_or_keys(self._pars):             # <<<<<<<<<<<<<<
 * 
 *                 self._pars['skip_class_sz'] = 0
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_contains_specific_pattern_or_key); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_self->_pars};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 845, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":847
 *             if contains_specific_pattern_or_keys(self._pars):
 * 
 *                 self._pars['skip_class_sz'] = 0             # <<<<<<<<<<<<<<
 *                 self._pars['skip_background_and_thermo'] = 0
 *                 self._pars['skip_pkl'] = 0
 */
      if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_class_sz, __pyx_int_0) < 0))) __PYX_ERR(0, 847, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":848
 * 
 *                 self._pars['skip_class_sz'] = 0
 *                 self._pars['skip_background_and_thermo'] = 0             # <<<<<<<<<<<<<<
 *                 self._pars['skip_pkl'] = 0
 * 
 */
      if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_background_and_thermo, __pyx_int_0) < 0))) __PYX_ERR(0, 848, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":849
 *                 self._pars['skip_class_sz'] = 0
 *                 self._pars['skip_background_and_thermo'] = 0
 *                 self._pars['skip_pkl'] = 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
      if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_pkl, __pyx_int_0) < 0))) __PYX_ERR(0, 849, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":854
 *                 ## check if we need pknl :
 * 
 *                 pknl_in_output = re.compile(r'^hf$').match(self._pars['output'])             # <<<<<<<<<<<<<<
 * 
 *                 pknl_key_value_checks = any(self._pars.get(key) == 1 for key in ['use_pknl_in_2hterms_IA_only', 'use_pknl_in_2hterms'])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_compile); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u_hf};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 854, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_output); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 854, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 854, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_pknl_in_output = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":856
 *                 pknl_in_output = re.compile(r'^hf$').match(self._pars['output'])
 * 
 *                 pknl_key_value_checks = any(self._pars.get(key) == 1 for key in ['use_pknl_in_2hterms_IA_only', 'use_pknl_in_2hterms'])             # <<<<<<<<<<<<<<
 * 
 *                 non_linear_check = 'non_linear' in self._pars
 */
      __pyx_t_3 = __pyx_pf_9classy_sz_5Class_20compute_class_szfast_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_pknl_key_value_checks = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":858
 *                 pknl_key_value_checks = any(self._pars.get(key) == 1 for key in ['use_pknl_in_2hterms_IA_only', 'use_pknl_in_2hterms'])
 * 
 *                 non_linear_check = 'non_linear' in self._pars             # <<<<<<<<<<<<<<
 * 
 *                 if pknl_in_output or pknl_key_value_checks or non_linear_check:
 */
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_non_linear, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 858, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 858, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_non_linear_check, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":860
 *                 non_linear_check = 'non_linear' in self._pars
 * 
 *                 if pknl_in_output or pknl_key_value_checks or non_linear_check:             # <<<<<<<<<<<<<<
 * 
 *                     self._pars['skip_pknl'] = 0
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_pknl_in_output); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 860, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_1 = __pyx_t_8;
        goto __pyx_L29_bool_binop_done;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_pknl_key_value_checks); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 860, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_1 = __pyx_t_8;
        goto __pyx_L29_bool_binop_done;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_non_linear_check); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 860, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_8;
      __pyx_L29_bool_binop_done:;
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":862
 *                 if pknl_in_output or pknl_key_value_checks or non_linear_check:
 * 
 *                     self._pars['skip_pknl'] = 0             # <<<<<<<<<<<<<<
 * 
 *                 ## done with check of pknl
 */
        if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_pknl, __pyx_int_0) < 0))) __PYX_ERR(0, 862, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":860
 *                 non_linear_check = 'non_linear' in self._pars
 * 
 *                 if pknl_in_output or pknl_key_value_checks or non_linear_check:             # <<<<<<<<<<<<<<
 * 
 *                     self._pars['skip_pknl'] = 0
 */
      }

      /* "class-sz/python/classy.pyx":845
 * 
 * 
 *             if contains_specific_pattern_or_keys(self._pars):             # <<<<<<<<<<<<<<
 * 
 *                 self._pars['skip_class_sz'] = 0
 */
      goto __pyx_L27;
    }

    /* "class-sz/python/classy.pyx":869
 *             else:
 * 
 *                 self._pars['skip_class_sz'] = 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      if (unlikely((PyObject_SetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_class_sz, __pyx_int_1) < 0))) __PYX_ERR(0, 869, __pyx_L1_error)
    }
    __pyx_L27:;

    /* "class-sz/python/classy.pyx":839
 *         # test is anything else than class quantities are requested.
 *         # if so make sure we run at least input.
 *         if class_sz_in_dict_output(self._pars):             # <<<<<<<<<<<<<<
 * 
 *             self._pars['skip_input'] = 0
 */
  }

  /* "class-sz/python/classy.pyx":872
 * 
 * 
 *         skip_background_and_thermo = self._pars['skip_background_and_thermo']             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_background_and_thermo); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_skip_background_and_thermo = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":875
 * 
 * 
 *         if not skip_background_and_thermo:             # <<<<<<<<<<<<<<
 * 
 *             self.compute(level=["thermodynamics"])
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_skip_background_and_thermo); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 875, __pyx_L1_error)
  __pyx_t_8 = (!__pyx_t_1);
  if (__pyx_t_8) {

    /* "class-sz/python/classy.pyx":877
 *         if not skip_background_and_thermo:
 * 
 *             self.compute(level=["thermodynamics"])             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_u_thermodynamics);
    __Pyx_GIVEREF(__pyx_n_u_thermodynamics);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_u_thermodynamics)) __PYX_ERR(0, 877, __pyx_L1_error);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_level, __pyx_t_4) < 0) __PYX_ERR(0, 877, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":875
 * 
 * 
 *         if not skip_background_and_thermo:             # <<<<<<<<<<<<<<
 * 
 *             self.compute(level=["thermodynamics"])
 */
    goto __pyx_L32;
  }

  /* "class-sz/python/classy.pyx":882
 *         else:
 * 
 *             if not self._pars['skip_input']:             # <<<<<<<<<<<<<<
 *                 self.compute(level=["input"])
 * 
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_input); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 882, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = (!__pyx_t_8);
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":883
 * 
 *             if not self._pars['skip_input']:
 *                 self.compute(level=["input"])             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_n_u_input);
      __Pyx_GIVEREF(__pyx_n_u_input);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_input)) __PYX_ERR(0, 883, __pyx_L1_error);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_level, __pyx_t_2) < 0) __PYX_ERR(0, 883, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":882
 *         else:
 * 
 *             if not self._pars['skip_input']:             # <<<<<<<<<<<<<<
 *                 self.compute(level=["input"])
 * 
 */
      goto __pyx_L33;
    }

    /* "class-sz/python/classy.pyx":887
 *             else:
 * 
 *                 if 'H0' in self._pars:             # <<<<<<<<<<<<<<
 *                     self.ba.h = self._pars['H0']/100.
 * 
 */
    /*else*/ {
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_H0, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 887, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":888
 * 
 *                 if 'H0' in self._pars:
 *                     self.ba.h = self._pars['H0']/100.             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_H0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 888, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_2, __pyx_float_100_, 100., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 888, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 888, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_cur_scope->__pyx_v_self->ba.h = __pyx_t_9;

        /* "class-sz/python/classy.pyx":887
 *             else:
 * 
 *                 if 'H0' in self._pars:             # <<<<<<<<<<<<<<
 *                     self.ba.h = self._pars['H0']/100.
 * 
 */
      }
    }
    __pyx_L33:;
  }
  __pyx_L32:;

  /* "class-sz/python/classy.pyx":893
 * 
 * 
 *         params_settings = self._pars.copy()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 893, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_params_settings = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":896
 * 
 * 
 *         if 'age' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             # in this case the corresponding h value as been found
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_age, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 896, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":900
 *             # in this case the corresponding h value as been found
 *             # so we delete age and set H0
 *             params_settings['H0'] = 100.*self.h()             # <<<<<<<<<<<<<<
 * 
 *             del params_settings['age']
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 900, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_Multiply(__pyx_float_100_, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely((PyObject_SetItem(__pyx_v_params_settings, __pyx_n_u_H0, __pyx_t_2) < 0))) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":902
 *             params_settings['H0'] = 100.*self.h()
 * 
 *             del params_settings['age']             # <<<<<<<<<<<<<<
 * 
 * 
 */
    if (unlikely((PyObject_DelItem(__pyx_v_params_settings, __pyx_n_u_age) < 0))) __PYX_ERR(0, 902, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":896
 * 
 * 
 *         if 'age' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             # in this case the corresponding h value as been found
 */
  }

  /* "class-sz/python/classy.pyx":905
 * 
 * 
 *         cszfast = Class_szfast(params_settings=params_settings)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Class_szfast); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params_settings, __pyx_v_params_settings) < 0) __PYX_ERR(0, 905, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_cszfast = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":908
 * 
 * 
 *         if '100*theta_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           cszfast.get_H0_from_thetas(params_settings)
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_100_theta_s, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 908, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":910
 *         if '100*theta_s' in self._pars:
 * 
 *           cszfast.get_H0_from_thetas(params_settings)             # <<<<<<<<<<<<<<
 * 
 *         if 'sigma8' in self._pars:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_get_H0_from_thetas); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_params_settings};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":908
 * 
 * 
 *         if '100*theta_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *           cszfast.get_H0_from_thetas(params_settings)
 */
  }

  /* "class-sz/python/classy.pyx":912
 *           cszfast.get_H0_from_thetas(params_settings)
 * 
 *         if 'sigma8' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.find_As(params_settings)
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_sigma8, __pyx_cur_scope->__pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 912, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":914
 *         if 'sigma8' in self._pars:
 * 
 *             cszfast.find_As(params_settings)             # <<<<<<<<<<<<<<
 * 
 *             cszfast.logA_fast = params_settings['ln10^{10}A_s']
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_find_As); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_params_settings};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":916
 *             cszfast.find_As(params_settings)
 * 
 *             cszfast.logA_fast = params_settings['ln10^{10}A_s']             # <<<<<<<<<<<<<<
 * 
 *             cszfast.A_s_fast = np.exp(cszfast.logA_fast)*1e-10
 */
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_params_settings, __pyx_kp_u_ln10_10_A_s); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_cszfast, __pyx_n_s_logA_fast, __pyx_t_4) < 0) __PYX_ERR(0, 916, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":918
 *             cszfast.logA_fast = params_settings['ln10^{10}A_s']
 * 
 *             cszfast.A_s_fast = np.exp(cszfast.logA_fast)*1e-10             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_logA_fast); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 918, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_Multiply(__pyx_t_4, __pyx_float_1eneg_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_cszfast, __pyx_n_s_A_s_fast, __pyx_t_2) < 0) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":912
 *           cszfast.get_H0_from_thetas(params_settings)
 * 
 *         if 'sigma8' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.find_As(params_settings)
 */
  }

  /* "class-sz/python/classy.pyx":921
 * 
 * 
 *         cszfast.params_for_emulators = params_settings             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_cszfast, __pyx_n_s_params_for_emulators, __pyx_v_params_settings) < 0) __PYX_ERR(0, 921, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":924
 * 
 * 
 *         if self._pars['skip_cmb'] == 0:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.calculate_cmb(want_tt=True,
 */
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_cmb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 924, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":926
 *         if self._pars['skip_cmb'] == 0:
 * 
 *             cszfast.calculate_cmb(want_tt=True,             # <<<<<<<<<<<<<<
 *                                   want_te=True,
 *                                   want_ee=True,
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_cmb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_want_tt, Py_True) < 0) __PYX_ERR(0, 926, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":927
 * 
 *             cszfast.calculate_cmb(want_tt=True,
 *                                   want_te=True,             # <<<<<<<<<<<<<<
 *                                   want_ee=True,
 *                                   want_pp=True,
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_want_te, Py_True) < 0) __PYX_ERR(0, 926, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":928
 *             cszfast.calculate_cmb(want_tt=True,
 *                                   want_te=True,
 *                                   want_ee=True,             # <<<<<<<<<<<<<<
 *                                   want_pp=True,
 *                                   **params_settings)
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_want_ee, Py_True) < 0) __PYX_ERR(0, 926, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":929
 *                                   want_te=True,
 *                                   want_ee=True,
 *                                   want_pp=True,             # <<<<<<<<<<<<<<
 *                                   **params_settings)
 * 
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_want_pp, Py_True) < 0) __PYX_ERR(0, 926, __pyx_L1_error)
    __pyx_t_4 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":930
 *                                   want_ee=True,
 *                                   want_pp=True,
 *                                   **params_settings)             # <<<<<<<<<<<<<<
 * 
 *             # deactivate this option (15/06/2024)
 */
    if (unlikely(__pyx_v_params_settings == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 930, __pyx_L1_error)
    }
    if (__Pyx_MergeKeywords(__pyx_t_4, __pyx_v_params_settings) < 0) __PYX_ERR(0, 930, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":926
 *         if self._pars['skip_cmb'] == 0:
 * 
 *             cszfast.calculate_cmb(want_tt=True,             # <<<<<<<<<<<<<<
 *                                   want_te=True,
 *                                   want_ee=True,
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":924
 * 
 * 
 *         if self._pars['skip_cmb'] == 0:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.calculate_cmb(want_tt=True,
 */
  }

  /* "class-sz/python/classy.pyx":939
 * 
 * 
 *         if self._pars['skip_pkl'] == 0:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_pkl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":942
 * 
 * 
 *           start = time.time()             # <<<<<<<<<<<<<<
 *           cszfast.calculate_pkl(**params_settings)
 *           end = time.time()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_start = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":943
 * 
 *           start = time.time()
 *           cszfast.calculate_pkl(**params_settings)             # <<<<<<<<<<<<<<
 *           end = time.time()
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_pkl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(__pyx_v_params_settings == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 943, __pyx_L1_error)
    }
    if (likely(PyDict_CheckExact(__pyx_v_params_settings))) {
      __pyx_t_2 = PyDict_Copy(__pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 943, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 943, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":944
 *           start = time.time()
 *           cszfast.calculate_pkl(**params_settings)
 *           end = time.time()             # <<<<<<<<<<<<<<
 * 
 *         if self._pars['skip_pknl'] == 0:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 944, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_end = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":939
 * 
 * 
 *         if self._pars['skip_pkl'] == 0:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "class-sz/python/classy.pyx":946
 *           end = time.time()
 * 
 *         if self._pars['skip_pknl'] == 0:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_pknl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_4, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":949
 * 
 * 
 *           start = time.time()             # <<<<<<<<<<<<<<
 *           cszfast.calculate_pknl(**params_settings)
 *           end = time.time()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 949, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_start, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":950
 * 
 *           start = time.time()
 *           cszfast.calculate_pknl(**params_settings)             # <<<<<<<<<<<<<<
 *           end = time.time()
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_pknl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__pyx_v_params_settings == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 950, __pyx_L1_error)
    }
    if (likely(PyDict_CheckExact(__pyx_v_params_settings))) {
      __pyx_t_2 = PyDict_Copy(__pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":951
 *           start = time.time()
 *           cszfast.calculate_pknl(**params_settings)
 *           end = time.time()             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 951, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_end, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":946
 *           end = time.time()
 * 
 *         if self._pars['skip_pknl'] == 0:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "class-sz/python/classy.pyx":955
 * 
 * 
 *         if self._pars['skip_sigma8_and_der'] == 0:             # <<<<<<<<<<<<<<
 * 
 *           start = time.time()
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_sigma8_and_der); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":957
 *         if self._pars['skip_sigma8_and_der'] == 0:
 * 
 *           start = time.time()             # <<<<<<<<<<<<<<
 *           cszfast.calculate_sigma8_and_der(**params_settings)
 *           end = time.time()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 957, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_start, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":958
 * 
 *           start = time.time()
 *           cszfast.calculate_sigma8_and_der(**params_settings)             # <<<<<<<<<<<<<<
 *           end = time.time()
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_sigma8_and_der); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(__pyx_v_params_settings == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 958, __pyx_L1_error)
    }
    if (likely(PyDict_CheckExact(__pyx_v_params_settings))) {
      __pyx_t_2 = PyDict_Copy(__pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 958, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 958, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":959
 *           start = time.time()
 *           cszfast.calculate_sigma8_and_der(**params_settings)
 *           end = time.time()             # <<<<<<<<<<<<<<
 * 
 *           self.sigma8_fast = cszfast.sigma8
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 959, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_end, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":961
 *           end = time.time()
 * 
 *           self.sigma8_fast = cszfast.sigma8             # <<<<<<<<<<<<<<
 *           self.Neff_fast = cszfast.Neff
 *           self.A_s_fast = cszfast.A_s_fast
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_sigma8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 961, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_cur_scope->__pyx_v_self->sigma8_fast = __pyx_t_9;

    /* "class-sz/python/classy.pyx":962
 * 
 *           self.sigma8_fast = cszfast.sigma8
 *           self.Neff_fast = cszfast.Neff             # <<<<<<<<<<<<<<
 *           self.A_s_fast = cszfast.A_s_fast
 *           self.logA_fast = cszfast.logA_fast
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_Neff); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 962, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_cur_scope->__pyx_v_self->Neff_fast = __pyx_t_9;

    /* "class-sz/python/classy.pyx":963
 *           self.sigma8_fast = cszfast.sigma8
 *           self.Neff_fast = cszfast.Neff
 *           self.A_s_fast = cszfast.A_s_fast             # <<<<<<<<<<<<<<
 *           self.logA_fast = cszfast.logA_fast
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_A_s_fast); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 963, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_cur_scope->__pyx_v_self->A_s_fast = __pyx_t_9;

    /* "class-sz/python/classy.pyx":964
 *           self.Neff_fast = cszfast.Neff
 *           self.A_s_fast = cszfast.A_s_fast
 *           self.logA_fast = cszfast.logA_fast             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_logA_fast); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 964, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_cur_scope->__pyx_v_self->logA_fast = __pyx_t_9;

    /* "class-sz/python/classy.pyx":955
 * 
 * 
 *         if self._pars['skip_sigma8_and_der'] == 0:             # <<<<<<<<<<<<<<
 * 
 *           start = time.time()
 */
    goto __pyx_L41;
  }

  /* "class-sz/python/classy.pyx":968
 *         else:
 * 
 *           self.sigma8_fast = 0.             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_cur_scope->__pyx_v_self->sigma8_fast = 0.;
  }
  __pyx_L41:;

  /* "class-sz/python/classy.pyx":971
 * 
 * 
 *         if self._pars['skip_sigma8_at_z'] == 0:             # <<<<<<<<<<<<<<
 * 
 *           start = time.time()
 */
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_sigma8_at_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_4, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":973
 *         if self._pars['skip_sigma8_at_z'] == 0:
 * 
 *           start = time.time()             # <<<<<<<<<<<<<<
 *           cszfast.calculate_sigma8_at_z(**params_settings)
 *           end = time.time()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 973, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_start, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":974
 * 
 *           start = time.time()
 *           cszfast.calculate_sigma8_at_z(**params_settings)             # <<<<<<<<<<<<<<
 *           end = time.time()
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_sigma8_at_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__pyx_v_params_settings == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 974, __pyx_L1_error)
    }
    if (likely(PyDict_CheckExact(__pyx_v_params_settings))) {
      __pyx_t_2 = PyDict_Copy(__pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 974, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 974, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":975
 *           start = time.time()
 *           cszfast.calculate_sigma8_at_z(**params_settings)
 *           end = time.time()             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 975, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_end, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":971
 * 
 * 
 *         if self._pars['skip_sigma8_at_z'] == 0:             # <<<<<<<<<<<<<<
 * 
 *           start = time.time()
 */
  }

  /* "class-sz/python/classy.pyx":981
 * 
 * 
 *         if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *           if self._pars['skip_chi'] == 0:
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_background_and_thermo); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 981, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":983
 *         if self._pars['skip_background_and_thermo']:
 * 
 *           if self._pars['skip_chi'] == 0:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.calculate_chi(**params_settings)
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_chi); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 983, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 983, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":985
 *           if self._pars['skip_chi'] == 0:
 * 
 *             cszfast.calculate_chi(**params_settings)             # <<<<<<<<<<<<<<
 * 
 *           if self._pars['skip_hubble'] == 0:
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_chi); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 985, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(__pyx_v_params_settings == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
        __PYX_ERR(0, 985, __pyx_L1_error)
      }
      if (likely(PyDict_CheckExact(__pyx_v_params_settings))) {
        __pyx_t_4 = PyDict_Copy(__pyx_v_params_settings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 985, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_v_params_settings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 985, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 985, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":983
 *         if self._pars['skip_background_and_thermo']:
 * 
 *           if self._pars['skip_chi'] == 0:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.calculate_chi(**params_settings)
 */
    }

    /* "class-sz/python/classy.pyx":987
 *             cszfast.calculate_chi(**params_settings)
 * 
 *           if self._pars['skip_hubble'] == 0:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.calculate_hubble(**params_settings)
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_cur_scope->__pyx_v_self->_pars, __pyx_n_u_skip_hubble); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 987, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":989
 *           if self._pars['skip_hubble'] == 0:
 * 
 *             cszfast.calculate_hubble(**params_settings)             # <<<<<<<<<<<<<<
 * 
 *           self.tsz.use_class_sz_fast_mode = 1
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_hubble); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 989, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely(__pyx_v_params_settings == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
        __PYX_ERR(0, 989, __pyx_L1_error)
      }
      if (likely(PyDict_CheckExact(__pyx_v_params_settings))) {
        __pyx_t_4 = PyDict_Copy(__pyx_v_params_settings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 989, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_v_params_settings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 989, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 989, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":987
 *             cszfast.calculate_chi(**params_settings)
 * 
 *           if self._pars['skip_hubble'] == 0:             # <<<<<<<<<<<<<<
 * 
 *             cszfast.calculate_hubble(**params_settings)
 */
    }

    /* "class-sz/python/classy.pyx":991
 *             cszfast.calculate_hubble(**params_settings)
 * 
 *           self.tsz.use_class_sz_fast_mode = 1             # <<<<<<<<<<<<<<
 *           self.tsz.skip_background_and_thermo = 1
 *           self.class_szfast = cszfast
 */
    __pyx_cur_scope->__pyx_v_self->tsz.use_class_sz_fast_mode = 1;

    /* "class-sz/python/classy.pyx":992
 * 
 *           self.tsz.use_class_sz_fast_mode = 1
 *           self.tsz.skip_background_and_thermo = 1             # <<<<<<<<<<<<<<
 *           self.class_szfast = cszfast
 *           self.computed = True
 */
    __pyx_cur_scope->__pyx_v_self->tsz.skip_background_and_thermo = 1;

    /* "class-sz/python/classy.pyx":993
 *           self.tsz.use_class_sz_fast_mode = 1
 *           self.tsz.skip_background_and_thermo = 1
 *           self.class_szfast = cszfast             # <<<<<<<<<<<<<<
 *           self.computed = True
 *           return
 */
    __Pyx_INCREF(__pyx_v_cszfast);
    __Pyx_GIVEREF(__pyx_v_cszfast);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->class_szfast);
    __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->class_szfast);
    __pyx_cur_scope->__pyx_v_self->class_szfast = __pyx_v_cszfast;

    /* "class-sz/python/classy.pyx":994
 *           self.tsz.skip_background_and_thermo = 1
 *           self.class_szfast = cszfast
 *           self.computed = True             # <<<<<<<<<<<<<<
 *           return
 *         else:
 */
    __pyx_cur_scope->__pyx_v_self->computed = 1;

    /* "class-sz/python/classy.pyx":995
 *           self.class_szfast = cszfast
 *           self.computed = True
 *           return             # <<<<<<<<<<<<<<
 *         else:
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":981
 * 
 * 
 *         if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *           if self._pars['skip_chi'] == 0:
 */
  }

  /* "class-sz/python/classy.pyx":1002
 *           # end = time.time()
 *           # print('>>> class_sz bg/th calculation took:',end-start) # this takes < 1e-4s
 *           self.tsz.use_class_sz_fast_mode = 1             # <<<<<<<<<<<<<<
 *           if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *           &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  /*else*/ {
    __pyx_cur_scope->__pyx_v_self->tsz.use_class_sz_fast_mode = 1;

    /* "class-sz/python/classy.pyx":1004
 *           self.tsz.use_class_sz_fast_mode = 1
 *           if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *           &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *               self.struct_cleanup()
 *               raise CosmoComputationError(self.tsz.error_message)
 */
    __pyx_t_1 = (class_sz_cosmo_init((&__pyx_cur_scope->__pyx_v_self->ba), (&__pyx_cur_scope->__pyx_v_self->th), (&__pyx_cur_scope->__pyx_v_self->pt), (&__pyx_cur_scope->__pyx_v_self->nl), (&__pyx_cur_scope->__pyx_v_self->pm), (&__pyx_cur_scope->__pyx_v_self->sp), (&__pyx_cur_scope->__pyx_v_self->le), (&__pyx_cur_scope->__pyx_v_self->tsz), (&__pyx_cur_scope->__pyx_v_self->pr)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":1003
 *           # print('>>> class_sz bg/th calculation took:',end-start) # this takes < 1e-4s
 *           self.tsz.use_class_sz_fast_mode = 1
 *           if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *           &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *               self.struct_cleanup()
 */
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":1005
 *           if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *           &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *               self.struct_cleanup()             # <<<<<<<<<<<<<<
 *               raise CosmoComputationError(self.tsz.error_message)
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1005, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1005, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1006
 *           &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *               self.struct_cleanup()
 *               raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 * 
 *           if self.tsz.skip_class_sz:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1006, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_cur_scope->__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1006, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1006, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1006, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1003
 *           # print('>>> class_sz bg/th calculation took:',end-start) # this takes < 1e-4s
 *           self.tsz.use_class_sz_fast_mode = 1
 *           if class_sz_cosmo_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *           &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *               self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":1008
 *               raise CosmoComputationError(self.tsz.error_message)
 * 
 *           if self.tsz.skip_class_sz:             # <<<<<<<<<<<<<<
 * 
 *               self.computed = True
 */
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_self->tsz.skip_class_sz != 0);
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":1010
 *           if self.tsz.skip_class_sz:
 * 
 *               self.computed = True             # <<<<<<<<<<<<<<
 *               self.class_szfast = cszfast
 *               return
 */
      __pyx_cur_scope->__pyx_v_self->computed = 1;

      /* "class-sz/python/classy.pyx":1011
 * 
 *               self.computed = True
 *               self.class_szfast = cszfast             # <<<<<<<<<<<<<<
 *               return
 * 
 */
      __Pyx_INCREF(__pyx_v_cszfast);
      __Pyx_GIVEREF(__pyx_v_cszfast);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->class_szfast);
      __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->class_szfast);
      __pyx_cur_scope->__pyx_v_self->class_szfast = __pyx_v_cszfast;

      /* "class-sz/python/classy.pyx":1012
 *               self.computed = True
 *               self.class_szfast = cszfast
 *               return             # <<<<<<<<<<<<<<
 * 
 *           else:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":1008
 *               raise CosmoComputationError(self.tsz.error_message)
 * 
 *           if self.tsz.skip_class_sz:             # <<<<<<<<<<<<<<
 * 
 *               self.computed = True
 */
    }

    /* "class-sz/python/classy.pyx":1016
 *           else:
 * 
 *             start = time.time()             # <<<<<<<<<<<<<<
 * 
 *             cszfast.calculate_sigma(**params_settings)
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1016, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1016, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1016, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_start, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1018
 *             start = time.time()
 * 
 *             cszfast.calculate_sigma(**params_settings)             # <<<<<<<<<<<<<<
 * 
 *             if self.tsz.need_sigma == 1:
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_calculate_sigma); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1018, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(__pyx_v_params_settings == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
        __PYX_ERR(0, 1018, __pyx_L1_error)
      }
      if (likely(PyDict_CheckExact(__pyx_v_params_settings))) {
        __pyx_t_2 = PyDict_Copy(__pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1018, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_v_params_settings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1018, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1018, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "class-sz/python/classy.pyx":1020
 *             cszfast.calculate_sigma(**params_settings)
 * 
 *             if self.tsz.need_sigma == 1:             # <<<<<<<<<<<<<<
 * 
 *               index_z_r = 0
 */
      __pyx_t_1 = (__pyx_cur_scope->__pyx_v_self->tsz.need_sigma == 1);
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":1022
 *             if self.tsz.need_sigma == 1:
 * 
 *               index_z_r = 0             # <<<<<<<<<<<<<<
 * 
 *             for index_z in range(self.tsz.ndim_redshifts):
 */
        __Pyx_INCREF(__pyx_int_0);
        __pyx_v_index_z_r = __pyx_int_0;

        /* "class-sz/python/classy.pyx":1020
 *             cszfast.calculate_sigma(**params_settings)
 * 
 *             if self.tsz.need_sigma == 1:             # <<<<<<<<<<<<<<
 * 
 *               index_z_r = 0
 */
      }

      /* "class-sz/python/classy.pyx":1024
 *               index_z_r = 0
 * 
 *             for index_z in range(self.tsz.ndim_redshifts):             # <<<<<<<<<<<<<<
 * 
 *                 ln1pzc = cszfast.cszfast_pk_grid_ln1pz[index_z]
 */
      __pyx_t_10 = __pyx_cur_scope->__pyx_v_self->tsz.ndim_redshifts;
      __pyx_t_11 = __pyx_t_10;
      for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
        __pyx_v_index_z = __pyx_t_12;

        /* "class-sz/python/classy.pyx":1026
 *             for index_z in range(self.tsz.ndim_redshifts):
 * 
 *                 ln1pzc = cszfast.cszfast_pk_grid_ln1pz[index_z]             # <<<<<<<<<<<<<<
 * 
 *                 self.tsz.array_redshift[index_z] = ln1pzc
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_cszfast_pk_grid_ln1pz); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_4, __pyx_v_index_z, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ln1pzc, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "class-sz/python/classy.pyx":1028
 *                 ln1pzc = cszfast.cszfast_pk_grid_ln1pz[index_z]
 * 
 *                 self.tsz.array_redshift[index_z] = ln1pzc             # <<<<<<<<<<<<<<
 * 
 *                 for index_r in range(self.tsz.ndim_masses):
 */
        __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_v_ln1pzc); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1028, __pyx_L1_error)
        (__pyx_cur_scope->__pyx_v_self->tsz.array_redshift[__pyx_v_index_z]) = __pyx_t_9;

        /* "class-sz/python/classy.pyx":1030
 *                 self.tsz.array_redshift[index_z] = ln1pzc
 * 
 *                 for index_r in range(self.tsz.ndim_masses):             # <<<<<<<<<<<<<<
 * 
 *                     if index_z == 0:
 */
        __pyx_t_13 = __pyx_cur_scope->__pyx_v_self->tsz.ndim_masses;
        __pyx_t_14 = __pyx_t_13;
        for (__pyx_t_15 = 0; __pyx_t_15 < __pyx_t_14; __pyx_t_15+=1) {
          __pyx_v_index_r = __pyx_t_15;

          /* "class-sz/python/classy.pyx":1032
 *                 for index_r in range(self.tsz.ndim_masses):
 * 
 *                     if index_z == 0:             # <<<<<<<<<<<<<<
 * 
 *                         self.tsz.array_lnk[index_r] = cszfast.cszfast_pk_grid_lnk[index_r]
 */
          __pyx_t_1 = (__pyx_v_index_z == 0);
          if (__pyx_t_1) {

            /* "class-sz/python/classy.pyx":1034
 *                     if index_z == 0:
 * 
 *                         self.tsz.array_lnk[index_r] = cszfast.cszfast_pk_grid_lnk[index_r]             # <<<<<<<<<<<<<<
 *                         self.tsz.array_radius[index_r] = cszfast.cszfast_pk_grid_lnr[index_r]
 * 
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_cszfast_pk_grid_lnk); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1034, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_2, __pyx_v_index_r, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1034, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1034, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            (__pyx_cur_scope->__pyx_v_self->tsz.array_lnk[__pyx_v_index_r]) = __pyx_t_9;

            /* "class-sz/python/classy.pyx":1035
 * 
 *                         self.tsz.array_lnk[index_r] = cszfast.cszfast_pk_grid_lnk[index_r]
 *                         self.tsz.array_radius[index_r] = cszfast.cszfast_pk_grid_lnr[index_r]             # <<<<<<<<<<<<<<
 * 
 *                     self.tsz.array_sigma_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_lnsigma2_flat[index_z_r]
 */
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_cszfast_pk_grid_lnr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1035, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_4, __pyx_v_index_r, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1035, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1035, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            (__pyx_cur_scope->__pyx_v_self->tsz.array_radius[__pyx_v_index_r]) = __pyx_t_9;

            /* "class-sz/python/classy.pyx":1032
 *                 for index_r in range(self.tsz.ndim_masses):
 * 
 *                     if index_z == 0:             # <<<<<<<<<<<<<<
 * 
 *                         self.tsz.array_lnk[index_r] = cszfast.cszfast_pk_grid_lnk[index_r]
 */
          }

          /* "class-sz/python/classy.pyx":1037
 *                         self.tsz.array_radius[index_r] = cszfast.cszfast_pk_grid_lnr[index_r]
 * 
 *                     self.tsz.array_sigma_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_lnsigma2_flat[index_z_r]             # <<<<<<<<<<<<<<
 *                     self.tsz.array_dsigma2dR_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_dsigma2_flat[index_z_r]
 *                     self.tsz.array_pknl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pknl_flat[index_z_r]
 */
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_cszfast_pk_grid_lnsigma2_flat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1037, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1037, __pyx_L1_error) }
          __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_index_z_r); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1037, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1037, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1037, __pyx_L1_error) }
          __pyx_t_16 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_z_r); if (unlikely((__pyx_t_16 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1037, __pyx_L1_error)
          (__pyx_cur_scope->__pyx_v_self->tsz.array_sigma_at_z_and_R[__pyx_t_16]) = __pyx_t_9;

          /* "class-sz/python/classy.pyx":1038
 * 
 *                     self.tsz.array_sigma_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_lnsigma2_flat[index_z_r]
 *                     self.tsz.array_dsigma2dR_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_dsigma2_flat[index_z_r]             # <<<<<<<<<<<<<<
 *                     self.tsz.array_pknl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pknl_flat[index_z_r]
 *                     self.tsz.array_pkl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pkl_flat[index_z_r]
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_cszfast_pk_grid_dsigma2_flat); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1038, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1038, __pyx_L1_error) }
          __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_index_z_r); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1038, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1038, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1038, __pyx_L1_error) }
          __pyx_t_16 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_z_r); if (unlikely((__pyx_t_16 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1038, __pyx_L1_error)
          (__pyx_cur_scope->__pyx_v_self->tsz.array_dsigma2dR_at_z_and_R[__pyx_t_16]) = __pyx_t_9;

          /* "class-sz/python/classy.pyx":1039
 *                     self.tsz.array_sigma_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_lnsigma2_flat[index_z_r]
 *                     self.tsz.array_dsigma2dR_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_dsigma2_flat[index_z_r]
 *                     self.tsz.array_pknl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pknl_flat[index_z_r]             # <<<<<<<<<<<<<<
 *                     self.tsz.array_pkl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pkl_flat[index_z_r]
 * 
 */
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_cszfast_pk_grid_pknl_flat); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1039, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1039, __pyx_L1_error) }
          __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_index_z_r); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1039, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1039, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1039, __pyx_L1_error) }
          __pyx_t_16 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_z_r); if (unlikely((__pyx_t_16 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1039, __pyx_L1_error)
          (__pyx_cur_scope->__pyx_v_self->tsz.array_pknl_at_z_and_k[__pyx_t_16]) = __pyx_t_9;

          /* "class-sz/python/classy.pyx":1040
 *                     self.tsz.array_dsigma2dR_at_z_and_R[index_z_r] = cszfast.cszfast_pk_grid_dsigma2_flat[index_z_r]
 *                     self.tsz.array_pknl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pknl_flat[index_z_r]
 *                     self.tsz.array_pkl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pkl_flat[index_z_r]             # <<<<<<<<<<<<<<
 * 
 *                     index_z_r += 1
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_cszfast, __pyx_n_s_cszfast_pk_grid_pkl_flat); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1040, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1040, __pyx_L1_error) }
          __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_v_index_z_r); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1040, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1040, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1040, __pyx_L1_error) }
          __pyx_t_16 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_z_r); if (unlikely((__pyx_t_16 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1040, __pyx_L1_error)
          (__pyx_cur_scope->__pyx_v_self->tsz.array_pkl_at_z_and_k[__pyx_t_16]) = __pyx_t_9;

          /* "class-sz/python/classy.pyx":1042
 *                     self.tsz.array_pkl_at_z_and_k[index_z_r] = cszfast.cszfast_pk_grid_pkl_flat[index_z_r]
 * 
 *                     index_z_r += 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
          if (unlikely(!__pyx_v_index_z_r)) { __Pyx_RaiseUnboundLocalError("index_z_r"); __PYX_ERR(0, 1042, __pyx_L1_error) }
          __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_index_z_r, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1042, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_XDECREF_SET(__pyx_v_index_z_r, __pyx_t_2);
          __pyx_t_2 = 0;
        }
      }

      /* "class-sz/python/classy.pyx":1046
 * 
 * 
 *             end = time.time()             # <<<<<<<<<<<<<<
 *             # print('end tabulate sigma:',end-start)
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1046, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1046, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1046, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_end, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":1049
 *             # print('end tabulate sigma:',end-start)
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
      __pyx_t_1 = (class_sz_tabulate_init((&__pyx_cur_scope->__pyx_v_self->ba), (&__pyx_cur_scope->__pyx_v_self->th), (&__pyx_cur_scope->__pyx_v_self->pt), (&__pyx_cur_scope->__pyx_v_self->nl), (&__pyx_cur_scope->__pyx_v_self->pm), (&__pyx_cur_scope->__pyx_v_self->sp), (&__pyx_cur_scope->__pyx_v_self->le), (&__pyx_cur_scope->__pyx_v_self->tsz), (&__pyx_cur_scope->__pyx_v_self->pr)) == _FAILURE_);

      /* "class-sz/python/classy.pyx":1048
 *             end = time.time()
 *             # print('end tabulate sigma:',end-start)
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
      if (unlikely(__pyx_t_1)) {

        /* "class-sz/python/classy.pyx":1050
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 * 
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1050, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1050, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "class-sz/python/classy.pyx":1051
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 * 
 *             # print("before computing custom bias")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1051, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_cur_scope->__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1051, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1051, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 1051, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1048
 *             end = time.time()
 *             # print('end tabulate sigma:',end-start)
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
      }

      /* "class-sz/python/classy.pyx":1054
 * 
 *             # print("before computing custom bias")
 *             if self.tsz.has_b_custom1 == 1:             # <<<<<<<<<<<<<<
 *               # cszfast.calculate_custom1(**params_settings)
 *               # print("computing custom bias")
 */
      __pyx_t_1 = (__pyx_cur_scope->__pyx_v_self->tsz.has_b_custom1 == 1);
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":1057
 *               # cszfast.calculate_custom1(**params_settings)
 *               # print("computing custom bias")
 *               for index_z in range(self.tsz.array_b_custom1_n_z):             # <<<<<<<<<<<<<<
 *                 z = np.exp(self.tsz.array_b_custom1_ln1pz[index_z])-1.
 *                 # print(index_z,z)
 */
        __pyx_t_10 = __pyx_cur_scope->__pyx_v_self->tsz.array_b_custom1_n_z;
        __pyx_t_11 = __pyx_t_10;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_index_z = __pyx_t_12;

          /* "class-sz/python/classy.pyx":1058
 *               # print("computing custom bias")
 *               for index_z in range(self.tsz.array_b_custom1_n_z):
 *                 z = np.exp(self.tsz.array_b_custom1_ln1pz[index_z])-1.             # <<<<<<<<<<<<<<
 *                 # print(index_z,z)
 *                 self.tsz.array_b_custom1_bias[index_z] = np.log(classy_szfast.custom1_b(z,self))
 */
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1058, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1058, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyFloat_FromDouble((__pyx_cur_scope->__pyx_v_self->tsz.array_b_custom1_ln1pz[__pyx_v_index_z])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1058, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_6 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
            __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1058, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_4 = __Pyx_PyFloat_SubtractObjC(__pyx_t_2, __pyx_float_1_, 1., 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1058, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF_SET(__pyx_v_z, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "class-sz/python/classy.pyx":1060
 *                 z = np.exp(self.tsz.array_b_custom1_ln1pz[index_z])-1.
 *                 # print(index_z,z)
 *                 self.tsz.array_b_custom1_bias[index_z] = np.log(classy_szfast.custom1_b(z,self))             # <<<<<<<<<<<<<<
 *                 # print(index_z,self.tsz.array_b_custom1_bias[index_z])
 * 
 */
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1060, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_log); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1060, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_classy_szfast); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1060, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_custom1_b); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1060, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_z, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
            __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1060, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __pyx_t_7 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1060, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
          __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1060, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          (__pyx_cur_scope->__pyx_v_self->tsz.array_b_custom1_bias[__pyx_v_index_z]) = __pyx_t_9;
        }

        /* "class-sz/python/classy.pyx":1054
 * 
 *             # print("before computing custom bias")
 *             if self.tsz.has_b_custom1 == 1:             # <<<<<<<<<<<<<<
 *               # cszfast.calculate_custom1(**params_settings)
 *               # print("computing custom bias")
 */
      }

      /* "class-sz/python/classy.pyx":1065
 * 
 *             #### fill in custom profile
 *             if self.tsz.has_custom1 == 1:             # <<<<<<<<<<<<<<
 *               # cszfast.calculate_custom1(**params_settings)
 *               for index_z in range(self.tsz.array_custom1_redshift_kernel_n_z):
 */
      __pyx_t_1 = (__pyx_cur_scope->__pyx_v_self->tsz.has_custom1 == 1);
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":1067
 *             if self.tsz.has_custom1 == 1:
 *               # cszfast.calculate_custom1(**params_settings)
 *               for index_z in range(self.tsz.array_custom1_redshift_kernel_n_z):             # <<<<<<<<<<<<<<
 *                 z = np.exp(self.tsz.array_custom1_redshift_kernel_ln1pz[index_z])-1.
 *                 self.tsz.array_custom1_redshift_kernel_W[index_z] = np.log(classy_szfast.custom1_W(z,self))
 */
        __pyx_t_10 = __pyx_cur_scope->__pyx_v_self->tsz.array_custom1_redshift_kernel_n_z;
        __pyx_t_11 = __pyx_t_10;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_index_z = __pyx_t_12;

          /* "class-sz/python/classy.pyx":1068
 *               # cszfast.calculate_custom1(**params_settings)
 *               for index_z in range(self.tsz.array_custom1_redshift_kernel_n_z):
 *                 z = np.exp(self.tsz.array_custom1_redshift_kernel_ln1pz[index_z])-1.             # <<<<<<<<<<<<<<
 *                 self.tsz.array_custom1_redshift_kernel_W[index_z] = np.log(classy_szfast.custom1_W(z,self))
 * 
 */
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyFloat_FromDouble((__pyx_cur_scope->__pyx_v_self->tsz.array_custom1_redshift_kernel_ln1pz[__pyx_v_index_z])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_7 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1068, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __pyx_t_2 = __Pyx_PyFloat_SubtractObjC(__pyx_t_4, __pyx_float_1_, 1., 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1068, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF_SET(__pyx_v_z, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "class-sz/python/classy.pyx":1069
 *               for index_z in range(self.tsz.array_custom1_redshift_kernel_n_z):
 *                 z = np.exp(self.tsz.array_custom1_redshift_kernel_ln1pz[index_z])-1.
 *                 self.tsz.array_custom1_redshift_kernel_W[index_z] = np.log(classy_szfast.custom1_W(z,self))             # <<<<<<<<<<<<<<
 * 
 *               index_m_z = 0
 */
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_log); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_classy_szfast); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_custom1_W); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_z, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1069, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __pyx_t_6 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
            __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1069, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
          __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1069, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          (__pyx_cur_scope->__pyx_v_self->tsz.array_custom1_redshift_kernel_W[__pyx_v_index_z]) = __pyx_t_9;
        }

        /* "class-sz/python/classy.pyx":1071
 *                 self.tsz.array_custom1_redshift_kernel_W[index_z] = np.log(classy_szfast.custom1_W(z,self))
 * 
 *               index_m_z = 0             # <<<<<<<<<<<<<<
 *               for index_z in range(self.tsz.n_z_custom1_profile):
 *                 z =  np.exp(self.tsz.array_custom1_profile_ln_1pz[index_z])-1.
 */
        __Pyx_INCREF(__pyx_int_0);
        __pyx_v_index_m_z = __pyx_int_0;

        /* "class-sz/python/classy.pyx":1072
 * 
 *               index_m_z = 0
 *               for index_z in range(self.tsz.n_z_custom1_profile):             # <<<<<<<<<<<<<<
 *                 z =  np.exp(self.tsz.array_custom1_profile_ln_1pz[index_z])-1.
 *                 for index_m in range(self.tsz.n_m_custom1_profile):
 */
        __pyx_t_10 = __pyx_cur_scope->__pyx_v_self->tsz.n_z_custom1_profile;
        __pyx_t_11 = __pyx_t_10;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_index_z = __pyx_t_12;

          /* "class-sz/python/classy.pyx":1073
 *               index_m_z = 0
 *               for index_z in range(self.tsz.n_z_custom1_profile):
 *                 z =  np.exp(self.tsz.array_custom1_profile_ln_1pz[index_z])-1.             # <<<<<<<<<<<<<<
 *                 for index_m in range(self.tsz.n_m_custom1_profile):
 *                   m = np.exp(self.tsz.array_custom1_profile_ln_m[index_m])
 */
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1073, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1073, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyFloat_FromDouble((__pyx_cur_scope->__pyx_v_self->tsz.array_custom1_profile_ln_1pz[__pyx_v_index_z])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1073, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_6 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
            __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1073, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_4 = __Pyx_PyFloat_SubtractObjC(__pyx_t_2, __pyx_float_1_, 1., 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1073, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF_SET(__pyx_v_z, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "class-sz/python/classy.pyx":1074
 *               for index_z in range(self.tsz.n_z_custom1_profile):
 *                 z =  np.exp(self.tsz.array_custom1_profile_ln_1pz[index_z])-1.
 *                 for index_m in range(self.tsz.n_m_custom1_profile):             # <<<<<<<<<<<<<<
 *                   m = np.exp(self.tsz.array_custom1_profile_ln_m[index_m])
 *                   for index_x in range(self.tsz.n_k_custom1_profile):
 */
          __pyx_t_13 = __pyx_cur_scope->__pyx_v_self->tsz.n_m_custom1_profile;
          __pyx_t_14 = __pyx_t_13;
          for (__pyx_t_15 = 0; __pyx_t_15 < __pyx_t_14; __pyx_t_15+=1) {
            __pyx_v_index_m = __pyx_t_15;

            /* "class-sz/python/classy.pyx":1075
 *                 z =  np.exp(self.tsz.array_custom1_profile_ln_1pz[index_z])-1.
 *                 for index_m in range(self.tsz.n_m_custom1_profile):
 *                   m = np.exp(self.tsz.array_custom1_profile_ln_m[index_m])             # <<<<<<<<<<<<<<
 *                   for index_x in range(self.tsz.n_k_custom1_profile):
 *                     x = np.exp(self.tsz.array_custom1_profile_ln_x[index_x])
 */
            __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1075, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_exp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1075, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_2 = PyFloat_FromDouble((__pyx_cur_scope->__pyx_v_self->tsz.array_custom1_profile_ln_m[__pyx_v_index_m])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1075, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_6 = NULL;
            __pyx_t_5 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_6)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
                __pyx_t_5 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
              __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1075, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
            __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_4);
            __pyx_t_4 = 0;

            /* "class-sz/python/classy.pyx":1076
 *                 for index_m in range(self.tsz.n_m_custom1_profile):
 *                   m = np.exp(self.tsz.array_custom1_profile_ln_m[index_m])
 *                   for index_x in range(self.tsz.n_k_custom1_profile):             # <<<<<<<<<<<<<<
 *                     x = np.exp(self.tsz.array_custom1_profile_ln_x[index_x])
 *                     self.tsz.array_custom1_profile_u_at_lnx_lnm_ln1pz[index_x][index_m_z] = np.log(classy_szfast.custom1_ux(x,m,z,self))
 */
            __pyx_t_17 = __pyx_cur_scope->__pyx_v_self->tsz.n_k_custom1_profile;
            __pyx_t_18 = __pyx_t_17;
            for (__pyx_t_19 = 0; __pyx_t_19 < __pyx_t_18; __pyx_t_19+=1) {
              __pyx_v_index_x = __pyx_t_19;

              /* "class-sz/python/classy.pyx":1077
 *                   m = np.exp(self.tsz.array_custom1_profile_ln_m[index_m])
 *                   for index_x in range(self.tsz.n_k_custom1_profile):
 *                     x = np.exp(self.tsz.array_custom1_profile_ln_x[index_x])             # <<<<<<<<<<<<<<
 *                     self.tsz.array_custom1_profile_u_at_lnx_lnm_ln1pz[index_x][index_m_z] = np.log(classy_szfast.custom1_ux(x,m,z,self))
 *                   index_m_z += 1
 */
              __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1077, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1077, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __pyx_t_3 = PyFloat_FromDouble((__pyx_cur_scope->__pyx_v_self->tsz.array_custom1_profile_ln_x[__pyx_v_index_x])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1077, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_6 = NULL;
              __pyx_t_5 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_2))) {
                __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
                if (likely(__pyx_t_6)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                  __Pyx_INCREF(__pyx_t_6);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_2, function);
                  __pyx_t_5 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
                __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1077, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              }
              __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_4);
              __pyx_t_4 = 0;

              /* "class-sz/python/classy.pyx":1078
 *                   for index_x in range(self.tsz.n_k_custom1_profile):
 *                     x = np.exp(self.tsz.array_custom1_profile_ln_x[index_x])
 *                     self.tsz.array_custom1_profile_u_at_lnx_lnm_ln1pz[index_x][index_m_z] = np.log(classy_szfast.custom1_ux(x,m,z,self))             # <<<<<<<<<<<<<<
 *                   index_m_z += 1
 * 
 */
              __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1078, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_log); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1078, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_classy_szfast); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1078, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_custom1_ux); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1078, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              __pyx_t_6 = NULL;
              __pyx_t_5 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_7))) {
                __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
                if (likely(__pyx_t_6)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                  __Pyx_INCREF(__pyx_t_6);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_7, function);
                  __pyx_t_5 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_v_x, __pyx_v_m, __pyx_v_z, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
                __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1078, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              }
              __pyx_t_7 = NULL;
              __pyx_t_5 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_3))) {
                __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
                if (likely(__pyx_t_7)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                  __Pyx_INCREF(__pyx_t_7);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_3, function);
                  __pyx_t_5 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
                __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1078, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              }
              __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1078, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __pyx_t_16 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_m_z); if (unlikely((__pyx_t_16 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1078, __pyx_L1_error)
              ((__pyx_cur_scope->__pyx_v_self->tsz.array_custom1_profile_u_at_lnx_lnm_ln1pz[__pyx_v_index_x])[__pyx_t_16]) = __pyx_t_9;
            }

            /* "class-sz/python/classy.pyx":1079
 *                     x = np.exp(self.tsz.array_custom1_profile_ln_x[index_x])
 *                     self.tsz.array_custom1_profile_u_at_lnx_lnm_ln1pz[index_x][index_m_z] = np.log(classy_szfast.custom1_ux(x,m,z,self))
 *                   index_m_z += 1             # <<<<<<<<<<<<<<
 * 
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 */
            __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_index_m_z, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1079, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF_SET(__pyx_v_index_m_z, __pyx_t_4);
            __pyx_t_4 = 0;
          }
        }

        /* "class-sz/python/classy.pyx":1065
 * 
 *             #### fill in custom profile
 *             if self.tsz.has_custom1 == 1:             # <<<<<<<<<<<<<<
 *               # cszfast.calculate_custom1(**params_settings)
 *               for index_z in range(self.tsz.array_custom1_redshift_kernel_n_z):
 */
      }

      /* "class-sz/python/classy.pyx":1082
 * 
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
      __pyx_t_1 = (class_sz_integrate_init((&__pyx_cur_scope->__pyx_v_self->ba), (&__pyx_cur_scope->__pyx_v_self->th), (&__pyx_cur_scope->__pyx_v_self->pt), (&__pyx_cur_scope->__pyx_v_self->nl), (&__pyx_cur_scope->__pyx_v_self->pm), (&__pyx_cur_scope->__pyx_v_self->sp), (&__pyx_cur_scope->__pyx_v_self->le), (&__pyx_cur_scope->__pyx_v_self->tsz), (&__pyx_cur_scope->__pyx_v_self->pr)) == _FAILURE_);

      /* "class-sz/python/classy.pyx":1081
 *                   index_m_z += 1
 * 
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
      if (unlikely(__pyx_t_1)) {

        /* "class-sz/python/classy.pyx":1083
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1083, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1083, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "class-sz/python/classy.pyx":1084
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1084, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_cur_scope->__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1084, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1084, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1084, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1081
 *                   index_m_z += 1
 * 
 *             if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
      }

      /* "class-sz/python/classy.pyx":1086
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 *             &(self.tsz),&(self.csz)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
      __pyx_t_1 = (szcount_init((&__pyx_cur_scope->__pyx_v_self->ba), (&__pyx_cur_scope->__pyx_v_self->nl), (&__pyx_cur_scope->__pyx_v_self->pm), (&__pyx_cur_scope->__pyx_v_self->tsz), (&__pyx_cur_scope->__pyx_v_self->csz)) == _FAILURE_);

      /* "class-sz/python/classy.pyx":1085
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
      if (unlikely(__pyx_t_1)) {

        /* "class-sz/python/classy.pyx":1087
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 * 
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1087, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1087, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "class-sz/python/classy.pyx":1088
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 * 
 *             self.computed = True
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1088, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_cur_scope->__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1088, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_7 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1088, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1088, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1085
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 *             if szcount_init(&(self.ba), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.tsz),&(self.csz)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
      }

      /* "class-sz/python/classy.pyx":1090
 *                 raise CosmoComputationError(self.tsz.error_message)
 * 
 *             self.computed = True             # <<<<<<<<<<<<<<
 *             self.class_szfast = cszfast
 *             return
 */
      __pyx_cur_scope->__pyx_v_self->computed = 1;

      /* "class-sz/python/classy.pyx":1091
 * 
 *             self.computed = True
 *             self.class_szfast = cszfast             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __Pyx_INCREF(__pyx_v_cszfast);
      __Pyx_GIVEREF(__pyx_v_cszfast);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_self->class_szfast);
      __Pyx_DECREF(__pyx_cur_scope->__pyx_v_self->class_szfast);
      __pyx_cur_scope->__pyx_v_self->class_szfast = __pyx_v_cszfast;

      /* "class-sz/python/classy.pyx":1092
 *             self.computed = True
 *             self.class_szfast = cszfast
 *             return             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
    }
  }

  /* "class-sz/python/classy.pyx":727
 *     # @cython.wraparound(False)
 *     # the likelihood_mode parameter is used to identify whether we run within cobaya
 *     def compute_class_szfast(self,likelihood_mode=False):             # <<<<<<<<<<<<<<
 * 
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.compute_class_szfast", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_non_linear_check);
  __Pyx_XDECREF(__pyx_v_pknl_in_output);
  __Pyx_XDECREF(__pyx_v_pknl_key_value_checks);
  __Pyx_XDECREF(__pyx_v_skip_background_and_thermo);
  __Pyx_XDECREF(__pyx_v_params_settings);
  __Pyx_XDECREF(__pyx_v_cszfast);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_end);
  __Pyx_XDECREF(__pyx_v_index_z_r);
  __Pyx_XDECREF(__pyx_v_ln1pzc);
  __Pyx_XDECREF(__pyx_v_z);
  __Pyx_XDECREF(__pyx_v_index_m_z);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_gb_9classy_sz_5Class_20compute_class_szfast_2generator1);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1097
 * 
 * 
 *     def compute_class_sz(self,pdict_to_update):             # <<<<<<<<<<<<<<
 *         integrate_only = False
 *         try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_27compute_class_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_27compute_class_sz = {"compute_class_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_27compute_class_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_27compute_class_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_pdict_to_update = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("compute_class_sz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pdict_to_update,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pdict_to_update)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1097, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "compute_class_sz") < 0)) __PYX_ERR(0, 1097, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_pdict_to_update = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("compute_class_sz", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1097, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.compute_class_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_26compute_class_sz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_pdict_to_update);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_26compute_class_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_pdict_to_update) {
  int __pyx_v_integrate_only;
  PyObject *__pyx_v_N_ngal = NULL;
  PyObject *__pyx_v_k = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_index_g = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  double __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  PyObject *(*__pyx_t_15)(PyObject *);
  PyObject *__pyx_t_16 = NULL;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("compute_class_sz", 1);

  /* "class-sz/python/classy.pyx":1098
 * 
 *     def compute_class_sz(self,pdict_to_update):
 *         integrate_only = False             # <<<<<<<<<<<<<<
 *         try:
 *             N_ngal = self._pars['galaxy_samples_list_num']
 */
  __pyx_v_integrate_only = 0;

  /* "class-sz/python/classy.pyx":1099
 *     def compute_class_sz(self,pdict_to_update):
 *         integrate_only = False
 *         try:             # <<<<<<<<<<<<<<
 *             N_ngal = self._pars['galaxy_samples_list_num']
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "class-sz/python/classy.pyx":1100
 *         integrate_only = False
 *         try:
 *             N_ngal = self._pars['galaxy_samples_list_num']             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             N_ngal = -1
 */
      __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_galaxy_samples_list_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1100, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_N_ngal = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "class-sz/python/classy.pyx":1099
 *     def compute_class_sz(self,pdict_to_update):
 *         integrate_only = False
 *         try:             # <<<<<<<<<<<<<<
 *             N_ngal = self._pars['galaxy_samples_list_num']
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":1101
 *         try:
 *             N_ngal = self._pars['galaxy_samples_list_num']
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             N_ngal = -1
 *         self._fillparfile()
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_5) {
      __Pyx_AddTraceback("classy_sz.Class.compute_class_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1101, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "class-sz/python/classy.pyx":1102
 *             N_ngal = self._pars['galaxy_samples_list_num']
 *         except KeyError:
 *             N_ngal = -1             # <<<<<<<<<<<<<<
 *         self._fillparfile()
 *         for k,v in pdict_to_update.items():
 */
      __Pyx_INCREF(__pyx_int_neg_1);
      __Pyx_XDECREF_SET(__pyx_v_N_ngal, __pyx_int_neg_1);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "class-sz/python/classy.pyx":1099
 *     def compute_class_sz(self,pdict_to_update):
 *         integrate_only = False
 *         try:             # <<<<<<<<<<<<<<
 *             N_ngal = self._pars['galaxy_samples_list_num']
 *         except KeyError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "class-sz/python/classy.pyx":1103
 *         except KeyError:
 *             N_ngal = -1
 *         self._fillparfile()             # <<<<<<<<<<<<<<
 *         for k,v in pdict_to_update.items():
 *           if k == 'betaGNFW':
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_fillparfile); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":1104
 *             N_ngal = -1
 *         self._fillparfile()
 *         for k,v in pdict_to_update.items():             # <<<<<<<<<<<<<<
 *           if k == 'betaGNFW':
 *             self.tsz.betaGNFW = pdict_to_update[k]
 */
  __pyx_t_9 = 0;
  if (unlikely(__pyx_v_pdict_to_update == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(0, 1104, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_dict_iterator(__pyx_v_pdict_to_update, 0, __pyx_n_s_items, (&__pyx_t_10), (&__pyx_t_5)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __pyx_t_7 = __pyx_t_6;
  __pyx_t_6 = 0;
  while (1) {
    __pyx_t_11 = __Pyx_dict_iter_next(__pyx_t_7, __pyx_t_10, &__pyx_t_9, &__pyx_t_6, &__pyx_t_4, NULL, __pyx_t_5);
    if (unlikely(__pyx_t_11 == 0)) break;
    if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 1104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":1105
 *         self._fillparfile()
 *         for k,v in pdict_to_update.items():
 *           if k == 'betaGNFW':             # <<<<<<<<<<<<<<
 *             self.tsz.betaGNFW = pdict_to_update[k]
 *           if k == 'P0GNFW':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_betaGNFW, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1105, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1106
 *         for k,v in pdict_to_update.items():
 *           if k == 'betaGNFW':
 *             self.tsz.betaGNFW = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1106, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1106, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_self->tsz.betaGNFW = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1105
 *         self._fillparfile()
 *         for k,v in pdict_to_update.items():
 *           if k == 'betaGNFW':             # <<<<<<<<<<<<<<
 *             self.tsz.betaGNFW = pdict_to_update[k]
 *           if k == 'P0GNFW':
 */
    }

    /* "class-sz/python/classy.pyx":1107
 *           if k == 'betaGNFW':
 *             self.tsz.betaGNFW = pdict_to_update[k]
 *           if k == 'P0GNFW':             # <<<<<<<<<<<<<<
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'alpha_s_HOD':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_P0GNFW, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1107, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1108
 *             self.tsz.betaGNFW = pdict_to_update[k]
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'alpha_s_HOD':
 *             self.tsz.alpha_s_HOD = pdict_to_update[k]
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1108, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_self->tsz.P0GNFW = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1107
 *           if k == 'betaGNFW':
 *             self.tsz.betaGNFW = pdict_to_update[k]
 *           if k == 'P0GNFW':             # <<<<<<<<<<<<<<
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'alpha_s_HOD':
 */
    }

    /* "class-sz/python/classy.pyx":1109
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'alpha_s_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_s_HOD = pdict_to_update[k]
 *           if k == 'sigma_log10M_HOD':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_s_HOD, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1109, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1110
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'alpha_s_HOD':
 *             self.tsz.alpha_s_HOD = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'sigma_log10M_HOD':
 *             self.tsz.sigma_log10M_HOD = pdict_to_update[k]
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1110, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_self->tsz.alpha_s_HOD = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1109
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'alpha_s_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_s_HOD = pdict_to_update[k]
 *           if k == 'sigma_log10M_HOD':
 */
    }

    /* "class-sz/python/classy.pyx":1111
 *           if k == 'alpha_s_HOD':
 *             self.tsz.alpha_s_HOD = pdict_to_update[k]
 *           if k == 'sigma_log10M_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.sigma_log10M_HOD = pdict_to_update[k]
 *           if k == 'M_min_HOD':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_sigma_log10M_HOD, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1111, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1112
 *             self.tsz.alpha_s_HOD = pdict_to_update[k]
 *           if k == 'sigma_log10M_HOD':
 *             self.tsz.sigma_log10M_HOD = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'M_min_HOD':
 *             self.tsz.M_min_HOD = pdict_to_update[k]
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1112, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_self->tsz.sigma_log10M_HOD = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1111
 *           if k == 'alpha_s_HOD':
 *             self.tsz.alpha_s_HOD = pdict_to_update[k]
 *           if k == 'sigma_log10M_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.sigma_log10M_HOD = pdict_to_update[k]
 *           if k == 'M_min_HOD':
 */
    }

    /* "class-sz/python/classy.pyx":1113
 *           if k == 'sigma_log10M_HOD':
 *             self.tsz.sigma_log10M_HOD = pdict_to_update[k]
 *           if k == 'M_min_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.M_min_HOD = pdict_to_update[k]
 *           if k == 'M1_prime_HOD':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_M_min_HOD, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1113, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1114
 *             self.tsz.sigma_log10M_HOD = pdict_to_update[k]
 *           if k == 'M_min_HOD':
 *             self.tsz.M_min_HOD = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'M1_prime_HOD':
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1114, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_self->tsz.M_min_HOD = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1113
 *           if k == 'sigma_log10M_HOD':
 *             self.tsz.sigma_log10M_HOD = pdict_to_update[k]
 *           if k == 'M_min_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.M_min_HOD = pdict_to_update[k]
 *           if k == 'M1_prime_HOD':
 */
    }

    /* "class-sz/python/classy.pyx":1115
 *           if k == 'M_min_HOD':
 *             self.tsz.M_min_HOD = pdict_to_update[k]
 *           if k == 'M1_prime_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]
 *           if N_ngal != -1:
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_M1_prime_HOD, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1115, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1116
 *             self.tsz.M_min_HOD = pdict_to_update[k]
 *           if k == 'M1_prime_HOD':
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if N_ngal != -1:
 *             for index_g in range(N_ngal):
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1116, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_self->tsz.M1_prime_HOD = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1115
 *           if k == 'M_min_HOD':
 *             self.tsz.M_min_HOD = pdict_to_update[k]
 *           if k == 'M1_prime_HOD':             # <<<<<<<<<<<<<<
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]
 *           if N_ngal != -1:
 */
    }

    /* "class-sz/python/classy.pyx":1117
 *           if k == 'M1_prime_HOD':
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]
 *           if N_ngal != -1:             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):
 */
    __pyx_t_12 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_N_ngal, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1117, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1118
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]
 *           if N_ngal != -1:
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_N_ngal); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1118, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_6 = __pyx_t_4; __Pyx_INCREF(__pyx_t_6);
        __pyx_t_14 = 0;
        __pyx_t_15 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1118, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1118, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_15)) {
          if (likely(PyList_CheckExact(__pyx_t_6))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1118, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_14); __Pyx_INCREF(__pyx_t_4); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1118, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1118, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1118, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_14); __Pyx_INCREF(__pyx_t_4); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1118, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1118, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_15(__pyx_t_6);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1118, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_index_g, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "class-sz/python/classy.pyx":1119
 *           if N_ngal != -1:
 *             for index_g in range(N_ngal):
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_16 = __Pyx_PyUnicode_Concat(__pyx_n_u_alpha_s_HOD_ngal, __pyx_t_4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_t_16, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1119, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (__pyx_t_12) {

          /* "class-sz/python/classy.pyx":1120
 *             for index_g in range(N_ngal):
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):
 */
          __pyx_t_16 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1120, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_n_u_alpha_s_HOD_ngal, __pyx_t_16); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1120, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_t_4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1120, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_16); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1120, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_g); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1120, __pyx_L1_error)
          (__pyx_v_self->tsz.alpha_s_HOD_ngal[__pyx_t_17]) = __pyx_t_13;

          /* "class-sz/python/classy.pyx":1119
 *           if N_ngal != -1:
 *             for index_g in range(N_ngal):
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        }

        /* "class-sz/python/classy.pyx":1118
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]
 *           if N_ngal != -1:
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 */
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":1121
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 */
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_N_ngal); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1121, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
        __pyx_t_16 = __pyx_t_6; __Pyx_INCREF(__pyx_t_16);
        __pyx_t_14 = 0;
        __pyx_t_15 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_16 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1121, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      for (;;) {
        if (likely(!__pyx_t_15)) {
          if (likely(PyList_CheckExact(__pyx_t_16))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_16);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_14); __Pyx_INCREF(__pyx_t_6); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
            #else
            __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1121, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_16);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_14); __Pyx_INCREF(__pyx_t_6); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1121, __pyx_L1_error)
            #else
            __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1121, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          }
        } else {
          __pyx_t_6 = __pyx_t_15(__pyx_t_16);
          if (unlikely(!__pyx_t_6)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1121, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_index_g, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1122
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        __pyx_t_6 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_n_u_sigma_log10M_HOD_ngal, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_t_4, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1122, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_12) {

          /* "class-sz/python/classy.pyx":1123
 *             for index_g in range(N_ngal):
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):
 */
          __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_n_u_sigma_log10M_HOD_ngal, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1123, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_g); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1123, __pyx_L1_error)
          (__pyx_v_self->tsz.sigma_log10M_HOD_ngal[__pyx_t_17]) = __pyx_t_13;

          /* "class-sz/python/classy.pyx":1122
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        }

        /* "class-sz/python/classy.pyx":1121
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):
 *                     self.tsz.alpha_s_HOD_ngal[index_g] = pdict_to_update['alpha_s_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 */
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

      /* "class-sz/python/classy.pyx":1124
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 */
      __pyx_t_16 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_N_ngal); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      if (likely(PyList_CheckExact(__pyx_t_16)) || PyTuple_CheckExact(__pyx_t_16)) {
        __pyx_t_4 = __pyx_t_16; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_14 = 0;
        __pyx_t_15 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_16); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1124, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1124, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      for (;;) {
        if (likely(!__pyx_t_15)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_16 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_14); __Pyx_INCREF(__pyx_t_16); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
            #else
            __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1124, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_16 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_14); __Pyx_INCREF(__pyx_t_16); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1124, __pyx_L1_error)
            #else
            __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1124, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
          }
        } else {
          __pyx_t_16 = __pyx_t_15(__pyx_t_4);
          if (unlikely(!__pyx_t_16)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1124, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_16);
        }
        __Pyx_XDECREF_SET(__pyx_v_index_g, __pyx_t_16);
        __pyx_t_16 = 0;

        /* "class-sz/python/classy.pyx":1125
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        __pyx_t_16 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1125, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_n_u_M_min_HOD_ngal, __pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1125, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_t_6, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1125, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (__pyx_t_12) {

          /* "class-sz/python/classy.pyx":1126
 *             for index_g in range(N_ngal):
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):
 */
          __pyx_t_6 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1126, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_16 = __Pyx_PyUnicode_Concat(__pyx_n_u_M_min_HOD_ngal, __pyx_t_6); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1126, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1126, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1126, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_g); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1126, __pyx_L1_error)
          (__pyx_v_self->tsz.M_min_HOD_ngal[__pyx_t_17]) = __pyx_t_13;

          /* "class-sz/python/classy.pyx":1125
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        }

        /* "class-sz/python/classy.pyx":1124
 *                 if k == 'sigma_log10M_HOD_ngal_'+str(index_g):
 *                     self.tsz.sigma_log10M_HOD_ngal[index_g] = pdict_to_update['sigma_log10M_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 */
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "class-sz/python/classy.pyx":1127
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_N_ngal); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1127, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_6 = __pyx_t_4; __Pyx_INCREF(__pyx_t_6);
        __pyx_t_14 = 0;
        __pyx_t_15 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1127, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1127, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_15)) {
          if (likely(PyList_CheckExact(__pyx_t_6))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1127, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_14); __Pyx_INCREF(__pyx_t_4); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1127, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1127, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1127, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_14); __Pyx_INCREF(__pyx_t_4); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1127, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1127, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_15(__pyx_t_6);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1127, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_index_g, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "class-sz/python/classy.pyx":1128
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1128, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_16 = __Pyx_PyUnicode_Concat(__pyx_n_u_M1_prime_HOD_ngal, __pyx_t_4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1128, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_t_16, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1128, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (__pyx_t_12) {

          /* "class-sz/python/classy.pyx":1129
 *             for index_g in range(N_ngal):
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'M0_HOD_ngal_'+str(index_g):
 */
          __pyx_t_16 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1129, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_n_u_M1_prime_HOD_ngal, __pyx_t_16); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1129, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_t_4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1129, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_16); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1129, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_g); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1129, __pyx_L1_error)
          (__pyx_v_self->tsz.M1_prime_HOD_ngal[__pyx_t_17]) = __pyx_t_13;

          /* "class-sz/python/classy.pyx":1128
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        }

        /* "class-sz/python/classy.pyx":1127
 *                 if k == 'M_min_HOD_ngal_'+str(index_g):
 *                     self.tsz.M_min_HOD_ngal[index_g] = pdict_to_update['M_min_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 */
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":1130
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'M0_HOD_ngal_'+str(index_g):
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 */
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_N_ngal); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
        __pyx_t_16 = __pyx_t_6; __Pyx_INCREF(__pyx_t_16);
        __pyx_t_14 = 0;
        __pyx_t_15 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_16 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1130, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1130, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      for (;;) {
        if (likely(!__pyx_t_15)) {
          if (likely(PyList_CheckExact(__pyx_t_16))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_16);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1130, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_14); __Pyx_INCREF(__pyx_t_6); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1130, __pyx_L1_error)
            #else
            __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1130, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_16);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1130, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_14); __Pyx_INCREF(__pyx_t_6); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1130, __pyx_L1_error)
            #else
            __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1130, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          }
        } else {
          __pyx_t_6 = __pyx_t_15(__pyx_t_16);
          if (unlikely(!__pyx_t_6)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1130, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_index_g, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1131
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'M0_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        __pyx_t_6 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_n_u_M0_HOD_ngal, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_t_4, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1131, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_12) {

          /* "class-sz/python/classy.pyx":1132
 *             for index_g in range(N_ngal):
 *                 if k == 'M0_HOD_ngal_'+str(index_g):
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):
 */
          __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1132, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_n_u_M0_HOD_ngal, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1132, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1132, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1132, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_g); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1132, __pyx_L1_error)
          (__pyx_v_self->tsz.M0_HOD_ngal[__pyx_t_17]) = __pyx_t_13;

          /* "class-sz/python/classy.pyx":1131
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'M0_HOD_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        }

        /* "class-sz/python/classy.pyx":1130
 *                 if k == 'M1_prime_HOD_ngal_'+str(index_g):
 *                     self.tsz.M1_prime_HOD_ngal[index_g] = pdict_to_update['M1_prime_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'M0_HOD_ngal_'+str(index_g):
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 */
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

      /* "class-sz/python/classy.pyx":1133
 *                 if k == 'M0_HOD_ngal_'+str(index_g):
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 */
      __pyx_t_16 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_N_ngal); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      if (likely(PyList_CheckExact(__pyx_t_16)) || PyTuple_CheckExact(__pyx_t_16)) {
        __pyx_t_4 = __pyx_t_16; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_14 = 0;
        __pyx_t_15 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_16); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1133, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1133, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      for (;;) {
        if (likely(!__pyx_t_15)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1133, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_16 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_14); __Pyx_INCREF(__pyx_t_16); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1133, __pyx_L1_error)
            #else
            __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1133, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1133, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_16 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_14); __Pyx_INCREF(__pyx_t_16); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1133, __pyx_L1_error)
            #else
            __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1133, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
          }
        } else {
          __pyx_t_16 = __pyx_t_15(__pyx_t_4);
          if (unlikely(!__pyx_t_16)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1133, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_16);
        }
        __Pyx_XDECREF_SET(__pyx_v_index_g, __pyx_t_16);
        __pyx_t_16 = 0;

        /* "class-sz/python/classy.pyx":1134
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        __pyx_t_16 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1134, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_n_u_dndz_stretch_ngal, __pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1134, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_t_6, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1134, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (__pyx_t_12) {

          /* "class-sz/python/classy.pyx":1135
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_shift_ngal_'+str(index_g):
 */
          __pyx_t_6 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1135, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_16 = __Pyx_PyUnicode_Concat(__pyx_n_u_dndz_stretch_ngal, __pyx_t_6); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1135, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_t_16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1135, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1135, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_g); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1135, __pyx_L1_error)
          (__pyx_v_self->tsz.dndz_stretch_ngal[__pyx_t_17]) = __pyx_t_13;

          /* "class-sz/python/classy.pyx":1134
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 */
        }

        /* "class-sz/python/classy.pyx":1133
 *                 if k == 'M0_HOD_ngal_'+str(index_g):
 *                     self.tsz.M0_HOD_ngal[index_g] = pdict_to_update['M0_HOD_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 */
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "class-sz/python/classy.pyx":1136
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'dndz_shift_ngal_'+str(index_g):
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_N_ngal); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_6 = __pyx_t_4; __Pyx_INCREF(__pyx_t_6);
        __pyx_t_14 = 0;
        __pyx_t_15 = NULL;
      } else {
        __pyx_t_14 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1136, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1136, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_15)) {
          if (likely(PyList_CheckExact(__pyx_t_6))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1136, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_14); __Pyx_INCREF(__pyx_t_4); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1136, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1136, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1136, __pyx_L1_error)
              #endif
              if (__pyx_t_14 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_14); __Pyx_INCREF(__pyx_t_4); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 1136, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1136, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_15(__pyx_t_6);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1136, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_index_g, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "class-sz/python/classy.pyx":1137
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_shift_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]
 *           if k == 'dndz_shift_source_gal':
 */
        __pyx_t_4 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1137, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_16 = __Pyx_PyUnicode_Concat(__pyx_n_u_dndz_shift_ngal, __pyx_t_4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1137, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_t_16, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1137, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (__pyx_t_12) {

          /* "class-sz/python/classy.pyx":1138
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_shift_ngal_'+str(index_g):
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]             # <<<<<<<<<<<<<<
 *           if k == 'dndz_shift_source_gal':
 *               self.tsz.dndz_shift_source_gal = pdict_to_update[k]
 */
          __pyx_t_16 = __Pyx_PyObject_Unicode(__pyx_v_index_g); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1138, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_n_u_dndz_shift_ngal, __pyx_t_16); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1138, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_t_4); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1138, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_16); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1138, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index_g); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1138, __pyx_L1_error)
          (__pyx_v_self->tsz.dndz_shift_ngal[__pyx_t_17]) = __pyx_t_13;

          /* "class-sz/python/classy.pyx":1137
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):
 *                 if k == 'dndz_shift_ngal_'+str(index_g):             # <<<<<<<<<<<<<<
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]
 *           if k == 'dndz_shift_source_gal':
 */
        }

        /* "class-sz/python/classy.pyx":1136
 *                 if k == 'dndz_stretch_ngal_'+str(index_g):
 *                     self.tsz.dndz_stretch_ngal[index_g] = pdict_to_update['dndz_stretch_ngal_'+str(index_g)]
 *             for index_g in range(N_ngal):             # <<<<<<<<<<<<<<
 *                 if k == 'dndz_shift_ngal_'+str(index_g):
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]
 */
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":1117
 *           if k == 'M1_prime_HOD':
 *             self.tsz.M1_prime_HOD = pdict_to_update[k]
 *           if N_ngal != -1:             # <<<<<<<<<<<<<<
 *             for index_g in range(N_ngal):
 *                 if k == 'alpha_s_HOD_ngal_'+str(index_g):
 */
    }

    /* "class-sz/python/classy.pyx":1139
 *                 if k == 'dndz_shift_ngal_'+str(index_g):
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]
 *           if k == 'dndz_shift_source_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_shift_source_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_source_gal':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_dndz_shift_source_gal, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1139, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1140
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]
 *           if k == 'dndz_shift_source_gal':
 *               self.tsz.dndz_shift_source_gal = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'dndz_stretch_source_gal':
 *               self.tsz.dndz_stretch_source_gal = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1140, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.dndz_shift_source_gal = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1139
 *                 if k == 'dndz_shift_ngal_'+str(index_g):
 *                     self.tsz.dndz_shift_ngal[index_g] = pdict_to_update['dndz_shift_ngal_'+str(index_g)]
 *           if k == 'dndz_shift_source_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_shift_source_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_source_gal':
 */
    }

    /* "class-sz/python/classy.pyx":1141
 *           if k == 'dndz_shift_source_gal':
 *               self.tsz.dndz_shift_source_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_source_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_stretch_source_gal = pdict_to_update[k]
 *           if k == 'dndz_shift_gal':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_dndz_stretch_source_gal, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1141, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1142
 *               self.tsz.dndz_shift_source_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_source_gal':
 *               self.tsz.dndz_stretch_source_gal = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'dndz_shift_gal':
 *               self.tsz.dndz_shift_gal = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1142, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1142, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.dndz_stretch_source_gal = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1141
 *           if k == 'dndz_shift_source_gal':
 *               self.tsz.dndz_shift_source_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_source_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_stretch_source_gal = pdict_to_update[k]
 *           if k == 'dndz_shift_gal':
 */
    }

    /* "class-sz/python/classy.pyx":1143
 *           if k == 'dndz_stretch_source_gal':
 *               self.tsz.dndz_stretch_source_gal = pdict_to_update[k]
 *           if k == 'dndz_shift_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_shift_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_gal':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_dndz_shift_gal, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1143, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1144
 *               self.tsz.dndz_stretch_source_gal = pdict_to_update[k]
 *           if k == 'dndz_shift_gal':
 *               self.tsz.dndz_shift_gal = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'dndz_stretch_gal':
 *               self.tsz.dndz_stretch_gal = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1144, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1144, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.dndz_shift_gal = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1143
 *           if k == 'dndz_stretch_source_gal':
 *               self.tsz.dndz_stretch_source_gal = pdict_to_update[k]
 *           if k == 'dndz_shift_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_shift_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_gal':
 */
    }

    /* "class-sz/python/classy.pyx":1145
 *           if k == 'dndz_shift_gal':
 *               self.tsz.dndz_shift_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_stretch_gal = pdict_to_update[k]
 *           if k == 'shear_calibration_m':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_dndz_stretch_gal, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1145, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1146
 *               self.tsz.dndz_shift_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_gal':
 *               self.tsz.dndz_stretch_gal = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'shear_calibration_m':
 *               self.tsz.shear_calibration_m = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1146, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.dndz_stretch_gal = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1145
 *           if k == 'dndz_shift_gal':
 *               self.tsz.dndz_shift_gal = pdict_to_update[k]
 *           if k == 'dndz_stretch_gal':             # <<<<<<<<<<<<<<
 *               self.tsz.dndz_stretch_gal = pdict_to_update[k]
 *           if k == 'shear_calibration_m':
 */
    }

    /* "class-sz/python/classy.pyx":1147
 *           if k == 'dndz_stretch_gal':
 *               self.tsz.dndz_stretch_gal = pdict_to_update[k]
 *           if k == 'shear_calibration_m':             # <<<<<<<<<<<<<<
 *               self.tsz.shear_calibration_m = pdict_to_update[k]
 *           if k == 'A_IA':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_shear_calibration_m, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1147, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1148
 *               self.tsz.dndz_stretch_gal = pdict_to_update[k]
 *           if k == 'shear_calibration_m':
 *               self.tsz.shear_calibration_m = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'A_IA':
 *               self.tsz.A_IA = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1148, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1148, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.shear_calibration_m = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1147
 *           if k == 'dndz_stretch_gal':
 *               self.tsz.dndz_stretch_gal = pdict_to_update[k]
 *           if k == 'shear_calibration_m':             # <<<<<<<<<<<<<<
 *               self.tsz.shear_calibration_m = pdict_to_update[k]
 *           if k == 'A_IA':
 */
    }

    /* "class-sz/python/classy.pyx":1149
 *           if k == 'shear_calibration_m':
 *               self.tsz.shear_calibration_m = pdict_to_update[k]
 *           if k == 'A_IA':             # <<<<<<<<<<<<<<
 *               self.tsz.A_IA = pdict_to_update[k]
 *           if k == 'fNL':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_A_IA, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1149, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1150
 *               self.tsz.shear_calibration_m = pdict_to_update[k]
 *           if k == 'A_IA':
 *               self.tsz.A_IA = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1150, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1150, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.A_IA = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1149
 *           if k == 'shear_calibration_m':
 *               self.tsz.shear_calibration_m = pdict_to_update[k]
 *           if k == 'A_IA':             # <<<<<<<<<<<<<<
 *               self.tsz.A_IA = pdict_to_update[k]
 *           if k == 'fNL':
 */
    }

    /* "class-sz/python/classy.pyx":1151
 *           if k == 'A_IA':
 *               self.tsz.A_IA = pdict_to_update[k]
 *           if k == 'fNL':             # <<<<<<<<<<<<<<
 *             self.tsz.fNL = pdict_to_update[k]
 *           if k == 'P0GNFW':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_fNL, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1151, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1152
 *               self.tsz.A_IA = pdict_to_update[k]
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1152, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.fNL = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1151
 *           if k == 'A_IA':
 *               self.tsz.A_IA = pdict_to_update[k]
 *           if k == 'fNL':             # <<<<<<<<<<<<<<
 *             self.tsz.fNL = pdict_to_update[k]
 *           if k == 'P0GNFW':
 */
    }

    /* "class-sz/python/classy.pyx":1153
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update[k]
 *           if k == 'P0GNFW':             # <<<<<<<<<<<<<<
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'c500':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_P0GNFW, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1153, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1154
 *             self.tsz.fNL = pdict_to_update[k]
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'c500':
 *             self.tsz.c500 = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1154, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.P0GNFW = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1153
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update[k]
 *           if k == 'P0GNFW':             # <<<<<<<<<<<<<<
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'c500':
 */
    }

    /* "class-sz/python/classy.pyx":1155
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'c500':             # <<<<<<<<<<<<<<
 *             self.tsz.c500 = pdict_to_update[k]
 *           if k == 'M_min':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_c500, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1155, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1156
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'c500':
 *             self.tsz.c500 = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'M_min':
 *             self.tsz.M1SZ = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1156, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1156, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.c500 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1155
 *           if k == 'P0GNFW':
 *             self.tsz.P0GNFW = pdict_to_update[k]
 *           if k == 'c500':             # <<<<<<<<<<<<<<
 *             self.tsz.c500 = pdict_to_update[k]
 *           if k == 'M_min':
 */
    }

    /* "class-sz/python/classy.pyx":1157
 *           if k == 'c500':
 *             self.tsz.c500 = pdict_to_update[k]
 *           if k == 'M_min':             # <<<<<<<<<<<<<<
 *             self.tsz.M1SZ = pdict_to_update[k]
 *           if k == 'M_max':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_M_min, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1157, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1158
 *             self.tsz.c500 = pdict_to_update[k]
 *           if k == 'M_min':
 *             self.tsz.M1SZ = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'M_max':
 *             self.tsz.M2SZ = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1158, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1158, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.M1SZ = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1157
 *           if k == 'c500':
 *             self.tsz.c500 = pdict_to_update[k]
 *           if k == 'M_min':             # <<<<<<<<<<<<<<
 *             self.tsz.M1SZ = pdict_to_update[k]
 *           if k == 'M_max':
 */
    }

    /* "class-sz/python/classy.pyx":1159
 *           if k == 'M_min':
 *             self.tsz.M1SZ = pdict_to_update[k]
 *           if k == 'M_max':             # <<<<<<<<<<<<<<
 *             self.tsz.M2SZ = pdict_to_update[k]
 *           if k == 'z_min':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_M_max, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1159, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1160
 *             self.tsz.M1SZ = pdict_to_update[k]
 *           if k == 'M_max':
 *             self.tsz.M2SZ = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'z_min':
 *             self.tsz.z1SZ = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1160, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1160, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.M2SZ = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1159
 *           if k == 'M_min':
 *             self.tsz.M1SZ = pdict_to_update[k]
 *           if k == 'M_max':             # <<<<<<<<<<<<<<
 *             self.tsz.M2SZ = pdict_to_update[k]
 *           if k == 'z_min':
 */
    }

    /* "class-sz/python/classy.pyx":1161
 *           if k == 'M_max':
 *             self.tsz.M2SZ = pdict_to_update[k]
 *           if k == 'z_min':             # <<<<<<<<<<<<<<
 *             self.tsz.z1SZ = pdict_to_update[k]
 *           if k == 'z_max':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_z_min, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1161, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1162
 *             self.tsz.M2SZ = pdict_to_update[k]
 *           if k == 'z_min':
 *             self.tsz.z1SZ = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'z_max':
 *             self.tsz.z2SZ = pdict_to_update[k]
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1162, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1162, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.z1SZ = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1161
 *           if k == 'M_max':
 *             self.tsz.M2SZ = pdict_to_update[k]
 *           if k == 'z_min':             # <<<<<<<<<<<<<<
 *             self.tsz.z1SZ = pdict_to_update[k]
 *           if k == 'z_max':
 */
    }

    /* "class-sz/python/classy.pyx":1163
 *           if k == 'z_min':
 *             self.tsz.z1SZ = pdict_to_update[k]
 *           if k == 'z_max':             # <<<<<<<<<<<<<<
 *             self.tsz.z2SZ = pdict_to_update[k]
 *           if k == 'fNL':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_z_max, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1163, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1164
 *             self.tsz.z1SZ = pdict_to_update[k]
 *           if k == 'z_max':
 *             self.tsz.z2SZ = pdict_to_update[k]             # <<<<<<<<<<<<<<
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update['fNL']
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_pdict_to_update, __pyx_v_k); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.z2SZ = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1163
 *           if k == 'z_min':
 *             self.tsz.z1SZ = pdict_to_update[k]
 *           if k == 'z_max':             # <<<<<<<<<<<<<<
 *             self.tsz.z2SZ = pdict_to_update[k]
 *           if k == 'fNL':
 */
    }

    /* "class-sz/python/classy.pyx":1165
 *           if k == 'z_max':
 *             self.tsz.z2SZ = pdict_to_update[k]
 *           if k == 'fNL':             # <<<<<<<<<<<<<<
 *             self.tsz.fNL = pdict_to_update['fNL']
 *           if k == 'A_rho0':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_fNL, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1165, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1166
 *             self.tsz.z2SZ = pdict_to_update[k]
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update['fNL']             # <<<<<<<<<<<<<<
 *           if k == 'A_rho0':
 *             self.tsz.A_rho0 = pdict_to_update['A_rho0']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_fNL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1166, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1166, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.fNL = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1165
 *           if k == 'z_max':
 *             self.tsz.z2SZ = pdict_to_update[k]
 *           if k == 'fNL':             # <<<<<<<<<<<<<<
 *             self.tsz.fNL = pdict_to_update['fNL']
 *           if k == 'A_rho0':
 */
    }

    /* "class-sz/python/classy.pyx":1167
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update['fNL']
 *           if k == 'A_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.A_rho0 = pdict_to_update['A_rho0']
 *           if k == 'A_alpha':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_A_rho0, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1167, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1168
 *             self.tsz.fNL = pdict_to_update['fNL']
 *           if k == 'A_rho0':
 *             self.tsz.A_rho0 = pdict_to_update['A_rho0']             # <<<<<<<<<<<<<<
 *           if k == 'A_alpha':
 *             self.tsz.A_alpha = pdict_to_update['A_alpha']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_A_rho0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1168, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.A_rho0 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1167
 *           if k == 'fNL':
 *             self.tsz.fNL = pdict_to_update['fNL']
 *           if k == 'A_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.A_rho0 = pdict_to_update['A_rho0']
 *           if k == 'A_alpha':
 */
    }

    /* "class-sz/python/classy.pyx":1169
 *           if k == 'A_rho0':
 *             self.tsz.A_rho0 = pdict_to_update['A_rho0']
 *           if k == 'A_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.A_alpha = pdict_to_update['A_alpha']
 *           if k == 'A_beta':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_A_alpha, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1169, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1170
 *             self.tsz.A_rho0 = pdict_to_update['A_rho0']
 *           if k == 'A_alpha':
 *             self.tsz.A_alpha = pdict_to_update['A_alpha']             # <<<<<<<<<<<<<<
 *           if k == 'A_beta':
 *               self.tsz.A_beta = pdict_to_update['A_beta']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_A_alpha); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1170, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.A_alpha = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1169
 *           if k == 'A_rho0':
 *             self.tsz.A_rho0 = pdict_to_update['A_rho0']
 *           if k == 'A_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.A_alpha = pdict_to_update['A_alpha']
 *           if k == 'A_beta':
 */
    }

    /* "class-sz/python/classy.pyx":1171
 *           if k == 'A_alpha':
 *             self.tsz.A_alpha = pdict_to_update['A_alpha']
 *           if k == 'A_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.A_beta = pdict_to_update['A_beta']
 *           if k == 'alpha_m_rho0':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_A_beta, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1171, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1172
 *             self.tsz.A_alpha = pdict_to_update['A_alpha']
 *           if k == 'A_beta':
 *               self.tsz.A_beta = pdict_to_update['A_beta']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_m_rho0':
 *             self.tsz.alpha_m_rho0 = pdict_to_update['alpha_m_rho0']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_A_beta); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1172, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.A_beta = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1171
 *           if k == 'A_alpha':
 *             self.tsz.A_alpha = pdict_to_update['A_alpha']
 *           if k == 'A_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.A_beta = pdict_to_update['A_beta']
 *           if k == 'alpha_m_rho0':
 */
    }

    /* "class-sz/python/classy.pyx":1173
 *           if k == 'A_beta':
 *               self.tsz.A_beta = pdict_to_update['A_beta']
 *           if k == 'alpha_m_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_m_rho0 = pdict_to_update['alpha_m_rho0']
 *           if k == 'alpha_m_alpha':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_m_rho0, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1173, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1174
 *               self.tsz.A_beta = pdict_to_update['A_beta']
 *           if k == 'alpha_m_rho0':
 *             self.tsz.alpha_m_rho0 = pdict_to_update['alpha_m_rho0']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_m_alpha':
 *             self.tsz.alpha_m_alpha = pdict_to_update['alpha_m_alpha']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_m_rho0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1174, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_m_rho0 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1173
 *           if k == 'A_beta':
 *               self.tsz.A_beta = pdict_to_update['A_beta']
 *           if k == 'alpha_m_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_m_rho0 = pdict_to_update['alpha_m_rho0']
 *           if k == 'alpha_m_alpha':
 */
    }

    /* "class-sz/python/classy.pyx":1175
 *           if k == 'alpha_m_rho0':
 *             self.tsz.alpha_m_rho0 = pdict_to_update['alpha_m_rho0']
 *           if k == 'alpha_m_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_m_alpha = pdict_to_update['alpha_m_alpha']
 *           if k == 'alpha_m_beta':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_m_alpha, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1175, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1176
 *             self.tsz.alpha_m_rho0 = pdict_to_update['alpha_m_rho0']
 *           if k == 'alpha_m_alpha':
 *             self.tsz.alpha_m_alpha = pdict_to_update['alpha_m_alpha']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_m_beta':
 *               self.tsz.alpha_m_beta = pdict_to_update['alpha_m_beta']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_m_alpha); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1176, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_m_alpha = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1175
 *           if k == 'alpha_m_rho0':
 *             self.tsz.alpha_m_rho0 = pdict_to_update['alpha_m_rho0']
 *           if k == 'alpha_m_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_m_alpha = pdict_to_update['alpha_m_alpha']
 *           if k == 'alpha_m_beta':
 */
    }

    /* "class-sz/python/classy.pyx":1177
 *           if k == 'alpha_m_alpha':
 *             self.tsz.alpha_m_alpha = pdict_to_update['alpha_m_alpha']
 *           if k == 'alpha_m_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_beta = pdict_to_update['alpha_m_beta']
 *           if k == 'alpha_z_rho0':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_m_beta, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1177, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1178
 *             self.tsz.alpha_m_alpha = pdict_to_update['alpha_m_alpha']
 *           if k == 'alpha_m_beta':
 *               self.tsz.alpha_m_beta = pdict_to_update['alpha_m_beta']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_z_rho0':
 *             self.tsz.alpha_z_rho0 = pdict_to_update['alpha_z_rho0']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_m_beta); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1178, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_m_beta = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1177
 *           if k == 'alpha_m_alpha':
 *             self.tsz.alpha_m_alpha = pdict_to_update['alpha_m_alpha']
 *           if k == 'alpha_m_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_beta = pdict_to_update['alpha_m_beta']
 *           if k == 'alpha_z_rho0':
 */
    }

    /* "class-sz/python/classy.pyx":1179
 *           if k == 'alpha_m_beta':
 *               self.tsz.alpha_m_beta = pdict_to_update['alpha_m_beta']
 *           if k == 'alpha_z_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_z_rho0 = pdict_to_update['alpha_z_rho0']
 *           if k == 'alpha_z_alpha':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_z_rho0, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1179, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1180
 *               self.tsz.alpha_m_beta = pdict_to_update['alpha_m_beta']
 *           if k == 'alpha_z_rho0':
 *             self.tsz.alpha_z_rho0 = pdict_to_update['alpha_z_rho0']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_z_alpha':
 *             self.tsz.alpha_z_alpha = pdict_to_update['alpha_z_alpha']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_z_rho0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1180, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_z_rho0 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1179
 *           if k == 'alpha_m_beta':
 *               self.tsz.alpha_m_beta = pdict_to_update['alpha_m_beta']
 *           if k == 'alpha_z_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_z_rho0 = pdict_to_update['alpha_z_rho0']
 *           if k == 'alpha_z_alpha':
 */
    }

    /* "class-sz/python/classy.pyx":1181
 *           if k == 'alpha_z_rho0':
 *             self.tsz.alpha_z_rho0 = pdict_to_update['alpha_z_rho0']
 *           if k == 'alpha_z_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_z_alpha = pdict_to_update['alpha_z_alpha']
 *           if k == 'alpha_z_beta':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_z_alpha, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1181, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1182
 *             self.tsz.alpha_z_rho0 = pdict_to_update['alpha_z_rho0']
 *           if k == 'alpha_z_alpha':
 *             self.tsz.alpha_z_alpha = pdict_to_update['alpha_z_alpha']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_z_beta':
 *               self.tsz.alpha_z_beta = pdict_to_update['alpha_z_beta']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_z_alpha); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1182, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_z_alpha = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1181
 *           if k == 'alpha_z_rho0':
 *             self.tsz.alpha_z_rho0 = pdict_to_update['alpha_z_rho0']
 *           if k == 'alpha_z_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_z_alpha = pdict_to_update['alpha_z_alpha']
 *           if k == 'alpha_z_beta':
 */
    }

    /* "class-sz/python/classy.pyx":1183
 *           if k == 'alpha_z_alpha':
 *             self.tsz.alpha_z_alpha = pdict_to_update['alpha_z_alpha']
 *           if k == 'alpha_z_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_beta = pdict_to_update['alpha_z_beta']
 *           if k == 'c_B16':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_z_beta, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1183, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1184
 *             self.tsz.alpha_z_alpha = pdict_to_update['alpha_z_alpha']
 *           if k == 'alpha_z_beta':
 *               self.tsz.alpha_z_beta = pdict_to_update['alpha_z_beta']             # <<<<<<<<<<<<<<
 *           if k == 'c_B16':
 *               self.tsz.c_B16 = pdict_to_update['cp_B16']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_z_beta); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1184, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_z_beta = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1183
 *           if k == 'alpha_z_alpha':
 *             self.tsz.alpha_z_alpha = pdict_to_update['alpha_z_alpha']
 *           if k == 'alpha_z_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_beta = pdict_to_update['alpha_z_beta']
 *           if k == 'c_B16':
 */
    }

    /* "class-sz/python/classy.pyx":1185
 *           if k == 'alpha_z_beta':
 *               self.tsz.alpha_z_beta = pdict_to_update['alpha_z_beta']
 *           if k == 'c_B16':             # <<<<<<<<<<<<<<
 *               self.tsz.c_B16 = pdict_to_update['cp_B16']
 *           if k == 'mcut':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_c_B16, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1185, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1186
 *               self.tsz.alpha_z_beta = pdict_to_update['alpha_z_beta']
 *           if k == 'c_B16':
 *               self.tsz.c_B16 = pdict_to_update['cp_B16']             # <<<<<<<<<<<<<<
 *           if k == 'mcut':
 *               self.tsz.mcut = pdict_to_update['mcut']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_cp_B16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1186, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.c_B16 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1185
 *           if k == 'alpha_z_beta':
 *               self.tsz.alpha_z_beta = pdict_to_update['alpha_z_beta']
 *           if k == 'c_B16':             # <<<<<<<<<<<<<<
 *               self.tsz.c_B16 = pdict_to_update['cp_B16']
 *           if k == 'mcut':
 */
    }

    /* "class-sz/python/classy.pyx":1187
 *           if k == 'c_B16':
 *               self.tsz.c_B16 = pdict_to_update['cp_B16']
 *           if k == 'mcut':             # <<<<<<<<<<<<<<
 *               self.tsz.mcut = pdict_to_update['mcut']
 *           if k == 'alphap_m_rho0':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_mcut, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1187, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1188
 *               self.tsz.c_B16 = pdict_to_update['cp_B16']
 *           if k == 'mcut':
 *               self.tsz.mcut = pdict_to_update['mcut']             # <<<<<<<<<<<<<<
 *           if k == 'alphap_m_rho0':
 *               self.tsz.alphap_m_rho0 = pdict_to_update['alphap_m_rho0']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_mcut); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1188, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.mcut = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1187
 *           if k == 'c_B16':
 *               self.tsz.c_B16 = pdict_to_update['cp_B16']
 *           if k == 'mcut':             # <<<<<<<<<<<<<<
 *               self.tsz.mcut = pdict_to_update['mcut']
 *           if k == 'alphap_m_rho0':
 */
    }

    /* "class-sz/python/classy.pyx":1189
 *           if k == 'mcut':
 *               self.tsz.mcut = pdict_to_update['mcut']
 *           if k == 'alphap_m_rho0':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_rho0 = pdict_to_update['alphap_m_rho0']
 *           if k == 'alphap_m_alpha':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alphap_m_rho0, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1189, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1190
 *               self.tsz.mcut = pdict_to_update['mcut']
 *           if k == 'alphap_m_rho0':
 *               self.tsz.alphap_m_rho0 = pdict_to_update['alphap_m_rho0']             # <<<<<<<<<<<<<<
 *           if k == 'alphap_m_alpha':
 *              self.tsz.alphap_m_alpha = pdict_to_update['alphap_m_alpha']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alphap_m_rho0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1190, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alphap_m_rho0 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1189
 *           if k == 'mcut':
 *               self.tsz.mcut = pdict_to_update['mcut']
 *           if k == 'alphap_m_rho0':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_rho0 = pdict_to_update['alphap_m_rho0']
 *           if k == 'alphap_m_alpha':
 */
    }

    /* "class-sz/python/classy.pyx":1191
 *           if k == 'alphap_m_rho0':
 *               self.tsz.alphap_m_rho0 = pdict_to_update['alphap_m_rho0']
 *           if k == 'alphap_m_alpha':             # <<<<<<<<<<<<<<
 *              self.tsz.alphap_m_alpha = pdict_to_update['alphap_m_alpha']
 *           if k == 'alphap_m_beta':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alphap_m_alpha, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1191, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1192
 *               self.tsz.alphap_m_rho0 = pdict_to_update['alphap_m_rho0']
 *           if k == 'alphap_m_alpha':
 *              self.tsz.alphap_m_alpha = pdict_to_update['alphap_m_alpha']             # <<<<<<<<<<<<<<
 *           if k == 'alphap_m_beta':
 *               self.tsz.alphap_m_beta = pdict_to_update['alphap_m_beta']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alphap_m_alpha); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1192, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alphap_m_alpha = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1191
 *           if k == 'alphap_m_rho0':
 *               self.tsz.alphap_m_rho0 = pdict_to_update['alphap_m_rho0']
 *           if k == 'alphap_m_alpha':             # <<<<<<<<<<<<<<
 *              self.tsz.alphap_m_alpha = pdict_to_update['alphap_m_alpha']
 *           if k == 'alphap_m_beta':
 */
    }

    /* "class-sz/python/classy.pyx":1193
 *           if k == 'alphap_m_alpha':
 *              self.tsz.alphap_m_alpha = pdict_to_update['alphap_m_alpha']
 *           if k == 'alphap_m_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_beta = pdict_to_update['alphap_m_beta']
 *           if k == 'alpha_c_rho0':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alphap_m_beta, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1193, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1194
 *              self.tsz.alphap_m_alpha = pdict_to_update['alphap_m_alpha']
 *           if k == 'alphap_m_beta':
 *               self.tsz.alphap_m_beta = pdict_to_update['alphap_m_beta']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_c_rho0':
 *             self.tsz.alpha_c_rho0 = pdict_to_update['alpha_c_rho0']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alphap_m_beta); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1194, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1194, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alphap_m_beta = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1193
 *           if k == 'alphap_m_alpha':
 *              self.tsz.alphap_m_alpha = pdict_to_update['alphap_m_alpha']
 *           if k == 'alphap_m_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_beta = pdict_to_update['alphap_m_beta']
 *           if k == 'alpha_c_rho0':
 */
    }

    /* "class-sz/python/classy.pyx":1195
 *           if k == 'alphap_m_beta':
 *               self.tsz.alphap_m_beta = pdict_to_update['alphap_m_beta']
 *           if k == 'alpha_c_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_c_rho0 = pdict_to_update['alpha_c_rho0']
 *           if k == 'alpha_c_alpha':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_c_rho0, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1195, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1196
 *               self.tsz.alphap_m_beta = pdict_to_update['alphap_m_beta']
 *           if k == 'alpha_c_rho0':
 *             self.tsz.alpha_c_rho0 = pdict_to_update['alpha_c_rho0']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_c_alpha':
 *             self.tsz.alpha_c_alpha = pdict_to_update['alpha_c_alpha']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_c_rho0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1196, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_c_rho0 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1195
 *           if k == 'alphap_m_beta':
 *               self.tsz.alphap_m_beta = pdict_to_update['alphap_m_beta']
 *           if k == 'alpha_c_rho0':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_c_rho0 = pdict_to_update['alpha_c_rho0']
 *           if k == 'alpha_c_alpha':
 */
    }

    /* "class-sz/python/classy.pyx":1197
 *           if k == 'alpha_c_rho0':
 *             self.tsz.alpha_c_rho0 = pdict_to_update['alpha_c_rho0']
 *           if k == 'alpha_c_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_c_alpha = pdict_to_update['alpha_c_alpha']
 *           if k == 'alpha_c_beta':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_c_alpha, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1197, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1198
 *             self.tsz.alpha_c_rho0 = pdict_to_update['alpha_c_rho0']
 *           if k == 'alpha_c_alpha':
 *             self.tsz.alpha_c_alpha = pdict_to_update['alpha_c_alpha']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_c_beta':
 *               self.tsz.alpha_c_beta = pdict_to_update['alpha_c_beta']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_c_alpha); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1198, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_c_alpha = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1197
 *           if k == 'alpha_c_rho0':
 *             self.tsz.alpha_c_rho0 = pdict_to_update['alpha_c_rho0']
 *           if k == 'alpha_c_alpha':             # <<<<<<<<<<<<<<
 *             self.tsz.alpha_c_alpha = pdict_to_update['alpha_c_alpha']
 *           if k == 'alpha_c_beta':
 */
    }

    /* "class-sz/python/classy.pyx":1199
 *           if k == 'alpha_c_alpha':
 *             self.tsz.alpha_c_alpha = pdict_to_update['alpha_c_alpha']
 *           if k == 'alpha_c_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_beta = pdict_to_update['alpha_c_beta']
 *           if k == 'gamma_B16':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_c_beta, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1199, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1200
 *             self.tsz.alpha_c_alpha = pdict_to_update['alpha_c_alpha']
 *           if k == 'alpha_c_beta':
 *               self.tsz.alpha_c_beta = pdict_to_update['alpha_c_beta']             # <<<<<<<<<<<<<<
 *           if k == 'gamma_B16':
 *               self.tsz.gamma_B16 = pdict_to_update['gamma_B16']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_c_beta); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1200, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_c_beta = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1199
 *           if k == 'alpha_c_alpha':
 *             self.tsz.alpha_c_alpha = pdict_to_update['alpha_c_alpha']
 *           if k == 'alpha_c_beta':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_beta = pdict_to_update['alpha_c_beta']
 *           if k == 'gamma_B16':
 */
    }

    /* "class-sz/python/classy.pyx":1201
 *           if k == 'alpha_c_beta':
 *               self.tsz.alpha_c_beta = pdict_to_update['alpha_c_beta']
 *           if k == 'gamma_B16':             # <<<<<<<<<<<<<<
 *               self.tsz.gamma_B16 = pdict_to_update['gamma_B16']
 *           if k == 'xc_B16':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_gamma_B16, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1201, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1202
 *               self.tsz.alpha_c_beta = pdict_to_update['alpha_c_beta']
 *           if k == 'gamma_B16':
 *               self.tsz.gamma_B16 = pdict_to_update['gamma_B16']             # <<<<<<<<<<<<<<
 *           if k == 'xc_B16':
 *               self.tsz.xc_B16 = pdict_to_update['xc_B16']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_gamma_B16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1202, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.gamma_B16 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1201
 *           if k == 'alpha_c_beta':
 *               self.tsz.alpha_c_beta = pdict_to_update['alpha_c_beta']
 *           if k == 'gamma_B16':             # <<<<<<<<<<<<<<
 *               self.tsz.gamma_B16 = pdict_to_update['gamma_B16']
 *           if k == 'xc_B16':
 */
    }

    /* "class-sz/python/classy.pyx":1203
 *           if k == 'gamma_B16':
 *               self.tsz.gamma_B16 = pdict_to_update['gamma_B16']
 *           if k == 'xc_B16':             # <<<<<<<<<<<<<<
 *               self.tsz.xc_B16 = pdict_to_update['xc_B16']
 *           if k == 'P0_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_xc_B16, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1203, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1204
 *               self.tsz.gamma_B16 = pdict_to_update['gamma_B16']
 *           if k == 'xc_B16':
 *               self.tsz.xc_B16 = pdict_to_update['xc_B16']             # <<<<<<<<<<<<<<
 *           if k == 'P0_B12':
 *               self.tsz.P0_B12 = pdict_to_update['P0_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_xc_B16); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.xc_B16 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1203
 *           if k == 'gamma_B16':
 *               self.tsz.gamma_B16 = pdict_to_update['gamma_B16']
 *           if k == 'xc_B16':             # <<<<<<<<<<<<<<
 *               self.tsz.xc_B16 = pdict_to_update['xc_B16']
 *           if k == 'P0_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1205
 *           if k == 'xc_B16':
 *               self.tsz.xc_B16 = pdict_to_update['xc_B16']
 *           if k == 'P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.P0_B12 = pdict_to_update['P0_B12']
 *           if k == 'beta_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_P0_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1205, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1206
 *               self.tsz.xc_B16 = pdict_to_update['xc_B16']
 *           if k == 'P0_B12':
 *               self.tsz.P0_B12 = pdict_to_update['P0_B12']             # <<<<<<<<<<<<<<
 *           if k == 'beta_B12':
 *               self.tsz.beta_B12 = pdict_to_update['beta_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_P0_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1206, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.P0_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1205
 *           if k == 'xc_B16':
 *               self.tsz.xc_B16 = pdict_to_update['xc_B16']
 *           if k == 'P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.P0_B12 = pdict_to_update['P0_B12']
 *           if k == 'beta_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1207
 *           if k == 'P0_B12':
 *               self.tsz.P0_B12 = pdict_to_update['P0_B12']
 *           if k == 'beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.beta_B12 = pdict_to_update['beta_B12']
 *           if k == 'alpha_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_beta_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1208
 *               self.tsz.P0_B12 = pdict_to_update['P0_B12']
 *           if k == 'beta_B12':
 *               self.tsz.beta_B12 = pdict_to_update['beta_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_B12':
 *               self.tsz.alpha_B12 = pdict_to_update['alpha_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_beta_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1208, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.beta_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1207
 *           if k == 'P0_B12':
 *               self.tsz.P0_B12 = pdict_to_update['P0_B12']
 *           if k == 'beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.beta_B12 = pdict_to_update['beta_B12']
 *           if k == 'alpha_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1209
 *           if k == 'beta_B12':
 *               self.tsz.beta_B12 = pdict_to_update['beta_B12']
 *           if k == 'alpha_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_B12 = pdict_to_update['alpha_B12']
 *           if k == 'gamma_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1209, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1210
 *               self.tsz.beta_B12 = pdict_to_update['beta_B12']
 *           if k == 'alpha_B12':
 *               self.tsz.alpha_B12 = pdict_to_update['alpha_B12']             # <<<<<<<<<<<<<<
 *           if k == 'gamma_B12':
 *               self.tsz.gamma_B12 = pdict_to_update['gamma_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1210, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1209
 *           if k == 'beta_B12':
 *               self.tsz.beta_B12 = pdict_to_update['beta_B12']
 *           if k == 'alpha_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_B12 = pdict_to_update['alpha_B12']
 *           if k == 'gamma_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1211
 *           if k == 'alpha_B12':
 *               self.tsz.alpha_B12 = pdict_to_update['alpha_B12']
 *           if k == 'gamma_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.gamma_B12 = pdict_to_update['gamma_B12']
 *           if k == 'xc_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_gamma_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1211, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1212
 *               self.tsz.alpha_B12 = pdict_to_update['alpha_B12']
 *           if k == 'gamma_B12':
 *               self.tsz.gamma_B12 = pdict_to_update['gamma_B12']             # <<<<<<<<<<<<<<
 *           if k == 'xc_B12':
 *               self.tsz.xc_B12 = pdict_to_update['xc_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_gamma_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1212, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.gamma_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1211
 *           if k == 'alpha_B12':
 *               self.tsz.alpha_B12 = pdict_to_update['alpha_B12']
 *           if k == 'gamma_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.gamma_B12 = pdict_to_update['gamma_B12']
 *           if k == 'xc_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1213
 *           if k == 'gamma_B12':
 *               self.tsz.gamma_B12 = pdict_to_update['gamma_B12']
 *           if k == 'xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.xc_B12 = pdict_to_update['xc_B12']
 *           if k == 'alpha_m_P0_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_xc_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1213, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1214
 *               self.tsz.gamma_B12 = pdict_to_update['gamma_B12']
 *           if k == 'xc_B12':
 *               self.tsz.xc_B12 = pdict_to_update['xc_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_m_P0_B12':
 *               self.tsz.alpha_m_P0_B12 = pdict_to_update['alpha_m_P0_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_xc_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1214, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1214, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.xc_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1213
 *           if k == 'gamma_B12':
 *               self.tsz.gamma_B12 = pdict_to_update['gamma_B12']
 *           if k == 'xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.xc_B12 = pdict_to_update['xc_B12']
 *           if k == 'alpha_m_P0_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1215
 *           if k == 'xc_B12':
 *               self.tsz.xc_B12 = pdict_to_update['xc_B12']
 *           if k == 'alpha_m_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_P0_B12 = pdict_to_update['alpha_m_P0_B12']
 *           if k == 'alpha_m_xc_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_m_P0_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1215, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1216
 *               self.tsz.xc_B12 = pdict_to_update['xc_B12']
 *           if k == 'alpha_m_P0_B12':
 *               self.tsz.alpha_m_P0_B12 = pdict_to_update['alpha_m_P0_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_m_xc_B12':
 *               self.tsz.alpha_m_xc_B12 = pdict_to_update['alpha_m_xc_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_m_P0_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1216, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_m_P0_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1215
 *           if k == 'xc_B12':
 *               self.tsz.xc_B12 = pdict_to_update['xc_B12']
 *           if k == 'alpha_m_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_P0_B12 = pdict_to_update['alpha_m_P0_B12']
 *           if k == 'alpha_m_xc_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1217
 *           if k == 'alpha_m_P0_B12':
 *               self.tsz.alpha_m_P0_B12 = pdict_to_update['alpha_m_P0_B12']
 *           if k == 'alpha_m_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_xc_B12 = pdict_to_update['alpha_m_xc_B12']
 *           if k == 'alpha_m_beta_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_m_xc_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1217, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1218
 *               self.tsz.alpha_m_P0_B12 = pdict_to_update['alpha_m_P0_B12']
 *           if k == 'alpha_m_xc_B12':
 *               self.tsz.alpha_m_xc_B12 = pdict_to_update['alpha_m_xc_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_m_beta_B12':
 *               self.tsz.alpha_m_beta_B12 = pdict_to_update['alpha_m_beta_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_m_xc_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1218, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1218, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_m_xc_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1217
 *           if k == 'alpha_m_P0_B12':
 *               self.tsz.alpha_m_P0_B12 = pdict_to_update['alpha_m_P0_B12']
 *           if k == 'alpha_m_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_xc_B12 = pdict_to_update['alpha_m_xc_B12']
 *           if k == 'alpha_m_beta_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1219
 *           if k == 'alpha_m_xc_B12':
 *               self.tsz.alpha_m_xc_B12 = pdict_to_update['alpha_m_xc_B12']
 *           if k == 'alpha_m_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_beta_B12 = pdict_to_update['alpha_m_beta_B12']
 *           if k == 'alpha_z_P0_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_m_beta_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1219, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1220
 *               self.tsz.alpha_m_xc_B12 = pdict_to_update['alpha_m_xc_B12']
 *           if k == 'alpha_m_beta_B12':
 *               self.tsz.alpha_m_beta_B12 = pdict_to_update['alpha_m_beta_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_z_P0_B12':
 *               self.tsz.alpha_z_P0_B12 = pdict_to_update['alpha_z_P0_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_m_beta_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1220, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1220, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_m_beta_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1219
 *           if k == 'alpha_m_xc_B12':
 *               self.tsz.alpha_m_xc_B12 = pdict_to_update['alpha_m_xc_B12']
 *           if k == 'alpha_m_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_m_beta_B12 = pdict_to_update['alpha_m_beta_B12']
 *           if k == 'alpha_z_P0_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1221
 *           if k == 'alpha_m_beta_B12':
 *               self.tsz.alpha_m_beta_B12 = pdict_to_update['alpha_m_beta_B12']
 *           if k == 'alpha_z_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_P0_B12 = pdict_to_update['alpha_z_P0_B12']
 *           if k == 'alpha_z_xc_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_z_P0_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1221, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1222
 *               self.tsz.alpha_m_beta_B12 = pdict_to_update['alpha_m_beta_B12']
 *           if k == 'alpha_z_P0_B12':
 *               self.tsz.alpha_z_P0_B12 = pdict_to_update['alpha_z_P0_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_z_xc_B12':
 *               self.tsz.alpha_z_xc_B12 = pdict_to_update['alpha_z_xc_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_z_P0_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1222, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_z_P0_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1221
 *           if k == 'alpha_m_beta_B12':
 *               self.tsz.alpha_m_beta_B12 = pdict_to_update['alpha_m_beta_B12']
 *           if k == 'alpha_z_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_P0_B12 = pdict_to_update['alpha_z_P0_B12']
 *           if k == 'alpha_z_xc_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1223
 *           if k == 'alpha_z_P0_B12':
 *               self.tsz.alpha_z_P0_B12 = pdict_to_update['alpha_z_P0_B12']
 *           if k == 'alpha_z_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_xc_B12 = pdict_to_update['alpha_z_xc_B12']
 *           if k == 'alpha_z_beta_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_z_xc_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1223, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1224
 *               self.tsz.alpha_z_P0_B12 = pdict_to_update['alpha_z_P0_B12']
 *           if k == 'alpha_z_xc_B12':
 *               self.tsz.alpha_z_xc_B12 = pdict_to_update['alpha_z_xc_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_z_beta_B12':
 *               self.tsz.alpha_z_beta_B12 = pdict_to_update['alpha_z_beta_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_z_xc_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1224, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_z_xc_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1223
 *           if k == 'alpha_z_P0_B12':
 *               self.tsz.alpha_z_P0_B12 = pdict_to_update['alpha_z_P0_B12']
 *           if k == 'alpha_z_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_xc_B12 = pdict_to_update['alpha_z_xc_B12']
 *           if k == 'alpha_z_beta_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1225
 *           if k == 'alpha_z_xc_B12':
 *               self.tsz.alpha_z_xc_B12 = pdict_to_update['alpha_z_xc_B12']
 *           if k == 'alpha_z_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_beta_B12 = pdict_to_update['alpha_z_beta_B12']
 *           if k == 'c_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_z_beta_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1225, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1226
 *               self.tsz.alpha_z_xc_B12 = pdict_to_update['alpha_z_xc_B12']
 *           if k == 'alpha_z_beta_B12':
 *               self.tsz.alpha_z_beta_B12 = pdict_to_update['alpha_z_beta_B12']             # <<<<<<<<<<<<<<
 *           if k == 'c_B12':
 *               self.tsz.c_B12 = pdict_to_update['cp_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_z_beta_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1226, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_z_beta_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1225
 *           if k == 'alpha_z_xc_B12':
 *               self.tsz.alpha_z_xc_B12 = pdict_to_update['alpha_z_xc_B12']
 *           if k == 'alpha_z_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_z_beta_B12 = pdict_to_update['alpha_z_beta_B12']
 *           if k == 'c_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1227
 *           if k == 'alpha_z_beta_B12':
 *               self.tsz.alpha_z_beta_B12 = pdict_to_update['alpha_z_beta_B12']
 *           if k == 'c_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.c_B12 = pdict_to_update['cp_B12']
 *           if k == 'mcut_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_c_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1227, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1228
 *               self.tsz.alpha_z_beta_B12 = pdict_to_update['alpha_z_beta_B12']
 *           if k == 'c_B12':
 *               self.tsz.c_B12 = pdict_to_update['cp_B12']             # <<<<<<<<<<<<<<
 *           if k == 'mcut_B12':
 *               self.tsz.mcut_B12 = pdict_to_update['mcut_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_cp_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1228, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1228, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.c_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1227
 *           if k == 'alpha_z_beta_B12':
 *               self.tsz.alpha_z_beta_B12 = pdict_to_update['alpha_z_beta_B12']
 *           if k == 'c_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.c_B12 = pdict_to_update['cp_B12']
 *           if k == 'mcut_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1229
 *           if k == 'c_B12':
 *               self.tsz.c_B12 = pdict_to_update['cp_B12']
 *           if k == 'mcut_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.mcut_B12 = pdict_to_update['mcut_B12']
 *           if k == 'alphap_m_P0_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_mcut_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1229, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1230
 *               self.tsz.c_B12 = pdict_to_update['cp_B12']
 *           if k == 'mcut_B12':
 *               self.tsz.mcut_B12 = pdict_to_update['mcut_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alphap_m_P0_B12':
 *               self.tsz.alphap_m_P0_B12 = pdict_to_update['alphap_m_P0_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_mcut_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1230, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.mcut_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1229
 *           if k == 'c_B12':
 *               self.tsz.c_B12 = pdict_to_update['cp_B12']
 *           if k == 'mcut_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.mcut_B12 = pdict_to_update['mcut_B12']
 *           if k == 'alphap_m_P0_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1231
 *           if k == 'mcut_B12':
 *               self.tsz.mcut_B12 = pdict_to_update['mcut_B12']
 *           if k == 'alphap_m_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_P0_B12 = pdict_to_update['alphap_m_P0_B12']
 *           if k == 'alphap_m_xc_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alphap_m_P0_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1231, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1232
 *               self.tsz.mcut_B12 = pdict_to_update['mcut_B12']
 *           if k == 'alphap_m_P0_B12':
 *               self.tsz.alphap_m_P0_B12 = pdict_to_update['alphap_m_P0_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alphap_m_xc_B12':
 *               self.tsz.alphap_m_xc_B12 = pdict_to_update['alphap_m_xc_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alphap_m_P0_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1232, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alphap_m_P0_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1231
 *           if k == 'mcut_B12':
 *               self.tsz.mcut_B12 = pdict_to_update['mcut_B12']
 *           if k == 'alphap_m_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_P0_B12 = pdict_to_update['alphap_m_P0_B12']
 *           if k == 'alphap_m_xc_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1233
 *           if k == 'alphap_m_P0_B12':
 *               self.tsz.alphap_m_P0_B12 = pdict_to_update['alphap_m_P0_B12']
 *           if k == 'alphap_m_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_xc_B12 = pdict_to_update['alphap_m_xc_B12']
 *           if k == 'alphap_m_beta_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alphap_m_xc_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1233, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1234
 *               self.tsz.alphap_m_P0_B12 = pdict_to_update['alphap_m_P0_B12']
 *           if k == 'alphap_m_xc_B12':
 *               self.tsz.alphap_m_xc_B12 = pdict_to_update['alphap_m_xc_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alphap_m_beta_B12':
 *               self.tsz.alphap_m_beta_B12 = pdict_to_update['alphap_m_beta_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alphap_m_xc_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1234, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alphap_m_xc_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1233
 *           if k == 'alphap_m_P0_B12':
 *               self.tsz.alphap_m_P0_B12 = pdict_to_update['alphap_m_P0_B12']
 *           if k == 'alphap_m_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_xc_B12 = pdict_to_update['alphap_m_xc_B12']
 *           if k == 'alphap_m_beta_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1235
 *           if k == 'alphap_m_xc_B12':
 *               self.tsz.alphap_m_xc_B12 = pdict_to_update['alphap_m_xc_B12']
 *           if k == 'alphap_m_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_beta_B12 = pdict_to_update['alphap_m_beta_B12']
 *           if k == 'alpha_c_P0_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alphap_m_beta_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1235, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1236
 *               self.tsz.alphap_m_xc_B12 = pdict_to_update['alphap_m_xc_B12']
 *           if k == 'alphap_m_beta_B12':
 *               self.tsz.alphap_m_beta_B12 = pdict_to_update['alphap_m_beta_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_c_P0_B12':
 *               self.tsz.alpha_c_P0_B12 = pdict_to_update['alpha_c_P0_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alphap_m_beta_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1236, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1236, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alphap_m_beta_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1235
 *           if k == 'alphap_m_xc_B12':
 *               self.tsz.alphap_m_xc_B12 = pdict_to_update['alphap_m_xc_B12']
 *           if k == 'alphap_m_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alphap_m_beta_B12 = pdict_to_update['alphap_m_beta_B12']
 *           if k == 'alpha_c_P0_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1237
 *           if k == 'alphap_m_beta_B12':
 *               self.tsz.alphap_m_beta_B12 = pdict_to_update['alphap_m_beta_B12']
 *           if k == 'alpha_c_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_P0_B12 = pdict_to_update['alpha_c_P0_B12']
 *           if k == 'alpha_c_xc_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_c_P0_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1237, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1238
 *               self.tsz.alphap_m_beta_B12 = pdict_to_update['alphap_m_beta_B12']
 *           if k == 'alpha_c_P0_B12':
 *               self.tsz.alpha_c_P0_B12 = pdict_to_update['alpha_c_P0_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_c_xc_B12':
 *               self.tsz.alpha_c_xc_B12 = pdict_to_update['alpha_c_xc_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_c_P0_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1238, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1238, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_c_P0_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1237
 *           if k == 'alphap_m_beta_B12':
 *               self.tsz.alphap_m_beta_B12 = pdict_to_update['alphap_m_beta_B12']
 *           if k == 'alpha_c_P0_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_P0_B12 = pdict_to_update['alpha_c_P0_B12']
 *           if k == 'alpha_c_xc_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1239
 *           if k == 'alpha_c_P0_B12':
 *               self.tsz.alpha_c_P0_B12 = pdict_to_update['alpha_c_P0_B12']
 *           if k == 'alpha_c_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_xc_B12 = pdict_to_update['alpha_c_xc_B12']
 *           if k == 'alpha_c_beta_B12':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_c_xc_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1239, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1240
 *               self.tsz.alpha_c_P0_B12 = pdict_to_update['alpha_c_P0_B12']
 *           if k == 'alpha_c_xc_B12':
 *               self.tsz.alpha_c_xc_B12 = pdict_to_update['alpha_c_xc_B12']             # <<<<<<<<<<<<<<
 *           if k == 'alpha_c_beta_B12':
 *               self.tsz.alpha_c_beta_B12 = pdict_to_update['alpha_c_beta_B12']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_c_xc_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1240, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_c_xc_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1239
 *           if k == 'alpha_c_P0_B12':
 *               self.tsz.alpha_c_P0_B12 = pdict_to_update['alpha_c_P0_B12']
 *           if k == 'alpha_c_xc_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_xc_B12 = pdict_to_update['alpha_c_xc_B12']
 *           if k == 'alpha_c_beta_B12':
 */
    }

    /* "class-sz/python/classy.pyx":1241
 *           if k == 'alpha_c_xc_B12':
 *               self.tsz.alpha_c_xc_B12 = pdict_to_update['alpha_c_xc_B12']
 *           if k == 'alpha_c_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_beta_B12 = pdict_to_update['alpha_c_beta_B12']
 *           if k == 'x_outSZ':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_alpha_c_beta_B12, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1241, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1242
 *               self.tsz.alpha_c_xc_B12 = pdict_to_update['alpha_c_xc_B12']
 *           if k == 'alpha_c_beta_B12':
 *               self.tsz.alpha_c_beta_B12 = pdict_to_update['alpha_c_beta_B12']             # <<<<<<<<<<<<<<
 *           if k == 'x_outSZ':
 *               self.tsz.x_outSZ = pdict_to_update['x_outSZ']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_alpha_c_beta_B12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1242, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_c_beta_B12 = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1241
 *           if k == 'alpha_c_xc_B12':
 *               self.tsz.alpha_c_xc_B12 = pdict_to_update['alpha_c_xc_B12']
 *           if k == 'alpha_c_beta_B12':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_c_beta_B12 = pdict_to_update['alpha_c_beta_B12']
 *           if k == 'x_outSZ':
 */
    }

    /* "class-sz/python/classy.pyx":1243
 *           if k == 'alpha_c_beta_B12':
 *               self.tsz.alpha_c_beta_B12 = pdict_to_update['alpha_c_beta_B12']
 *           if k == 'x_outSZ':             # <<<<<<<<<<<<<<
 *               self.tsz.x_outSZ = pdict_to_update['x_outSZ']
 *           # CIB parameters
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_x_outSZ, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1243, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1244
 *               self.tsz.alpha_c_beta_B12 = pdict_to_update['alpha_c_beta_B12']
 *           if k == 'x_outSZ':
 *               self.tsz.x_outSZ = pdict_to_update['x_outSZ']             # <<<<<<<<<<<<<<
 *           # CIB parameters
 *           if k == 'Redshift_evolution_of_dust_temperature':
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_x_outSZ); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1244, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.x_outSZ = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1243
 *           if k == 'alpha_c_beta_B12':
 *               self.tsz.alpha_c_beta_B12 = pdict_to_update['alpha_c_beta_B12']
 *           if k == 'x_outSZ':             # <<<<<<<<<<<<<<
 *               self.tsz.x_outSZ = pdict_to_update['x_outSZ']
 *           # CIB parameters
 */
    }

    /* "class-sz/python/classy.pyx":1246
 *               self.tsz.x_outSZ = pdict_to_update['x_outSZ']
 *           # CIB parameters
 *           if k == 'Redshift_evolution_of_dust_temperature':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_cib = pdict_to_update['Redshift_evolution_of_dust_temperature']
 *           if k == 'Dust_temperature_today_in_Kelvins':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_Redshift_evolution_of_dust_tempe, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1246, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1247
 *           # CIB parameters
 *           if k == 'Redshift_evolution_of_dust_temperature':
 *               self.tsz.alpha_cib = pdict_to_update['Redshift_evolution_of_dust_temperature']             # <<<<<<<<<<<<<<
 *           if k == 'Dust_temperature_today_in_Kelvins':
 *               self.tsz.T0_cib = pdict_to_update['Dust_temperature_today_in_Kelvins']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_Redshift_evolution_of_dust_tempe); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1247, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.alpha_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1246
 *               self.tsz.x_outSZ = pdict_to_update['x_outSZ']
 *           # CIB parameters
 *           if k == 'Redshift_evolution_of_dust_temperature':             # <<<<<<<<<<<<<<
 *               self.tsz.alpha_cib = pdict_to_update['Redshift_evolution_of_dust_temperature']
 *           if k == 'Dust_temperature_today_in_Kelvins':
 */
    }

    /* "class-sz/python/classy.pyx":1248
 *           if k == 'Redshift_evolution_of_dust_temperature':
 *               self.tsz.alpha_cib = pdict_to_update['Redshift_evolution_of_dust_temperature']
 *           if k == 'Dust_temperature_today_in_Kelvins':             # <<<<<<<<<<<<<<
 *               self.tsz.T0_cib = pdict_to_update['Dust_temperature_today_in_Kelvins']
 *           if k == 'Emissivity_index_of_sed':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_Dust_temperature_today_in_Kelvin, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1248, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1249
 *               self.tsz.alpha_cib = pdict_to_update['Redshift_evolution_of_dust_temperature']
 *           if k == 'Dust_temperature_today_in_Kelvins':
 *               self.tsz.T0_cib = pdict_to_update['Dust_temperature_today_in_Kelvins']             # <<<<<<<<<<<<<<
 *           if k == 'Emissivity_index_of_sed':
 *               self.tsz.beta_cib = pdict_to_update['Emissivity_index_of_sed']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_Dust_temperature_today_in_Kelvin); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1249, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1249, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.T0_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1248
 *           if k == 'Redshift_evolution_of_dust_temperature':
 *               self.tsz.alpha_cib = pdict_to_update['Redshift_evolution_of_dust_temperature']
 *           if k == 'Dust_temperature_today_in_Kelvins':             # <<<<<<<<<<<<<<
 *               self.tsz.T0_cib = pdict_to_update['Dust_temperature_today_in_Kelvins']
 *           if k == 'Emissivity_index_of_sed':
 */
    }

    /* "class-sz/python/classy.pyx":1250
 *           if k == 'Dust_temperature_today_in_Kelvins':
 *               self.tsz.T0_cib = pdict_to_update['Dust_temperature_today_in_Kelvins']
 *           if k == 'Emissivity_index_of_sed':             # <<<<<<<<<<<<<<
 *               self.tsz.beta_cib = pdict_to_update['Emissivity_index_of_sed']
 *           if k == 'Power_law_index_of_SED_at_high_frequency':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_Emissivity_index_of_sed, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1250, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1251
 *               self.tsz.T0_cib = pdict_to_update['Dust_temperature_today_in_Kelvins']
 *           if k == 'Emissivity_index_of_sed':
 *               self.tsz.beta_cib = pdict_to_update['Emissivity_index_of_sed']             # <<<<<<<<<<<<<<
 *           if k == 'Power_law_index_of_SED_at_high_frequency':
 *               self.tsz.gamma_cib = pdict_to_update['Power_law_index_of_SED_at_high_frequency']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_Emissivity_index_of_sed); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1251, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1251, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.beta_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1250
 *           if k == 'Dust_temperature_today_in_Kelvins':
 *               self.tsz.T0_cib = pdict_to_update['Dust_temperature_today_in_Kelvins']
 *           if k == 'Emissivity_index_of_sed':             # <<<<<<<<<<<<<<
 *               self.tsz.beta_cib = pdict_to_update['Emissivity_index_of_sed']
 *           if k == 'Power_law_index_of_SED_at_high_frequency':
 */
    }

    /* "class-sz/python/classy.pyx":1252
 *           if k == 'Emissivity_index_of_sed':
 *               self.tsz.beta_cib = pdict_to_update['Emissivity_index_of_sed']
 *           if k == 'Power_law_index_of_SED_at_high_frequency':             # <<<<<<<<<<<<<<
 *               self.tsz.gamma_cib = pdict_to_update['Power_law_index_of_SED_at_high_frequency']
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_Power_law_index_of_SED_at_high_f, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1252, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1253
 *               self.tsz.beta_cib = pdict_to_update['Emissivity_index_of_sed']
 *           if k == 'Power_law_index_of_SED_at_high_frequency':
 *               self.tsz.gamma_cib = pdict_to_update['Power_law_index_of_SED_at_high_frequency']             # <<<<<<<<<<<<<<
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':
 *               self.tsz.delta_cib = pdict_to_update['Redshift_evolution_of_L_-_M_normalisation']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_Power_law_index_of_SED_at_high_f); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1253, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1253, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.gamma_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1252
 *           if k == 'Emissivity_index_of_sed':
 *               self.tsz.beta_cib = pdict_to_update['Emissivity_index_of_sed']
 *           if k == 'Power_law_index_of_SED_at_high_frequency':             # <<<<<<<<<<<<<<
 *               self.tsz.gamma_cib = pdict_to_update['Power_law_index_of_SED_at_high_frequency']
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':
 */
    }

    /* "class-sz/python/classy.pyx":1254
 *           if k == 'Power_law_index_of_SED_at_high_frequency':
 *               self.tsz.gamma_cib = pdict_to_update['Power_law_index_of_SED_at_high_frequency']
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':             # <<<<<<<<<<<<<<
 *               self.tsz.delta_cib = pdict_to_update['Redshift_evolution_of_L_-_M_normalisation']
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_kp_u_Redshift_evolution_of_L___M_norm, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1254, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1255
 *               self.tsz.gamma_cib = pdict_to_update['Power_law_index_of_SED_at_high_frequency']
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':
 *               self.tsz.delta_cib = pdict_to_update['Redshift_evolution_of_L_-_M_normalisation']             # <<<<<<<<<<<<<<
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':
 *               self.tsz.L0_cib = pdict_to_update['Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_kp_u_Redshift_evolution_of_L___M_norm); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1255, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1255, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.delta_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1254
 *           if k == 'Power_law_index_of_SED_at_high_frequency':
 *               self.tsz.gamma_cib = pdict_to_update['Power_law_index_of_SED_at_high_frequency']
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':             # <<<<<<<<<<<<<<
 *               self.tsz.delta_cib = pdict_to_update['Redshift_evolution_of_L_-_M_normalisation']
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':
 */
    }

    /* "class-sz/python/classy.pyx":1256
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':
 *               self.tsz.delta_cib = pdict_to_update['Redshift_evolution_of_L_-_M_normalisation']
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':             # <<<<<<<<<<<<<<
 *               self.tsz.L0_cib = pdict_to_update['Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]']
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_kp_u_Normalisation_of_L___M_relation, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1256, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1257
 *               self.tsz.delta_cib = pdict_to_update['Redshift_evolution_of_L_-_M_normalisation']
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':
 *               self.tsz.L0_cib = pdict_to_update['Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]']             # <<<<<<<<<<<<<<
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':
 *               self.tsz.sigma2_LM_cib = pdict_to_update['Size_of_halo_masses_sourcing_CIB_emission']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_kp_u_Normalisation_of_L___M_relation); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1257, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.L0_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1256
 *           if k == 'Redshift_evolution_of_L_-_M_normalisation':
 *               self.tsz.delta_cib = pdict_to_update['Redshift_evolution_of_L_-_M_normalisation']
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':             # <<<<<<<<<<<<<<
 *               self.tsz.L0_cib = pdict_to_update['Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]']
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':
 */
    }

    /* "class-sz/python/classy.pyx":1258
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':
 *               self.tsz.L0_cib = pdict_to_update['Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]']
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':             # <<<<<<<<<<<<<<
 *               self.tsz.sigma2_LM_cib = pdict_to_update['Size_of_halo_masses_sourcing_CIB_emission']
 *           if k =='Most_efficient_halo_mass_in_Msun':
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_Size_of_halo_masses_sourcing_CIB, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1258, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1259
 *               self.tsz.L0_cib = pdict_to_update['Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]']
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':
 *               self.tsz.sigma2_LM_cib = pdict_to_update['Size_of_halo_masses_sourcing_CIB_emission']             # <<<<<<<<<<<<<<
 *           if k =='Most_efficient_halo_mass_in_Msun':
 *               self.tsz.m_eff_cib = pdict_to_update['Most_efficient_halo_mass_in_Msun']
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_Size_of_halo_masses_sourcing_CIB); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1259, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1259, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.sigma2_LM_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1258
 *           if k == 'Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]':
 *               self.tsz.L0_cib = pdict_to_update['Normalisation_of_L_-_M_relation_in_[JyMPc2/Msun]']
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':             # <<<<<<<<<<<<<<
 *               self.tsz.sigma2_LM_cib = pdict_to_update['Size_of_halo_masses_sourcing_CIB_emission']
 *           if k =='Most_efficient_halo_mass_in_Msun':
 */
    }

    /* "class-sz/python/classy.pyx":1260
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':
 *               self.tsz.sigma2_LM_cib = pdict_to_update['Size_of_halo_masses_sourcing_CIB_emission']
 *           if k =='Most_efficient_halo_mass_in_Msun':             # <<<<<<<<<<<<<<
 *               self.tsz.m_eff_cib = pdict_to_update['Most_efficient_halo_mass_in_Msun']
 * 
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_Most_efficient_halo_mass_in_Msun, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1260, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1261
 *               self.tsz.sigma2_LM_cib = pdict_to_update['Size_of_halo_masses_sourcing_CIB_emission']
 *           if k =='Most_efficient_halo_mass_in_Msun':
 *               self.tsz.m_eff_cib = pdict_to_update['Most_efficient_halo_mass_in_Msun']             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_Most_efficient_halo_mass_in_Msun); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1261, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1261, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.m_eff_cib = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1260
 *           if k == 'Size_of_halo_masses_sourcing_CIB_emission':
 *               self.tsz.sigma2_LM_cib = pdict_to_update['Size_of_halo_masses_sourcing_CIB_emission']
 *           if k =='Most_efficient_halo_mass_in_Msun':             # <<<<<<<<<<<<<<
 *               self.tsz.m_eff_cib = pdict_to_update['Most_efficient_halo_mass_in_Msun']
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1265
 * 
 *           #pk at z parameter:
 *           if k == 'z_for_pk_hm':             # <<<<<<<<<<<<<<
 *               self.tsz.z_for_pk_hm = pdict_to_update['z_for_pk_hm']
 *               integrate_only = True
 */
    __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_k, __pyx_n_u_z_for_pk_hm, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 1265, __pyx_L1_error)
    if (__pyx_t_12) {

      /* "class-sz/python/classy.pyx":1266
 *           #pk at z parameter:
 *           if k == 'z_for_pk_hm':
 *               self.tsz.z_for_pk_hm = pdict_to_update['z_for_pk_hm']             # <<<<<<<<<<<<<<
 *               integrate_only = True
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_pdict_to_update, __pyx_n_u_z_for_pk_hm); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_self->tsz.z_for_pk_hm = __pyx_t_13;

      /* "class-sz/python/classy.pyx":1267
 *           if k == 'z_for_pk_hm':
 *               self.tsz.z_for_pk_hm = pdict_to_update['z_for_pk_hm']
 *               integrate_only = True             # <<<<<<<<<<<<<<
 * 
 *         if not integrate_only:
 */
      __pyx_v_integrate_only = 1;

      /* "class-sz/python/classy.pyx":1265
 * 
 *           #pk at z parameter:
 *           if k == 'z_for_pk_hm':             # <<<<<<<<<<<<<<
 *               self.tsz.z_for_pk_hm = pdict_to_update['z_for_pk_hm']
 *               integrate_only = True
 */
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":1269
 *               integrate_only = True
 * 
 *         if not integrate_only:             # <<<<<<<<<<<<<<
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  __pyx_t_12 = (!__pyx_v_integrate_only);
  if (__pyx_t_12) {

    /* "class-sz/python/classy.pyx":1271
 *         if not integrate_only:
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)
 */
    __pyx_t_12 = (class_sz_tabulate_init((&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->nl), (&__pyx_v_self->pm), (&__pyx_v_self->sp), (&__pyx_v_self->le), (&__pyx_v_self->tsz), (&__pyx_v_self->pr)) == _FAILURE_);

    /* "class-sz/python/classy.pyx":1270
 * 
 *         if not integrate_only:
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    if (unlikely(__pyx_t_12)) {

      /* "class-sz/python/classy.pyx":1272
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()             # <<<<<<<<<<<<<<
 *                 raise CosmoComputationError(self.tsz.error_message)
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_16 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_16)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_16, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1272, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":1273
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 *                 raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_16 = __Pyx_PyBytes_FromString(__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_4 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_16};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1273, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(0, 1273, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1270
 * 
 *         if not integrate_only:
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *                 self.struct_cleanup()
 */
    }

    /* "class-sz/python/classy.pyx":1269
 *               integrate_only = True
 * 
 *         if not integrate_only:             # <<<<<<<<<<<<<<
 *             if class_sz_tabulate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *             &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 */
  }

  /* "class-sz/python/classy.pyx":1276
 * 
 *         if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *         &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:             # <<<<<<<<<<<<<<
 *             self.struct_cleanup()
 *             raise CosmoComputationError(self.tsz.error_message)
 */
  __pyx_t_12 = (class_sz_integrate_init((&__pyx_v_self->ba), (&__pyx_v_self->th), (&__pyx_v_self->pt), (&__pyx_v_self->nl), (&__pyx_v_self->pm), (&__pyx_v_self->sp), (&__pyx_v_self->le), (&__pyx_v_self->tsz), (&__pyx_v_self->pr)) == _FAILURE_);

  /* "class-sz/python/classy.pyx":1275
 *                 raise CosmoComputationError(self.tsz.error_message)
 * 
 *         if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *         &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *             self.struct_cleanup()
 */
  if (unlikely(__pyx_t_12)) {

    /* "class-sz/python/classy.pyx":1277
 *         if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),
 *         &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *             self.struct_cleanup()             # <<<<<<<<<<<<<<
 *             raise CosmoComputationError(self.tsz.error_message)
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_16 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_16)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_16);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_16, NULL};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":1278
 *         &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *             self.struct_cleanup()
 *             raise CosmoComputationError(self.tsz.error_message)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoComputationError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_16 = __Pyx_PyBytes_FromString(__pyx_v_self->tsz.error_message); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_4 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_16};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_Raise(__pyx_t_7, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __PYX_ERR(0, 1278, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1275
 *                 raise CosmoComputationError(self.tsz.error_message)
 * 
 *         if class_sz_integrate_init(&(self.ba), &(self.th), &(self.pt), &(self.nl), &(self.pm),             # <<<<<<<<<<<<<<
 *         &(self.sp),&(self.le),&(self.tsz),&(self.pr)) == _FAILURE_:
 *             self.struct_cleanup()
 */
  }

  /* "class-sz/python/classy.pyx":1281
 * 
 * 
 *         self.computed = True             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_v_self->computed = 1;

  /* "class-sz/python/classy.pyx":1282
 * 
 *         self.computed = True
 *         return             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1097
 * 
 * 
 *     def compute_class_sz(self,pdict_to_update):             # <<<<<<<<<<<<<<
 *         integrate_only = False
 *         try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("classy_sz.Class.compute_class_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_N_ngal);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_index_g);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1287
 * 
 * 
 *     def raw_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         raw_cl(lmax=-1, nofail=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_29raw_cl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_28raw_cl, "\n        raw_cl(lmax=-1, nofail=False)\n\n        Return a dictionary of the primary C_l\n\n        Parameters\n        ----------\n        lmax : int, optional\n                Define the maximum l for which the C_l will be returned\n                (inclusively). This number will be checked against the maximum l\n                at which they were actually computed by CLASS, and an error will\n                be raised if the desired lmax is bigger than what CLASS can\n                give.\n        nofail: bool, optional\n                Check and enforce the computation of the spectra module\n                beforehand, with the desired lmax.\n\n        Returns\n        -------\n        cl : dict\n                Dictionary that contains the power spectrum for 'tt', 'te', etc... The\n                index associated with each is defined wrt. Class convention, and are non\n                important from the python point of view. It also returns now the\n                ell array.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_29raw_cl = {"raw_cl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_29raw_cl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_28raw_cl};
static PyObject *__pyx_pw_9classy_sz_5Class_29raw_cl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_lmax = 0;
  PyObject *__pyx_v_nofail = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("raw_cl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lmax,&__pyx_n_s_nofail,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lmax);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1287, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nofail);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1287, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "raw_cl") < 0)) __PYX_ERR(0, 1287, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_lmax = values[0];
    __pyx_v_nofail = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("raw_cl", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 1287, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.raw_cl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_28raw_cl(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_lmax, __pyx_v_nofail);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_28raw_cl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_lmax, PyObject *__pyx_v_nofail) {
  int __pyx_v_lmaxR;
  double *__pyx_v_rcl;
  double **__pyx_v_cl_md;
  int __pyx_v_index_md;
  double **__pyx_v_cl_md_ic;
  PyObject *__pyx_v_has_flags = NULL;
  PyObject *__pyx_v_spectra = NULL;
  PyObject *__pyx_v_flag = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_cl = NULL;
  PyObject *__pyx_v_elem = NULL;
  long __pyx_v_ell;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  unsigned int __pyx_t_17;
  long __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("raw_cl", 0);
  __Pyx_INCREF(__pyx_v_lmax);

  /* "class-sz/python/classy.pyx":1314
 *         """
 *         cdef int lmaxR
 *         cdef double *rcl = <double*> calloc(self.sp.ct_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         # Quantities for tensor modes
 */
  __pyx_v_rcl = ((double *)calloc(__pyx_v_self->sp.ct_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":1317
 * 
 *         # Quantities for tensor modes
 *         cdef double **cl_md = <double**> calloc(self.sp.md_size, sizeof(double*))             # <<<<<<<<<<<<<<
 *         for index_md in range(self.sp.md_size):
 *             cl_md[index_md] = <double*> calloc(self.sp.ct_size, sizeof(double))
 */
  __pyx_v_cl_md = ((double **)calloc(__pyx_v_self->sp.md_size, (sizeof(double *))));

  /* "class-sz/python/classy.pyx":1318
 *         # Quantities for tensor modes
 *         cdef double **cl_md = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):             # <<<<<<<<<<<<<<
 *             cl_md[index_md] = <double*> calloc(self.sp.ct_size, sizeof(double))
 * 
 */
  __pyx_t_1 = __pyx_v_self->sp.md_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_index_md = __pyx_t_3;

    /* "class-sz/python/classy.pyx":1319
 *         cdef double **cl_md = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):
 *             cl_md[index_md] = <double*> calloc(self.sp.ct_size, sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         # Quantities for isocurvature modes
 */
    (__pyx_v_cl_md[__pyx_v_index_md]) = ((double *)calloc(__pyx_v_self->sp.ct_size, (sizeof(double))));
  }

  /* "class-sz/python/classy.pyx":1322
 * 
 *         # Quantities for isocurvature modes
 *         cdef double **cl_md_ic = <double**> calloc(self.sp.md_size, sizeof(double*))             # <<<<<<<<<<<<<<
 *         for index_md in range(self.sp.md_size):
 *             cl_md_ic[index_md] = <double*> calloc(self.sp.ct_size*self.sp.ic_ic_size[index_md], sizeof(double))
 */
  __pyx_v_cl_md_ic = ((double **)calloc(__pyx_v_self->sp.md_size, (sizeof(double *))));

  /* "class-sz/python/classy.pyx":1323
 *         # Quantities for isocurvature modes
 *         cdef double **cl_md_ic = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):             # <<<<<<<<<<<<<<
 *             cl_md_ic[index_md] = <double*> calloc(self.sp.ct_size*self.sp.ic_ic_size[index_md], sizeof(double))
 * 
 */
  __pyx_t_1 = __pyx_v_self->sp.md_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_index_md = __pyx_t_3;

    /* "class-sz/python/classy.pyx":1324
 *         cdef double **cl_md_ic = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):
 *             cl_md_ic[index_md] = <double*> calloc(self.sp.ct_size*self.sp.ic_ic_size[index_md], sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         # Define a list of integers, refering to the flags and indices of each
 */
    (__pyx_v_cl_md_ic[__pyx_v_index_md]) = ((double *)calloc((__pyx_v_self->sp.ct_size * (__pyx_v_self->sp.ic_ic_size[__pyx_v_index_md])), (sizeof(double))));
  }

  /* "class-sz/python/classy.pyx":1330
 *         # over them, checking if they are defined or not.
 *         has_flags = [
 *             (self.sp.has_tt, self.sp.index_ct_tt, 'tt'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_ee, self.sp.index_ct_ee, 'ee'),
 *             (self.sp.has_te, self.sp.index_ct_te, 'te'),
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_tt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_tt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4)) __PYX_ERR(0, 1330, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5)) __PYX_ERR(0, 1330, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_tt);
  __Pyx_GIVEREF(__pyx_n_u_tt);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_tt)) __PYX_ERR(0, 1330, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1331
 *         has_flags = [
 *             (self.sp.has_tt, self.sp.index_ct_tt, 'tt'),
 *             (self.sp.has_ee, self.sp.index_ct_ee, 'ee'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_te, self.sp.index_ct_te, 'te'),
 *             (self.sp.has_bb, self.sp.index_ct_bb, 'bb'),
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_ee); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_ee); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(0, 1331, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_4)) __PYX_ERR(0, 1331, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ee);
  __Pyx_GIVEREF(__pyx_n_u_ee);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_n_u_ee)) __PYX_ERR(0, 1331, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1332
 *             (self.sp.has_tt, self.sp.index_ct_tt, 'tt'),
 *             (self.sp.has_ee, self.sp.index_ct_ee, 'ee'),
 *             (self.sp.has_te, self.sp.index_ct_te, 'te'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_bb, self.sp.index_ct_bb, 'bb'),
 *             (self.sp.has_pp, self.sp.index_ct_pp, 'pp'),
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_te); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_te); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4)) __PYX_ERR(0, 1332, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_5)) __PYX_ERR(0, 1332, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_te);
  __Pyx_GIVEREF(__pyx_n_u_te);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_n_u_te)) __PYX_ERR(0, 1332, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1333
 *             (self.sp.has_ee, self.sp.index_ct_ee, 'ee'),
 *             (self.sp.has_te, self.sp.index_ct_te, 'te'),
 *             (self.sp.has_bb, self.sp.index_ct_bb, 'bb'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_pp, self.sp.index_ct_pp, 'pp'),
 *             (self.sp.has_tp, self.sp.index_ct_tp, 'tp'),]
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_bb); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_bb); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_5)) __PYX_ERR(0, 1333, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_4)) __PYX_ERR(0, 1333, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_bb);
  __Pyx_GIVEREF(__pyx_n_u_bb);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_n_u_bb)) __PYX_ERR(0, 1333, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1334
 *             (self.sp.has_te, self.sp.index_ct_te, 'te'),
 *             (self.sp.has_bb, self.sp.index_ct_bb, 'bb'),
 *             (self.sp.has_pp, self.sp.index_ct_pp, 'pp'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_tp, self.sp.index_ct_tp, 'tp'),]
 *         spectra = []
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_pp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_pp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(0, 1334, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_5)) __PYX_ERR(0, 1334, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_pp);
  __Pyx_GIVEREF(__pyx_n_u_pp);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_n_u_pp)) __PYX_ERR(0, 1334, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1335
 *             (self.sp.has_bb, self.sp.index_ct_bb, 'bb'),
 *             (self.sp.has_pp, self.sp.index_ct_pp, 'pp'),
 *             (self.sp.has_tp, self.sp.index_ct_tp, 'tp'),]             # <<<<<<<<<<<<<<
 *         spectra = []
 * 
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_tp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_tp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = PyTuple_New(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_5)) __PYX_ERR(0, 1335, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_4)) __PYX_ERR(0, 1335, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_tp);
  __Pyx_GIVEREF(__pyx_n_u_tp);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_n_u_tp)) __PYX_ERR(0, 1335, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1329
 *         # possible output Cl. It allows for a clear and concise way of looping
 *         # over them, checking if they are defined or not.
 *         has_flags = [             # <<<<<<<<<<<<<<
 *             (self.sp.has_tt, self.sp.index_ct_tt, 'tt'),
 *             (self.sp.has_ee, self.sp.index_ct_ee, 'ee'),
 */
  __pyx_t_4 = PyList_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_6)) __PYX_ERR(0, 1329, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 1, __pyx_t_7)) __PYX_ERR(0, 1329, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 2, __pyx_t_8)) __PYX_ERR(0, 1329, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 3, __pyx_t_9)) __PYX_ERR(0, 1329, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 4, __pyx_t_10)) __PYX_ERR(0, 1329, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_11);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 5, __pyx_t_11)) __PYX_ERR(0, 1329, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_t_11 = 0;
  __pyx_v_has_flags = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1336
 *             (self.sp.has_pp, self.sp.index_ct_pp, 'pp'),
 *             (self.sp.has_tp, self.sp.index_ct_tp, 'tp'),]
 *         spectra = []             # <<<<<<<<<<<<<<
 * 
 *         for flag, index, name in has_flags:
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_spectra = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1338
 *         spectra = []
 * 
 *         for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *             if flag:
 *                 spectra.append(name)
 */
  __pyx_t_4 = __pyx_v_has_flags; __Pyx_INCREF(__pyx_t_4);
  __pyx_t_12 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
      #endif
      if (__pyx_t_12 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_11 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_11); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
    #else
    __pyx_t_11 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1338, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_11))) || (PyList_CheckExact(__pyx_t_11))) {
      PyObject* sequence = __pyx_t_11;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1338, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_10 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      #else
      __pyx_t_10 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_10 = __pyx_t_13(__pyx_t_7); if (unlikely(!__pyx_t_10)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_10);
      index = 1; __pyx_t_9 = __pyx_t_13(__pyx_t_7); if (unlikely(!__pyx_t_9)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_9);
      index = 2; __pyx_t_8 = __pyx_t_13(__pyx_t_7); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_7), 3) < 0) __PYX_ERR(0, 1338, __pyx_L1_error)
      __pyx_t_13 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L10_unpacking_done;
      __pyx_L9_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_13 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1338, __pyx_L1_error)
      __pyx_L10_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_flag, __pyx_t_10);
    __pyx_t_10 = 0;
    __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_9);
    __pyx_t_9 = 0;
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":1339
 * 
 *         for flag, index, name in has_flags:
 *             if flag:             # <<<<<<<<<<<<<<
 *                 spectra.append(name)
 * 
 */
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 1339, __pyx_L1_error)
    if (__pyx_t_14) {

      /* "class-sz/python/classy.pyx":1340
 *         for flag, index, name in has_flags:
 *             if flag:
 *                 spectra.append(name)             # <<<<<<<<<<<<<<
 * 
 *         if not spectra:
 */
      __pyx_t_15 = __Pyx_PyList_Append(__pyx_v_spectra, __pyx_v_name); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(0, 1340, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1339
 * 
 *         for flag, index, name in has_flags:
 *             if flag:             # <<<<<<<<<<<<<<
 *                 spectra.append(name)
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1338
 *         spectra = []
 * 
 *         for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *             if flag:
 *                 spectra.append(name)
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1342
 *                 spectra.append(name)
 * 
 *         if not spectra:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No Cl computed")
 *         lmaxR = self.sp.l_max_tot
 */
  __pyx_t_14 = (PyList_GET_SIZE(__pyx_v_spectra) != 0);
  __pyx_t_16 = (!__pyx_t_14);
  if (unlikely(__pyx_t_16)) {

    /* "class-sz/python/classy.pyx":1343
 * 
 *         if not spectra:
 *             raise CosmoSevereError("No Cl computed")             # <<<<<<<<<<<<<<
 *         lmaxR = self.sp.l_max_tot
 *         if lmax == -1:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1343, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_8 = NULL;
    __pyx_t_17 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
        __pyx_t_17 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_kp_u_No_Cl_computed};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1343, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1343, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1342
 *                 spectra.append(name)
 * 
 *         if not spectra:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No Cl computed")
 *         lmaxR = self.sp.l_max_tot
 */
  }

  /* "class-sz/python/classy.pyx":1344
 *         if not spectra:
 *             raise CosmoSevereError("No Cl computed")
 *         lmaxR = self.sp.l_max_tot             # <<<<<<<<<<<<<<
 *         if lmax == -1:
 *             lmax = lmaxR
 */
  __pyx_t_1 = __pyx_v_self->sp.l_max_tot;
  __pyx_v_lmaxR = __pyx_t_1;

  /* "class-sz/python/classy.pyx":1345
 *             raise CosmoSevereError("No Cl computed")
 *         lmaxR = self.sp.l_max_tot
 *         if lmax == -1:             # <<<<<<<<<<<<<<
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 */
  __pyx_t_16 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_lmax, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1345, __pyx_L1_error)
  if (__pyx_t_16) {

    /* "class-sz/python/classy.pyx":1346
 *         lmaxR = self.sp.l_max_tot
 *         if lmax == -1:
 *             lmax = lmaxR             # <<<<<<<<<<<<<<
 *         if lmax > lmaxR:
 *             if nofail:
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_lmax, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":1345
 *             raise CosmoSevereError("No Cl computed")
 *         lmaxR = self.sp.l_max_tot
 *         if lmax == -1:             # <<<<<<<<<<<<<<
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 */
  }

  /* "class-sz/python/classy.pyx":1347
 *         if lmax == -1:
 *             lmax = lmaxR
 *         if lmax > lmaxR:             # <<<<<<<<<<<<<<
 *             if nofail:
 *                 self._pars_check("l_max_scalars",lmax)
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = PyObject_RichCompare(__pyx_v_lmax, __pyx_t_4, Py_GT); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (__pyx_t_16) {

    /* "class-sz/python/classy.pyx":1348
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 *             if nofail:             # <<<<<<<<<<<<<<
 *                 self._pars_check("l_max_scalars",lmax)
 *                 self.compute(["lensing"])
 */
    __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_v_nofail); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1348, __pyx_L1_error)
    if (likely(__pyx_t_16)) {

      /* "class-sz/python/classy.pyx":1349
 *         if lmax > lmaxR:
 *             if nofail:
 *                 self._pars_check("l_max_scalars",lmax)             # <<<<<<<<<<<<<<
 *                 self.compute(["lensing"])
 *             else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pars_check); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_n_u_l_max_scalars, __pyx_v_lmax};
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_17, 2+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1349, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "class-sz/python/classy.pyx":1350
 *             if nofail:
 *                 self._pars_check("l_max_scalars",lmax)
 *                 self.compute(["lensing"])             # <<<<<<<<<<<<<<
 *             else:
 *                 raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1350, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyList_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1350, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_n_u_lensing);
      __Pyx_GIVEREF(__pyx_n_u_lensing);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_8, 0, __pyx_n_u_lensing)) __PYX_ERR(0, 1350, __pyx_L1_error);
      __pyx_t_9 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "class-sz/python/classy.pyx":1348
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 *             if nofail:             # <<<<<<<<<<<<<<
 *                 self._pars_check("l_max_scalars",lmax)
 *                 self.compute(["lensing"])
 */
      goto __pyx_L16;
    }

    /* "class-sz/python/classy.pyx":1352
 *                 self.compute(["lensing"])
 *             else:
 *                 raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)             # <<<<<<<<<<<<<<
 * 
 *         # Initialise all the needed Cls arrays
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = PyUnicode_Format(__pyx_kp_u_Can_only_compute_up_to_lmax_d, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_9};
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1352, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_Raise(__pyx_t_11, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __PYX_ERR(0, 1352, __pyx_L1_error)
    }
    __pyx_L16:;

    /* "class-sz/python/classy.pyx":1347
 *         if lmax == -1:
 *             lmax = lmaxR
 *         if lmax > lmaxR:             # <<<<<<<<<<<<<<
 *             if nofail:
 *                 self._pars_check("l_max_scalars",lmax)
 */
  }

  /* "class-sz/python/classy.pyx":1355
 * 
 *         # Initialise all the needed Cls arrays
 *         cl = {}             # <<<<<<<<<<<<<<
 *         for elem in spectra:
 *             cl[elem] = np.zeros(lmax+1, dtype=np.double)
 */
  __pyx_t_11 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_v_cl = ((PyObject*)__pyx_t_11);
  __pyx_t_11 = 0;

  /* "class-sz/python/classy.pyx":1356
 *         # Initialise all the needed Cls arrays
 *         cl = {}
 *         for elem in spectra:             # <<<<<<<<<<<<<<
 *             cl[elem] = np.zeros(lmax+1, dtype=np.double)
 * 
 */
  __pyx_t_11 = __pyx_v_spectra; __Pyx_INCREF(__pyx_t_11);
  __pyx_t_12 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_11);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1356, __pyx_L1_error)
      #endif
      if (__pyx_t_12 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyList_GET_ITEM(__pyx_t_11, __pyx_t_12); __Pyx_INCREF(__pyx_t_4); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 1356, __pyx_L1_error)
    #else
    __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_11, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_elem, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":1357
 *         cl = {}
 *         for elem in spectra:
 *             cl[elem] = np.zeros(lmax+1, dtype=np.double)             # <<<<<<<<<<<<<<
 * 
 *         # Recover for each ell the information from CLASS
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_zeros); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4)) __PYX_ERR(0, 1357, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_np); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_double); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_8, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_v_elem, __pyx_t_7) < 0))) __PYX_ERR(0, 1357, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":1356
 *         # Initialise all the needed Cls arrays
 *         cl = {}
 *         for elem in spectra:             # <<<<<<<<<<<<<<
 *             cl[elem] = np.zeros(lmax+1, dtype=np.double)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "class-sz/python/classy.pyx":1360
 * 
 *         # Recover for each ell the information from CLASS
 *         for ell from 2<=ell<lmax+1:             # <<<<<<<<<<<<<<
 *             if spectra_cl_at_l(&self.sp, ell, rcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)
 */
  __pyx_t_11 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_18 = __Pyx_PyInt_As_long(__pyx_t_11); if (unlikely((__pyx_t_18 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  for (__pyx_v_ell = 2; __pyx_v_ell < __pyx_t_18; __pyx_v_ell++) {

    /* "class-sz/python/classy.pyx":1361
 *         # Recover for each ell the information from CLASS
 *         for ell from 2<=ell<lmax+1:
 *             if spectra_cl_at_l(&self.sp, ell, rcl, cl_md, cl_md_ic) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.sp.error_message)
 *             for flag, index, name in has_flags:
 */
    __pyx_t_16 = (spectra_cl_at_l((&__pyx_v_self->sp), __pyx_v_ell, __pyx_v_rcl, __pyx_v_cl_md, __pyx_v_cl_md_ic) == _FAILURE_);
    if (unlikely(__pyx_t_16)) {

      /* "class-sz/python/classy.pyx":1362
 *         for ell from 2<=ell<lmax+1:
 *             if spectra_cl_at_l(&self.sp, ell, rcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)             # <<<<<<<<<<<<<<
 *             for flag, index, name in has_flags:
 *                 if name in spectra:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1362, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->sp.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1362, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_4};
        __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1362, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_Raise(__pyx_t_11, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __PYX_ERR(0, 1362, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1361
 *         # Recover for each ell the information from CLASS
 *         for ell from 2<=ell<lmax+1:
 *             if spectra_cl_at_l(&self.sp, ell, rcl, cl_md, cl_md_ic) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.sp.error_message)
 *             for flag, index, name in has_flags:
 */
    }

    /* "class-sz/python/classy.pyx":1363
 *             if spectra_cl_at_l(&self.sp, ell, rcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)
 *             for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *                 if name in spectra:
 *                     cl[name][ell] = rcl[index]
 */
    __pyx_t_11 = __pyx_v_has_flags; __Pyx_INCREF(__pyx_t_11);
    __pyx_t_12 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_11);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1363, __pyx_L1_error)
        #endif
        if (__pyx_t_12 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_7 = PyList_GET_ITEM(__pyx_t_11, __pyx_t_12); __Pyx_INCREF(__pyx_t_7); __pyx_t_12++; if (unlikely((0 < 0))) __PYX_ERR(0, 1363, __pyx_L1_error)
      #else
      __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_11, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1363, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
        PyObject* sequence = __pyx_t_7;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1363, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_9 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_9 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        #else
        __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        #endif
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_10 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1363, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
        index = 0; __pyx_t_4 = __pyx_t_13(__pyx_t_10); if (unlikely(!__pyx_t_4)) goto __pyx_L25_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        index = 1; __pyx_t_8 = __pyx_t_13(__pyx_t_10); if (unlikely(!__pyx_t_8)) goto __pyx_L25_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        index = 2; __pyx_t_9 = __pyx_t_13(__pyx_t_10); if (unlikely(!__pyx_t_9)) goto __pyx_L25_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_10), 3) < 0) __PYX_ERR(0, 1363, __pyx_L1_error)
        __pyx_t_13 = NULL;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L26_unpacking_done;
        __pyx_L25_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_13 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1363, __pyx_L1_error)
        __pyx_L26_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_flag, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "class-sz/python/classy.pyx":1364
 *                 raise CosmoSevereError(self.sp.error_message)
 *             for flag, index, name in has_flags:
 *                 if name in spectra:             # <<<<<<<<<<<<<<
 *                     cl[name][ell] = rcl[index]
 *         cl['ell'] = np.arange(lmax+1)
 */
      __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1364, __pyx_L1_error)
      if (__pyx_t_16) {

        /* "class-sz/python/classy.pyx":1365
 *             for flag, index, name in has_flags:
 *                 if name in spectra:
 *                     cl[name][ell] = rcl[index]             # <<<<<<<<<<<<<<
 *         cl['ell'] = np.arange(lmax+1)
 * 
 */
        __pyx_t_19 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index); if (unlikely((__pyx_t_19 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1365, __pyx_L1_error)
        __pyx_t_7 = PyFloat_FromDouble((__pyx_v_rcl[__pyx_t_19])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1365, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_v_name); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1365, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (unlikely((__Pyx_SetItemInt(__pyx_t_9, __pyx_v_ell, __pyx_t_7, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 1365, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "class-sz/python/classy.pyx":1364
 *                 raise CosmoSevereError(self.sp.error_message)
 *             for flag, index, name in has_flags:
 *                 if name in spectra:             # <<<<<<<<<<<<<<
 *                     cl[name][ell] = rcl[index]
 *         cl['ell'] = np.arange(lmax+1)
 */
      }

      /* "class-sz/python/classy.pyx":1363
 *             if spectra_cl_at_l(&self.sp, ell, rcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)
 *             for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *                 if name in spectra:
 *                     cl[name][ell] = rcl[index]
 */
    }
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }

  /* "class-sz/python/classy.pyx":1366
 *                 if name in spectra:
 *                     cl[name][ell] = rcl[index]
 *         cl['ell'] = np.arange(lmax+1)             # <<<<<<<<<<<<<<
 * 
 *         free(rcl)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_arange); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_17 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_17 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
    __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1366, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_11) < 0))) __PYX_ERR(0, 1366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "class-sz/python/classy.pyx":1368
 *         cl['ell'] = np.arange(lmax+1)
 * 
 *         free(rcl)             # <<<<<<<<<<<<<<
 *         for index_md in range(self.sp.md_size):
 *             free(cl_md[index_md])
 */
  free(__pyx_v_rcl);

  /* "class-sz/python/classy.pyx":1369
 * 
 *         free(rcl)
 *         for index_md in range(self.sp.md_size):             # <<<<<<<<<<<<<<
 *             free(cl_md[index_md])
 *             free(cl_md_ic[index_md])
 */
  __pyx_t_1 = __pyx_v_self->sp.md_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_index_md = __pyx_t_3;

    /* "class-sz/python/classy.pyx":1370
 *         free(rcl)
 *         for index_md in range(self.sp.md_size):
 *             free(cl_md[index_md])             # <<<<<<<<<<<<<<
 *             free(cl_md_ic[index_md])
 *         free(cl_md)
 */
    free((__pyx_v_cl_md[__pyx_v_index_md]));

    /* "class-sz/python/classy.pyx":1371
 *         for index_md in range(self.sp.md_size):
 *             free(cl_md[index_md])
 *             free(cl_md_ic[index_md])             # <<<<<<<<<<<<<<
 *         free(cl_md)
 *         free(cl_md_ic)
 */
    free((__pyx_v_cl_md_ic[__pyx_v_index_md]));
  }

  /* "class-sz/python/classy.pyx":1372
 *             free(cl_md[index_md])
 *             free(cl_md_ic[index_md])
 *         free(cl_md)             # <<<<<<<<<<<<<<
 *         free(cl_md_ic)
 * 
 */
  free(__pyx_v_cl_md);

  /* "class-sz/python/classy.pyx":1373
 *             free(cl_md_ic[index_md])
 *         free(cl_md)
 *         free(cl_md_ic)             # <<<<<<<<<<<<<<
 * 
 *         return cl
 */
  free(__pyx_v_cl_md_ic);

  /* "class-sz/python/classy.pyx":1375
 *         free(cl_md_ic)
 * 
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def lensed_cl(self, lmax=-1,nofail=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1287
 * 
 * 
 *     def raw_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         raw_cl(lmax=-1, nofail=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("classy_sz.Class.raw_cl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_has_flags);
  __Pyx_XDECREF(__pyx_v_spectra);
  __Pyx_XDECREF(__pyx_v_flag);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XDECREF(__pyx_v_elem);
  __Pyx_XDECREF(__pyx_v_lmax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1377
 *         return cl
 * 
 *     def lensed_cl(self, lmax=-1,nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         lensed_cl(lmax=-1, nofail=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_31lensed_cl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_30lensed_cl, "\n        lensed_cl(lmax=-1, nofail=False)\n\n        Return a dictionary of the lensed C_l, computed by CLASS, without the\n        density C_ls. They must be asked separately with the function aptly\n        named density_cl\n\n        Parameters\n        ----------\n        lmax : int, optional\n                Define the maximum l for which the C_l will be returned (inclusively)\n        nofail: bool, optional\n                Check and enforce the computation of the lensing module beforehand\n\n        Returns\n        -------\n        cl : dict\n                Dictionary that contains the power spectrum for 'tt', 'te', etc... The\n                index associated with each is defined wrt. Class convention, and are non\n                important from the python point of view.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_31lensed_cl = {"lensed_cl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_31lensed_cl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_30lensed_cl};
static PyObject *__pyx_pw_9classy_sz_5Class_31lensed_cl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_lmax = 0;
  PyObject *__pyx_v_nofail = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lensed_cl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lmax,&__pyx_n_s_nofail,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lmax);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1377, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nofail);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1377, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lensed_cl") < 0)) __PYX_ERR(0, 1377, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_lmax = values[0];
    __pyx_v_nofail = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lensed_cl", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 1377, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.lensed_cl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_30lensed_cl(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_lmax, __pyx_v_nofail);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_30lensed_cl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_lmax, PyObject *__pyx_v_nofail) {
  int __pyx_v_lmaxR;
  double *__pyx_v_lcl;
  PyObject *__pyx_v_cls = NULL;
  PyObject *__pyx_v_nl = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_lcp = NULL;
  PyObject *__pyx_v_has_flags = NULL;
  PyObject *__pyx_v_spectra = NULL;
  PyObject *__pyx_v_flag = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_cl = NULL;
  PyObject *__pyx_v_elem = NULL;
  long __pyx_v_ell;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  long __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lensed_cl", 0);
  __Pyx_INCREF(__pyx_v_lmax);

  /* "class-sz/python/classy.pyx":1400
 *         """
 *         cdef int lmaxR
 *         cdef double *lcl = <double*> calloc(self.le.lt_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:
 */
  __pyx_v_lcl = ((double *)calloc(__pyx_v_self->le.lt_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":1402
 *         cdef double *lcl = <double*> calloc(self.le.lt_size,sizeof(double))
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           # bypass all together and replace by cosmopower call.
 *           cls = {}
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":1404
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           # bypass all together and replace by cosmopower call.
 *           cls = {}             # <<<<<<<<<<<<<<
 *           cls['ell'] = np.arange(20000)
 *           cls['tt'] = np.zeros(20000)
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_cls = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1405
 *           # bypass all together and replace by cosmopower call.
 *           cls = {}
 *           cls['ell'] = np.arange(20000)             # <<<<<<<<<<<<<<
 *           cls['tt'] = np.zeros(20000)
 *           cls['te'] = np.zeros(20000)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_arange); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_int_20000};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1405, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_cls, __pyx_n_u_ell, __pyx_t_2) < 0))) __PYX_ERR(0, 1405, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1406
 *           cls = {}
 *           cls['ell'] = np.arange(20000)
 *           cls['tt'] = np.zeros(20000)             # <<<<<<<<<<<<<<
 *           cls['te'] = np.zeros(20000)
 *           cls['ee'] = np.zeros(20000)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_int_20000};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1406, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_cls, __pyx_n_u_tt, __pyx_t_2) < 0))) __PYX_ERR(0, 1406, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1407
 *           cls['ell'] = np.arange(20000)
 *           cls['tt'] = np.zeros(20000)
 *           cls['te'] = np.zeros(20000)             # <<<<<<<<<<<<<<
 *           cls['ee'] = np.zeros(20000)
 *           cls['pp'] = np.zeros(20000)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_int_20000};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1407, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_cls, __pyx_n_u_te, __pyx_t_2) < 0))) __PYX_ERR(0, 1407, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1408
 *           cls['tt'] = np.zeros(20000)
 *           cls['te'] = np.zeros(20000)
 *           cls['ee'] = np.zeros(20000)             # <<<<<<<<<<<<<<
 *           cls['pp'] = np.zeros(20000)
 *           cls['bb'] = np.zeros(20000)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_int_20000};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1408, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_cls, __pyx_n_u_ee, __pyx_t_2) < 0))) __PYX_ERR(0, 1408, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1409
 *           cls['te'] = np.zeros(20000)
 *           cls['ee'] = np.zeros(20000)
 *           cls['pp'] = np.zeros(20000)             # <<<<<<<<<<<<<<
 *           cls['bb'] = np.zeros(20000)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_int_20000};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1409, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_cls, __pyx_n_u_pp, __pyx_t_2) < 0))) __PYX_ERR(0, 1409, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1410
 *           cls['ee'] = np.zeros(20000)
 *           cls['pp'] = np.zeros(20000)
 *           cls['bb'] = np.zeros(20000)             # <<<<<<<<<<<<<<
 * 
 *           nl = len(self.class_szfast.cp_predicted_tt_spectrum)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_int_20000};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_cls, __pyx_n_u_bb, __pyx_t_2) < 0))) __PYX_ERR(0, 1410, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1412
 *           cls['bb'] = np.zeros(20000)
 * 
 *           nl = len(self.class_szfast.cp_predicted_tt_spectrum)             # <<<<<<<<<<<<<<
 *           lcp = np.asarray(cls['ell'][2:nl+2])
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cp_predicted_tt_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1412, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_nl = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1413
 * 
 *           nl = len(self.class_szfast.cp_predicted_tt_spectrum)
 *           lcp = np.asarray(cls['ell'][2:nl+2])             # <<<<<<<<<<<<<<
 * 
 *           cls['tt'][2:nl+2] = self.class_szfast.cp_predicted_tt_spectrum
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_cls, __pyx_n_u_ell); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_nl, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetSlice(__pyx_t_3, 2, 0, NULL, &__pyx_t_7, NULL, 1, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1413, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_lcp = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1415
 *           lcp = np.asarray(cls['ell'][2:nl+2])
 * 
 *           cls['tt'][2:nl+2] = self.class_szfast.cp_predicted_tt_spectrum             # <<<<<<<<<<<<<<
 *           # cls['tt'][2:nl+2] *= 1./(lcp*(lcp+1.)/2./np.pi)
 *           cls['te'][2:nl+2] = self.class_szfast.cp_predicted_te_spectrum
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cp_predicted_tt_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_cls, __pyx_n_u_tt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_nl, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_PyObject_SetSlice(__pyx_t_4, __pyx_t_2, 2, 0, NULL, &__pyx_t_8, NULL, 1, 0, 1) < 0) __PYX_ERR(0, 1415, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1417
 *           cls['tt'][2:nl+2] = self.class_szfast.cp_predicted_tt_spectrum
 *           # cls['tt'][2:nl+2] *= 1./(lcp*(lcp+1.)/2./np.pi)
 *           cls['te'][2:nl+2] = self.class_szfast.cp_predicted_te_spectrum             # <<<<<<<<<<<<<<
 *           # cls['te'][2:nl+2] *= 1./(lcp*(lcp+1.)/2./np.pi)
 *           cls['ee'][2:nl+2] = self.class_szfast.cp_predicted_ee_spectrum
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cp_predicted_te_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cls, __pyx_n_u_te); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_nl, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_PyObject_SetSlice(__pyx_t_8, __pyx_t_2, 2, 0, NULL, &__pyx_t_4, NULL, 1, 0, 1) < 0) __PYX_ERR(0, 1417, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1419
 *           cls['te'][2:nl+2] = self.class_szfast.cp_predicted_te_spectrum
 *           # cls['te'][2:nl+2] *= 1./(lcp*(lcp+1.)/2./np.pi)
 *           cls['ee'][2:nl+2] = self.class_szfast.cp_predicted_ee_spectrum             # <<<<<<<<<<<<<<
 *           # cls['ee'][2:nl+2] *= 1./(lcp*(lcp+1.)/2./np.pi)
 *           # cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum/4. ## this is clkk... works for so lensinglite lkl
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cp_predicted_ee_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_cls, __pyx_n_u_ee); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_nl, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1419, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_PyObject_SetSlice(__pyx_t_4, __pyx_t_2, 2, 0, NULL, &__pyx_t_8, NULL, 1, 0, 1) < 0) __PYX_ERR(0, 1419, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1422
 *           # cls['ee'][2:nl+2] *= 1./(lcp*(lcp+1.)/2./np.pi)
 *           # cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum/4. ## this is clkk... works for so lensinglite lkl
 *           if self._pars['skip_input'] == 0:             # <<<<<<<<<<<<<<
 *             if self.tsz.want_pp:
 *               cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_skip_input); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1422, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":1423
 *           # cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum/4. ## this is clkk... works for so lensinglite lkl
 *           if self._pars['skip_input'] == 0:
 *             if self.tsz.want_pp:             # <<<<<<<<<<<<<<
 *               cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.
 *           else:
 */
      __pyx_t_1 = (__pyx_v_self->tsz.want_pp != 0);
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":1424
 *           if self._pars['skip_input'] == 0:
 *             if self.tsz.want_pp:
 *               cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.             # <<<<<<<<<<<<<<
 *           else:
 *             cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cp_predicted_pp_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1424, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cls, __pyx_n_u_pp); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1424, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_nl, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1424, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_PyObject_SetSlice(__pyx_t_8, __pyx_t_2, 2, 0, NULL, &__pyx_t_4, NULL, 1, 0, 1) < 0) __PYX_ERR(0, 1424, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "class-sz/python/classy.pyx":1423
 *           # cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum/4. ## this is clkk... works for so lensinglite lkl
 *           if self._pars['skip_input'] == 0:
 *             if self.tsz.want_pp:             # <<<<<<<<<<<<<<
 *               cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.
 *           else:
 */
      }

      /* "class-sz/python/classy.pyx":1422
 *           # cls['ee'][2:nl+2] *= 1./(lcp*(lcp+1.)/2./np.pi)
 *           # cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum/4. ## this is clkk... works for so lensinglite lkl
 *           if self._pars['skip_input'] == 0:             # <<<<<<<<<<<<<<
 *             if self.tsz.want_pp:
 *               cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.
 */
      goto __pyx_L4;
    }

    /* "class-sz/python/classy.pyx":1426
 *               cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.
 *           else:
 *             cls['pp'][2:nl+2] = self.class_szfast.cp_predicted_pp_spectrum # /(lcp*(lcp+1.))**2.             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cp_predicted_pp_spectrum); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1426, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_cls, __pyx_n_u_pp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1426, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_nl, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1426, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_PyObject_SetSlice(__pyx_t_4, __pyx_t_2, 2, 0, NULL, &__pyx_t_8, NULL, 1, 0, 1) < 0) __PYX_ERR(0, 1426, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L4:;

    /* "class-sz/python/classy.pyx":1429
 * 
 * 
 *           free(lcl)             # <<<<<<<<<<<<<<
 *           return cls
 *         else:
 */
    free(__pyx_v_lcl);

    /* "class-sz/python/classy.pyx":1430
 * 
 *           free(lcl)
 *           return cls             # <<<<<<<<<<<<<<
 *         else:
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_cls);
    __pyx_r = __pyx_v_cls;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":1402
 *         cdef double *lcl = <double*> calloc(self.le.lt_size,sizeof(double))
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           # bypass all together and replace by cosmopower call.
 *           cls = {}
 */
  }

  /* "class-sz/python/classy.pyx":1436
 *           # possible output Cl. It allows for a clear and concise way of looping
 *           # over them, checking if they are defined or not.
 *           has_flags = [             # <<<<<<<<<<<<<<
 *               (self.le.has_tt, self.le.index_lt_tt, 'tt'),
 *               (self.le.has_ee, self.le.index_lt_ee, 'ee'),
 */
  /*else*/ {

    /* "class-sz/python/classy.pyx":1437
 *           # over them, checking if they are defined or not.
 *           has_flags = [
 *               (self.le.has_tt, self.le.index_lt_tt, 'tt'),             # <<<<<<<<<<<<<<
 *               (self.le.has_ee, self.le.index_lt_ee, 'ee'),
 *               (self.le.has_te, self.le.index_lt_te, 'te'),
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->le.has_tt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->le.index_lt_tt); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 1437, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_8)) __PYX_ERR(0, 1437, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_u_tt);
    __Pyx_GIVEREF(__pyx_n_u_tt);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_n_u_tt)) __PYX_ERR(0, 1437, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":1438
 *           has_flags = [
 *               (self.le.has_tt, self.le.index_lt_tt, 'tt'),
 *               (self.le.has_ee, self.le.index_lt_ee, 'ee'),             # <<<<<<<<<<<<<<
 *               (self.le.has_te, self.le.index_lt_te, 'te'),
 *               (self.le.has_bb, self.le.index_lt_bb, 'bb'),
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->le.has_ee); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->le.index_lt_ee); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8)) __PYX_ERR(0, 1438, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_2)) __PYX_ERR(0, 1438, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_u_ee);
    __Pyx_GIVEREF(__pyx_n_u_ee);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_n_u_ee)) __PYX_ERR(0, 1438, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1439
 *               (self.le.has_tt, self.le.index_lt_tt, 'tt'),
 *               (self.le.has_ee, self.le.index_lt_ee, 'ee'),
 *               (self.le.has_te, self.le.index_lt_te, 'te'),             # <<<<<<<<<<<<<<
 *               (self.le.has_bb, self.le.index_lt_bb, 'bb'),
 *               (self.le.has_pp, self.le.index_lt_pp, 'pp'),
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->le.has_te); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->le.index_lt_te); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 1439, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_8)) __PYX_ERR(0, 1439, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_u_te);
    __Pyx_GIVEREF(__pyx_n_u_te);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_n_u_te)) __PYX_ERR(0, 1439, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":1440
 *               (self.le.has_ee, self.le.index_lt_ee, 'ee'),
 *               (self.le.has_te, self.le.index_lt_te, 'te'),
 *               (self.le.has_bb, self.le.index_lt_bb, 'bb'),             # <<<<<<<<<<<<<<
 *               (self.le.has_pp, self.le.index_lt_pp, 'pp'),
 *               (self.le.has_tp, self.le.index_lt_tp, 'tp'),]
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->le.has_bb); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->le.index_lt_bb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8)) __PYX_ERR(0, 1440, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_2)) __PYX_ERR(0, 1440, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_u_bb);
    __Pyx_GIVEREF(__pyx_n_u_bb);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_n_u_bb)) __PYX_ERR(0, 1440, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1441
 *               (self.le.has_te, self.le.index_lt_te, 'te'),
 *               (self.le.has_bb, self.le.index_lt_bb, 'bb'),
 *               (self.le.has_pp, self.le.index_lt_pp, 'pp'),             # <<<<<<<<<<<<<<
 *               (self.le.has_tp, self.le.index_lt_tp, 'tp'),]
 *           spectra = []
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->le.has_pp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->le.index_lt_pp); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2)) __PYX_ERR(0, 1441, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_8)) __PYX_ERR(0, 1441, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_u_pp);
    __Pyx_GIVEREF(__pyx_n_u_pp);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_n_u_pp)) __PYX_ERR(0, 1441, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":1442
 *               (self.le.has_bb, self.le.index_lt_bb, 'bb'),
 *               (self.le.has_pp, self.le.index_lt_pp, 'pp'),
 *               (self.le.has_tp, self.le.index_lt_tp, 'tp'),]             # <<<<<<<<<<<<<<
 *           spectra = []
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_self->le.has_tp); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->le.index_lt_tp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = PyTuple_New(3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8)) __PYX_ERR(0, 1442, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_2)) __PYX_ERR(0, 1442, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_u_tp);
    __Pyx_GIVEREF(__pyx_n_u_tp);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_n_u_tp)) __PYX_ERR(0, 1442, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1436
 *           # possible output Cl. It allows for a clear and concise way of looping
 *           # over them, checking if they are defined or not.
 *           has_flags = [             # <<<<<<<<<<<<<<
 *               (self.le.has_tt, self.le.index_lt_tt, 'tt'),
 *               (self.le.has_ee, self.le.index_lt_ee, 'ee'),
 */
    __pyx_t_2 = PyList_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1436, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_4)) __PYX_ERR(0, 1436, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_7);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_t_7)) __PYX_ERR(0, 1436, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_t_3)) __PYX_ERR(0, 1436, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_t_9)) __PYX_ERR(0, 1436, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_10);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_t_10)) __PYX_ERR(0, 1436, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_11);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_t_11)) __PYX_ERR(0, 1436, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_7 = 0;
    __pyx_t_3 = 0;
    __pyx_t_9 = 0;
    __pyx_t_10 = 0;
    __pyx_t_11 = 0;
    __pyx_v_has_flags = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1443
 *               (self.le.has_pp, self.le.index_lt_pp, 'pp'),
 *               (self.le.has_tp, self.le.index_lt_tp, 'tp'),]
 *           spectra = []             # <<<<<<<<<<<<<<
 * 
 *           for flag, index, name in has_flags:
 */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_spectra = ((PyObject*)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1445
 *           spectra = []
 * 
 *           for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *               if flag:
 *                   spectra.append(name)
 */
    __pyx_t_2 = __pyx_v_has_flags; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1445, __pyx_L1_error)
        #endif
        if (__pyx_t_6 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_11 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_11); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1445, __pyx_L1_error)
      #else
      __pyx_t_11 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1445, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      #endif
      if ((likely(PyTuple_CheckExact(__pyx_t_11))) || (PyList_CheckExact(__pyx_t_11))) {
        PyObject* sequence = __pyx_t_11;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 1445, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_10 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_10 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_3);
        #else
        __pyx_t_10 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1445, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1445, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_3 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1445, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1445, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
        index = 0; __pyx_t_10 = __pyx_t_12(__pyx_t_7); if (unlikely(!__pyx_t_10)) goto __pyx_L8_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_10);
        index = 1; __pyx_t_9 = __pyx_t_12(__pyx_t_7); if (unlikely(!__pyx_t_9)) goto __pyx_L8_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_9);
        index = 2; __pyx_t_3 = __pyx_t_12(__pyx_t_7); if (unlikely(!__pyx_t_3)) goto __pyx_L8_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_7), 3) < 0) __PYX_ERR(0, 1445, __pyx_L1_error)
        __pyx_t_12 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L9_unpacking_done;
        __pyx_L8_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_12 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 1445, __pyx_L1_error)
        __pyx_L9_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_flag, __pyx_t_10);
      __pyx_t_10 = 0;
      __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1446
 * 
 *           for flag, index, name in has_flags:
 *               if flag:             # <<<<<<<<<<<<<<
 *                   spectra.append(name)
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1446, __pyx_L1_error)
      if (__pyx_t_1) {

        /* "class-sz/python/classy.pyx":1447
 *           for flag, index, name in has_flags:
 *               if flag:
 *                   spectra.append(name)             # <<<<<<<<<<<<<<
 * 
 *           if not spectra:
 */
        __pyx_t_13 = __Pyx_PyList_Append(__pyx_v_spectra, __pyx_v_name); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 1447, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1446
 * 
 *           for flag, index, name in has_flags:
 *               if flag:             # <<<<<<<<<<<<<<
 *                   spectra.append(name)
 * 
 */
      }

      /* "class-sz/python/classy.pyx":1445
 *           spectra = []
 * 
 *           for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *               if flag:
 *                   spectra.append(name)
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1449
 *                   spectra.append(name)
 * 
 *           if not spectra:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No lensed Cl computed")
 *           lmaxR = self.le.l_lensed_max
 */
    __pyx_t_1 = (PyList_GET_SIZE(__pyx_v_spectra) != 0);
    __pyx_t_14 = (!__pyx_t_1);
    if (unlikely(__pyx_t_14)) {

      /* "class-sz/python/classy.pyx":1450
 * 
 *           if not spectra:
 *               raise CosmoSevereError("No lensed Cl computed")             # <<<<<<<<<<<<<<
 *           lmaxR = self.le.l_lensed_max
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_No_lensed_Cl_computed};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1450, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 1450, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1449
 *                   spectra.append(name)
 * 
 *           if not spectra:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No lensed Cl computed")
 *           lmaxR = self.le.l_lensed_max
 */
    }

    /* "class-sz/python/classy.pyx":1451
 *           if not spectra:
 *               raise CosmoSevereError("No lensed Cl computed")
 *           lmaxR = self.le.l_lensed_max             # <<<<<<<<<<<<<<
 * 
 *           if lmax == -1:
 */
    __pyx_t_15 = __pyx_v_self->le.l_lensed_max;
    __pyx_v_lmaxR = __pyx_t_15;

    /* "class-sz/python/classy.pyx":1453
 *           lmaxR = self.le.l_lensed_max
 * 
 *           if lmax == -1:             # <<<<<<<<<<<<<<
 *               lmax = lmaxR
 *           if lmax > lmaxR:
 */
    __pyx_t_14 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_lmax, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 1453, __pyx_L1_error)
    if (__pyx_t_14) {

      /* "class-sz/python/classy.pyx":1454
 * 
 *           if lmax == -1:
 *               lmax = lmaxR             # <<<<<<<<<<<<<<
 *           if lmax > lmaxR:
 *               if nofail:
 */
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_lmax, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":1453
 *           lmaxR = self.le.l_lensed_max
 * 
 *           if lmax == -1:             # <<<<<<<<<<<<<<
 *               lmax = lmaxR
 *           if lmax > lmaxR:
 */
    }

    /* "class-sz/python/classy.pyx":1455
 *           if lmax == -1:
 *               lmax = lmaxR
 *           if lmax > lmaxR:             # <<<<<<<<<<<<<<
 *               if nofail:
 *                   self._pars_check("l_max_scalars",lmax)
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = PyObject_RichCompare(__pyx_v_lmax, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_14) {

      /* "class-sz/python/classy.pyx":1456
 *               lmax = lmaxR
 *           if lmax > lmaxR:
 *               if nofail:             # <<<<<<<<<<<<<<
 *                   self._pars_check("l_max_scalars",lmax)
 *                   self.compute(["lensing"])
 */
      __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_v_nofail); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 1456, __pyx_L1_error)
      if (likely(__pyx_t_14)) {

        /* "class-sz/python/classy.pyx":1457
 *           if lmax > lmaxR:
 *               if nofail:
 *                   self._pars_check("l_max_scalars",lmax)             # <<<<<<<<<<<<<<
 *                   self.compute(["lensing"])
 *               else:
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pars_check); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1457, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_n_u_l_max_scalars, __pyx_v_lmax};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1457, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "class-sz/python/classy.pyx":1458
 *               if nofail:
 *                   self._pars_check("l_max_scalars",lmax)
 *                   self.compute(["lensing"])             # <<<<<<<<<<<<<<
 *               else:
 *                   raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_n_u_lensing);
        __Pyx_GIVEREF(__pyx_n_u_lensing);
        if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_lensing)) __PYX_ERR(0, 1458, __pyx_L1_error);
        __pyx_t_9 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_3};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1458, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "class-sz/python/classy.pyx":1456
 *               lmax = lmaxR
 *           if lmax > lmaxR:
 *               if nofail:             # <<<<<<<<<<<<<<
 *                   self._pars_check("l_max_scalars",lmax)
 *                   self.compute(["lensing"])
 */
        goto __pyx_L15;
      }

      /* "class-sz/python/classy.pyx":1460
 *                   self.compute(["lensing"])
 *               else:
 *                   raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)             # <<<<<<<<<<<<<<
 * 
 *           cl = {}
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1460, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1460, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_9 = PyUnicode_Format(__pyx_kp_u_Can_only_compute_up_to_lmax_d, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1460, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_9};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1460, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_Raise(__pyx_t_11, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __PYX_ERR(0, 1460, __pyx_L1_error)
      }
      __pyx_L15:;

      /* "class-sz/python/classy.pyx":1455
 *           if lmax == -1:
 *               lmax = lmaxR
 *           if lmax > lmaxR:             # <<<<<<<<<<<<<<
 *               if nofail:
 *                   self._pars_check("l_max_scalars",lmax)
 */
    }

    /* "class-sz/python/classy.pyx":1462
 *                   raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)
 * 
 *           cl = {}             # <<<<<<<<<<<<<<
 *           # Simple Cls, for temperature and polarisation, are not so big in size
 *           for elem in spectra:
 */
    __pyx_t_11 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1462, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_v_cl = ((PyObject*)__pyx_t_11);
    __pyx_t_11 = 0;

    /* "class-sz/python/classy.pyx":1464
 *           cl = {}
 *           # Simple Cls, for temperature and polarisation, are not so big in size
 *           for elem in spectra:             # <<<<<<<<<<<<<<
 *               cl[elem] = np.zeros(lmax+1, dtype=np.double)
 *           for ell from 2<=ell<lmax+1:
 */
    __pyx_t_11 = __pyx_v_spectra; __Pyx_INCREF(__pyx_t_11);
    __pyx_t_6 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_11);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1464, __pyx_L1_error)
        #endif
        if (__pyx_t_6 >= __pyx_temp) break;
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_11, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1464, __pyx_L1_error)
      #else
      __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_11, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1464, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_elem, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":1465
 *           # Simple Cls, for temperature and polarisation, are not so big in size
 *           for elem in spectra:
 *               cl[elem] = np.zeros(lmax+1, dtype=np.double)             # <<<<<<<<<<<<<<
 *           for ell from 2<=ell<lmax+1:
 *               if lensing_cl_at_l(&self.le,ell,lcl) == _FAILURE_:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 1465, __pyx_L1_error);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_np); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_double); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_v_elem, __pyx_t_7) < 0))) __PYX_ERR(0, 1465, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":1464
 *           cl = {}
 *           # Simple Cls, for temperature and polarisation, are not so big in size
 *           for elem in spectra:             # <<<<<<<<<<<<<<
 *               cl[elem] = np.zeros(lmax+1, dtype=np.double)
 *           for ell from 2<=ell<lmax+1:
 */
    }
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "class-sz/python/classy.pyx":1466
 *           for elem in spectra:
 *               cl[elem] = np.zeros(lmax+1, dtype=np.double)
 *           for ell from 2<=ell<lmax+1:             # <<<<<<<<<<<<<<
 *               if lensing_cl_at_l(&self.le,ell,lcl) == _FAILURE_:
 *                   raise CosmoSevereError(self.le.error_message)
 */
    __pyx_t_11 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_16 = __Pyx_PyInt_As_long(__pyx_t_11); if (unlikely((__pyx_t_16 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1466, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    for (__pyx_v_ell = 2; __pyx_v_ell < __pyx_t_16; __pyx_v_ell++) {

      /* "class-sz/python/classy.pyx":1467
 *               cl[elem] = np.zeros(lmax+1, dtype=np.double)
 *           for ell from 2<=ell<lmax+1:
 *               if lensing_cl_at_l(&self.le,ell,lcl) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.le.error_message)
 *               for flag, index, name in has_flags:
 */
      __pyx_t_14 = (lensing_cl_at_l((&__pyx_v_self->le), __pyx_v_ell, __pyx_v_lcl) == _FAILURE_);
      if (unlikely(__pyx_t_14)) {

        /* "class-sz/python/classy.pyx":1468
 *           for ell from 2<=ell<lmax+1:
 *               if lensing_cl_at_l(&self.le,ell,lcl) == _FAILURE_:
 *                   raise CosmoSevereError(self.le.error_message)             # <<<<<<<<<<<<<<
 *               for flag, index, name in has_flags:
 *                   if name in spectra:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1468, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_self->le.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1468, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1468, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_Raise(__pyx_t_11, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __PYX_ERR(0, 1468, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1467
 *               cl[elem] = np.zeros(lmax+1, dtype=np.double)
 *           for ell from 2<=ell<lmax+1:
 *               if lensing_cl_at_l(&self.le,ell,lcl) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.le.error_message)
 *               for flag, index, name in has_flags:
 */
      }

      /* "class-sz/python/classy.pyx":1469
 *               if lensing_cl_at_l(&self.le,ell,lcl) == _FAILURE_:
 *                   raise CosmoSevereError(self.le.error_message)
 *               for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *                   if name in spectra:
 *                       cl[name][ell] = lcl[index]
 */
      __pyx_t_11 = __pyx_v_has_flags; __Pyx_INCREF(__pyx_t_11);
      __pyx_t_6 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_11);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1469, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_11, __pyx_t_6); __Pyx_INCREF(__pyx_t_7); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1469, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_11, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1469, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
          PyObject* sequence = __pyx_t_7;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 3)) {
            if (size > 3) __Pyx_RaiseTooManyValuesError(3);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1469, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 2); 
          } else {
            __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_9 = PyList_GET_ITEM(sequence, 2); 
          }
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_9);
          #else
          __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1469, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1469, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_9 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1469, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_10 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1469, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10);
          index = 0; __pyx_t_2 = __pyx_t_12(__pyx_t_10); if (unlikely(!__pyx_t_2)) goto __pyx_L24_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          index = 1; __pyx_t_3 = __pyx_t_12(__pyx_t_10); if (unlikely(!__pyx_t_3)) goto __pyx_L24_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          index = 2; __pyx_t_9 = __pyx_t_12(__pyx_t_10); if (unlikely(!__pyx_t_9)) goto __pyx_L24_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_10), 3) < 0) __PYX_ERR(0, 1469, __pyx_L1_error)
          __pyx_t_12 = NULL;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L25_unpacking_done;
          __pyx_L24_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_12 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1469, __pyx_L1_error)
          __pyx_L25_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_flag, __pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "class-sz/python/classy.pyx":1470
 *                   raise CosmoSevereError(self.le.error_message)
 *               for flag, index, name in has_flags:
 *                   if name in spectra:             # <<<<<<<<<<<<<<
 *                       cl[name][ell] = lcl[index]
 *           cl['ell'] = np.arange(lmax+1)
 */
        __pyx_t_14 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(0, 1470, __pyx_L1_error)
        if (__pyx_t_14) {

          /* "class-sz/python/classy.pyx":1471
 *               for flag, index, name in has_flags:
 *                   if name in spectra:
 *                       cl[name][ell] = lcl[index]             # <<<<<<<<<<<<<<
 *           cl['ell'] = np.arange(lmax+1)
 * 
 */
          __pyx_t_17 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index); if (unlikely((__pyx_t_17 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1471, __pyx_L1_error)
          __pyx_t_7 = PyFloat_FromDouble((__pyx_v_lcl[__pyx_t_17])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1471, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_v_name); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1471, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (unlikely((__Pyx_SetItemInt(__pyx_t_9, __pyx_v_ell, __pyx_t_7, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 1471, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "class-sz/python/classy.pyx":1470
 *                   raise CosmoSevereError(self.le.error_message)
 *               for flag, index, name in has_flags:
 *                   if name in spectra:             # <<<<<<<<<<<<<<
 *                       cl[name][ell] = lcl[index]
 *           cl['ell'] = np.arange(lmax+1)
 */
        }

        /* "class-sz/python/classy.pyx":1469
 *               if lensing_cl_at_l(&self.le,ell,lcl) == _FAILURE_:
 *                   raise CosmoSevereError(self.le.error_message)
 *               for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *                   if name in spectra:
 *                       cl[name][ell] = lcl[index]
 */
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }

    /* "class-sz/python/classy.pyx":1472
 *                   if name in spectra:
 *                       cl[name][ell] = lcl[index]
 *           cl['ell'] = np.arange(lmax+1)             # <<<<<<<<<<<<<<
 * 
 *           free(lcl)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_arange); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
      __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_11) < 0))) __PYX_ERR(0, 1472, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "class-sz/python/classy.pyx":1474
 *           cl['ell'] = np.arange(lmax+1)
 * 
 *           free(lcl)             # <<<<<<<<<<<<<<
 *           return cl
 * 
 */
    free(__pyx_v_lcl);

    /* "class-sz/python/classy.pyx":1475
 * 
 *           free(lcl)
 *           return cl             # <<<<<<<<<<<<<<
 * 
 *     def density_cl(self, lmax=-1, nofail=False):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_cl);
    __pyx_r = __pyx_v_cl;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":1377
 *         return cl
 * 
 *     def lensed_cl(self, lmax=-1,nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         lensed_cl(lmax=-1, nofail=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("classy_sz.Class.lensed_cl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cls);
  __Pyx_XDECREF(__pyx_v_nl);
  __Pyx_XDECREF(__pyx_v_lcp);
  __Pyx_XDECREF(__pyx_v_has_flags);
  __Pyx_XDECREF(__pyx_v_spectra);
  __Pyx_XDECREF(__pyx_v_flag);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XDECREF(__pyx_v_elem);
  __Pyx_XDECREF(__pyx_v_lmax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1477
 *           return cl
 * 
 *     def density_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         density_cl(lmax=-1, nofail=False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_33density_cl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_32density_cl, "\n        density_cl(lmax=-1, nofail=False)\n\n        Return a dictionary of the primary C_l for the matter\n\n        Parameters\n        ----------\n        lmax : int, optional\n            Define the maximum l for which the C_l will be returned (inclusively)\n        nofail: bool, optional\n            Check and enforce the computation of the lensing module beforehand\n\n        Returns\n        -------\n        cl : numpy array of numpy.ndarrays\n            Array that contains the list (in this order) of self correlation of\n            1st bin, then successive correlations (set by non_diagonal) to the\n            following bins, then self correlation of 2nd bin, etc. The array\n            starts at index_ct_dd.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_33density_cl = {"density_cl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_33density_cl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_32density_cl};
static PyObject *__pyx_pw_9classy_sz_5Class_33density_cl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_lmax = 0;
  PyObject *__pyx_v_nofail = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("density_cl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_lmax,&__pyx_n_s_nofail,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_lmax);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1477, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nofail);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1477, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "density_cl") < 0)) __PYX_ERR(0, 1477, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_lmax = values[0];
    __pyx_v_nofail = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("density_cl", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 1477, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.density_cl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_32density_cl(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_lmax, __pyx_v_nofail);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_32density_cl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_lmax, PyObject *__pyx_v_nofail) {
  int __pyx_v_lmaxR;
  double *__pyx_v_dcl;
  double **__pyx_v_cl_md;
  int __pyx_v_index_md;
  double **__pyx_v_cl_md_ic;
  PyObject *__pyx_v_has_flags = NULL;
  PyObject *__pyx_v_spectra = NULL;
  PyObject *__pyx_v_flag = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_l_max_flag = NULL;
  PyObject *__pyx_v_cl = NULL;
  PyObject *__pyx_v_size = NULL;
  PyObject *__pyx_v_elem = NULL;
  long __pyx_v_ell;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_t_16;
  unsigned int __pyx_t_17;
  PyObject *(*__pyx_t_18)(PyObject *);
  long __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("density_cl", 0);
  __Pyx_INCREF(__pyx_v_lmax);

  /* "class-sz/python/classy.pyx":1499
 *         """
 *         cdef int lmaxR
 *         cdef double *dcl = <double*> calloc(self.sp.ct_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         # Quantities for tensor modes
 */
  __pyx_v_dcl = ((double *)calloc(__pyx_v_self->sp.ct_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":1502
 * 
 *         # Quantities for tensor modes
 *         cdef double **cl_md = <double**> calloc(self.sp.md_size, sizeof(double*))             # <<<<<<<<<<<<<<
 *         for index_md in range(self.sp.md_size):
 *             cl_md[index_md] = <double*> calloc(self.sp.ct_size, sizeof(double))
 */
  __pyx_v_cl_md = ((double **)calloc(__pyx_v_self->sp.md_size, (sizeof(double *))));

  /* "class-sz/python/classy.pyx":1503
 *         # Quantities for tensor modes
 *         cdef double **cl_md = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):             # <<<<<<<<<<<<<<
 *             cl_md[index_md] = <double*> calloc(self.sp.ct_size, sizeof(double))
 * 
 */
  __pyx_t_1 = __pyx_v_self->sp.md_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_index_md = __pyx_t_3;

    /* "class-sz/python/classy.pyx":1504
 *         cdef double **cl_md = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):
 *             cl_md[index_md] = <double*> calloc(self.sp.ct_size, sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         # Quantities for isocurvature modes
 */
    (__pyx_v_cl_md[__pyx_v_index_md]) = ((double *)calloc(__pyx_v_self->sp.ct_size, (sizeof(double))));
  }

  /* "class-sz/python/classy.pyx":1507
 * 
 *         # Quantities for isocurvature modes
 *         cdef double **cl_md_ic = <double**> calloc(self.sp.md_size, sizeof(double*))             # <<<<<<<<<<<<<<
 *         for index_md in range(self.sp.md_size):
 *             cl_md_ic[index_md] = <double*> calloc(self.sp.ct_size*self.sp.ic_ic_size[index_md], sizeof(double))
 */
  __pyx_v_cl_md_ic = ((double **)calloc(__pyx_v_self->sp.md_size, (sizeof(double *))));

  /* "class-sz/python/classy.pyx":1508
 *         # Quantities for isocurvature modes
 *         cdef double **cl_md_ic = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):             # <<<<<<<<<<<<<<
 *             cl_md_ic[index_md] = <double*> calloc(self.sp.ct_size*self.sp.ic_ic_size[index_md], sizeof(double))
 * 
 */
  __pyx_t_1 = __pyx_v_self->sp.md_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_index_md = __pyx_t_3;

    /* "class-sz/python/classy.pyx":1509
 *         cdef double **cl_md_ic = <double**> calloc(self.sp.md_size, sizeof(double*))
 *         for index_md in range(self.sp.md_size):
 *             cl_md_ic[index_md] = <double*> calloc(self.sp.ct_size*self.sp.ic_ic_size[index_md], sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         lmaxR = self.pt.l_lss_max
 */
    (__pyx_v_cl_md_ic[__pyx_v_index_md]) = ((double *)calloc((__pyx_v_self->sp.ct_size * (__pyx_v_self->sp.ic_ic_size[__pyx_v_index_md])), (sizeof(double))));
  }

  /* "class-sz/python/classy.pyx":1511
 *             cl_md_ic[index_md] = <double*> calloc(self.sp.ct_size*self.sp.ic_ic_size[index_md], sizeof(double))
 * 
 *         lmaxR = self.pt.l_lss_max             # <<<<<<<<<<<<<<
 *         has_flags = [
 *             (self.sp.has_dd, self.sp.index_ct_dd, 'dd'),
 */
  __pyx_t_1 = __pyx_v_self->pt.l_lss_max;
  __pyx_v_lmaxR = __pyx_t_1;

  /* "class-sz/python/classy.pyx":1513
 *         lmaxR = self.pt.l_lss_max
 *         has_flags = [
 *             (self.sp.has_dd, self.sp.index_ct_dd, 'dd'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_td, self.sp.index_ct_td, 'td'),
 *             (self.sp.has_ll, self.sp.index_ct_ll, 'll'),
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_dd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_dd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4)) __PYX_ERR(0, 1513, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5)) __PYX_ERR(0, 1513, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_dd);
  __Pyx_GIVEREF(__pyx_n_u_dd);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_dd)) __PYX_ERR(0, 1513, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1514
 *         has_flags = [
 *             (self.sp.has_dd, self.sp.index_ct_dd, 'dd'),
 *             (self.sp.has_td, self.sp.index_ct_td, 'td'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_ll, self.sp.index_ct_ll, 'll'),
 *             (self.sp.has_dl, self.sp.index_ct_dl, 'dl'),
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_td); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_td); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(0, 1514, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_4)) __PYX_ERR(0, 1514, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_td);
  __Pyx_GIVEREF(__pyx_n_u_td);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_n_u_td)) __PYX_ERR(0, 1514, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1515
 *             (self.sp.has_dd, self.sp.index_ct_dd, 'dd'),
 *             (self.sp.has_td, self.sp.index_ct_td, 'td'),
 *             (self.sp.has_ll, self.sp.index_ct_ll, 'll'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_dl, self.sp.index_ct_dl, 'dl'),
 *             (self.sp.has_tl, self.sp.index_ct_tl, 'tl')]
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_ll); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_ll); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4)) __PYX_ERR(0, 1515, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_5)) __PYX_ERR(0, 1515, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_ll);
  __Pyx_GIVEREF(__pyx_n_u_ll);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_n_u_ll)) __PYX_ERR(0, 1515, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1516
 *             (self.sp.has_td, self.sp.index_ct_td, 'td'),
 *             (self.sp.has_ll, self.sp.index_ct_ll, 'll'),
 *             (self.sp.has_dl, self.sp.index_ct_dl, 'dl'),             # <<<<<<<<<<<<<<
 *             (self.sp.has_tl, self.sp.index_ct_tl, 'tl')]
 *         spectra = []
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_dl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_dl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_5)) __PYX_ERR(0, 1516, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_4)) __PYX_ERR(0, 1516, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_dl);
  __Pyx_GIVEREF(__pyx_n_u_dl);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_n_u_dl)) __PYX_ERR(0, 1516, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":1517
 *             (self.sp.has_ll, self.sp.index_ct_ll, 'll'),
 *             (self.sp.has_dl, self.sp.index_ct_dl, 'dl'),
 *             (self.sp.has_tl, self.sp.index_ct_tl, 'tl')]             # <<<<<<<<<<<<<<
 *         spectra = []
 * 
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->sp.has_tl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_tl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(0, 1517, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_5)) __PYX_ERR(0, 1517, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_tl);
  __Pyx_GIVEREF(__pyx_n_u_tl);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_n_u_tl)) __PYX_ERR(0, 1517, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1512
 * 
 *         lmaxR = self.pt.l_lss_max
 *         has_flags = [             # <<<<<<<<<<<<<<
 *             (self.sp.has_dd, self.sp.index_ct_dd, 'dd'),
 *             (self.sp.has_td, self.sp.index_ct_td, 'td'),
 */
  __pyx_t_5 = PyList_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 1512, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 1, __pyx_t_7)) __PYX_ERR(0, 1512, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 2, __pyx_t_8)) __PYX_ERR(0, 1512, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 3, __pyx_t_9)) __PYX_ERR(0, 1512, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 4, __pyx_t_10)) __PYX_ERR(0, 1512, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_v_has_flags = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1518
 *             (self.sp.has_dl, self.sp.index_ct_dl, 'dl'),
 *             (self.sp.has_tl, self.sp.index_ct_tl, 'tl')]
 *         spectra = []             # <<<<<<<<<<<<<<
 * 
 *         for flag, index, name in has_flags:
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_spectra = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1520
 *         spectra = []
 * 
 *         for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *             if flag:
 *                 spectra.append(name)
 */
  __pyx_t_5 = __pyx_v_has_flags; __Pyx_INCREF(__pyx_t_5);
  __pyx_t_11 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1520, __pyx_L1_error)
      #endif
      if (__pyx_t_11 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_10 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_11); __Pyx_INCREF(__pyx_t_10); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1520, __pyx_L1_error)
    #else
    __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    #endif
    if ((likely(PyTuple_CheckExact(__pyx_t_10))) || (PyList_CheckExact(__pyx_t_10))) {
      PyObject* sequence = __pyx_t_10;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1520, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_7 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      #else
      __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1520, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
      index = 0; __pyx_t_9 = __pyx_t_12(__pyx_t_6); if (unlikely(!__pyx_t_9)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_9);
      index = 1; __pyx_t_8 = __pyx_t_12(__pyx_t_6); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      index = 2; __pyx_t_7 = __pyx_t_12(__pyx_t_6); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_6), 3) < 0) __PYX_ERR(0, 1520, __pyx_L1_error)
      __pyx_t_12 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L10_unpacking_done;
      __pyx_L9_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_12 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1520, __pyx_L1_error)
      __pyx_L10_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_flag, __pyx_t_9);
    __pyx_t_9 = 0;
    __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":1521
 * 
 *         for flag, index, name in has_flags:
 *             if flag:             # <<<<<<<<<<<<<<
 *                 spectra.append(name)
 *                 l_max_flag = self.sp.l_max_ct[self.sp.index_md_scalars][index]
 */
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(0, 1521, __pyx_L1_error)
    if (__pyx_t_13) {

      /* "class-sz/python/classy.pyx":1522
 *         for flag, index, name in has_flags:
 *             if flag:
 *                 spectra.append(name)             # <<<<<<<<<<<<<<
 *                 l_max_flag = self.sp.l_max_ct[self.sp.index_md_scalars][index]
 *                 if l_max_flag < lmax and lmax > 0:
 */
      __pyx_t_14 = __Pyx_PyList_Append(__pyx_v_spectra, __pyx_v_name); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 1522, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1523
 *             if flag:
 *                 spectra.append(name)
 *                 l_max_flag = self.sp.l_max_ct[self.sp.index_md_scalars][index]             # <<<<<<<<<<<<<<
 *                 if l_max_flag < lmax and lmax > 0:
 *                     raise CosmoSevereError(
 */
      __pyx_t_15 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index); if (unlikely((__pyx_t_15 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1523, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyInt_From_int(((__pyx_v_self->sp.l_max_ct[__pyx_v_self->sp.index_md_scalars])[__pyx_t_15])); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1523, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_XDECREF_SET(__pyx_v_l_max_flag, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "class-sz/python/classy.pyx":1524
 *                 spectra.append(name)
 *                 l_max_flag = self.sp.l_max_ct[self.sp.index_md_scalars][index]
 *                 if l_max_flag < lmax and lmax > 0:             # <<<<<<<<<<<<<<
 *                     raise CosmoSevereError(
 *                         "the %s spectrum was computed until l=%i " % (
 */
      __pyx_t_10 = PyObject_RichCompare(__pyx_v_l_max_flag, __pyx_v_lmax, Py_LT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (__pyx_t_16) {
      } else {
        __pyx_t_13 = __pyx_t_16;
        goto __pyx_L13_bool_binop_done;
      }
      __pyx_t_10 = PyObject_RichCompare(__pyx_v_lmax, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1524, __pyx_L1_error)
      __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1524, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_13 = __pyx_t_16;
      __pyx_L13_bool_binop_done:;
      if (unlikely(__pyx_t_13)) {

        /* "class-sz/python/classy.pyx":1525
 *                 l_max_flag = self.sp.l_max_ct[self.sp.index_md_scalars][index]
 *                 if l_max_flag < lmax and lmax > 0:
 *                     raise CosmoSevereError(             # <<<<<<<<<<<<<<
 *                         "the %s spectrum was computed until l=%i " % (
 *                             name.upper(), l_max_flag) +
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1525, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "class-sz/python/classy.pyx":1527
 *                     raise CosmoSevereError(
 *                         "the %s spectrum was computed until l=%i " % (
 *                             name.upper(), l_max_flag) +             # <<<<<<<<<<<<<<
 *                         "but you asked a l=%i" % lmax)
 * 
 */
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_name, __pyx_n_s_upper); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = NULL;
        __pyx_t_17 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_17 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_17, 0+__pyx_t_17);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1527, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8)) __PYX_ERR(0, 1527, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_l_max_flag);
        __Pyx_GIVEREF(__pyx_v_l_max_flag);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_l_max_flag)) __PYX_ERR(0, 1527, __pyx_L1_error);
        __pyx_t_8 = 0;

        /* "class-sz/python/classy.pyx":1526
 *                 if l_max_flag < lmax and lmax > 0:
 *                     raise CosmoSevereError(
 *                         "the %s spectrum was computed until l=%i " % (             # <<<<<<<<<<<<<<
 *                             name.upper(), l_max_flag) +
 *                         "but you asked a l=%i" % lmax)
 */
        __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_the_s_spectrum_was_computed_unti, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1526, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "class-sz/python/classy.pyx":1528
 *                         "the %s spectrum was computed until l=%i " % (
 *                             name.upper(), l_max_flag) +
 *                         "but you asked a l=%i" % lmax)             # <<<<<<<<<<<<<<
 * 
 *         if not spectra:
 */
        __pyx_t_9 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_but_you_asked_a_l_i, __pyx_v_lmax); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1528, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);

        /* "class-sz/python/classy.pyx":1527
 *                     raise CosmoSevereError(
 *                         "the %s spectrum was computed until l=%i " % (
 *                             name.upper(), l_max_flag) +             # <<<<<<<<<<<<<<
 *                         "but you asked a l=%i" % lmax)
 * 
 */
        __pyx_t_6 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1527, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = NULL;
        __pyx_t_17 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_17 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_6};
          __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1525, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_Raise(__pyx_t_10, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __PYX_ERR(0, 1525, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1524
 *                 spectra.append(name)
 *                 l_max_flag = self.sp.l_max_ct[self.sp.index_md_scalars][index]
 *                 if l_max_flag < lmax and lmax > 0:             # <<<<<<<<<<<<<<
 *                     raise CosmoSevereError(
 *                         "the %s spectrum was computed until l=%i " % (
 */
      }

      /* "class-sz/python/classy.pyx":1521
 * 
 *         for flag, index, name in has_flags:
 *             if flag:             # <<<<<<<<<<<<<<
 *                 spectra.append(name)
 *                 l_max_flag = self.sp.l_max_ct[self.sp.index_md_scalars][index]
 */
    }

    /* "class-sz/python/classy.pyx":1520
 *         spectra = []
 * 
 *         for flag, index, name in has_flags:             # <<<<<<<<<<<<<<
 *             if flag:
 *                 spectra.append(name)
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1530
 *                         "but you asked a l=%i" % lmax)
 * 
 *         if not spectra:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No density Cl computed")
 *         if lmax == -1:
 */
  __pyx_t_13 = (PyList_GET_SIZE(__pyx_v_spectra) != 0);
  __pyx_t_16 = (!__pyx_t_13);
  if (unlikely(__pyx_t_16)) {

    /* "class-sz/python/classy.pyx":1531
 * 
 *         if not spectra:
 *             raise CosmoSevereError("No density Cl computed")             # <<<<<<<<<<<<<<
 *         if lmax == -1:
 *             lmax = lmaxR
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_7 = NULL;
    __pyx_t_17 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_17 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_kp_u_No_density_Cl_computed};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1531, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 1531, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1530
 *                         "but you asked a l=%i" % lmax)
 * 
 *         if not spectra:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No density Cl computed")
 *         if lmax == -1:
 */
  }

  /* "class-sz/python/classy.pyx":1532
 *         if not spectra:
 *             raise CosmoSevereError("No density Cl computed")
 *         if lmax == -1:             # <<<<<<<<<<<<<<
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 */
  __pyx_t_16 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_lmax, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1532, __pyx_L1_error)
  if (__pyx_t_16) {

    /* "class-sz/python/classy.pyx":1533
 *             raise CosmoSevereError("No density Cl computed")
 *         if lmax == -1:
 *             lmax = lmaxR             # <<<<<<<<<<<<<<
 *         if lmax > lmaxR:
 *             if nofail:
 */
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_lmax, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":1532
 *         if not spectra:
 *             raise CosmoSevereError("No density Cl computed")
 *         if lmax == -1:             # <<<<<<<<<<<<<<
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 */
  }

  /* "class-sz/python/classy.pyx":1534
 *         if lmax == -1:
 *             lmax = lmaxR
 *         if lmax > lmaxR:             # <<<<<<<<<<<<<<
 *             if nofail:
 *                 self._pars_check("l_max_lss",lmax)
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = PyObject_RichCompare(__pyx_v_lmax, __pyx_t_5, Py_GT); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1534, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1534, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__pyx_t_16) {

    /* "class-sz/python/classy.pyx":1535
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 *             if nofail:             # <<<<<<<<<<<<<<
 *                 self._pars_check("l_max_lss",lmax)
 *                 self._pars_check("output",'nCl')
 */
    __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_v_nofail); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1535, __pyx_L1_error)
    if (likely(__pyx_t_16)) {

      /* "class-sz/python/classy.pyx":1536
 *         if lmax > lmaxR:
 *             if nofail:
 *                 self._pars_check("l_max_lss",lmax)             # <<<<<<<<<<<<<<
 *                 self._pars_check("output",'nCl')
 *                 self.compute()
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pars_check); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_n_u_l_max_lss, __pyx_v_lmax};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_17, 2+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1536, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "class-sz/python/classy.pyx":1537
 *             if nofail:
 *                 self._pars_check("l_max_lss",lmax)
 *                 self._pars_check("output",'nCl')             # <<<<<<<<<<<<<<
 *                 self.compute()
 *             else:
 */
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pars_check); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1538
 *                 self._pars_check("l_max_lss",lmax)
 *                 self._pars_check("output",'nCl')
 *                 self.compute()             # <<<<<<<<<<<<<<
 *             else:
 *                 raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)
 */
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1538, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_7 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_17, 0+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1538, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1535
 *             lmax = lmaxR
 *         if lmax > lmaxR:
 *             if nofail:             # <<<<<<<<<<<<<<
 *                 self._pars_check("l_max_lss",lmax)
 *                 self._pars_check("output",'nCl')
 */
      goto __pyx_L19;
    }

    /* "class-sz/python/classy.pyx":1540
 *                 self.compute()
 *             else:
 *                 raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)             # <<<<<<<<<<<<<<
 * 
 *         cl = {}
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_lmaxR); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_Can_only_compute_up_to_lmax_d, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 1540, __pyx_L1_error)
    }
    __pyx_L19:;

    /* "class-sz/python/classy.pyx":1534
 *         if lmax == -1:
 *             lmax = lmaxR
 *         if lmax > lmaxR:             # <<<<<<<<<<<<<<
 *             if nofail:
 *                 self._pars_check("l_max_lss",lmax)
 */
  }

  /* "class-sz/python/classy.pyx":1542
 *                 raise CosmoSevereError("Can only compute up to lmax=%d"%lmaxR)
 * 
 *         cl = {}             # <<<<<<<<<<<<<<
 * 
 *         # For density Cls, the size is bigger (different redshfit bins)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_cl = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1546
 *         # For density Cls, the size is bigger (different redshfit bins)
 *         # computes the size, given the number of correlations needed to be computed
 *         size = int((self.sp.d_size*(self.sp.d_size+1)-(self.sp.d_size-self.sp.non_diag)*             # <<<<<<<<<<<<<<
 *                 (self.sp.d_size-1-self.sp.non_diag))/2);
 *         for elem in ['dd', 'll', 'dl']:
 */
  __pyx_t_5 = __Pyx_PyInt_FromDouble((((double)((__pyx_v_self->sp.d_size * (__pyx_v_self->sp.d_size + 1)) - ((__pyx_v_self->sp.d_size - __pyx_v_self->sp.non_diag) * ((__pyx_v_self->sp.d_size - 1) - __pyx_v_self->sp.non_diag)))) / 2.0)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_size = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1548
 *         size = int((self.sp.d_size*(self.sp.d_size+1)-(self.sp.d_size-self.sp.non_diag)*
 *                 (self.sp.d_size-1-self.sp.non_diag))/2);
 *         for elem in ['dd', 'll', 'dl']:             # <<<<<<<<<<<<<<
 *             if elem in spectra:
 *                 cl[elem] = {}
 */
  __pyx_t_5 = __pyx_tuple__25; __Pyx_INCREF(__pyx_t_5);
  __pyx_t_11 = 0;
  for (;;) {
    if (__pyx_t_11 >= 3) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_11); __Pyx_INCREF(__pyx_t_10); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1548, __pyx_L1_error)
    #else
    __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1548, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_elem, ((PyObject*)__pyx_t_10));
    __pyx_t_10 = 0;

    /* "class-sz/python/classy.pyx":1549
 *                 (self.sp.d_size-1-self.sp.non_diag))/2);
 *         for elem in ['dd', 'll', 'dl']:
 *             if elem in spectra:             # <<<<<<<<<<<<<<
 *                 cl[elem] = {}
 *                 for index in range(size):
 */
    __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_v_elem, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1549, __pyx_L1_error)
    if (__pyx_t_16) {

      /* "class-sz/python/classy.pyx":1550
 *         for elem in ['dd', 'll', 'dl']:
 *             if elem in spectra:
 *                 cl[elem] = {}             # <<<<<<<<<<<<<<
 *                 for index in range(size):
 *                     cl[elem][index] = np.zeros(
 */
      __pyx_t_10 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1550, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_v_elem, __pyx_t_10) < 0))) __PYX_ERR(0, 1550, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "class-sz/python/classy.pyx":1551
 *             if elem in spectra:
 *                 cl[elem] = {}
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl[elem][index] = np.zeros(
 *                         lmax+1, dtype=np.double)
 */
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_size); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (likely(PyList_CheckExact(__pyx_t_10)) || PyTuple_CheckExact(__pyx_t_10)) {
        __pyx_t_6 = __pyx_t_10; __Pyx_INCREF(__pyx_t_6);
        __pyx_t_15 = 0;
        __pyx_t_18 = NULL;
      } else {
        __pyx_t_15 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1551, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_18 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1551, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      for (;;) {
        if (likely(!__pyx_t_18)) {
          if (likely(PyList_CheckExact(__pyx_t_6))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1551, __pyx_L1_error)
              #endif
              if (__pyx_t_15 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_10 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_15); __Pyx_INCREF(__pyx_t_10); __pyx_t_15++; if (unlikely((0 < 0))) __PYX_ERR(0, 1551, __pyx_L1_error)
            #else
            __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1551, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1551, __pyx_L1_error)
              #endif
              if (__pyx_t_15 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_15); __Pyx_INCREF(__pyx_t_10); __pyx_t_15++; if (unlikely((0 < 0))) __PYX_ERR(0, 1551, __pyx_L1_error)
            #else
            __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_15); __pyx_t_15++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1551, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            #endif
          }
        } else {
          __pyx_t_10 = __pyx_t_18(__pyx_t_6);
          if (unlikely(!__pyx_t_10)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1551, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_10);
        }
        __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "class-sz/python/classy.pyx":1552
 *                 cl[elem] = {}
 *                 for index in range(size):
 *                     cl[elem][index] = np.zeros(             # <<<<<<<<<<<<<<
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_np); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1552, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_zeros); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1552, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "class-sz/python/classy.pyx":1553
 *                 for index in range(size):
 *                     cl[elem][index] = np.zeros(
 *                         lmax+1, dtype=np.double)             # <<<<<<<<<<<<<<
 *         for elem in ['td', 'tl']:
 *             if elem in spectra:
 */
        __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1553, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);

        /* "class-sz/python/classy.pyx":1552
 *                 cl[elem] = {}
 *                 for index in range(size):
 *                     cl[elem][index] = np.zeros(             # <<<<<<<<<<<<<<
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:
 */
        __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1552, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_10);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10)) __PYX_ERR(0, 1552, __pyx_L1_error);
        __pyx_t_10 = 0;

        /* "class-sz/python/classy.pyx":1553
 *                 for index in range(size):
 *                     cl[elem][index] = np.zeros(
 *                         lmax+1, dtype=np.double)             # <<<<<<<<<<<<<<
 *         for elem in ['td', 'tl']:
 *             if elem in spectra:
 */
        __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1553, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1553, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_double); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1553, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_dtype, __pyx_t_4) < 0) __PYX_ERR(0, 1553, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "class-sz/python/classy.pyx":1552
 *                 cl[elem] = {}
 *                 for index in range(size):
 *                     cl[elem][index] = np.zeros(             # <<<<<<<<<<<<<<
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1552, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_v_elem); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1552, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (unlikely((PyObject_SetItem(__pyx_t_10, __pyx_v_index, __pyx_t_4) < 0))) __PYX_ERR(0, 1552, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "class-sz/python/classy.pyx":1551
 *             if elem in spectra:
 *                 cl[elem] = {}
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl[elem][index] = np.zeros(
 *                         lmax+1, dtype=np.double)
 */
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":1549
 *                 (self.sp.d_size-1-self.sp.non_diag))/2);
 *         for elem in ['dd', 'll', 'dl']:
 *             if elem in spectra:             # <<<<<<<<<<<<<<
 *                 cl[elem] = {}
 *                 for index in range(size):
 */
    }

    /* "class-sz/python/classy.pyx":1548
 *         size = int((self.sp.d_size*(self.sp.d_size+1)-(self.sp.d_size-self.sp.non_diag)*
 *                 (self.sp.d_size-1-self.sp.non_diag))/2);
 *         for elem in ['dd', 'll', 'dl']:             # <<<<<<<<<<<<<<
 *             if elem in spectra:
 *                 cl[elem] = {}
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1554
 *                     cl[elem][index] = np.zeros(
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:             # <<<<<<<<<<<<<<
 *             if elem in spectra:
 *                 cl[elem] = np.zeros(lmax+1, dtype=np.double)
 */
  __pyx_t_5 = __pyx_tuple__26; __Pyx_INCREF(__pyx_t_5);
  __pyx_t_11 = 0;
  for (;;) {
    if (__pyx_t_11 >= 2) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_11); __Pyx_INCREF(__pyx_t_6); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1554, __pyx_L1_error)
    #else
    __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_elem, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":1555
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:
 *             if elem in spectra:             # <<<<<<<<<<<<<<
 *                 cl[elem] = np.zeros(lmax+1, dtype=np.double)
 * 
 */
    __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_v_elem, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1555, __pyx_L1_error)
    if (__pyx_t_16) {

      /* "class-sz/python/classy.pyx":1556
 *         for elem in ['td', 'tl']:
 *             if elem in spectra:
 *                 cl[elem] = np.zeros(lmax+1, dtype=np.double)             # <<<<<<<<<<<<<<
 * 
 *         for ell from 2<=ell<lmax+1:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_zeros); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_6);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6)) __PYX_ERR(0, 1556, __pyx_L1_error);
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_double); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_10, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_v_elem, __pyx_t_7) < 0))) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":1555
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:
 *             if elem in spectra:             # <<<<<<<<<<<<<<
 *                 cl[elem] = np.zeros(lmax+1, dtype=np.double)
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1554
 *                     cl[elem][index] = np.zeros(
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:             # <<<<<<<<<<<<<<
 *             if elem in spectra:
 *                 cl[elem] = np.zeros(lmax+1, dtype=np.double)
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1558
 *                 cl[elem] = np.zeros(lmax+1, dtype=np.double)
 * 
 *         for ell from 2<=ell<lmax+1:             # <<<<<<<<<<<<<<
 *             if spectra_cl_at_l(&self.sp, ell, dcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)
 */
  __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_19 = __Pyx_PyInt_As_long(__pyx_t_5); if (unlikely((__pyx_t_19 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 1558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  for (__pyx_v_ell = 2; __pyx_v_ell < __pyx_t_19; __pyx_v_ell++) {

    /* "class-sz/python/classy.pyx":1559
 * 
 *         for ell from 2<=ell<lmax+1:
 *             if spectra_cl_at_l(&self.sp, ell, dcl, cl_md, cl_md_ic) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.sp.error_message)
 *             if 'dd' in spectra:
 */
    __pyx_t_16 = (spectra_cl_at_l((&__pyx_v_self->sp), __pyx_v_ell, __pyx_v_dcl, __pyx_v_cl_md, __pyx_v_cl_md_ic) == _FAILURE_);
    if (unlikely(__pyx_t_16)) {

      /* "class-sz/python/classy.pyx":1560
 *         for ell from 2<=ell<lmax+1:
 *             if spectra_cl_at_l(&self.sp, ell, dcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)             # <<<<<<<<<<<<<<
 *             if 'dd' in spectra:
 *                 for index in range(size):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_self->sp.error_message); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = NULL;
      __pyx_t_17 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_17 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1560, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 1560, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1559
 * 
 *         for ell from 2<=ell<lmax+1:
 *             if spectra_cl_at_l(&self.sp, ell, dcl, cl_md, cl_md_ic) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.sp.error_message)
 *             if 'dd' in spectra:
 */
    }

    /* "class-sz/python/classy.pyx":1561
 *             if spectra_cl_at_l(&self.sp, ell, dcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)
 *             if 'dd' in spectra:             # <<<<<<<<<<<<<<
 *                 for index in range(size):
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 */
    __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_dd, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1561, __pyx_L1_error)
    if (__pyx_t_16) {

      /* "class-sz/python/classy.pyx":1562
 *                 raise CosmoSevereError(self.sp.error_message)
 *             if 'dd' in spectra:
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 *             if 'll' in spectra:
 */
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_size); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
        __pyx_t_7 = __pyx_t_5; __Pyx_INCREF(__pyx_t_7);
        __pyx_t_11 = 0;
        __pyx_t_18 = NULL;
      } else {
        __pyx_t_11 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1562, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_18 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1562, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      for (;;) {
        if (likely(!__pyx_t_18)) {
          if (likely(PyList_CheckExact(__pyx_t_7))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1562, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_11); __Pyx_INCREF(__pyx_t_5); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1562, __pyx_L1_error)
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1562, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1562, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_11); __Pyx_INCREF(__pyx_t_5); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1562, __pyx_L1_error)
            #else
            __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1562, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          }
        } else {
          __pyx_t_5 = __pyx_t_18(__pyx_t_7);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1562, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "class-sz/python/classy.pyx":1563
 *             if 'dd' in spectra:
 *                 for index in range(size):
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]             # <<<<<<<<<<<<<<
 *             if 'll' in spectra:
 *                 for index in range(size):
 */
        __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_dd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1563, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PyNumber_Add(__pyx_t_5, __pyx_v_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1563, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_15 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_15 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1563, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyFloat_FromDouble((__pyx_v_dcl[__pyx_t_15])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1563, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_dd); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1563, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_t_5, __pyx_v_index); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1563, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely((__Pyx_SetItemInt(__pyx_t_10, __pyx_v_ell, __pyx_t_6, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 1563, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1562
 *                 raise CosmoSevereError(self.sp.error_message)
 *             if 'dd' in spectra:
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 *             if 'll' in spectra:
 */
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":1561
 *             if spectra_cl_at_l(&self.sp, ell, dcl, cl_md, cl_md_ic) == _FAILURE_:
 *                 raise CosmoSevereError(self.sp.error_message)
 *             if 'dd' in spectra:             # <<<<<<<<<<<<<<
 *                 for index in range(size):
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 */
    }

    /* "class-sz/python/classy.pyx":1564
 *                 for index in range(size):
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 *             if 'll' in spectra:             # <<<<<<<<<<<<<<
 *                 for index in range(size):
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 */
    __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_ll, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1564, __pyx_L1_error)
    if (__pyx_t_16) {

      /* "class-sz/python/classy.pyx":1565
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 *             if 'll' in spectra:
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 *             if 'dl' in spectra:
 */
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_size); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1565, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
        __pyx_t_6 = __pyx_t_7; __Pyx_INCREF(__pyx_t_6);
        __pyx_t_11 = 0;
        __pyx_t_18 = NULL;
      } else {
        __pyx_t_11 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1565, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_18 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1565, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      for (;;) {
        if (likely(!__pyx_t_18)) {
          if (likely(PyList_CheckExact(__pyx_t_6))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1565, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1565, __pyx_L1_error)
            #else
            __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1565, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1565, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1565, __pyx_L1_error)
            #else
            __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1565, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          }
        } else {
          __pyx_t_7 = __pyx_t_18(__pyx_t_6);
          if (unlikely(!__pyx_t_7)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1565, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "class-sz/python/classy.pyx":1566
 *             if 'll' in spectra:
 *                 for index in range(size):
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]             # <<<<<<<<<<<<<<
 *             if 'dl' in spectra:
 *                 for index in range(size):
 */
        __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_ll); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1566, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = PyNumber_Add(__pyx_t_7, __pyx_v_index); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1566, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_15 = __Pyx_PyIndex_AsSsize_t(__pyx_t_10); if (unlikely((__pyx_t_15 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1566, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = PyFloat_FromDouble((__pyx_v_dcl[__pyx_t_15])); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1566, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_7 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ll); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1566, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_7, __pyx_v_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1566, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely((__Pyx_SetItemInt(__pyx_t_5, __pyx_v_ell, __pyx_t_10, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 1566, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "class-sz/python/classy.pyx":1565
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 *             if 'll' in spectra:
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 *             if 'dl' in spectra:
 */
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":1564
 *                 for index in range(size):
 *                     cl['dd'][index][ell] = dcl[self.sp.index_ct_dd+index]
 *             if 'll' in spectra:             # <<<<<<<<<<<<<<
 *                 for index in range(size):
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 */
    }

    /* "class-sz/python/classy.pyx":1567
 *                 for index in range(size):
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 *             if 'dl' in spectra:             # <<<<<<<<<<<<<<
 *                 for index in range(size):
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]
 */
    __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_dl, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1567, __pyx_L1_error)
    if (__pyx_t_16) {

      /* "class-sz/python/classy.pyx":1568
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 *             if 'dl' in spectra:
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]
 *             if 'td' in spectra:
 */
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_size); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
        __pyx_t_10 = __pyx_t_6; __Pyx_INCREF(__pyx_t_10);
        __pyx_t_11 = 0;
        __pyx_t_18 = NULL;
      } else {
        __pyx_t_11 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_18 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_10); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 1568, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      for (;;) {
        if (likely(!__pyx_t_18)) {
          if (likely(PyList_CheckExact(__pyx_t_10))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_10);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1568, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_11); __Pyx_INCREF(__pyx_t_6); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1568, __pyx_L1_error)
            #else
            __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1568, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_10);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1568, __pyx_L1_error)
              #endif
              if (__pyx_t_11 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_11); __Pyx_INCREF(__pyx_t_6); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 1568, __pyx_L1_error)
            #else
            __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1568, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            #endif
          }
        } else {
          __pyx_t_6 = __pyx_t_18(__pyx_t_10);
          if (unlikely(!__pyx_t_6)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1568, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_6);
        }
        __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1569
 *             if 'dl' in spectra:
 *                 for index in range(size):
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]             # <<<<<<<<<<<<<<
 *             if 'td' in spectra:
 *                 cl['td'][ell] = dcl[self.sp.index_ct_td]
 */
        __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->sp.index_ct_dl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = PyNumber_Add(__pyx_t_6, __pyx_v_index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_15 = __Pyx_PyIndex_AsSsize_t(__pyx_t_5); if (unlikely((__pyx_t_15 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 1569, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyFloat_FromDouble((__pyx_v_dcl[__pyx_t_15])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_dl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1569, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely((__Pyx_SetItemInt(__pyx_t_7, __pyx_v_ell, __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 1569, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "class-sz/python/classy.pyx":1568
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 *             if 'dl' in spectra:
 *                 for index in range(size):             # <<<<<<<<<<<<<<
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]
 *             if 'td' in spectra:
 */
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "class-sz/python/classy.pyx":1567
 *                 for index in range(size):
 *                     cl['ll'][index][ell] = dcl[self.sp.index_ct_ll+index]
 *             if 'dl' in spectra:             # <<<<<<<<<<<<<<
 *                 for index in range(size):
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]
 */
    }

    /* "class-sz/python/classy.pyx":1570
 *                 for index in range(size):
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]
 *             if 'td' in spectra:             # <<<<<<<<<<<<<<
 *                 cl['td'][ell] = dcl[self.sp.index_ct_td]
 *             if 'tl' in spectra:
 */
    __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_td, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1570, __pyx_L1_error)
    if (__pyx_t_16) {

      /* "class-sz/python/classy.pyx":1571
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]
 *             if 'td' in spectra:
 *                 cl['td'][ell] = dcl[self.sp.index_ct_td]             # <<<<<<<<<<<<<<
 *             if 'tl' in spectra:
 *                 cl['tl'][ell] = dcl[self.sp.index_ct_tl]
 */
      __pyx_t_10 = PyFloat_FromDouble((__pyx_v_dcl[__pyx_v_self->sp.index_ct_td])); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_td); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1571, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely((__Pyx_SetItemInt(__pyx_t_5, __pyx_v_ell, __pyx_t_10, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 1571, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "class-sz/python/classy.pyx":1570
 *                 for index in range(size):
 *                     cl['dl'][index][ell] = dcl[self.sp.index_ct_dl+index]
 *             if 'td' in spectra:             # <<<<<<<<<<<<<<
 *                 cl['td'][ell] = dcl[self.sp.index_ct_td]
 *             if 'tl' in spectra:
 */
    }

    /* "class-sz/python/classy.pyx":1572
 *             if 'td' in spectra:
 *                 cl['td'][ell] = dcl[self.sp.index_ct_td]
 *             if 'tl' in spectra:             # <<<<<<<<<<<<<<
 *                 cl['tl'][ell] = dcl[self.sp.index_ct_tl]
 *         cl['ell'] = np.arange(lmax+1)
 */
    __pyx_t_16 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_tl, __pyx_v_spectra, Py_EQ)); if (unlikely((__pyx_t_16 < 0))) __PYX_ERR(0, 1572, __pyx_L1_error)
    if (__pyx_t_16) {

      /* "class-sz/python/classy.pyx":1573
 *                 cl['td'][ell] = dcl[self.sp.index_ct_td]
 *             if 'tl' in spectra:
 *                 cl['tl'][ell] = dcl[self.sp.index_ct_tl]             # <<<<<<<<<<<<<<
 *         cl['ell'] = np.arange(lmax+1)
 * 
 */
      __pyx_t_10 = PyFloat_FromDouble((__pyx_v_dcl[__pyx_v_self->sp.index_ct_tl])); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_tl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1573, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely((__Pyx_SetItemInt(__pyx_t_5, __pyx_v_ell, __pyx_t_10, long, 1, __Pyx_PyInt_From_long, 0, 1, 1) < 0))) __PYX_ERR(0, 1573, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "class-sz/python/classy.pyx":1572
 *             if 'td' in spectra:
 *                 cl['td'][ell] = dcl[self.sp.index_ct_td]
 *             if 'tl' in spectra:             # <<<<<<<<<<<<<<
 *                 cl['tl'][ell] = dcl[self.sp.index_ct_tl]
 *         cl['ell'] = np.arange(lmax+1)
 */
    }
  }

  /* "class-sz/python/classy.pyx":1574
 *             if 'tl' in spectra:
 *                 cl['tl'][ell] = dcl[self.sp.index_ct_tl]
 *         cl['ell'] = np.arange(lmax+1)             # <<<<<<<<<<<<<<
 * 
 *         free(dcl)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_arange); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_lmax, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_17 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_17 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_17, 1+__pyx_t_17);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_10) < 0))) __PYX_ERR(0, 1574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "class-sz/python/classy.pyx":1576
 *         cl['ell'] = np.arange(lmax+1)
 * 
 *         free(dcl)             # <<<<<<<<<<<<<<
 *         for index_md in range(self.sp.md_size):
 *             free(cl_md[index_md])
 */
  free(__pyx_v_dcl);

  /* "class-sz/python/classy.pyx":1577
 * 
 *         free(dcl)
 *         for index_md in range(self.sp.md_size):             # <<<<<<<<<<<<<<
 *             free(cl_md[index_md])
 *             free(cl_md_ic[index_md])
 */
  __pyx_t_1 = __pyx_v_self->sp.md_size;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_index_md = __pyx_t_3;

    /* "class-sz/python/classy.pyx":1578
 *         free(dcl)
 *         for index_md in range(self.sp.md_size):
 *             free(cl_md[index_md])             # <<<<<<<<<<<<<<
 *             free(cl_md_ic[index_md])
 *         free(cl_md)
 */
    free((__pyx_v_cl_md[__pyx_v_index_md]));

    /* "class-sz/python/classy.pyx":1579
 *         for index_md in range(self.sp.md_size):
 *             free(cl_md[index_md])
 *             free(cl_md_ic[index_md])             # <<<<<<<<<<<<<<
 *         free(cl_md)
 *         free(cl_md_ic)
 */
    free((__pyx_v_cl_md_ic[__pyx_v_index_md]));
  }

  /* "class-sz/python/classy.pyx":1580
 *             free(cl_md[index_md])
 *             free(cl_md_ic[index_md])
 *         free(cl_md)             # <<<<<<<<<<<<<<
 *         free(cl_md_ic)
 * 
 */
  free(__pyx_v_cl_md);

  /* "class-sz/python/classy.pyx":1581
 *             free(cl_md_ic[index_md])
 *         free(cl_md)
 *         free(cl_md_ic)             # <<<<<<<<<<<<<<
 * 
 *         return cl
 */
  free(__pyx_v_cl_md_ic);

  /* "class-sz/python/classy.pyx":1583
 *         free(cl_md_ic)
 * 
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def z_of_r (self,z_array):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1477
 *           return cl
 * 
 *     def density_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         density_cl(lmax=-1, nofail=False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("classy_sz.Class.density_cl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_has_flags);
  __Pyx_XDECREF(__pyx_v_spectra);
  __Pyx_XDECREF(__pyx_v_flag);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_l_max_flag);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XDECREF(__pyx_v_size);
  __Pyx_XDECREF(__pyx_v_elem);
  __Pyx_XDECREF(__pyx_v_lmax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1585
 *         return cl
 * 
 *     def z_of_r (self,z_array):             # <<<<<<<<<<<<<<
 *         """
 *         returns chi [Mpc] vs dzdchi [1/Mpc]
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_35z_of_r(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_34z_of_r, "\n        returns chi [Mpc] vs dzdchi [1/Mpc]\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_35z_of_r = {"z_of_r", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_35z_of_r, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_34z_of_r};
static PyObject *__pyx_pw_9classy_sz_5Class_35z_of_r(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_array = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("z_of_r (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_array,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_array)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1585, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "z_of_r") < 0)) __PYX_ERR(0, 1585, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z_array = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("z_of_r", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1585, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.z_of_r", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_34z_of_r(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_array);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_34z_of_r(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_array) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_dzdr = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_redshift = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  double __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("z_of_r", 1);

  /* "class-sz/python/classy.pyx":1589
 *         returns chi [Mpc] vs dzdchi [1/Mpc]
 *         """
 *         cdef double tau=0.0             # <<<<<<<<<<<<<<
 *         cdef int last_index=0 #junk
 *         cdef double * pvecback
 */
  __pyx_v_tau = 0.0;

  /* "class-sz/python/classy.pyx":1590
 *         """
 *         cdef double tau=0.0
 *         cdef int last_index=0 #junk             # <<<<<<<<<<<<<<
 *         cdef double * pvecback
 *         r = np.zeros(len(z_array),'float64')
 */
  __pyx_v_last_index = 0;

  /* "class-sz/python/classy.pyx":1592
 *         cdef int last_index=0 #junk
 *         cdef double * pvecback
 *         r = np.zeros(len(z_array),'float64')             # <<<<<<<<<<<<<<
 *         dzdr = np.zeros(len(z_array),'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = PyObject_Length(__pyx_v_z_array); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1592, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_r = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1593
 *         cdef double * pvecback
 *         r = np.zeros(len(z_array),'float64')
 *         dzdr = np.zeros(len(z_array),'float64')             # <<<<<<<<<<<<<<
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = PyObject_Length(__pyx_v_z_array); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1593, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_dzdr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1595
 *         dzdr = np.zeros(len(z_array),'float64')
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":1600
 *         ### raise CosmoSevereError(self.ba.error_message)
 * 
 *         if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 *           i = 0
 *           for redshift in z_array:
 */
  __pyx_t_7 = (__pyx_v_self->tsz.skip_background_and_thermo != 0);
  if (__pyx_t_7) {

    /* "class-sz/python/classy.pyx":1601
 * 
 *         if self.tsz.skip_background_and_thermo:
 *           i = 0             # <<<<<<<<<<<<<<
 *           for redshift in z_array:
 *             r[i] = self.class_szfast.get_chi(redshift)/self.h()
 */
    __Pyx_INCREF(__pyx_int_0);
    __pyx_v_i = __pyx_int_0;

    /* "class-sz/python/classy.pyx":1602
 *         if self.tsz.skip_background_and_thermo:
 *           i = 0
 *           for redshift in z_array:             # <<<<<<<<<<<<<<
 *             r[i] = self.class_szfast.get_chi(redshift)/self.h()
 *             dzdr[i] = self.class_szfast.get_hubble(redshift)
 */
    if (likely(PyList_CheckExact(__pyx_v_z_array)) || PyTuple_CheckExact(__pyx_v_z_array)) {
      __pyx_t_1 = __pyx_v_z_array; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_z_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1602, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1602, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1602, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1602, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1602, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1602, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1602, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1602, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_8(__pyx_t_1);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1602, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_redshift, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":1603
 *           i = 0
 *           for redshift in z_array:
 *             r[i] = self.class_szfast.get_chi(redshift)/self.h()             # <<<<<<<<<<<<<<
 *             dzdr[i] = self.class_szfast.get_hubble(redshift)
 *             i += 1
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_chi); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_redshift};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1603, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1603, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely((PyObject_SetItem(__pyx_v_r, __pyx_v_i, __pyx_t_5) < 0))) __PYX_ERR(0, 1603, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1604
 *           for redshift in z_array:
 *             r[i] = self.class_szfast.get_chi(redshift)/self.h()
 *             dzdr[i] = self.class_szfast.get_hubble(redshift)             # <<<<<<<<<<<<<<
 *             i += 1
 *         else:
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_hubble); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_redshift};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      if (unlikely((PyObject_SetItem(__pyx_v_dzdr, __pyx_v_i, __pyx_t_5) < 0))) __PYX_ERR(0, 1604, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1605
 *             r[i] = self.class_szfast.get_chi(redshift)/self.h()
 *             dzdr[i] = self.class_szfast.get_hubble(redshift)
 *             i += 1             # <<<<<<<<<<<<<<
 *         else:
 *           i = 0
 */
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1602
 *         if self.tsz.skip_background_and_thermo:
 *           i = 0
 *           for redshift in z_array:             # <<<<<<<<<<<<<<
 *             r[i] = self.class_szfast.get_chi(redshift)/self.h()
 *             dzdr[i] = self.class_szfast.get_hubble(redshift)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":1600
 *         ### raise CosmoSevereError(self.ba.error_message)
 * 
 *         if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 *           i = 0
 *           for redshift in z_array:
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":1607
 *             i += 1
 *         else:
 *           i = 0             # <<<<<<<<<<<<<<
 *           for redshift in z_array:
 *               if background_tau_of_z(&self.ba,redshift,&tau)==_FAILURE_:
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_int_0);
    __pyx_v_i = __pyx_int_0;

    /* "class-sz/python/classy.pyx":1608
 *         else:
 *           i = 0
 *           for redshift in z_array:             # <<<<<<<<<<<<<<
 *               if background_tau_of_z(&self.ba,redshift,&tau)==_FAILURE_:
 *                   raise CosmoSevereError(self.ba.error_message)
 */
    if (likely(PyList_CheckExact(__pyx_v_z_array)) || PyTuple_CheckExact(__pyx_v_z_array)) {
      __pyx_t_1 = __pyx_v_z_array; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_z_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1608, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1608, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1608, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_5); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1608, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1608, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1608, __pyx_L1_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_5); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1608, __pyx_L1_error)
          #else
          __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1608, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          #endif
        }
      } else {
        __pyx_t_5 = __pyx_t_8(__pyx_t_1);
        if (unlikely(!__pyx_t_5)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1608, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_XDECREF_SET(__pyx_v_redshift, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1609
 *           i = 0
 *           for redshift in z_array:
 *               if background_tau_of_z(&self.ba,redshift,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.ba.error_message)
 * 
 */
      __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_redshift); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1609, __pyx_L1_error)
      __pyx_t_7 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_10, (&__pyx_v_tau)) == _FAILURE_);
      if (unlikely(__pyx_t_7)) {

        /* "class-sz/python/classy.pyx":1610
 *           for redshift in z_array:
 *               if background_tau_of_z(&self.ba,redshift,&tau)==_FAILURE_:
 *                   raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *               if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1610, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1610, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_2};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1610, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __PYX_ERR(0, 1610, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1609
 *           i = 0
 *           for redshift in z_array:
 *               if background_tau_of_z(&self.ba,redshift,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.ba.error_message)
 * 
 */
      }

      /* "class-sz/python/classy.pyx":1612
 *                   raise CosmoSevereError(self.ba.error_message)
 * 
 *               if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.ba.error_message)
 * 
 */
      __pyx_t_7 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
      if (unlikely(__pyx_t_7)) {

        /* "class-sz/python/classy.pyx":1613
 * 
 *               if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *                   raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *               # store r
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_2};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1613, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __PYX_ERR(0, 1613, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1612
 *                   raise CosmoSevereError(self.ba.error_message)
 * 
 *               if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.ba.error_message)
 * 
 */
      }

      /* "class-sz/python/classy.pyx":1616
 * 
 *               # store r
 *               r[i] = pvecback[self.ba.index_bg_conf_distance]             # <<<<<<<<<<<<<<
 *               # store dz/dr = H
 *               dzdr[i] = pvecback[self.ba.index_bg_H]
 */
      __pyx_t_5 = PyFloat_FromDouble((__pyx_v_pvecback[__pyx_v_self->ba.index_bg_conf_distance])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1616, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely((PyObject_SetItem(__pyx_v_r, __pyx_v_i, __pyx_t_5) < 0))) __PYX_ERR(0, 1616, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1618
 *               r[i] = pvecback[self.ba.index_bg_conf_distance]
 *               # store dz/dr = H
 *               dzdr[i] = pvecback[self.ba.index_bg_H]             # <<<<<<<<<<<<<<
 * 
 *               i += 1
 */
      __pyx_t_5 = PyFloat_FromDouble((__pyx_v_pvecback[__pyx_v_self->ba.index_bg_H])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1618, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely((PyObject_SetItem(__pyx_v_dzdr, __pyx_v_i, __pyx_t_5) < 0))) __PYX_ERR(0, 1618, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1620
 *               dzdr[i] = pvecback[self.ba.index_bg_H]
 * 
 *               i += 1             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
      __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1620, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":1608
 *         else:
 *           i = 0
 *           for redshift in z_array:             # <<<<<<<<<<<<<<
 *               if background_tau_of_z(&self.ba,redshift,&tau)==_FAILURE_:
 *                   raise CosmoSevereError(self.ba.error_message)
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":1622
 *               i += 1
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 *         return r[:],dzdr[:]
 * 
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":1623
 * 
 *         free(pvecback)
 *         return r[:],dzdr[:]             # <<<<<<<<<<<<<<
 * 
 *     def luminosity_distance(self, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_r, 0, 0, NULL, NULL, &__pyx_slice__5, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_dzdr, 0, 0, NULL, NULL, &__pyx_slice__5, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 1623, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5)) __PYX_ERR(0, 1623, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1585
 *         return cl
 * 
 *     def z_of_r (self,z_array):             # <<<<<<<<<<<<<<
 *         """
 *         returns chi [Mpc] vs dzdchi [1/Mpc]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("classy_sz.Class.z_of_r", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_dzdr);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_redshift);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1625
 *         return r[:],dzdr[:]
 * 
 *     def luminosity_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         luminosity_distance(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_37luminosity_distance(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_36luminosity_distance, "\n        luminosity_distance(z)\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_37luminosity_distance = {"luminosity_distance", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_37luminosity_distance, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_36luminosity_distance};
static PyObject *__pyx_pw_9classy_sz_5Class_37luminosity_distance(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("luminosity_distance (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1625, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "luminosity_distance") < 0)) __PYX_ERR(0, 1625, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("luminosity_distance", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1625, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.luminosity_distance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_36luminosity_distance(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_36luminosity_distance(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double __pyx_v_lum_distance;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("luminosity_distance", 1);

  /* "class-sz/python/classy.pyx":1629
 *         luminosity_distance(z)
 *         """
 *         cdef double tau=0.0             # <<<<<<<<<<<<<<
 *         cdef int last_index = 0  # junk
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 */
  __pyx_v_tau = 0.0;

  /* "class-sz/python/classy.pyx":1630
 *         """
 *         cdef double tau=0.0
 *         cdef int last_index = 0  # junk             # <<<<<<<<<<<<<<
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 */
  __pyx_v_last_index = 0;

  /* "class-sz/python/classy.pyx":1631
 *         cdef double tau=0.0
 *         cdef int last_index = 0  # junk
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba, z, &tau)==_FAILURE_:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":1633
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba, z, &tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1633, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":1634
 * 
 *         if background_tau_of_z(&self.ba, z, &tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba, tau, self.ba.long_info,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1634, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1634, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1634, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1633
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba, z, &tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":1637
 * 
 *         if background_at_tau(&self.ba, tau, self.ba.long_info,
 *                 self.ba.inter_normal, &last_index, pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 *         lum_distance = pvecback[self.ba.index_bg_lum_distance]
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);

  /* "class-sz/python/classy.pyx":1636
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba, tau, self.ba.long_info,             # <<<<<<<<<<<<<<
 *                 self.ba.inter_normal, &last_index, pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)
 */
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":1638
 *         if background_at_tau(&self.ba, tau, self.ba.long_info,
 *                 self.ba.inter_normal, &last_index, pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 *         lum_distance = pvecback[self.ba.index_bg_lum_distance]
 *         free(pvecback)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1638, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1636
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba, tau, self.ba.long_info,             # <<<<<<<<<<<<<<
 *                 self.ba.inter_normal, &last_index, pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)
 */
  }

  /* "class-sz/python/classy.pyx":1639
 *                 self.ba.inter_normal, &last_index, pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)
 *         lum_distance = pvecback[self.ba.index_bg_lum_distance]             # <<<<<<<<<<<<<<
 *         free(pvecback)
 *         return lum_distance
 */
  __pyx_v_lum_distance = (__pyx_v_pvecback[__pyx_v_self->ba.index_bg_lum_distance]);

  /* "class-sz/python/classy.pyx":1640
 *             raise CosmoSevereError(self.ba.error_message)
 *         lum_distance = pvecback[self.ba.index_bg_lum_distance]
 *         free(pvecback)             # <<<<<<<<<<<<<<
 *         return lum_distance
 * 
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":1641
 *         lum_distance = pvecback[self.ba.index_bg_lum_distance]
 *         free(pvecback)
 *         return lum_distance             # <<<<<<<<<<<<<<
 * 
 *     def get_pkl_at_z(self, z_asked, params_values_dict=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_lum_distance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1625
 *         return r[:],dzdr[:]
 * 
 *     def luminosity_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         luminosity_distance(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.luminosity_distance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1643
 *         return lum_distance
 * 
 *     def get_pkl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_39get_pkl_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_39get_pkl_at_z = {"get_pkl_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_39get_pkl_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_39get_pkl_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_params_values_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pkl_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_params_values_dict,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1643, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_params_values_dict);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1643, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pkl_at_z") < 0)) __PYX_ERR(0, 1643, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z_asked = values[0];
    __pyx_v_params_values_dict = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pkl_at_z", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1643, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pkl_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_38get_pkl_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_params_values_dict);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_38get_pkl_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_params_values_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pkl_at_z", 1);

  /* "class-sz/python/classy.pyx":1644
 * 
 *     def get_pkl_at_z(self, z_asked, params_values_dict=None):
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)             # <<<<<<<<<<<<<<
 * 
 *     def get_pknl_at_z(self, z_asked, params_values_dict=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_calculate_pkl_at_z); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_z_asked);
  __Pyx_GIVEREF(__pyx_v_z_asked);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_z_asked)) __PYX_ERR(0, 1644, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params_values_dict, __pyx_v_params_values_dict) < 0) __PYX_ERR(0, 1644, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1643
 *         return lum_distance
 * 
 *     def get_pkl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_pkl_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1646
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 *     def get_pknl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pknl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_41get_pknl_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_41get_pknl_at_z = {"get_pknl_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_41get_pknl_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_41get_pknl_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_params_values_dict = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pknl_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_params_values_dict,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1646, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_params_values_dict);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1646, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pknl_at_z") < 0)) __PYX_ERR(0, 1646, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z_asked = values[0];
    __pyx_v_params_values_dict = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pknl_at_z", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1646, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pknl_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_40get_pknl_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_params_values_dict);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_40get_pknl_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_params_values_dict) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pknl_at_z", 1);

  /* "class-sz/python/classy.pyx":1647
 * 
 *     def get_pknl_at_z(self, z_asked, params_values_dict=None):
 *         return self.class_szfast.calculate_pknl_at_z(z_asked, params_values_dict = params_values_dict)             # <<<<<<<<<<<<<<
 * 
 *     # Gives the total matter pk for a given (k,z)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_calculate_pknl_at_z); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_z_asked);
  __Pyx_GIVEREF(__pyx_v_z_asked);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_z_asked)) __PYX_ERR(0, 1647, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_params_values_dict, __pyx_v_params_values_dict) < 0) __PYX_ERR(0, 1647, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1646
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 *     def get_pknl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pknl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_pknl_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1650
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_43pk_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_42pk_unvectorized, "\n        Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)\n\n        .. note::\n\n            there is an additional check that output contains `mPk`,\n            because otherwise a segfault will occur\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_43pk_unvectorized = {"pk_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_43pk_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_42pk_unvectorized};
static PyObject *__pyx_pw_9classy_sz_5Class_43pk_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_unvectorized (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1650, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1650, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk_unvectorized", 1, 2, 2, 1); __PYX_ERR(0, 1650, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk_unvectorized") < 0)) __PYX_ERR(0, 1650, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1650, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1650, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk_unvectorized", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1650, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_42pk_unvectorized(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_42pk_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z) {
  double __pyx_v_pk;
  PyObject *__pyx_v_zmax = NULL;
  PyObject *__pyx_v_pk_linzmax = NULL;
  PyObject *__pyx_v_Dz = NULL;
  PyObject *__pyx_v_Dzmax = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  double __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_unvectorized", 1);

  /* "class-sz/python/classy.pyx":1661
 *         """
 *         cdef double pk
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *           # pk = self.get_pk_nonlin_at_k_and_z(k/self.h(), z)*self.h()**3
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":1664
 * 
 *           # pk = self.get_pk_nonlin_at_k_and_z(k/self.h(), z)*self.h()**3
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax             # <<<<<<<<<<<<<<
 *           if z>zmax:
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cszfast_pk_grid_zmax); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_zmax = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1665
 *           # pk = self.get_pk_nonlin_at_k_and_z(k/self.h(), z)*self.h()**3
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax
 *           if z>zmax:             # <<<<<<<<<<<<<<
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)
 */
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_v_zmax, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1665, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1665, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":1666
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax
 *           if z>zmax:
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)             # <<<<<<<<<<<<<<
 *             Dz = self.scale_independent_growth_factor(z)
 *             Dzmax = self.scale_independent_growth_factor(zmax)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pkl_at_k_and_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1666, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1666, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_4, __pyx_v_zmax};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1666, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_pk_linzmax = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1667
 *           if z>zmax:
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)             # <<<<<<<<<<<<<<
 *             Dzmax = self.scale_independent_growth_factor(zmax)
 *             pk = pk_linzmax*(Dz/Dzmax)**2.
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1667, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_Dz = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1668
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)
 *             Dzmax = self.scale_independent_growth_factor(zmax)             # <<<<<<<<<<<<<<
 *             pk = pk_linzmax*(Dz/Dzmax)**2.
 *           else:
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_zmax};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1668, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_Dzmax = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1669
 *             Dz = self.scale_independent_growth_factor(z)
 *             Dzmax = self.scale_independent_growth_factor(zmax)
 *             pk = pk_linzmax*(Dz/Dzmax)**2.             # <<<<<<<<<<<<<<
 *           else:
 *             pk = self.class_szfast.get_pknl_at_k_and_z(k,z)
 */
      __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_v_Dz, __pyx_v_Dzmax); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1669, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyNumber_Power(__pyx_t_3, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1669, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Multiply(__pyx_v_pk_linzmax, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1669, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1669, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_pk = __pyx_t_7;

      /* "class-sz/python/classy.pyx":1665
 *           # pk = self.get_pk_nonlin_at_k_and_z(k/self.h(), z)*self.h()**3
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax
 *           if z>zmax:             # <<<<<<<<<<<<<<
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)
 */
      goto __pyx_L4;
    }

    /* "class-sz/python/classy.pyx":1671
 *             pk = pk_linzmax*(Dz/Dzmax)**2.
 *           else:
 *             pk = self.class_szfast.get_pknl_at_k_and_z(k,z)             # <<<<<<<<<<<<<<
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pknl_at_k_and_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_4, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1671, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1671, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_pk = __pyx_t_7;
    }
    __pyx_L4:;

    /* "class-sz/python/classy.pyx":1661
 *         """
 *         cdef double pk
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *           # pk = self.get_pk_nonlin_at_k_and_z(k/self.h(), z)*self.h()**3
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":1673
 *             pk = self.class_szfast.get_pknl_at_k_and_z(k,z)
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":1674
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *           if (self.nl.method == nl_none):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_No_power_spectrum_computed_You_m};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1674, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1674, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1673
 *             pk = self.class_szfast.get_pknl_at_k_and_z(k,z)
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1676
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *           if (self.nl.method == nl_none):             # <<<<<<<<<<<<<<
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:
 *                   raise CosmoSevereError(self.nl.error_message)
 */
    __pyx_t_1 = (__pyx_v_self->nl.method == nl_none);
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":1677
 * 
 *           if (self.nl.method == nl_none):
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.nl.error_message)
 *           else:
 */
      __pyx_t_1 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_linear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_m, (&__pyx_v_pk), NULL) == _FAILURE_);
      if (unlikely(__pyx_t_1)) {

        /* "class-sz/python/classy.pyx":1678
 *           if (self.nl.method == nl_none):
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:
 *                   raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 *           else:
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1678, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1678, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1678, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 1678, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1677
 * 
 *           if (self.nl.method == nl_none):
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.nl.error_message)
 *           else:
 */
      }

      /* "class-sz/python/classy.pyx":1676
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *           if (self.nl.method == nl_none):             # <<<<<<<<<<<<<<
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:
 *                   raise CosmoSevereError(self.nl.error_message)
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":1680
 *                   raise CosmoSevereError(self.nl.error_message)
 *           else:
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.nl.error_message)
 * 
 */
    /*else*/ {
      __pyx_t_1 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_nonlinear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_m, (&__pyx_v_pk), NULL) == _FAILURE_);
      if (unlikely(__pyx_t_1)) {

        /* "class-sz/python/classy.pyx":1681
 *           else:
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:
 *                   raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return pk
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1681, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1681, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1681, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 1681, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1680
 *                   raise CosmoSevereError(self.nl.error_message)
 *           else:
 *               if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                   raise CosmoSevereError(self.nl.error_message)
 * 
 */
      }
    }
    __pyx_L6:;
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":1683
 *                   raise CosmoSevereError(self.nl.error_message)
 * 
 *         return pk             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_pk); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1650
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.pk_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_zmax);
  __Pyx_XDECREF(__pyx_v_pk_linzmax);
  __Pyx_XDECREF(__pyx_v_Dz);
  __Pyx_XDECREF(__pyx_v_Dzmax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1687
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_45pk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_44pk, "\n        Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.\n        This function handles both scalar and array inputs for k and z.\n\n        .. note::\n\n            there is an additional check that output contains `mPk`,\n            because otherwise a segfault will occur\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_45pk = {"pk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_45pk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_44pk};
static PyObject *__pyx_pw_9classy_sz_5Class_45pk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1687, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1687, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk", 1, 2, 2, 1); __PYX_ERR(0, 1687, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk") < 0)) __PYX_ERR(0, 1687, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1687, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_44pk(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_44pk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z) {
  double __pyx_v_pk;
  PyArrayObject *__pyx_v_k_array = 0;
  PyArrayObject *__pyx_v_z_array = 0;
  PyArrayObject *__pyx_v_pk_array = 0;
  int __pyx_v_i;
  int __pyx_v_n;
  PyObject *__pyx_v_zmax = NULL;
  PyObject *__pyx_v_pk_linzmax = NULL;
  PyObject *__pyx_v_Dz = NULL;
  PyObject *__pyx_v_Dzmax = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  double __pyx_t_17;
  double __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk", 1);

  /* "class-sz/python/classy.pyx":1702
 * 
 *         # Convert inputs to arrays if they are not already
 *         k_array = np.atleast_1d(np.array(k, dtype=np.float64))             # <<<<<<<<<<<<<<
 *         z_array = np.atleast_1d(np.array(z, dtype=np.float64))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_atleast_1d); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_k);
  __Pyx_GIVEREF(__pyx_v_k);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_k)) __PYX_ERR(0, 1702, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1702, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1702, __pyx_L1_error)
  __pyx_v_k_array = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1703
 *         # Convert inputs to arrays if they are not already
 *         k_array = np.atleast_1d(np.array(k, dtype=np.float64))
 *         z_array = np.atleast_1d(np.array(z, dtype=np.float64))             # <<<<<<<<<<<<<<
 * 
 *         # Check if shapes are broadcastable
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_atleast_1d); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_z);
  __Pyx_GIVEREF(__pyx_v_z);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_z)) __PYX_ERR(0, 1703, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1703, __pyx_L1_error)
  __pyx_v_z_array = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1706
 * 
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:             # <<<<<<<<<<<<<<
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 */
  __pyx_t_9 = (__pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_k_array) != __pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_z_array));
  if (__pyx_t_9) {

    /* "class-sz/python/classy.pyx":1707
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:
 *             try:             # <<<<<<<<<<<<<<
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      /*try:*/ {

        /* "class-sz/python/classy.pyx":1708
 *         if k_array.shape != z_array.shape:
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 raise ValueError("k and z must be broadcastable to the same shape.")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1708, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_broadcast_arrays); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1708, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_k_array), ((PyObject *)__pyx_v_z_array)};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1708, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1708, __pyx_L4_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          #else
          __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1708, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1708, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1708, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_6 = __pyx_t_13(__pyx_t_2); if (unlikely(!__pyx_t_6)) goto __pyx_L10_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          index = 1; __pyx_t_7 = __pyx_t_13(__pyx_t_2); if (unlikely(!__pyx_t_7)) goto __pyx_L10_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_2), 2) < 0) __PYX_ERR(0, 1708, __pyx_L4_error)
          __pyx_t_13 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L11_unpacking_done;
          __pyx_L10_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_13 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1708, __pyx_L4_error)
          __pyx_L11_unpacking_done:;
        }
        if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1708, __pyx_L4_error)
        if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1708, __pyx_L4_error)
        __Pyx_DECREF_SET(__pyx_v_k_array, ((PyArrayObject *)__pyx_t_6));
        __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_z_array, ((PyArrayObject *)__pyx_t_7));
        __pyx_t_7 = 0;

        /* "class-sz/python/classy.pyx":1707
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:
 *             try:             # <<<<<<<<<<<<<<
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 */
      }
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":1709
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 raise ValueError("k and z must be broadcastable to the same shape.")
 * 
 */
      __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_14) {
        __Pyx_AddTraceback("classy_sz.Class.pk", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_6) < 0) __PYX_ERR(0, 1709, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_6);

        /* "class-sz/python/classy.pyx":1710
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 *                 raise ValueError("k and z must be broadcastable to the same shape.")             # <<<<<<<<<<<<<<
 * 
 *         n = k_array.size
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1710, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 1710, __pyx_L6_except_error)
      }
      goto __pyx_L6_except_error;

      /* "class-sz/python/classy.pyx":1707
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:
 *             try:             # <<<<<<<<<<<<<<
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      goto __pyx_L1_error;
      __pyx_L9_try_end:;
    }

    /* "class-sz/python/classy.pyx":1706
 * 
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:             # <<<<<<<<<<<<<<
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 */
  }

  /* "class-sz/python/classy.pyx":1712
 *                 raise ValueError("k and z must be broadcastable to the same shape.")
 * 
 *         n = k_array.size             # <<<<<<<<<<<<<<
 *         pk_array = np.empty(n, dtype=np.float64)
 * 
 */
  __pyx_v_n = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_k_array);

  /* "class-sz/python/classy.pyx":1713
 * 
 *         n = k_array.size
 *         pk_array = np.empty(n, dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6)) __PYX_ERR(0, 1713, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1713, __pyx_L1_error)
  __pyx_v_pk_array = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":1715
 *         pk_array = np.empty(n, dtype=np.float64)
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 */
  __pyx_t_9 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_9) {

    /* "class-sz/python/classy.pyx":1716
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if z_array[i] > zmax:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cszfast_pk_grid_zmax); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1716, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_zmax = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":1717
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if z_array[i] > zmax:
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 */
    __pyx_t_14 = __pyx_v_n;
    __pyx_t_15 = __pyx_t_14;
    for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
      __pyx_v_i = __pyx_t_16;

      /* "class-sz/python/classy.pyx":1718
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 *                 if z_array[i] > zmax:             # <<<<<<<<<<<<<<
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 */
      __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyObject_RichCompare(__pyx_t_3, __pyx_v_zmax, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1718, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1718, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_9) {

        /* "class-sz/python/classy.pyx":1719
 *             for i in range(n):
 *                 if z_array[i] > zmax:
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)             # <<<<<<<<<<<<<<
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 *                     Dzmax = self.scale_independent_growth_factor(zmax)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pkl_at_k_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1719, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_k_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1719, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_1, __pyx_v_zmax};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1719, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_pk_linzmax, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1720
 *                 if z_array[i] > zmax:
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])             # <<<<<<<<<<<<<<
 *                     Dzmax = self.scale_independent_growth_factor(zmax)
 *                     pk_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1720, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1720, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1720, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_Dz, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1721
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 *                     Dzmax = self.scale_independent_growth_factor(zmax)             # <<<<<<<<<<<<<<
 *                     pk_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)
 *                 else:
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1721, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_zmax};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1721, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_Dzmax, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1722
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 *                     Dzmax = self.scale_independent_growth_factor(zmax)
 *                     pk_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     pk_array[i] = self.class_szfast.get_pknl_at_k_and_z(k_array[i], z_array[i])
 */
        __pyx_t_6 = __Pyx_PyNumber_Divide(__pyx_v_Dz, __pyx_v_Dzmax); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1722, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1722, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyFloat_FromDouble(pow(__pyx_t_17, 2.0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1722, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = PyNumber_Multiply(__pyx_v_pk_linzmax, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1722, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_pk_array), __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 1722, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "class-sz/python/classy.pyx":1718
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 *                 if z_array[i] > zmax:             # <<<<<<<<<<<<<<
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 */
        goto __pyx_L17;
      }

      /* "class-sz/python/classy.pyx":1724
 *                     pk_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)
 *                 else:
 *                     pk_array[i] = self.class_szfast.get_pknl_at_k_and_z(k_array[i], z_array[i])             # <<<<<<<<<<<<<<
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):
 */
      /*else*/ {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pknl_at_k_and_z); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1724, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_k_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1724, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1724, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_2 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_1, __pyx_t_7};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1724, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_pk_array), __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 1724, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_L17:;
    }

    /* "class-sz/python/classy.pyx":1715
 *         pk_array = np.empty(n, dtype=np.float64)
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 */
    goto __pyx_L14;
  }

  /* "class-sz/python/classy.pyx":1726
 *                     pk_array[i] = self.class_szfast.get_pknl_at_k_and_z(k_array[i], z_array[i])
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  /*else*/ {
    __pyx_t_9 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
    if (unlikely(__pyx_t_9)) {

      /* "class-sz/python/classy.pyx":1727
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *             for i in range(n):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1727, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_kp_u_No_power_spectrum_computed_You_m};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1727, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1727, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1726
 *                     pk_array[i] = self.class_szfast.get_pknl_at_k_and_z(k_array[i], z_array[i])
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1729
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.nl.method == nl_none:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:
 */
    __pyx_t_14 = __pyx_v_n;
    __pyx_t_15 = __pyx_t_14;
    for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
      __pyx_v_i = __pyx_t_16;

      /* "class-sz/python/classy.pyx":1730
 * 
 *             for i in range(n):
 *                 if self.nl.method == nl_none:             # <<<<<<<<<<<<<<
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:
 *                         raise CosmoSevereError(self.nl.error_message)
 */
      __pyx_t_9 = (__pyx_v_self->nl.method == nl_none);
      if (__pyx_t_9) {

        /* "class-sz/python/classy.pyx":1731
 *             for i in range(n):
 *                 if self.nl.method == nl_none:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                         raise CosmoSevereError(self.nl.error_message)
 *                 else:
 */
        __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_k_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1731, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1731, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1731, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_18 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1731, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_9 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_linear, __pyx_t_17, __pyx_t_18, __pyx_v_self->nl.index_pk_m, (&__pyx_v_pk), NULL) == _FAILURE_);
        if (unlikely(__pyx_t_9)) {

          /* "class-sz/python/classy.pyx":1732
 *                 if self.nl.method == nl_none:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:
 *                         raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 *                 else:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_nonlinear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1732, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1732, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_1 = NULL;
          __pyx_t_8 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_8 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_7};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1732, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __Pyx_Raise(__pyx_t_3, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __PYX_ERR(0, 1732, __pyx_L1_error)

          /* "class-sz/python/classy.pyx":1731
 *             for i in range(n):
 *                 if self.nl.method == nl_none:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                         raise CosmoSevereError(self.nl.error_message)
 *                 else:
 */
        }

        /* "class-sz/python/classy.pyx":1730
 * 
 *             for i in range(n):
 *                 if self.nl.method == nl_none:             # <<<<<<<<<<<<<<
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:
 *                         raise CosmoSevereError(self.nl.error_message)
 */
        goto __pyx_L21;
      }

      /* "class-sz/python/classy.pyx":1734
 *                         raise CosmoSevereError(self.nl.error_message)
 *                 else:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_nonlinear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                         raise CosmoSevereError(self.nl.error_message)
 *                 pk_array[i] = pk
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_k_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1734, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_18 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1734, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1734, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1734, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_9 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_nonlinear, __pyx_t_18, __pyx_t_17, __pyx_v_self->nl.index_pk_m, (&__pyx_v_pk), NULL) == _FAILURE_);
        if (unlikely(__pyx_t_9)) {

          /* "class-sz/python/classy.pyx":1735
 *                 else:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_nonlinear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:
 *                         raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 *                 pk_array[i] = pk
 * 
 */
          __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1735, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1735, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_1 = NULL;
          __pyx_t_8 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_8 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_7};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1735, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
          __Pyx_Raise(__pyx_t_3, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __PYX_ERR(0, 1735, __pyx_L1_error)

          /* "class-sz/python/classy.pyx":1734
 *                         raise CosmoSevereError(self.nl.error_message)
 *                 else:
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_nonlinear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                         raise CosmoSevereError(self.nl.error_message)
 *                 pk_array[i] = pk
 */
        }
      }
      __pyx_L21:;

      /* "class-sz/python/classy.pyx":1736
 *                     if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_nonlinear, k_array[i], z_array[i], self.nl.index_pk_m, &pk, NULL) == _FAILURE_:
 *                         raise CosmoSevereError(self.nl.error_message)
 *                 pk_array[i] = pk             # <<<<<<<<<<<<<<
 * 
 *         # Return a scalar if the input was scalar, otherwise return the array
 */
      __pyx_t_3 = PyFloat_FromDouble(__pyx_v_pk); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1736, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_pk_array), __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 1736, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
  }
  __pyx_L14:;

  /* "class-sz/python/classy.pyx":1739
 * 
 *         # Return a scalar if the input was scalar, otherwise return the array
 *         if pk_array.size == 1:             # <<<<<<<<<<<<<<
 *             return pk_array[0]
 *         else:
 */
  __pyx_t_9 = (__pyx_f_5numpy_7ndarray_4size_size(__pyx_v_pk_array) == 1);
  if (__pyx_t_9) {

    /* "class-sz/python/classy.pyx":1740
 *         # Return a scalar if the input was scalar, otherwise return the array
 *         if pk_array.size == 1:
 *             return pk_array[0]             # <<<<<<<<<<<<<<
 *         else:
 *             return pk_array
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_pk_array), 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":1739
 * 
 *         # Return a scalar if the input was scalar, otherwise return the array
 *         if pk_array.size == 1:             # <<<<<<<<<<<<<<
 *             return pk_array[0]
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":1742
 *             return pk_array[0]
 *         else:
 *             return pk_array             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_pk_array);
    __pyx_r = ((PyObject *)__pyx_v_pk_array);
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":1687
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.pk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_k_array);
  __Pyx_XDECREF((PyObject *)__pyx_v_z_array);
  __Pyx_XDECREF((PyObject *)__pyx_v_pk_array);
  __Pyx_XDECREF(__pyx_v_zmax);
  __Pyx_XDECREF(__pyx_v_pk_linzmax);
  __Pyx_XDECREF(__pyx_v_Dz);
  __Pyx_XDECREF(__pyx_v_Dzmax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1747
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_47pk_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_46pk_cb, "\n        Gives the cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)\n\n        .. note::\n\n            there is an additional check that output contains `mPk`,\n            because otherwise a segfault will occur\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_47pk_cb = {"pk_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_47pk_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_46pk_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_47pk_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1747, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1747, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk_cb", 1, 2, 2, 1); __PYX_ERR(0, 1747, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk_cb") < 0)) __PYX_ERR(0, 1747, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1747, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1747, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk_cb", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1747, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_46pk_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_46pk_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z) {
  double __pyx_v_pk_cb;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_cb", 1);

  /* "class-sz/python/classy.pyx":1759
 *         cdef double pk_cb
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 *         if (self.nl.has_pk_cb == _FALSE_):
 */
  __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":1760
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 *         if (self.nl.has_pk_cb == _FALSE_):
 *             raise CosmoSevereError("P_cb not computed (probably because there are no massive neutrinos) so you cannot ask for it")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_No_power_spectrum_computed_You_m};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1760, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1759
 *         cdef double pk_cb
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 *         if (self.nl.has_pk_cb == _FALSE_):
 */
  }

  /* "class-sz/python/classy.pyx":1761
 *         if (self.pt.has_pk_matter == _FALSE_):
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 *         if (self.nl.has_pk_cb == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("P_cb not computed (probably because there are no massive neutrinos) so you cannot ask for it")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->nl.has_pk_cb == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":1762
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 *         if (self.nl.has_pk_cb == _FALSE_):
 *             raise CosmoSevereError("P_cb not computed (probably because there are no massive neutrinos) so you cannot ask for it")             # <<<<<<<<<<<<<<
 * 
 *         if (self.nl.method == nl_none):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1762, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_P_cb_not_computed_probably_becau};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1762, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1761
 *         if (self.pt.has_pk_matter == _FALSE_):
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 *         if (self.nl.has_pk_cb == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("P_cb not computed (probably because there are no massive neutrinos) so you cannot ask for it")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":1764
 *             raise CosmoSevereError("P_cb not computed (probably because there are no massive neutrinos) so you cannot ask for it")
 * 
 *         if (self.nl.method == nl_none):             # <<<<<<<<<<<<<<
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)
 */
  __pyx_t_1 = (__pyx_v_self->nl.method == nl_none);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":1765
 * 
 *         if (self.nl.method == nl_none):
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 *         else:
 */
    __pyx_t_1 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_linear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_cb, (&__pyx_v_pk_cb), NULL) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":1766
 *         if (self.nl.method == nl_none):
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 *         else:
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1766, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 1766, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1765
 * 
 *         if (self.nl.method == nl_none):
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 *         else:
 */
    }

    /* "class-sz/python/classy.pyx":1764
 *             raise CosmoSevereError("P_cb not computed (probably because there are no massive neutrinos) so you cannot ask for it")
 * 
 *         if (self.nl.method == nl_none):             # <<<<<<<<<<<<<<
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)
 */
    goto __pyx_L5;
  }

  /* "class-sz/python/classy.pyx":1768
 *                 raise CosmoSevereError(self.nl.error_message)
 *         else:
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 */
  /*else*/ {
    __pyx_t_1 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_nonlinear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_cb, (&__pyx_v_pk_cb), NULL) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":1769
 *         else:
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return pk_cb
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1769, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 1769, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1768
 *                 raise CosmoSevereError(self.nl.error_message)
 *         else:
 *             if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_cb,&pk_cb,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 */
    }
  }
  __pyx_L5:;

  /* "class-sz/python/classy.pyx":1771
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 *         return pk_cb             # <<<<<<<<<<<<<<
 * 
 *     # Gives the total matter pk for a given (k,z)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_pk_cb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1747
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.pk_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1774
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_49pk_lin_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_48pk_lin_unvectorized, "\n        Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z\n\n        .. note::\n\n            there is an additional check that output contains `mPk`,\n            because otherwise a segfault will occur\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_49pk_lin_unvectorized = {"pk_lin_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_49pk_lin_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_48pk_lin_unvectorized};
static PyObject *__pyx_pw_9classy_sz_5Class_49pk_lin_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_lin_unvectorized (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1774, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1774, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk_lin_unvectorized", 1, 2, 2, 1); __PYX_ERR(0, 1774, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk_lin_unvectorized") < 0)) __PYX_ERR(0, 1774, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1774, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1774, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk_lin_unvectorized", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1774, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk_lin_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_48pk_lin_unvectorized(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_48pk_lin_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z) {
  double __pyx_v_pk_lin;
  PyObject *__pyx_v_zmax = NULL;
  PyObject *__pyx_v_pk_linzmax = NULL;
  PyObject *__pyx_v_Dz = NULL;
  PyObject *__pyx_v_Dzmax = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  double __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_lin_unvectorized", 1);

  /* "class-sz/python/classy.pyx":1786
 *         cdef double pk_lin
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *           # pk_lin = self.get_pk_lin_at_k_and_z(k/self.h(), z)*self.h()**3
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":1789
 * 
 *           # pk_lin = self.get_pk_lin_at_k_and_z(k/self.h(), z)*self.h()**3
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax             # <<<<<<<<<<<<<<
 *           if z>zmax:
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cszfast_pk_grid_zmax); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_zmax = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":1790
 *           # pk_lin = self.get_pk_lin_at_k_and_z(k/self.h(), z)*self.h()**3
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax
 *           if z>zmax:             # <<<<<<<<<<<<<<
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)
 */
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_v_zmax, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1790, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1790, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":1791
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax
 *           if z>zmax:
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)             # <<<<<<<<<<<<<<
 *             Dz = self.scale_independent_growth_factor(z)
 *             Dzmax = self.scale_independent_growth_factor(zmax)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pkl_at_k_and_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1791, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1791, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_4, __pyx_v_zmax};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1791, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_pk_linzmax = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1792
 *           if z>zmax:
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)             # <<<<<<<<<<<<<<
 *             Dzmax = self.scale_independent_growth_factor(zmax)
 *             pk_lin = pk_linzmax*(Dz/Dzmax)**2.
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1792, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1792, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1792, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_Dz = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1793
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)
 *             Dzmax = self.scale_independent_growth_factor(zmax)             # <<<<<<<<<<<<<<
 *             pk_lin = pk_linzmax*(Dz/Dzmax)**2.
 *           else:
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_zmax};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1793, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_v_Dzmax = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":1794
 *             Dz = self.scale_independent_growth_factor(z)
 *             Dzmax = self.scale_independent_growth_factor(zmax)
 *             pk_lin = pk_linzmax*(Dz/Dzmax)**2.             # <<<<<<<<<<<<<<
 *           else:
 *             pk_lin = self.class_szfast.get_pkl_at_k_and_z(k,z)
 */
      __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_v_Dz, __pyx_v_Dzmax); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyNumber_Power(__pyx_t_3, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Multiply(__pyx_v_pk_linzmax, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1794, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1794, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_pk_lin = __pyx_t_7;

      /* "class-sz/python/classy.pyx":1790
 *           # pk_lin = self.get_pk_lin_at_k_and_z(k/self.h(), z)*self.h()**3
 *           zmax = self.class_szfast.cszfast_pk_grid_zmax
 *           if z>zmax:             # <<<<<<<<<<<<<<
 *             pk_linzmax =  self.class_szfast.get_pkl_at_k_and_z(k,zmax)
 *             Dz = self.scale_independent_growth_factor(z)
 */
      goto __pyx_L4;
    }

    /* "class-sz/python/classy.pyx":1796
 *             pk_lin = pk_linzmax*(Dz/Dzmax)**2.
 *           else:
 *             pk_lin = self.class_szfast.get_pkl_at_k_and_z(k,z)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pkl_at_k_and_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_4, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1796, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1796, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_pk_lin = __pyx_t_7;
    }
    __pyx_L4:;

    /* "class-sz/python/classy.pyx":1786
 *         cdef double pk_lin
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *           # pk_lin = self.get_pk_lin_at_k_and_z(k/self.h(), z)*self.h()**3
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":1799
 * 
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":1800
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *           if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1800, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_No_power_spectrum_computed_You_m};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1800, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1799
 * 
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1802
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *           if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.nl.error_message)
 * 
 */
    __pyx_t_1 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_linear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_m, (&__pyx_v_pk_lin), NULL) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":1803
 * 
 *           if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:
 *               raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return pk_lin
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1803, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1803, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1802
 *               raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *           if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.nl.error_message)
 * 
 */
    }
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":1805
 *               raise CosmoSevereError(self.nl.error_message)
 * 
 *         return pk_lin             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_pk_lin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1774
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.pk_lin_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_zmax);
  __Pyx_XDECREF(__pyx_v_pk_linzmax);
  __Pyx_XDECREF(__pyx_v_Dz);
  __Pyx_XDECREF(__pyx_v_Dzmax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1810
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_51pk_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_50pk_lin, "\n        Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.\n        This function handles both scalar and array inputs for k and z.\n\n        .. note::\n\n            there is an additional check that output contains `mPk`,\n            because otherwise a segfault will occur\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_51pk_lin = {"pk_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_51pk_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_50pk_lin};
static PyObject *__pyx_pw_9classy_sz_5Class_51pk_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_lin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1810, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1810, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk_lin", 1, 2, 2, 1); __PYX_ERR(0, 1810, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk_lin") < 0)) __PYX_ERR(0, 1810, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk_lin", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1810, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_50pk_lin(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_50pk_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z) {
  double __pyx_v_pk_lin;
  PyArrayObject *__pyx_v_k_array = 0;
  PyArrayObject *__pyx_v_z_array = 0;
  PyArrayObject *__pyx_v_pk_lin_array = 0;
  int __pyx_v_i;
  int __pyx_v_n;
  PyObject *__pyx_v_zmax = NULL;
  PyObject *__pyx_v_pk_linzmax = NULL;
  PyObject *__pyx_v_Dz = NULL;
  PyObject *__pyx_v_Dzmax = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  double __pyx_t_17;
  double __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_lin", 1);

  /* "class-sz/python/classy.pyx":1825
 * 
 *         # Convert inputs to arrays if they are not already
 *         k_array = np.atleast_1d(np.array(k, dtype=np.float64))             # <<<<<<<<<<<<<<
 *         z_array = np.atleast_1d(np.array(z, dtype=np.float64))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_atleast_1d); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_k);
  __Pyx_GIVEREF(__pyx_v_k);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_k)) __PYX_ERR(0, 1825, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1825, __pyx_L1_error)
  __pyx_v_k_array = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1826
 *         # Convert inputs to arrays if they are not already
 *         k_array = np.atleast_1d(np.array(k, dtype=np.float64))
 *         z_array = np.atleast_1d(np.array(z, dtype=np.float64))             # <<<<<<<<<<<<<<
 * 
 *         # Check if shapes are broadcastable
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_atleast_1d); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_z);
  __Pyx_GIVEREF(__pyx_v_z);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_z)) __PYX_ERR(0, 1826, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1826, __pyx_L1_error)
  __pyx_v_z_array = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1829
 * 
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:             # <<<<<<<<<<<<<<
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 */
  __pyx_t_9 = (__pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_k_array) != __pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_z_array));
  if (__pyx_t_9) {

    /* "class-sz/python/classy.pyx":1830
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:
 *             try:             # <<<<<<<<<<<<<<
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      /*try:*/ {

        /* "class-sz/python/classy.pyx":1831
 *         if k_array.shape != z_array.shape:
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 raise ValueError("k and z must be broadcastable to the same shape.")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1831, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_broadcast_arrays); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1831, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_k_array), ((PyObject *)__pyx_v_z_array)};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1831, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1831, __pyx_L4_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          #else
          __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1831, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1831, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1831, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_6 = __pyx_t_13(__pyx_t_2); if (unlikely(!__pyx_t_6)) goto __pyx_L10_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          index = 1; __pyx_t_7 = __pyx_t_13(__pyx_t_2); if (unlikely(!__pyx_t_7)) goto __pyx_L10_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_2), 2) < 0) __PYX_ERR(0, 1831, __pyx_L4_error)
          __pyx_t_13 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L11_unpacking_done;
          __pyx_L10_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_13 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1831, __pyx_L4_error)
          __pyx_L11_unpacking_done:;
        }
        if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1831, __pyx_L4_error)
        if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1831, __pyx_L4_error)
        __Pyx_DECREF_SET(__pyx_v_k_array, ((PyArrayObject *)__pyx_t_6));
        __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_z_array, ((PyArrayObject *)__pyx_t_7));
        __pyx_t_7 = 0;

        /* "class-sz/python/classy.pyx":1830
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:
 *             try:             # <<<<<<<<<<<<<<
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 */
      }
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":1832
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 raise ValueError("k and z must be broadcastable to the same shape.")
 * 
 */
      __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_14) {
        __Pyx_AddTraceback("classy_sz.Class.pk_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_6) < 0) __PYX_ERR(0, 1832, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_6);

        /* "class-sz/python/classy.pyx":1833
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 *                 raise ValueError("k and z must be broadcastable to the same shape.")             # <<<<<<<<<<<<<<
 * 
 *         n = k_array.size
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1833, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 1833, __pyx_L6_except_error)
      }
      goto __pyx_L6_except_error;

      /* "class-sz/python/classy.pyx":1830
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:
 *             try:             # <<<<<<<<<<<<<<
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      goto __pyx_L1_error;
      __pyx_L9_try_end:;
    }

    /* "class-sz/python/classy.pyx":1829
 * 
 *         # Check if shapes are broadcastable
 *         if k_array.shape != z_array.shape:             # <<<<<<<<<<<<<<
 *             try:
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 */
  }

  /* "class-sz/python/classy.pyx":1835
 *                 raise ValueError("k and z must be broadcastable to the same shape.")
 * 
 *         n = k_array.size             # <<<<<<<<<<<<<<
 *         pk_lin_array = np.empty(n, dtype=np.float64)
 * 
 */
  __pyx_v_n = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_k_array);

  /* "class-sz/python/classy.pyx":1836
 * 
 *         n = k_array.size
 *         pk_lin_array = np.empty(n, dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6)) __PYX_ERR(0, 1836, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1836, __pyx_L1_error)
  __pyx_v_pk_lin_array = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":1838
 *         pk_lin_array = np.empty(n, dtype=np.float64)
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 */
  __pyx_t_9 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_9) {

    /* "class-sz/python/classy.pyx":1839
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if z_array[i] > zmax:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cszfast_pk_grid_zmax); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_zmax = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":1840
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if z_array[i] > zmax:
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 */
    __pyx_t_14 = __pyx_v_n;
    __pyx_t_15 = __pyx_t_14;
    for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
      __pyx_v_i = __pyx_t_16;

      /* "class-sz/python/classy.pyx":1841
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 *                 if z_array[i] > zmax:             # <<<<<<<<<<<<<<
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 */
      __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1841, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyObject_RichCompare(__pyx_t_3, __pyx_v_zmax, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1841, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1841, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_9) {

        /* "class-sz/python/classy.pyx":1842
 *             for i in range(n):
 *                 if z_array[i] > zmax:
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)             # <<<<<<<<<<<<<<
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 *                     Dzmax = self.scale_independent_growth_factor(zmax)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pkl_at_k_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1842, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_k_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1842, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_1, __pyx_v_zmax};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1842, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_pk_linzmax, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1843
 *                 if z_array[i] > zmax:
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])             # <<<<<<<<<<<<<<
 *                     Dzmax = self.scale_independent_growth_factor(zmax)
 *                     pk_lin_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1843, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1843, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1843, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_Dz, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1844
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 *                     Dzmax = self.scale_independent_growth_factor(zmax)             # <<<<<<<<<<<<<<
 *                     pk_lin_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)
 *                 else:
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_scale_independent_growth_factor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1844, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_zmax};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1844, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_Dzmax, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":1845
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 *                     Dzmax = self.scale_independent_growth_factor(zmax)
 *                     pk_lin_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     pk_lin_array[i] = self.class_szfast.get_pkl_at_k_and_z(k_array[i], z_array[i])
 */
        __pyx_t_6 = __Pyx_PyNumber_Divide(__pyx_v_Dz, __pyx_v_Dzmax); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1845, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1845, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyFloat_FromDouble(pow(__pyx_t_17, 2.0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1845, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_3 = PyNumber_Multiply(__pyx_v_pk_linzmax, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1845, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_pk_lin_array), __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 1845, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "class-sz/python/classy.pyx":1841
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 *                 if z_array[i] > zmax:             # <<<<<<<<<<<<<<
 *                     pk_linzmax = self.class_szfast.get_pkl_at_k_and_z(k_array[i], zmax)
 *                     Dz = self.scale_independent_growth_factor(z_array[i])
 */
        goto __pyx_L17;
      }

      /* "class-sz/python/classy.pyx":1847
 *                     pk_lin_array[i] = pk_linzmax * pow(Dz / Dzmax, 2.0)
 *                 else:
 *                     pk_lin_array[i] = self.class_szfast.get_pkl_at_k_and_z(k_array[i], z_array[i])             # <<<<<<<<<<<<<<
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):
 */
      /*else*/ {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_pkl_at_k_and_z); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_1 = __Pyx_GetItemInt(((PyObject *)__pyx_v_k_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_2 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_1, __pyx_t_7};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1847, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_pk_lin_array), __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 1847, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_L17:;
    }

    /* "class-sz/python/classy.pyx":1838
 *         pk_lin_array = np.empty(n, dtype=np.float64)
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *             zmax = self.class_szfast.cszfast_pk_grid_zmax
 *             for i in range(n):
 */
    goto __pyx_L14;
  }

  /* "class-sz/python/classy.pyx":1849
 *                     pk_lin_array[i] = self.class_szfast.get_pkl_at_k_and_z(k_array[i], z_array[i])
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  /*else*/ {
    __pyx_t_9 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
    if (unlikely(__pyx_t_9)) {

      /* "class-sz/python/classy.pyx":1850
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *             for i in range(n):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_kp_u_No_power_spectrum_computed_You_m};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1850, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1850, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1849
 *                     pk_lin_array[i] = self.class_szfast.get_pkl_at_k_and_z(k_array[i], z_array[i])
 *         else:
 *             if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1852
 *                 raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk_lin, NULL) == _FAILURE_:
 *                     raise CosmoSevereError(self.nl.error_message)
 */
    __pyx_t_14 = __pyx_v_n;
    __pyx_t_15 = __pyx_t_14;
    for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
      __pyx_v_i = __pyx_t_16;

      /* "class-sz/python/classy.pyx":1853
 * 
 *             for i in range(n):
 *                 if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk_lin, NULL) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                     raise CosmoSevereError(self.nl.error_message)
 *                 pk_lin_array[i] = pk_lin
 */
      __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_k_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1853, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_18 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1853, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_linear, __pyx_t_17, __pyx_t_18, __pyx_v_self->nl.index_pk_m, (&__pyx_v_pk_lin), NULL) == _FAILURE_);
      if (unlikely(__pyx_t_9)) {

        /* "class-sz/python/classy.pyx":1854
 *             for i in range(n):
 *                 if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk_lin, NULL) == _FAILURE_:
 *                     raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 *                 pk_lin_array[i] = pk_lin
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1854, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1854, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_1 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_7};
          __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1854, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 1854, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":1853
 * 
 *             for i in range(n):
 *                 if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk_lin, NULL) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                     raise CosmoSevereError(self.nl.error_message)
 *                 pk_lin_array[i] = pk_lin
 */
      }

      /* "class-sz/python/classy.pyx":1855
 *                 if nonlinear_pk_at_k_and_z(&self.ba, &self.pm, &self.nl, pk_linear, k_array[i], z_array[i], self.nl.index_pk_m, &pk_lin, NULL) == _FAILURE_:
 *                     raise CosmoSevereError(self.nl.error_message)
 *                 pk_lin_array[i] = pk_lin             # <<<<<<<<<<<<<<
 * 
 *         # Return a scalar if the input was scalar, otherwise return the array
 */
      __pyx_t_3 = PyFloat_FromDouble(__pyx_v_pk_lin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1855, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_pk_lin_array), __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 1855, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
  }
  __pyx_L14:;

  /* "class-sz/python/classy.pyx":1858
 * 
 *         # Return a scalar if the input was scalar, otherwise return the array
 *         if pk_lin_array.size == 1:             # <<<<<<<<<<<<<<
 *             return pk_lin_array[0]
 *         else:
 */
  __pyx_t_9 = (__pyx_f_5numpy_7ndarray_4size_size(__pyx_v_pk_lin_array) == 1);
  if (__pyx_t_9) {

    /* "class-sz/python/classy.pyx":1859
 *         # Return a scalar if the input was scalar, otherwise return the array
 *         if pk_lin_array.size == 1:
 *             return pk_lin_array[0]             # <<<<<<<<<<<<<<
 *         else:
 *             return pk_lin_array
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_pk_lin_array), 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":1858
 * 
 *         # Return a scalar if the input was scalar, otherwise return the array
 *         if pk_lin_array.size == 1:             # <<<<<<<<<<<<<<
 *             return pk_lin_array[0]
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":1861
 *             return pk_lin_array[0]
 *         else:
 *             return pk_lin_array             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_pk_lin_array);
    __pyx_r = ((PyObject *)__pyx_v_pk_lin_array);
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":1810
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.pk_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_k_array);
  __Pyx_XDECREF((PyObject *)__pyx_v_z_array);
  __Pyx_XDECREF((PyObject *)__pyx_v_pk_lin_array);
  __Pyx_XDECREF(__pyx_v_zmax);
  __Pyx_XDECREF(__pyx_v_pk_linzmax);
  __Pyx_XDECREF(__pyx_v_Dz);
  __Pyx_XDECREF(__pyx_v_Dzmax);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1867
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_nonlin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_53pk_nonlin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_52pk_nonlin, "\n        Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z\n\n        .. note::\n\n            there is an additional check that output contains `mPk`,\n            because otherwise a segfault will occur\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_53pk_nonlin = {"pk_nonlin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_53pk_nonlin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_52pk_nonlin};
static PyObject *__pyx_pw_9classy_sz_5Class_53pk_nonlin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_nonlin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1867, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1867, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk_nonlin", 1, 2, 2, 1); __PYX_ERR(0, 1867, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk_nonlin") < 0)) __PYX_ERR(0, 1867, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1867, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1867, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk_nonlin", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1867, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk_nonlin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_52pk_nonlin(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_52pk_nonlin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z) {
  double __pyx_v_pk_lin;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_nonlin", 1);

  /* "class-sz/python/classy.pyx":1879
 *         cdef double pk_lin
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":1880
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_No_power_spectrum_computed_You_m};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1880, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1879
 *         cdef double pk_lin
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":1882
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  __pyx_t_1 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_nonlinear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_m, (&__pyx_v_pk_lin), NULL) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":1883
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:
 *             raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return pk_lin
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1883, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1882
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_nonlinear,k,z,self.nl.index_pk_m,&pk_lin,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":1885
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 *         return pk_lin             # <<<<<<<<<<<<<<
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_pk_lin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1867
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_nonlin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.pk_nonlin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1888
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb_lin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_55pk_cb_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_54pk_cb_lin, "\n        Gives the linear cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z\n\n        .. note::\n\n            there is an additional check that output contains `mPk`,\n            because otherwise a segfault will occur\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_55pk_cb_lin = {"pk_cb_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_55pk_cb_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_54pk_cb_lin};
static PyObject *__pyx_pw_9classy_sz_5Class_55pk_cb_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_cb_lin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1888, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1888, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk_cb_lin", 1, 2, 2, 1); __PYX_ERR(0, 1888, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk_cb_lin") < 0)) __PYX_ERR(0, 1888, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1888, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 1888, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk_cb_lin", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1888, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk_cb_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_54pk_cb_lin(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_54pk_cb_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z) {
  double __pyx_v_pk_cb_lin;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_cb_lin", 1);

  /* "class-sz/python/classy.pyx":1900
 *         cdef double pk_cb_lin
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":1901
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1901, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_No_power_spectrum_computed_You_m};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1901, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1901, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1900
 *         cdef double pk_cb_lin
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":1903
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("P_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->nl.has_pk_cb == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":1904
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):
 *             raise CosmoSevereError("P_cb not computed by CLASS (probably because there are no massive neutrinos)")             # <<<<<<<<<<<<<<
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb_lin,NULL)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_P_cb_not_computed_by_CLASS_proba};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1904, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1904, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1903
 *             raise CosmoSevereError("No power spectrum computed. You must add mPk to the list of outputs.")
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("P_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":1906
 *             raise CosmoSevereError("P_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb_lin,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  __pyx_t_1 = (nonlinear_pk_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_linear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_cb, (&__pyx_v_pk_cb_lin), NULL) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":1907
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb_lin,NULL)==_FAILURE_:
 *             raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return pk_cb_lin
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1907, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 1907, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":1906
 *             raise CosmoSevereError("P_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 *         if nonlinear_pk_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_cb,&pk_cb_lin,NULL)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":1909
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 *         return pk_cb_lin             # <<<<<<<<<<<<<<
 * 
 *     #def get_pk(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_pk_cb_lin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1888
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb_lin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.pk_cb_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1922
 *     #    return pk
 * 
 *     def get_pk_cb(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_57get_pk_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_56get_pk_cb, " Fast function to get the power spectrum on a k and z array ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_57get_pk_cb = {"get_pk_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_57get_pk_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_56get_pk_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_57get_pk_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_k = 0;
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_k_size;
  int __pyx_v_z_size;
  int __pyx_v_mu_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,&__pyx_n_s_k_size,&__pyx_n_s_z_size,&__pyx_n_s_mu_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb", 1, 5, 5, 1); __PYX_ERR(0, 1922, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb", 1, 5, 5, 2); __PYX_ERR(0, 1922, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb", 1, 5, 5, 3); __PYX_ERR(0, 1922, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mu_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb", 1, 5, 5, 4); __PYX_ERR(0, 1922, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_cb") < 0)) __PYX_ERR(0, 1922, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_k = ((PyArrayObject *)values[0]);
    __pyx_v_z = ((PyArrayObject *)values[1]);
    __pyx_v_k_size = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
    __pyx_v_mu_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_mu_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1922, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_cb", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 1922, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_k), __pyx_ptype_5numpy_ndarray, 1, "k", 0))) __PYX_ERR(0, 1922, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 1922, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_56get_pk_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z, __pyx_v_k_size, __pyx_v_z_size, __pyx_v_mu_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_56get_pk_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, int __pyx_v_mu_size) {
  PyArrayObject *__pyx_v_pk_cb = 0;
  int __pyx_v_index_k;
  int __pyx_v_index_z;
  int __pyx_v_index_mu;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k;
  __Pyx_Buffer __pyx_pybuffer_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk_cb;
  __Pyx_Buffer __pyx_pybuffer_pk_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  int __pyx_t_17;
  Py_ssize_t __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  Py_ssize_t __pyx_t_20;
  int __pyx_t_21;
  __pyx_t_9classy_sz_DTYPE_t __pyx_t_22;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_cb", 1);
  __pyx_pybuffer_pk_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_pk_cb.refcount = 0;
  __pyx_pybuffernd_pk_cb.data = NULL;
  __pyx_pybuffernd_pk_cb.rcbuffer = &__pyx_pybuffer_pk_cb;
  __pyx_pybuffer_k.pybuffer.buf = NULL;
  __pyx_pybuffer_k.refcount = 0;
  __pyx_pybuffernd_k.data = NULL;
  __pyx_pybuffernd_k.rcbuffer = &__pyx_pybuffer_k;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k.rcbuffer->pybuffer, (PyObject*)__pyx_v_k, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 3, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1922, __pyx_L1_error)
  }
  __pyx_pybuffernd_k.diminfo[0].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k.diminfo[0].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_k.diminfo[1].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_k.diminfo[1].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[1]; __pyx_pybuffernd_k.diminfo[2].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[2]; __pyx_pybuffernd_k.diminfo[2].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[2];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1922, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":1924
 *     def get_pk_cb(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')             # <<<<<<<<<<<<<<
 *         cdef int index_k, index_z, index_mu
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_k_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_mu_size); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 1924, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(0, 1924, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5)) __PYX_ERR(0, 1924, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_6, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1924, __pyx_L1_error)
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 3, 0, __pyx_stack) == -1)) {
      __pyx_v_pk_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 1924, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk_cb.diminfo[0].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk_cb.diminfo[0].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_pk_cb.diminfo[1].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_pk_cb.diminfo[1].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[1]; __pyx_pybuffernd_pk_cb.diminfo[2].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[2]; __pyx_pybuffernd_pk_cb.diminfo[2].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[2];
    }
  }
  __pyx_t_8 = 0;
  __pyx_v_pk_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1927
 *         cdef int index_k, index_z, index_mu
 * 
 *         for index_k in xrange(k_size):             # <<<<<<<<<<<<<<
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):
 */
  __pyx_t_9 = __pyx_v_k_size;
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_index_k = __pyx_t_11;

    /* "class-sz/python/classy.pyx":1928
 * 
 *         for index_k in xrange(k_size):
 *             for index_z in xrange(z_size):             # <<<<<<<<<<<<<<
 *                 for index_mu in xrange(mu_size):
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb(k[index_k,index_z,index_mu],z[index_z])
 */
    __pyx_t_12 = __pyx_v_z_size;
    __pyx_t_13 = __pyx_t_12;
    for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
      __pyx_v_index_z = __pyx_t_14;

      /* "class-sz/python/classy.pyx":1929
 *         for index_k in xrange(k_size):
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):             # <<<<<<<<<<<<<<
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb(k[index_k,index_z,index_mu],z[index_z])
 *         return pk_cb
 */
      __pyx_t_15 = __pyx_v_mu_size;
      __pyx_t_16 = __pyx_t_15;
      for (__pyx_t_17 = 0; __pyx_t_17 < __pyx_t_16; __pyx_t_17+=1) {
        __pyx_v_index_mu = __pyx_t_17;

        /* "class-sz/python/classy.pyx":1930
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb(k[index_k,index_z,index_mu],z[index_z])             # <<<<<<<<<<<<<<
 *         return pk_cb
 * 
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pk_cb); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1930, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_18 = __pyx_v_index_k;
        __pyx_t_19 = __pyx_v_index_z;
        __pyx_t_20 = __pyx_v_index_mu;
        __pyx_t_21 = -1;
        if (__pyx_t_18 < 0) {
          __pyx_t_18 += __pyx_pybuffernd_k.diminfo[0].shape;
          if (unlikely(__pyx_t_18 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_18 >= __pyx_pybuffernd_k.diminfo[0].shape)) __pyx_t_21 = 0;
        if (__pyx_t_19 < 0) {
          __pyx_t_19 += __pyx_pybuffernd_k.diminfo[1].shape;
          if (unlikely(__pyx_t_19 < 0)) __pyx_t_21 = 1;
        } else if (unlikely(__pyx_t_19 >= __pyx_pybuffernd_k.diminfo[1].shape)) __pyx_t_21 = 1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_k.diminfo[2].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 2;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_k.diminfo[2].shape)) __pyx_t_21 = 2;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1930, __pyx_L1_error)
        }
        __pyx_t_6 = PyFloat_FromDouble((*__Pyx_BufPtrStrided3d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k.rcbuffer->pybuffer.buf, __pyx_t_18, __pyx_pybuffernd_k.diminfo[0].strides, __pyx_t_19, __pyx_pybuffernd_k.diminfo[1].strides, __pyx_t_20, __pyx_pybuffernd_k.diminfo[2].strides))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1930, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_20 = __pyx_v_index_z;
        __pyx_t_21 = -1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_z.diminfo[0].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_21 = 0;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1930, __pyx_L1_error)
        }
        __pyx_t_5 = PyFloat_FromDouble((*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_z.diminfo[0].strides))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1930, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_6, __pyx_t_5};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1930, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_t_22 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_22 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1930, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_20 = __pyx_v_index_k;
        __pyx_t_19 = __pyx_v_index_z;
        __pyx_t_18 = __pyx_v_index_mu;
        __pyx_t_21 = -1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_pk_cb.diminfo[0].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_pk_cb.diminfo[0].shape)) __pyx_t_21 = 0;
        if (__pyx_t_19 < 0) {
          __pyx_t_19 += __pyx_pybuffernd_pk_cb.diminfo[1].shape;
          if (unlikely(__pyx_t_19 < 0)) __pyx_t_21 = 1;
        } else if (unlikely(__pyx_t_19 >= __pyx_pybuffernd_pk_cb.diminfo[1].shape)) __pyx_t_21 = 1;
        if (__pyx_t_18 < 0) {
          __pyx_t_18 += __pyx_pybuffernd_pk_cb.diminfo[2].shape;
          if (unlikely(__pyx_t_18 < 0)) __pyx_t_21 = 2;
        } else if (unlikely(__pyx_t_18 >= __pyx_pybuffernd_pk_cb.diminfo[2].shape)) __pyx_t_21 = 2;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1930, __pyx_L1_error)
        }
        *__Pyx_BufPtrStrided3d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_pk_cb.diminfo[0].strides, __pyx_t_19, __pyx_pybuffernd_pk_cb.diminfo[1].strides, __pyx_t_18, __pyx_pybuffernd_pk_cb.diminfo[2].strides) = __pyx_t_22;
      }
    }
  }

  /* "class-sz/python/classy.pyx":1931
 *                 for index_mu in xrange(mu_size):
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb(k[index_k,index_z,index_mu],z[index_z])
 *         return pk_cb             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_pk_cb);
  __pyx_r = ((PyObject *)__pyx_v_pk_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1922
 *     #    return pk
 * 
 *     def get_pk_cb(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.get_pk_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pk_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1933
 *         return pk_cb
 * 
 *     def get_pk_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk = np.zeros((k_size,z_size,mu_size),'float64')
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_59get_pk_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_58get_pk_lin, " Fast function to get the linear power spectrum on a k and z array ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_59get_pk_lin = {"get_pk_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_59get_pk_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_58get_pk_lin};
static PyObject *__pyx_pw_9classy_sz_5Class_59get_pk_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_k = 0;
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_k_size;
  int __pyx_v_z_size;
  int __pyx_v_mu_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_lin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,&__pyx_n_s_k_size,&__pyx_n_s_z_size,&__pyx_n_s_mu_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_lin", 1, 5, 5, 1); __PYX_ERR(0, 1933, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_lin", 1, 5, 5, 2); __PYX_ERR(0, 1933, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_lin", 1, 5, 5, 3); __PYX_ERR(0, 1933, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mu_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_lin", 1, 5, 5, 4); __PYX_ERR(0, 1933, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_lin") < 0)) __PYX_ERR(0, 1933, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_k = ((PyArrayObject *)values[0]);
    __pyx_v_z = ((PyArrayObject *)values[1]);
    __pyx_v_k_size = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
    __pyx_v_mu_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_mu_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1933, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_lin", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 1933, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_k), __pyx_ptype_5numpy_ndarray, 1, "k", 0))) __PYX_ERR(0, 1933, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 1933, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_58get_pk_lin(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z, __pyx_v_k_size, __pyx_v_z_size, __pyx_v_mu_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_58get_pk_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, int __pyx_v_mu_size) {
  PyArrayObject *__pyx_v_pk = 0;
  int __pyx_v_index_k;
  int __pyx_v_index_z;
  int __pyx_v_index_mu;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k;
  __Pyx_Buffer __pyx_pybuffer_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk;
  __Pyx_Buffer __pyx_pybuffer_pk;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  int __pyx_t_17;
  Py_ssize_t __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  Py_ssize_t __pyx_t_20;
  int __pyx_t_21;
  __pyx_t_9classy_sz_DTYPE_t __pyx_t_22;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_lin", 1);
  __pyx_pybuffer_pk.pybuffer.buf = NULL;
  __pyx_pybuffer_pk.refcount = 0;
  __pyx_pybuffernd_pk.data = NULL;
  __pyx_pybuffernd_pk.rcbuffer = &__pyx_pybuffer_pk;
  __pyx_pybuffer_k.pybuffer.buf = NULL;
  __pyx_pybuffer_k.refcount = 0;
  __pyx_pybuffernd_k.data = NULL;
  __pyx_pybuffernd_k.rcbuffer = &__pyx_pybuffer_k;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k.rcbuffer->pybuffer, (PyObject*)__pyx_v_k, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 3, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1933, __pyx_L1_error)
  }
  __pyx_pybuffernd_k.diminfo[0].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k.diminfo[0].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_k.diminfo[1].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_k.diminfo[1].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[1]; __pyx_pybuffernd_k.diminfo[2].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[2]; __pyx_pybuffernd_k.diminfo[2].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[2];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1933, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":1935
 *     def get_pk_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk = np.zeros((k_size,z_size,mu_size),'float64')             # <<<<<<<<<<<<<<
 *         cdef int index_k, index_z, index_mu
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_k_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_mu_size); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 1935, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(0, 1935, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5)) __PYX_ERR(0, 1935, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_6, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1935, __pyx_L1_error)
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 3, 0, __pyx_stack) == -1)) {
      __pyx_v_pk = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 1935, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk.diminfo[0].strides = __pyx_pybuffernd_pk.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk.diminfo[0].shape = __pyx_pybuffernd_pk.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_pk.diminfo[1].strides = __pyx_pybuffernd_pk.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_pk.diminfo[1].shape = __pyx_pybuffernd_pk.rcbuffer->pybuffer.shape[1]; __pyx_pybuffernd_pk.diminfo[2].strides = __pyx_pybuffernd_pk.rcbuffer->pybuffer.strides[2]; __pyx_pybuffernd_pk.diminfo[2].shape = __pyx_pybuffernd_pk.rcbuffer->pybuffer.shape[2];
    }
  }
  __pyx_t_8 = 0;
  __pyx_v_pk = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1938
 *         cdef int index_k, index_z, index_mu
 * 
 *         for index_k in xrange(k_size):             # <<<<<<<<<<<<<<
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):
 */
  __pyx_t_9 = __pyx_v_k_size;
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_index_k = __pyx_t_11;

    /* "class-sz/python/classy.pyx":1939
 * 
 *         for index_k in xrange(k_size):
 *             for index_z in xrange(z_size):             # <<<<<<<<<<<<<<
 *                 for index_mu in xrange(mu_size):
 *                     pk[index_k,index_z,index_mu] = self.pk_lin(k[index_k,index_z,index_mu],z[index_z])
 */
    __pyx_t_12 = __pyx_v_z_size;
    __pyx_t_13 = __pyx_t_12;
    for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
      __pyx_v_index_z = __pyx_t_14;

      /* "class-sz/python/classy.pyx":1940
 *         for index_k in xrange(k_size):
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):             # <<<<<<<<<<<<<<
 *                     pk[index_k,index_z,index_mu] = self.pk_lin(k[index_k,index_z,index_mu],z[index_z])
 *         return pk
 */
      __pyx_t_15 = __pyx_v_mu_size;
      __pyx_t_16 = __pyx_t_15;
      for (__pyx_t_17 = 0; __pyx_t_17 < __pyx_t_16; __pyx_t_17+=1) {
        __pyx_v_index_mu = __pyx_t_17;

        /* "class-sz/python/classy.pyx":1941
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):
 *                     pk[index_k,index_z,index_mu] = self.pk_lin(k[index_k,index_z,index_mu],z[index_z])             # <<<<<<<<<<<<<<
 *         return pk
 * 
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pk_lin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1941, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_18 = __pyx_v_index_k;
        __pyx_t_19 = __pyx_v_index_z;
        __pyx_t_20 = __pyx_v_index_mu;
        __pyx_t_21 = -1;
        if (__pyx_t_18 < 0) {
          __pyx_t_18 += __pyx_pybuffernd_k.diminfo[0].shape;
          if (unlikely(__pyx_t_18 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_18 >= __pyx_pybuffernd_k.diminfo[0].shape)) __pyx_t_21 = 0;
        if (__pyx_t_19 < 0) {
          __pyx_t_19 += __pyx_pybuffernd_k.diminfo[1].shape;
          if (unlikely(__pyx_t_19 < 0)) __pyx_t_21 = 1;
        } else if (unlikely(__pyx_t_19 >= __pyx_pybuffernd_k.diminfo[1].shape)) __pyx_t_21 = 1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_k.diminfo[2].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 2;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_k.diminfo[2].shape)) __pyx_t_21 = 2;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1941, __pyx_L1_error)
        }
        __pyx_t_6 = PyFloat_FromDouble((*__Pyx_BufPtrStrided3d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k.rcbuffer->pybuffer.buf, __pyx_t_18, __pyx_pybuffernd_k.diminfo[0].strides, __pyx_t_19, __pyx_pybuffernd_k.diminfo[1].strides, __pyx_t_20, __pyx_pybuffernd_k.diminfo[2].strides))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1941, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_20 = __pyx_v_index_z;
        __pyx_t_21 = -1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_z.diminfo[0].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_21 = 0;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1941, __pyx_L1_error)
        }
        __pyx_t_5 = PyFloat_FromDouble((*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_z.diminfo[0].strides))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1941, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_6, __pyx_t_5};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1941, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_t_22 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_22 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1941, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_20 = __pyx_v_index_k;
        __pyx_t_19 = __pyx_v_index_z;
        __pyx_t_18 = __pyx_v_index_mu;
        __pyx_t_21 = -1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_pk.diminfo[0].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_pk.diminfo[0].shape)) __pyx_t_21 = 0;
        if (__pyx_t_19 < 0) {
          __pyx_t_19 += __pyx_pybuffernd_pk.diminfo[1].shape;
          if (unlikely(__pyx_t_19 < 0)) __pyx_t_21 = 1;
        } else if (unlikely(__pyx_t_19 >= __pyx_pybuffernd_pk.diminfo[1].shape)) __pyx_t_21 = 1;
        if (__pyx_t_18 < 0) {
          __pyx_t_18 += __pyx_pybuffernd_pk.diminfo[2].shape;
          if (unlikely(__pyx_t_18 < 0)) __pyx_t_21 = 2;
        } else if (unlikely(__pyx_t_18 >= __pyx_pybuffernd_pk.diminfo[2].shape)) __pyx_t_21 = 2;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1941, __pyx_L1_error)
        }
        *__Pyx_BufPtrStrided3d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_pk.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_pk.diminfo[0].strides, __pyx_t_19, __pyx_pybuffernd_pk.diminfo[1].strides, __pyx_t_18, __pyx_pybuffernd_pk.diminfo[2].strides) = __pyx_t_22;
      }
    }
  }

  /* "class-sz/python/classy.pyx":1942
 *                 for index_mu in xrange(mu_size):
 *                     pk[index_k,index_z,index_mu] = self.pk_lin(k[index_k,index_z,index_mu],z[index_z])
 *         return pk             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_cb_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_pk);
  __pyx_r = ((PyObject *)__pyx_v_pk);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1933
 *         return pk_cb
 * 
 *     def get_pk_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk = np.zeros((k_size,z_size,mu_size),'float64')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.get_pk_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pk);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1944
 *         return pk
 * 
 *     def get_pk_cb_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_61get_pk_cb_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_60get_pk_cb_lin, " Fast function to get the linear power spectrum on a k and z array ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_61get_pk_cb_lin = {"get_pk_cb_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_61get_pk_cb_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_60get_pk_cb_lin};
static PyObject *__pyx_pw_9classy_sz_5Class_61get_pk_cb_lin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_k = 0;
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_k_size;
  int __pyx_v_z_size;
  int __pyx_v_mu_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_cb_lin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,&__pyx_n_s_k_size,&__pyx_n_s_z_size,&__pyx_n_s_mu_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_lin", 1, 5, 5, 1); __PYX_ERR(0, 1944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_lin", 1, 5, 5, 2); __PYX_ERR(0, 1944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_lin", 1, 5, 5, 3); __PYX_ERR(0, 1944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mu_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_lin", 1, 5, 5, 4); __PYX_ERR(0, 1944, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_cb_lin") < 0)) __PYX_ERR(0, 1944, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_k = ((PyArrayObject *)values[0]);
    __pyx_v_z = ((PyArrayObject *)values[1]);
    __pyx_v_k_size = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
    __pyx_v_mu_size = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_mu_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1944, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_cb_lin", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 1944, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_cb_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_k), __pyx_ptype_5numpy_ndarray, 1, "k", 0))) __PYX_ERR(0, 1944, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 1944, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_60get_pk_cb_lin(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z, __pyx_v_k_size, __pyx_v_z_size, __pyx_v_mu_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_60get_pk_cb_lin(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, int __pyx_v_mu_size) {
  PyArrayObject *__pyx_v_pk_cb = 0;
  int __pyx_v_index_k;
  int __pyx_v_index_z;
  int __pyx_v_index_mu;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k;
  __Pyx_Buffer __pyx_pybuffer_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk_cb;
  __Pyx_Buffer __pyx_pybuffer_pk_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  int __pyx_t_17;
  Py_ssize_t __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  Py_ssize_t __pyx_t_20;
  int __pyx_t_21;
  __pyx_t_9classy_sz_DTYPE_t __pyx_t_22;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_cb_lin", 1);
  __pyx_pybuffer_pk_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_pk_cb.refcount = 0;
  __pyx_pybuffernd_pk_cb.data = NULL;
  __pyx_pybuffernd_pk_cb.rcbuffer = &__pyx_pybuffer_pk_cb;
  __pyx_pybuffer_k.pybuffer.buf = NULL;
  __pyx_pybuffer_k.refcount = 0;
  __pyx_pybuffernd_k.data = NULL;
  __pyx_pybuffernd_k.rcbuffer = &__pyx_pybuffer_k;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k.rcbuffer->pybuffer, (PyObject*)__pyx_v_k, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 3, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1944, __pyx_L1_error)
  }
  __pyx_pybuffernd_k.diminfo[0].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k.diminfo[0].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_k.diminfo[1].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_k.diminfo[1].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[1]; __pyx_pybuffernd_k.diminfo[2].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[2]; __pyx_pybuffernd_k.diminfo[2].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[2];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 1944, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":1946
 *     def get_pk_cb_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')             # <<<<<<<<<<<<<<
 *         cdef int index_k, index_z, index_mu
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_k_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_mu_size); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_6, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1946, __pyx_L1_error)
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 3, 0, __pyx_stack) == -1)) {
      __pyx_v_pk_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 1946, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk_cb.diminfo[0].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk_cb.diminfo[0].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_pk_cb.diminfo[1].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_pk_cb.diminfo[1].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[1]; __pyx_pybuffernd_pk_cb.diminfo[2].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[2]; __pyx_pybuffernd_pk_cb.diminfo[2].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[2];
    }
  }
  __pyx_t_8 = 0;
  __pyx_v_pk_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1949
 *         cdef int index_k, index_z, index_mu
 * 
 *         for index_k in xrange(k_size):             # <<<<<<<<<<<<<<
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):
 */
  __pyx_t_9 = __pyx_v_k_size;
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_index_k = __pyx_t_11;

    /* "class-sz/python/classy.pyx":1950
 * 
 *         for index_k in xrange(k_size):
 *             for index_z in xrange(z_size):             # <<<<<<<<<<<<<<
 *                 for index_mu in xrange(mu_size):
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb_lin(k[index_k,index_z,index_mu],z[index_z])
 */
    __pyx_t_12 = __pyx_v_z_size;
    __pyx_t_13 = __pyx_t_12;
    for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
      __pyx_v_index_z = __pyx_t_14;

      /* "class-sz/python/classy.pyx":1951
 *         for index_k in xrange(k_size):
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):             # <<<<<<<<<<<<<<
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb_lin(k[index_k,index_z,index_mu],z[index_z])
 *         return pk_cb
 */
      __pyx_t_15 = __pyx_v_mu_size;
      __pyx_t_16 = __pyx_t_15;
      for (__pyx_t_17 = 0; __pyx_t_17 < __pyx_t_16; __pyx_t_17+=1) {
        __pyx_v_index_mu = __pyx_t_17;

        /* "class-sz/python/classy.pyx":1952
 *             for index_z in xrange(z_size):
 *                 for index_mu in xrange(mu_size):
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb_lin(k[index_k,index_z,index_mu],z[index_z])             # <<<<<<<<<<<<<<
 *         return pk_cb
 * 
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pk_cb_lin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1952, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_18 = __pyx_v_index_k;
        __pyx_t_19 = __pyx_v_index_z;
        __pyx_t_20 = __pyx_v_index_mu;
        __pyx_t_21 = -1;
        if (__pyx_t_18 < 0) {
          __pyx_t_18 += __pyx_pybuffernd_k.diminfo[0].shape;
          if (unlikely(__pyx_t_18 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_18 >= __pyx_pybuffernd_k.diminfo[0].shape)) __pyx_t_21 = 0;
        if (__pyx_t_19 < 0) {
          __pyx_t_19 += __pyx_pybuffernd_k.diminfo[1].shape;
          if (unlikely(__pyx_t_19 < 0)) __pyx_t_21 = 1;
        } else if (unlikely(__pyx_t_19 >= __pyx_pybuffernd_k.diminfo[1].shape)) __pyx_t_21 = 1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_k.diminfo[2].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 2;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_k.diminfo[2].shape)) __pyx_t_21 = 2;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1952, __pyx_L1_error)
        }
        __pyx_t_6 = PyFloat_FromDouble((*__Pyx_BufPtrStrided3d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k.rcbuffer->pybuffer.buf, __pyx_t_18, __pyx_pybuffernd_k.diminfo[0].strides, __pyx_t_19, __pyx_pybuffernd_k.diminfo[1].strides, __pyx_t_20, __pyx_pybuffernd_k.diminfo[2].strides))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1952, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_20 = __pyx_v_index_z;
        __pyx_t_21 = -1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_z.diminfo[0].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_21 = 0;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1952, __pyx_L1_error)
        }
        __pyx_t_5 = PyFloat_FromDouble((*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_z.diminfo[0].strides))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1952, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_6, __pyx_t_5};
          __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1952, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_t_22 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_22 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1952, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_20 = __pyx_v_index_k;
        __pyx_t_19 = __pyx_v_index_z;
        __pyx_t_18 = __pyx_v_index_mu;
        __pyx_t_21 = -1;
        if (__pyx_t_20 < 0) {
          __pyx_t_20 += __pyx_pybuffernd_pk_cb.diminfo[0].shape;
          if (unlikely(__pyx_t_20 < 0)) __pyx_t_21 = 0;
        } else if (unlikely(__pyx_t_20 >= __pyx_pybuffernd_pk_cb.diminfo[0].shape)) __pyx_t_21 = 0;
        if (__pyx_t_19 < 0) {
          __pyx_t_19 += __pyx_pybuffernd_pk_cb.diminfo[1].shape;
          if (unlikely(__pyx_t_19 < 0)) __pyx_t_21 = 1;
        } else if (unlikely(__pyx_t_19 >= __pyx_pybuffernd_pk_cb.diminfo[1].shape)) __pyx_t_21 = 1;
        if (__pyx_t_18 < 0) {
          __pyx_t_18 += __pyx_pybuffernd_pk_cb.diminfo[2].shape;
          if (unlikely(__pyx_t_18 < 0)) __pyx_t_21 = 2;
        } else if (unlikely(__pyx_t_18 >= __pyx_pybuffernd_pk_cb.diminfo[2].shape)) __pyx_t_21 = 2;
        if (unlikely(__pyx_t_21 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_21);
          __PYX_ERR(0, 1952, __pyx_L1_error)
        }
        *__Pyx_BufPtrStrided3d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_pk_cb.diminfo[0].strides, __pyx_t_19, __pyx_pybuffernd_pk_cb.diminfo[1].strides, __pyx_t_18, __pyx_pybuffernd_pk_cb.diminfo[2].strides) = __pyx_t_22;
      }
    }
  }

  /* "class-sz/python/classy.pyx":1953
 *                 for index_mu in xrange(mu_size):
 *                     pk_cb[index_k,index_z,index_mu] = self.pk_cb_lin(k[index_k,index_z,index_mu],z[index_z])
 *         return pk_cb             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_and_k_and_z(self, nonlinear=True, only_clustering_species = False,h_units=False):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_pk_cb);
  __pyx_r = ((PyObject *)__pyx_v_pk_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":1944
 *         return pk
 * 
 *     def get_pk_cb_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.get_pk_cb_lin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pk_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":1955
 *         return pk_cb
 * 
 *     def get_pk_and_k_and_z(self, nonlinear=True, only_clustering_species = False,h_units=False):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a grid of matter power spectrum values and the z and k
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_63get_pk_and_k_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_62get_pk_and_k_and_z, "\n        Returns a grid of matter power spectrum values and the z and k\n        at which it has been fully computed. Useful for creating interpolators.\n\n        Parameters\n        ----------\n        nonlinear : bool\n                Whether the returned power spectrum values are linear or non-linear (default)\n        nonlinear : bool\n                Whether the returned power spectrum is for galaxy clustering and excludes massive neutrinos, or always includes evrything (default)\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_63get_pk_and_k_and_z = {"get_pk_and_k_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_63get_pk_and_k_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_62get_pk_and_k_and_z};
static PyObject *__pyx_pw_9classy_sz_5Class_63get_pk_and_k_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_nonlinear = 0;
  PyObject *__pyx_v_only_clustering_species = 0;
  PyObject *__pyx_v_h_units = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_and_k_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nonlinear,&__pyx_n_s_only_clustering_species,&__pyx_n_s_h_units,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nonlinear);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1955, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_only_clustering_species);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1955, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_h_units);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1955, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_and_k_and_z") < 0)) __PYX_ERR(0, 1955, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_nonlinear = values[0];
    __pyx_v_only_clustering_species = values[1];
    __pyx_v_h_units = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_and_k_and_z", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 1955, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_and_k_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_62get_pk_and_k_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_nonlinear, __pyx_v_only_clustering_species, __pyx_v_h_units);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_62get_pk_and_k_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nonlinear, PyObject *__pyx_v_only_clustering_species, PyObject *__pyx_v_h_units) {
  PyArrayObject *__pyx_v_pk_at_k_z = 0;
  PyArrayObject *__pyx_v_k = 0;
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_index_k;
  int __pyx_v_index_tau;
  int __pyx_v_index_pk;
  CYTHON_UNUSED double __pyx_v_z_max_nonlinear;
  CYTHON_UNUSED double __pyx_v_z_max_requested;
  double __pyx_v_units;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k;
  __Pyx_Buffer __pyx_pybuffer_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk_at_k_z;
  __Pyx_Buffer __pyx_pybuffer_pk_at_k_z;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyArrayObject *__pyx_t_7 = NULL;
  PyArrayObject *__pyx_t_8 = NULL;
  PyArrayObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  __pyx_t_9classy_sz_DTYPE_t __pyx_t_18;
  double __pyx_t_19;
  int __pyx_t_20;
  int __pyx_t_21;
  Py_ssize_t __pyx_t_22;
  int __pyx_t_23;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_and_k_and_z", 1);
  __pyx_pybuffer_pk_at_k_z.pybuffer.buf = NULL;
  __pyx_pybuffer_pk_at_k_z.refcount = 0;
  __pyx_pybuffernd_pk_at_k_z.data = NULL;
  __pyx_pybuffernd_pk_at_k_z.rcbuffer = &__pyx_pybuffer_pk_at_k_z;
  __pyx_pybuffer_k.pybuffer.buf = NULL;
  __pyx_pybuffer_k.refcount = 0;
  __pyx_pybuffernd_k.data = NULL;
  __pyx_pybuffernd_k.rcbuffer = &__pyx_pybuffer_k;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;

  /* "class-sz/python/classy.pyx":1967
 *                 Whether the returned power spectrum is for galaxy clustering and excludes massive neutrinos, or always includes evrything (default)
 *         """
 *         cdef np.ndarray[DTYPE_t,ndim=2] pk_at_k_z = np.zeros((self.nl.k_size, self.nl.ln_tau_size),'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t,ndim=1] k = np.zeros((self.nl.k_size),'float64')
 *         cdef np.ndarray[DTYPE_t,ndim=1] z = np.zeros((self.nl.ln_tau_size),'float64')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->nl.k_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->nl.ln_tau_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 1967, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4)) __PYX_ERR(0, 1967, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_5, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1967, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 2, 0, __pyx_stack) == -1)) {
      __pyx_v_pk_at_k_z = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 1967, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk_at_k_z.diminfo[0].strides = __pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk_at_k_z.diminfo[0].shape = __pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_pk_at_k_z.diminfo[1].strides = __pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_pk_at_k_z.diminfo[1].shape = __pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer.shape[1];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_pk_at_k_z = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1968
 *         """
 *         cdef np.ndarray[DTYPE_t,ndim=2] pk_at_k_z = np.zeros((self.nl.k_size, self.nl.ln_tau_size),'float64')
 *         cdef np.ndarray[DTYPE_t,ndim=1] k = np.zeros((self.nl.k_size),'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t,ndim=1] z = np.zeros((self.nl.ln_tau_size),'float64')
 *         cdef int index_k, index_tau, index_pk
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->nl.k_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1968, __pyx_L1_error)
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_k = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_k.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 1968, __pyx_L1_error)
    } else {__pyx_pybuffernd_k.diminfo[0].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k.diminfo[0].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_8 = 0;
  __pyx_v_k = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1969
 *         cdef np.ndarray[DTYPE_t,ndim=2] pk_at_k_z = np.zeros((self.nl.k_size, self.nl.ln_tau_size),'float64')
 *         cdef np.ndarray[DTYPE_t,ndim=1] k = np.zeros((self.nl.k_size),'float64')
 *         cdef np.ndarray[DTYPE_t,ndim=1] z = np.zeros((self.nl.ln_tau_size),'float64')             # <<<<<<<<<<<<<<
 *         cdef int index_k, index_tau, index_pk
 *         cdef double z_max_nonlinear, z_max_requested
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->nl.ln_tau_size); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_5, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1969, __pyx_L1_error)
  __pyx_t_9 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_t_9, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_z = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_z.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 1969, __pyx_L1_error)
    } else {__pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_9 = 0;
  __pyx_v_z = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":1973
 *         cdef double z_max_nonlinear, z_max_requested
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           if h_units:
 *               units=1./self.ba.h
 */
  __pyx_t_10 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_10) {

    /* "class-sz/python/classy.pyx":1974
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if h_units:             # <<<<<<<<<<<<<<
 *               units=1./self.ba.h
 *           else:
 */
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_h_units); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 1974, __pyx_L1_error)
    if (__pyx_t_10) {

      /* "class-sz/python/classy.pyx":1975
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if h_units:
 *               units=1./self.ba.h             # <<<<<<<<<<<<<<
 *           else:
 *               units=1
 */
      if (unlikely(__pyx_v_self->ba.h == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 1975, __pyx_L1_error)
      }
      __pyx_v_units = (1. / __pyx_v_self->ba.h);

      /* "class-sz/python/classy.pyx":1974
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if h_units:             # <<<<<<<<<<<<<<
 *               units=1./self.ba.h
 *           else:
 */
      goto __pyx_L4;
    }

    /* "class-sz/python/classy.pyx":1977
 *               units=1./self.ba.h
 *           else:
 *               units=1             # <<<<<<<<<<<<<<
 *           return self.class_szfast.cszfast_pk_grid_pknl, self.class_szfast.cszfast_pk_grid_k*units,self.class_szfast.cszfast_pk_grid_z
 *         else:
 */
    /*else*/ {
      __pyx_v_units = 1.0;
    }
    __pyx_L4:;

    /* "class-sz/python/classy.pyx":1978
 *           else:
 *               units=1
 *           return self.class_szfast.cszfast_pk_grid_pknl, self.class_szfast.cszfast_pk_grid_k*units,self.class_szfast.cszfast_pk_grid_z             # <<<<<<<<<<<<<<
 *         else:
 *           # consistency checks
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cszfast_pk_grid_pknl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cszfast_pk_grid_k); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyFloat_FromDouble(__pyx_v_units); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_cszfast_pk_grid_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 1978, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4)) __PYX_ERR(0, 1978, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_5)) __PYX_ERR(0, 1978, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":1973
 *         cdef double z_max_nonlinear, z_max_requested
 * 
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           if h_units:
 *               units=1./self.ba.h
 */
  }

  /* "class-sz/python/classy.pyx":1982
 *           # consistency checks
 * 
 *           if self.nl.has_pk_matter == False:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations; add 'mPk' in 'output'")
 * 
 */
  /*else*/ {
    __pyx_t_10 = (__pyx_v_self->nl.has_pk_matter == 0);
    if (unlikely(__pyx_t_10)) {

      /* "class-sz/python/classy.pyx":1983
 * 
 *           if self.nl.has_pk_matter == False:
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations; add 'mPk' in 'output'")             # <<<<<<<<<<<<<<
 * 
 *           if nonlinear == True and self.nl.method == nl_none:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1983, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_You_ask_classy_to_return_an_arra};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1983, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1983, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1982
 *           # consistency checks
 * 
 *           if self.nl.has_pk_matter == False:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations; add 'mPk' in 'output'")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1985
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations; add 'mPk' in 'output'")
 * 
 *           if nonlinear == True and self.nl.method == nl_none:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("You ask classy to return an array of nonlinear P(k,z) values, but the input parameters sent to CLASS did not require any non-linear P(k,z) calculations; add e.g. 'halofit' or 'HMcode' in 'nonlinear'")
 * 
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_nonlinear, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1985, __pyx_L1_error)
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 1985, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_11) {
    } else {
      __pyx_t_10 = __pyx_t_11;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_11 = (__pyx_v_self->nl.method == nl_none);
    __pyx_t_10 = __pyx_t_11;
    __pyx_L7_bool_binop_done:;
    if (unlikely(__pyx_t_10)) {

      /* "class-sz/python/classy.pyx":1986
 * 
 *           if nonlinear == True and self.nl.method == nl_none:
 *               raise CosmoSevereError("You ask classy to return an array of nonlinear P(k,z) values, but the input parameters sent to CLASS did not require any non-linear P(k,z) calculations; add e.g. 'halofit' or 'HMcode' in 'nonlinear'")             # <<<<<<<<<<<<<<
 * 
 *           # check wich type of P(k) to return (total or clustering only, i.e. without massive neutrino contribution)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1986, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_You_ask_classy_to_return_an_arra_2};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1986, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1986, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1985
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations; add 'mPk' in 'output'")
 * 
 *           if nonlinear == True and self.nl.method == nl_none:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("You ask classy to return an array of nonlinear P(k,z) values, but the input parameters sent to CLASS did not require any non-linear P(k,z) calculations; add e.g. 'halofit' or 'HMcode' in 'nonlinear'")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":1989
 * 
 *           # check wich type of P(k) to return (total or clustering only, i.e. without massive neutrino contribution)
 *           if (only_clustering_species == True):             # <<<<<<<<<<<<<<
 *               index_pk = self.nl.index_pk_cluster
 *           else:
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_only_clustering_species, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1989, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 1989, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_10) {

      /* "class-sz/python/classy.pyx":1990
 *           # check wich type of P(k) to return (total or clustering only, i.e. without massive neutrino contribution)
 *           if (only_clustering_species == True):
 *               index_pk = self.nl.index_pk_cluster             # <<<<<<<<<<<<<<
 *           else:
 *               index_pk = self.nl.index_pk_total
 */
      __pyx_t_12 = __pyx_v_self->nl.index_pk_cluster;
      __pyx_v_index_pk = __pyx_t_12;

      /* "class-sz/python/classy.pyx":1989
 * 
 *           # check wich type of P(k) to return (total or clustering only, i.e. without massive neutrino contribution)
 *           if (only_clustering_species == True):             # <<<<<<<<<<<<<<
 *               index_pk = self.nl.index_pk_cluster
 *           else:
 */
      goto __pyx_L9;
    }

    /* "class-sz/python/classy.pyx":1992
 *               index_pk = self.nl.index_pk_cluster
 *           else:
 *               index_pk = self.nl.index_pk_total             # <<<<<<<<<<<<<<
 * 
 *           # get list of redshfits
 */
    /*else*/ {
      __pyx_t_12 = __pyx_v_self->nl.index_pk_total;
      __pyx_v_index_pk = __pyx_t_12;
    }
    __pyx_L9:;

    /* "class-sz/python/classy.pyx":1996
 *           # get list of redshfits
 * 
 *           if self.nl.ln_tau_size == 1:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations for z>0; pass either a list of z in 'z_pk' or one non-zero value in 'z_max_pk'")
 *           else:
 */
    __pyx_t_10 = (__pyx_v_self->nl.ln_tau_size == 1);
    if (unlikely(__pyx_t_10)) {

      /* "class-sz/python/classy.pyx":1997
 * 
 *           if self.nl.ln_tau_size == 1:
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations for z>0; pass either a list of z in 'z_pk' or one non-zero value in 'z_max_pk'")             # <<<<<<<<<<<<<<
 *           else:
 *               for index_tau in xrange(self.nl.ln_tau_size):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1997, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_You_ask_classy_to_return_an_arra_3};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1997, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 1997, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":1996
 *           # get list of redshfits
 * 
 *           if self.nl.ln_tau_size == 1:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations for z>0; pass either a list of z in 'z_pk' or one non-zero value in 'z_max_pk'")
 *           else:
 */
    }

    /* "class-sz/python/classy.pyx":1999
 *               raise CosmoSevereError("You ask classy to return an array of P(k,z) values, but the input parameters sent to CLASS did not require any P(k,z) calculations for z>0; pass either a list of z in 'z_pk' or one non-zero value in 'z_max_pk'")
 *           else:
 *               for index_tau in xrange(self.nl.ln_tau_size):             # <<<<<<<<<<<<<<
 *                   if index_tau == self.nl.ln_tau_size-1:
 *                       z[index_tau] = 0.
 */
    /*else*/ {
      __pyx_t_12 = __pyx_v_self->nl.ln_tau_size;
      __pyx_t_13 = __pyx_t_12;
      for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
        __pyx_v_index_tau = __pyx_t_14;

        /* "class-sz/python/classy.pyx":2000
 *           else:
 *               for index_tau in xrange(self.nl.ln_tau_size):
 *                   if index_tau == self.nl.ln_tau_size-1:             # <<<<<<<<<<<<<<
 *                       z[index_tau] = 0.
 *                   else:
 */
        __pyx_t_10 = (__pyx_v_index_tau == (__pyx_v_self->nl.ln_tau_size - 1));
        if (__pyx_t_10) {

          /* "class-sz/python/classy.pyx":2001
 *               for index_tau in xrange(self.nl.ln_tau_size):
 *                   if index_tau == self.nl.ln_tau_size-1:
 *                       z[index_tau] = 0.             # <<<<<<<<<<<<<<
 *                   else:
 *                       z[index_tau] = self.z_of_tau(np.exp(self.nl.ln_tau[index_tau]))
 */
          __pyx_t_15 = __pyx_v_index_tau;
          __pyx_t_16 = -1;
          if (__pyx_t_15 < 0) {
            __pyx_t_15 += __pyx_pybuffernd_z.diminfo[0].shape;
            if (unlikely(__pyx_t_15 < 0)) __pyx_t_16 = 0;
          } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_16 = 0;
          if (unlikely(__pyx_t_16 != -1)) {
            __Pyx_RaiseBufferIndexError(__pyx_t_16);
            __PYX_ERR(0, 2001, __pyx_L1_error)
          }
          *__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_15, __pyx_pybuffernd_z.diminfo[0].strides) = 0.;

          /* "class-sz/python/classy.pyx":2000
 *           else:
 *               for index_tau in xrange(self.nl.ln_tau_size):
 *                   if index_tau == self.nl.ln_tau_size-1:             # <<<<<<<<<<<<<<
 *                       z[index_tau] = 0.
 *                   else:
 */
          goto __pyx_L13;
        }

        /* "class-sz/python/classy.pyx":2003
 *                       z[index_tau] = 0.
 *                   else:
 *                       z[index_tau] = self.z_of_tau(np.exp(self.nl.ln_tau[index_tau]))             # <<<<<<<<<<<<<<
 * 
 *           # check consitency of the list of redshifts
 */
        /*else*/ {
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_z_of_tau); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2003, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2003, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2003, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->nl.ln_tau[__pyx_v_index_tau])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2003, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_17 = NULL;
          __pyx_t_6 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
              __pyx_t_6 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_17, __pyx_t_1};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2003, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __pyx_t_2 = NULL;
          __pyx_t_6 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_6 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2003, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_18 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2003, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_15 = __pyx_v_index_tau;
          __pyx_t_16 = -1;
          if (__pyx_t_15 < 0) {
            __pyx_t_15 += __pyx_pybuffernd_z.diminfo[0].shape;
            if (unlikely(__pyx_t_15 < 0)) __pyx_t_16 = 0;
          } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_16 = 0;
          if (unlikely(__pyx_t_16 != -1)) {
            __Pyx_RaiseBufferIndexError(__pyx_t_16);
            __PYX_ERR(0, 2003, __pyx_L1_error)
          }
          *__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_15, __pyx_pybuffernd_z.diminfo[0].strides) = __pyx_t_18;
        }
        __pyx_L13:;
      }
    }

    /* "class-sz/python/classy.pyx":2007
 *           # check consitency of the list of redshifts
 * 
 *           if nonlinear == True:             # <<<<<<<<<<<<<<
 *               z_max_nonlinear = self.z_of_tau(self.nl.tau[self.nl.index_tau_min_nl])
 *               z_max_requested = z[0]
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_nonlinear, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2007, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2007, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_10) {

      /* "class-sz/python/classy.pyx":2008
 * 
 *           if nonlinear == True:
 *               z_max_nonlinear = self.z_of_tau(self.nl.tau[self.nl.index_tau_min_nl])             # <<<<<<<<<<<<<<
 *               z_max_requested = z[0]
 *               # BB 1-04-23: i had to comment these lines because they lead to a bug in DESY1 lkl.
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_z_of_tau); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2008, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyFloat_FromDouble((__pyx_v_self->nl.tau[__pyx_v_self->nl.index_tau_min_nl])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2008, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2008, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_19 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_19 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2008, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_z_max_nonlinear = __pyx_t_19;

      /* "class-sz/python/classy.pyx":2009
 *           if nonlinear == True:
 *               z_max_nonlinear = self.z_of_tau(self.nl.tau[self.nl.index_tau_min_nl])
 *               z_max_requested = z[0]             # <<<<<<<<<<<<<<
 *               # BB 1-04-23: i had to comment these lines because they lead to a bug in DESY1 lkl.
 *               # if ((self.nl.tau_size - self.nl.ln_tau_size) < self.nl.index_tau_min_nl):
 */
      __pyx_t_15 = 0;
      __pyx_t_12 = -1;
      if (__pyx_t_15 < 0) {
        __pyx_t_15 += __pyx_pybuffernd_z.diminfo[0].shape;
        if (unlikely(__pyx_t_15 < 0)) __pyx_t_12 = 0;
      } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_12 = 0;
      if (unlikely(__pyx_t_12 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_12);
        __PYX_ERR(0, 2009, __pyx_L1_error)
      }
      __pyx_v_z_max_requested = (*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_15, __pyx_pybuffernd_z.diminfo[0].strides));

      /* "class-sz/python/classy.pyx":2007
 *           # check consitency of the list of redshifts
 * 
 *           if nonlinear == True:             # <<<<<<<<<<<<<<
 *               z_max_nonlinear = self.z_of_tau(self.nl.tau[self.nl.index_tau_min_nl])
 *               z_max_requested = z[0]
 */
    }

    /* "class-sz/python/classy.pyx":2015
 * 
 *           # get list of k
 *           if h_units:             # <<<<<<<<<<<<<<
 *               units=1./self.ba.h
 *           else:
 */
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_h_units); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2015, __pyx_L1_error)
    if (__pyx_t_10) {

      /* "class-sz/python/classy.pyx":2016
 *           # get list of k
 *           if h_units:
 *               units=1./self.ba.h             # <<<<<<<<<<<<<<
 *           else:
 *               units=1
 */
      if (unlikely(__pyx_v_self->ba.h == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 2016, __pyx_L1_error)
      }
      __pyx_v_units = (1. / __pyx_v_self->ba.h);

      /* "class-sz/python/classy.pyx":2015
 * 
 *           # get list of k
 *           if h_units:             # <<<<<<<<<<<<<<
 *               units=1./self.ba.h
 *           else:
 */
      goto __pyx_L15;
    }

    /* "class-sz/python/classy.pyx":2018
 *               units=1./self.ba.h
 *           else:
 *               units=1             # <<<<<<<<<<<<<<
 *           for index_k in xrange(self.nl.k_size):
 *               k[index_k] = self.nl.k[index_k]*units
 */
    /*else*/ {
      __pyx_v_units = 1.0;
    }
    __pyx_L15:;

    /* "class-sz/python/classy.pyx":2019
 *           else:
 *               units=1
 *           for index_k in xrange(self.nl.k_size):             # <<<<<<<<<<<<<<
 *               k[index_k] = self.nl.k[index_k]*units
 * 
 */
    __pyx_t_12 = __pyx_v_self->nl.k_size;
    __pyx_t_13 = __pyx_t_12;
    for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
      __pyx_v_index_k = __pyx_t_14;

      /* "class-sz/python/classy.pyx":2020
 *               units=1
 *           for index_k in xrange(self.nl.k_size):
 *               k[index_k] = self.nl.k[index_k]*units             # <<<<<<<<<<<<<<
 * 
 *           # get P(k,z) array
 */
      __pyx_t_15 = __pyx_v_index_k;
      __pyx_t_16 = -1;
      if (__pyx_t_15 < 0) {
        __pyx_t_15 += __pyx_pybuffernd_k.diminfo[0].shape;
        if (unlikely(__pyx_t_15 < 0)) __pyx_t_16 = 0;
      } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_k.diminfo[0].shape)) __pyx_t_16 = 0;
      if (unlikely(__pyx_t_16 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_16);
        __PYX_ERR(0, 2020, __pyx_L1_error)
      }
      *__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k.rcbuffer->pybuffer.buf, __pyx_t_15, __pyx_pybuffernd_k.diminfo[0].strides) = ((__pyx_v_self->nl.k[__pyx_v_index_k]) * __pyx_v_units);
    }

    /* "class-sz/python/classy.pyx":2024
 *           # get P(k,z) array
 * 
 *           for index_tau in xrange(self.nl.ln_tau_size):             # <<<<<<<<<<<<<<
 *               for index_k in xrange(self.nl.k_size):
 *                   if nonlinear == True:
 */
    __pyx_t_12 = __pyx_v_self->nl.ln_tau_size;
    __pyx_t_13 = __pyx_t_12;
    for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
      __pyx_v_index_tau = __pyx_t_14;

      /* "class-sz/python/classy.pyx":2025
 * 
 *           for index_tau in xrange(self.nl.ln_tau_size):
 *               for index_k in xrange(self.nl.k_size):             # <<<<<<<<<<<<<<
 *                   if nonlinear == True:
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_nl[index_pk][index_tau * self.nl.k_size + index_k])
 */
      __pyx_t_16 = __pyx_v_self->nl.k_size;
      __pyx_t_20 = __pyx_t_16;
      for (__pyx_t_21 = 0; __pyx_t_21 < __pyx_t_20; __pyx_t_21+=1) {
        __pyx_v_index_k = __pyx_t_21;

        /* "class-sz/python/classy.pyx":2026
 *           for index_tau in xrange(self.nl.ln_tau_size):
 *               for index_k in xrange(self.nl.k_size):
 *                   if nonlinear == True:             # <<<<<<<<<<<<<<
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_nl[index_pk][index_tau * self.nl.k_size + index_k])
 *                   else:
 */
        __pyx_t_3 = PyObject_RichCompare(__pyx_v_nonlinear, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2026, __pyx_L1_error)
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2026, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_10) {

          /* "class-sz/python/classy.pyx":2027
 *               for index_k in xrange(self.nl.k_size):
 *                   if nonlinear == True:
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_nl[index_pk][index_tau * self.nl.k_size + index_k])             # <<<<<<<<<<<<<<
 *                   else:
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_l[index_pk][index_tau * self.nl.k_size + index_k])
 */
          __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2027, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_exp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2027, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = PyFloat_FromDouble(((__pyx_v_self->nl.ln_pk_nl[__pyx_v_index_pk])[((__pyx_v_index_tau * __pyx_v_self->nl.k_size) + __pyx_v_index_k)])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2027, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_2 = NULL;
          __pyx_t_6 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_6 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2027, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_18 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2027, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_15 = __pyx_v_index_k;
          __pyx_t_22 = __pyx_v_index_tau;
          __pyx_t_23 = -1;
          if (__pyx_t_15 < 0) {
            __pyx_t_15 += __pyx_pybuffernd_pk_at_k_z.diminfo[0].shape;
            if (unlikely(__pyx_t_15 < 0)) __pyx_t_23 = 0;
          } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_pk_at_k_z.diminfo[0].shape)) __pyx_t_23 = 0;
          if (__pyx_t_22 < 0) {
            __pyx_t_22 += __pyx_pybuffernd_pk_at_k_z.diminfo[1].shape;
            if (unlikely(__pyx_t_22 < 0)) __pyx_t_23 = 1;
          } else if (unlikely(__pyx_t_22 >= __pyx_pybuffernd_pk_at_k_z.diminfo[1].shape)) __pyx_t_23 = 1;
          if (unlikely(__pyx_t_23 != -1)) {
            __Pyx_RaiseBufferIndexError(__pyx_t_23);
            __PYX_ERR(0, 2027, __pyx_L1_error)
          }
          *__Pyx_BufPtrStrided2d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer.buf, __pyx_t_15, __pyx_pybuffernd_pk_at_k_z.diminfo[0].strides, __pyx_t_22, __pyx_pybuffernd_pk_at_k_z.diminfo[1].strides) = __pyx_t_18;

          /* "class-sz/python/classy.pyx":2026
 *           for index_tau in xrange(self.nl.ln_tau_size):
 *               for index_k in xrange(self.nl.k_size):
 *                   if nonlinear == True:             # <<<<<<<<<<<<<<
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_nl[index_pk][index_tau * self.nl.k_size + index_k])
 *                   else:
 */
          goto __pyx_L22;
        }

        /* "class-sz/python/classy.pyx":2029
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_nl[index_pk][index_tau * self.nl.k_size + index_k])
 *                   else:
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_l[index_pk][index_tau * self.nl.k_size + index_k])             # <<<<<<<<<<<<<<
 * 
 *           return pk_at_k_z, k, z
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2029, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_exp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2029, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = PyFloat_FromDouble(((__pyx_v_self->nl.ln_pk_l[__pyx_v_index_pk])[((__pyx_v_index_tau * __pyx_v_self->nl.k_size) + __pyx_v_index_k)])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2029, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_2 = NULL;
          __pyx_t_6 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_6 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2029, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_18 == ((npy_double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2029, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_22 = __pyx_v_index_k;
          __pyx_t_15 = __pyx_v_index_tau;
          __pyx_t_23 = -1;
          if (__pyx_t_22 < 0) {
            __pyx_t_22 += __pyx_pybuffernd_pk_at_k_z.diminfo[0].shape;
            if (unlikely(__pyx_t_22 < 0)) __pyx_t_23 = 0;
          } else if (unlikely(__pyx_t_22 >= __pyx_pybuffernd_pk_at_k_z.diminfo[0].shape)) __pyx_t_23 = 0;
          if (__pyx_t_15 < 0) {
            __pyx_t_15 += __pyx_pybuffernd_pk_at_k_z.diminfo[1].shape;
            if (unlikely(__pyx_t_15 < 0)) __pyx_t_23 = 1;
          } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_pk_at_k_z.diminfo[1].shape)) __pyx_t_23 = 1;
          if (unlikely(__pyx_t_23 != -1)) {
            __Pyx_RaiseBufferIndexError(__pyx_t_23);
            __PYX_ERR(0, 2029, __pyx_L1_error)
          }
          *__Pyx_BufPtrStrided2d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer.buf, __pyx_t_22, __pyx_pybuffernd_pk_at_k_z.diminfo[0].strides, __pyx_t_15, __pyx_pybuffernd_pk_at_k_z.diminfo[1].strides) = __pyx_t_18;
        }
        __pyx_L22:;
      }
    }

    /* "class-sz/python/classy.pyx":2031
 *                       pk_at_k_z[index_k, index_tau] = np.exp(self.nl.ln_pk_l[index_pk][index_tau * self.nl.k_size + index_k])
 * 
 *           return pk_at_k_z, k, z             # <<<<<<<<<<<<<<
 * 
 *     # Gives sigma(R,z) for a given (R,z)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF((PyObject *)__pyx_v_pk_at_k_z);
    __Pyx_GIVEREF((PyObject *)__pyx_v_pk_at_k_z);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_pk_at_k_z))) __PYX_ERR(0, 2031, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)__pyx_v_k);
    __Pyx_GIVEREF((PyObject *)__pyx_v_k);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_k))) __PYX_ERR(0, 2031, __pyx_L1_error);
    __Pyx_INCREF((PyObject *)__pyx_v_z);
    __Pyx_GIVEREF((PyObject *)__pyx_v_z);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, ((PyObject *)__pyx_v_z))) __PYX_ERR(0, 2031, __pyx_L1_error);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":1955
 *         return pk_cb
 * 
 *     def get_pk_and_k_and_z(self, nonlinear=True, only_clustering_species = False,h_units=False):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a grid of matter power spectrum values and the z and k
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_17);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.get_pk_and_k_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_at_k_z.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pk_at_k_z);
  __Pyx_XDECREF((PyObject *)__pyx_v_k);
  __Pyx_XDECREF((PyObject *)__pyx_v_z);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2034
 * 
 *     # Gives sigma(R,z) for a given (R,z)
 *     def sigma(self,double R,double z, h_units = False):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (total matter) for a given R and z
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_65sigma(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_64sigma, "\n        Gives sigma (total matter) for a given R and z\n        (R is the radius in units of Mpc, so if R=8/h this will be the usual sigma8(z)\n\n        .. note::\n\n            there is an additional check to verify whether output contains `mPk`,\n            and whether k_max > ...\n            because otherwise a segfault will occur\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_65sigma = {"sigma", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_65sigma, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_64sigma};
static PyObject *__pyx_pw_9classy_sz_5Class_65sigma(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_R;
  double __pyx_v_z;
  CYTHON_UNUSED PyObject *__pyx_v_h_units = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sigma (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_R,&__pyx_n_s_z,&__pyx_n_s_h_units,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_R)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2034, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2034, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("sigma", 0, 2, 3, 1); __PYX_ERR(0, 2034, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_h_units);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2034, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sigma") < 0)) __PYX_ERR(0, 2034, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_R = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_R == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2034, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2034, __pyx_L3_error)
    __pyx_v_h_units = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sigma", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 2034, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.sigma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_64sigma(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_R, __pyx_v_z, __pyx_v_h_units);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_64sigma(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_R, double __pyx_v_z, CYTHON_UNUSED PyObject *__pyx_v_h_units) {
  double __pyx_v_sigma;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  double __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sigma", 1);

  /* "class-sz/python/classy.pyx":2047
 *         """
 *         cdef double sigma
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           if R == 8.0:
 *             return self.class_szfast.get_sigma8_at_z(z)
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2048
 *         cdef double sigma
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if R == 8.0:             # <<<<<<<<<<<<<<
 *             return self.class_szfast.get_sigma8_at_z(z)
 * 
 */
    __pyx_t_1 = (__pyx_v_R == 8.0);
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":2049
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if R == 8.0:
 *             return self.class_szfast.get_sigma8_at_z(z)             # <<<<<<<<<<<<<<
 * 
 *           sigma = self.class_szfast.get_sigma_at_r_and_z(R,z)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_sigma8_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2049, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":2048
 *         cdef double sigma
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if R == 8.0:             # <<<<<<<<<<<<<<
 *             return self.class_szfast.get_sigma8_at_z(z)
 * 
 */
    }

    /* "class-sz/python/classy.pyx":2051
 *             return self.class_szfast.get_sigma8_at_z(z)
 * 
 *           sigma = self.class_szfast.get_sigma_at_r_and_z(R,z)             # <<<<<<<<<<<<<<
 *           # if h_units == True:
 *           #   sigma = self.class_szfast.get_sigma_at_r_and_z(R*self.h(),z)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_sigma_at_r_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2051, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyFloat_FromDouble(__pyx_v_R); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2051, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2051, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_4, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_8 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_8 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2051, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_sigma = __pyx_t_8;

    /* "class-sz/python/classy.pyx":2047
 *         """
 *         cdef double sigma
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           if R == 8.0:
 *             return self.class_szfast.get_sigma8_at_z(z)
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":2057
 *           #   sigma = self.class_szfast.get_sigma_at_r_and_z(R,z)
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":2058
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):
 *               raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *           if (self.pt.k_max_for_pk < self.ba.h):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_No_power_spectrum_computed_In_or};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2058, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 2058, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":2057
 *           #   sigma = self.class_szfast.get_sigma_at_r_and_z(R,z)
 *         else:
 *           if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":2060
 *               raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 *           if (self.pt.k_max_for_pk < self.ba.h):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 */
    __pyx_t_1 = (__pyx_v_self->pt.k_max_for_pk < __pyx_v_self->ba.h);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":2061
 * 
 *           if (self.pt.k_max_for_pk < self.ba.h):
 *               raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")             # <<<<<<<<<<<<<<
 * 
 *           if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_m,out_sigma,&sigma)==_FAILURE_:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2061, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_kp_u_In_order_to_get_sigma_R_z_you_mu};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2061, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 2061, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":2060
 *               raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 *           if (self.pt.k_max_for_pk < self.ba.h):             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 */
    }

    /* "class-sz/python/classy.pyx":2063
 *               raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 *           if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_m,out_sigma,&sigma)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.nl.error_message)
 * 
 */
    __pyx_t_1 = (nonlinear_sigmas_at_z((&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->nl), __pyx_v_R, __pyx_v_z, __pyx_v_self->nl.index_pk_m, out_sigma, (&__pyx_v_sigma)) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":2064
 * 
 *           if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_m,out_sigma,&sigma)==_FAILURE_:
 *               raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return sigma
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2064, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2064, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2064, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 2064, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":2063
 *               raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 *           if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_m,out_sigma,&sigma)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.nl.error_message)
 * 
 */
    }
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":2066
 *               raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma             # <<<<<<<<<<<<<<
 * 
 *     # Gives sigma_cb(R,z) for a given (R,z)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_sigma); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2034
 * 
 *     # Gives sigma(R,z) for a given (R,z)
 *     def sigma(self,double R,double z, h_units = False):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (total matter) for a given R and z
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.sigma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2069
 * 
 *     # Gives sigma_cb(R,z) for a given (R,z)
 *     def sigma_cb(self,double R,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (cdm+b) for a given R and z
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_67sigma_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_66sigma_cb, "\n        Gives sigma (cdm+b) for a given R and z\n        (R is the radius in units of Mpc, so if R=8/h this will be the usual sigma8(z)\n\n        .. note::\n\n            there is an additional check to verify whether output contains `mPk`,\n            and whether k_max > ...\n            because otherwise a segfault will occur\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_67sigma_cb = {"sigma_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_67sigma_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_66sigma_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_67sigma_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_R;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sigma_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_R,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_R)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2069, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2069, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("sigma_cb", 1, 2, 2, 1); __PYX_ERR(0, 2069, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sigma_cb") < 0)) __PYX_ERR(0, 2069, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_R = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_R == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2069, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2069, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sigma_cb", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2069, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.sigma_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_66sigma_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_R, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_66sigma_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_R, double __pyx_v_z) {
  double __pyx_v_sigma_cb;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sigma_cb", 1);

  /* "class-sz/python/classy.pyx":2083
 *         cdef double sigma_cb
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2084
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):
 *             raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_No_power_spectrum_computed_In_or};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2084, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2084, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2083
 *         cdef double sigma_cb
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2086
 *             raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("sigma_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->nl.has_pk_cb == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2087
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):
 *             raise CosmoSevereError("sigma_cb not computed by CLASS (probably because there are no massive neutrinos)")             # <<<<<<<<<<<<<<
 * 
 *         if (self.pt.k_max_for_pk < self.ba.h):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2087, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_sigma_cb_not_computed_by_CLASS_p};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2087, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2087, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2086
 *             raise CosmoSevereError("No power spectrum computed. In order to get sigma(R,z) you must add mPk to the list of outputs.")
 * 
 *         if (self.nl.has_pk_cb == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("sigma_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2089
 *             raise CosmoSevereError("sigma_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 *         if (self.pt.k_max_for_pk < self.ba.h):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->pt.k_max_for_pk < __pyx_v_self->ba.h);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2090
 * 
 *         if (self.pt.k_max_for_pk < self.ba.h):
 *             raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")             # <<<<<<<<<<<<<<
 * 
 *         if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_cb,out_sigma,&sigma_cb)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2090, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_In_order_to_get_sigma_R_z_you_mu};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2090, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2090, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2089
 *             raise CosmoSevereError("sigma_cb not computed by CLASS (probably because there are no massive neutrinos)")
 * 
 *         if (self.pt.k_max_for_pk < self.ba.h):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2092
 *             raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 *         if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_cb,out_sigma,&sigma_cb)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  __pyx_t_1 = (nonlinear_sigmas_at_z((&__pyx_v_self->pr), (&__pyx_v_self->ba), (&__pyx_v_self->nl), __pyx_v_R, __pyx_v_z, __pyx_v_self->nl.index_pk_cb, out_sigma, (&__pyx_v_sigma_cb)) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2093
 * 
 *         if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_cb,out_sigma,&sigma_cb)==_FAILURE_:
 *             raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return sigma_cb
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2093, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2093, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2093, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2093, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2092
 *             raise CosmoSevereError("In order to get sigma(R,z) you must set 'P_k_max_h/Mpc' to 1 or bigger, in order to have k_max > 1 h/Mpc.")
 * 
 *         if nonlinear_sigmas_at_z(&self.pr,&self.ba,&self.nl,R,z,self.nl.index_pk_cb,out_sigma,&sigma_cb)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2095
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_cb             # <<<<<<<<<<<<<<
 * 
 *     # Gives effective logarithmic slope of P_L(k,z) (total matter) for a given (k,z)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_sigma_cb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2069
 * 
 *     # Gives sigma_cb(R,z) for a given (R,z)
 *     def sigma_cb(self,double R,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (cdm+b) for a given R and z
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.sigma_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2098
 * 
 *     # Gives effective logarithmic slope of P_L(k,z) (total matter) for a given (k,z)
 *     def pk_tilt(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives effective logarithmic slope of P_L(k,z) (total matter) for a given k and z
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_69pk_tilt(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_68pk_tilt, "\n        Gives effective logarithmic slope of P_L(k,z) (total matter) for a given k and z\n        (k is the wavenumber in units of 1/Mpc, z is the redshift, the output is dimensionless)\n\n        .. note::\n\n            there is an additional check to verify whether output contains `mPk` and whether k is in the right range\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_69pk_tilt = {"pk_tilt", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_69pk_tilt, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_68pk_tilt};
static PyObject *__pyx_pw_9classy_sz_5Class_69pk_tilt(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_tilt (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2098, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2098, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("pk_tilt", 1, 2, 2, 1); __PYX_ERR(0, 2098, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "pk_tilt") < 0)) __PYX_ERR(0, 2098, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2098, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2098, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pk_tilt", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2098, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.pk_tilt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_68pk_tilt(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_68pk_tilt(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_z) {
  double __pyx_v_pk_tilt;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_tilt", 1);

  /* "class-sz/python/classy.pyx":2110
 *         cdef double pk_tilt
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. In order to get pk_tilt(k,z) you must add mPk to the list of outputs.")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->pt.has_pk_matter == _FALSE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2111
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):
 *             raise CosmoSevereError("No power spectrum computed. In order to get pk_tilt(k,z) you must add mPk to the list of outputs.")             # <<<<<<<<<<<<<<
 * 
 *         if (k < self.nl.k[1] or k > self.nl.k[self.nl.k_size-2]):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_No_power_spectrum_computed_In_or_2};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2111, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2110
 *         cdef double pk_tilt
 * 
 *         if (self.pt.has_pk_matter == _FALSE_):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("No power spectrum computed. In order to get pk_tilt(k,z) you must add mPk to the list of outputs.")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2113
 *             raise CosmoSevereError("No power spectrum computed. In order to get pk_tilt(k,z) you must add mPk to the list of outputs.")
 * 
 *         if (k < self.nl.k[1] or k > self.nl.k[self.nl.k_size-2]):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("In order to get pk_tilt at k=%e 1/Mpc, you should compute P(k,z) in a wider range of k's"%k)
 * 
 */
  __pyx_t_6 = (__pyx_v_k < (__pyx_v_self->nl.k[1]));
  if (!__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_6 = (__pyx_v_k > (__pyx_v_self->nl.k[(__pyx_v_self->nl.k_size - 2)]));
  __pyx_t_1 = __pyx_t_6;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2114
 * 
 *         if (k < self.nl.k[1] or k > self.nl.k[self.nl.k_size-2]):
 *             raise CosmoSevereError("In order to get pk_tilt at k=%e 1/Mpc, you should compute P(k,z) in a wider range of k's"%k)             # <<<<<<<<<<<<<<
 * 
 *         if nonlinear_pk_tilt_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_total,&pk_tilt)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyFloat_FromDouble(__pyx_v_k); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyUnicode_Format(__pyx_kp_u_In_order_to_get_pk_tilt_at_k_e_1, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2114, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2113
 *             raise CosmoSevereError("No power spectrum computed. In order to get pk_tilt(k,z) you must add mPk to the list of outputs.")
 * 
 *         if (k < self.nl.k[1] or k > self.nl.k[self.nl.k_size-2]):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError("In order to get pk_tilt at k=%e 1/Mpc, you should compute P(k,z) in a wider range of k's"%k)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2116
 *             raise CosmoSevereError("In order to get pk_tilt at k=%e 1/Mpc, you should compute P(k,z) in a wider range of k's"%k)
 * 
 *         if nonlinear_pk_tilt_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_total,&pk_tilt)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  __pyx_t_1 = (nonlinear_pk_tilt_at_k_and_z((&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), pk_linear, __pyx_v_k, __pyx_v_z, __pyx_v_self->nl.index_pk_total, (&__pyx_v_pk_tilt)) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2117
 * 
 *         if nonlinear_pk_tilt_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_total,&pk_tilt)==_FAILURE_:
 *             raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return pk_tilt
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2117, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2117, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2116
 *             raise CosmoSevereError("In order to get pk_tilt at k=%e 1/Mpc, you should compute P(k,z) in a wider range of k's"%k)
 * 
 *         if nonlinear_pk_tilt_at_k_and_z(&self.ba,&self.pm,&self.nl,pk_linear,k,z,self.nl.index_pk_total,&pk_tilt)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2119
 *             raise CosmoSevereError(self.nl.error_message)
 * 
 *         return pk_tilt             # <<<<<<<<<<<<<<
 * 
 *     #calculates the hmcode window_function of the Navarrow Frenk White Profile
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_pk_tilt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2098
 * 
 *     # Gives effective logarithmic slope of P_L(k,z) (total matter) for a given (k,z)
 *     def pk_tilt(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives effective logarithmic slope of P_L(k,z) (total matter) for a given k and z
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.pk_tilt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2122
 * 
 *     #calculates the hmcode window_function of the Navarrow Frenk White Profile
 *     def nonlinear_hmcode_window_nfw(self,double k,double rv,double c):             # <<<<<<<<<<<<<<
 *         """
 *         Gives window_nfw for a given wavevector k, virial radius rv and concentration c
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_71nonlinear_hmcode_window_nfw(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_70nonlinear_hmcode_window_nfw, "\n        Gives window_nfw for a given wavevector k, virial radius rv and concentration c\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_71nonlinear_hmcode_window_nfw = {"nonlinear_hmcode_window_nfw", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_71nonlinear_hmcode_window_nfw, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_70nonlinear_hmcode_window_nfw};
static PyObject *__pyx_pw_9classy_sz_5Class_71nonlinear_hmcode_window_nfw(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_rv;
  double __pyx_v_c;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_window_nfw (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_rv,&__pyx_n_s_c,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2122, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_rv)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2122, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_window_nfw", 1, 3, 3, 1); __PYX_ERR(0, 2122, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_c)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2122, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_window_nfw", 1, 3, 3, 2); __PYX_ERR(0, 2122, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_window_nfw") < 0)) __PYX_ERR(0, 2122, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2122, __pyx_L3_error)
    __pyx_v_rv = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_rv == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2122, __pyx_L3_error)
    __pyx_v_c = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_c == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2122, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_window_nfw", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 2122, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_window_nfw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_70nonlinear_hmcode_window_nfw(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_rv, __pyx_v_c);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_70nonlinear_hmcode_window_nfw(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_rv, double __pyx_v_c) {
  double __pyx_v_window_nfw;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_window_nfw", 1);

  /* "class-sz/python/classy.pyx":2130
 * 
 * 
 *         if nonlinear_hmcode_window_nfw(&self.nl,k,rv,c,&window_nfw)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                  raise CosmoSevereError(self.sp.error_message)
 * 
 */
  __pyx_t_1 = (nonlinear_hmcode_window_nfw((&__pyx_v_self->nl), __pyx_v_k, __pyx_v_rv, __pyx_v_c, (&__pyx_v_window_nfw)) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2131
 * 
 *         if nonlinear_hmcode_window_nfw(&self.nl,k,rv,c,&window_nfw)==_FAILURE_:
 *                  raise CosmoSevereError(self.sp.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return window_nfw
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->sp.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2131, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2130
 * 
 * 
 *         if nonlinear_hmcode_window_nfw(&self.nl,k,rv,c,&window_nfw)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                  raise CosmoSevereError(self.sp.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2133
 *                  raise CosmoSevereError(self.sp.error_message)
 * 
 *         return window_nfw             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_window_nfw); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2122
 * 
 *     #calculates the hmcode window_function of the Navarrow Frenk White Profile
 *     def nonlinear_hmcode_window_nfw(self,double k,double rv,double c):             # <<<<<<<<<<<<<<
 *         """
 *         Gives window_nfw for a given wavevector k, virial radius rv and concentration c
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_window_nfw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2138
 *     #################################
 *     # gives an estimation of f(z)*sigma8(z) at the scale of 8 h/Mpc, computed as (d sigma8/d ln a)
 *     def effective_f_sigma8(self, z, z_step=0.1):             # <<<<<<<<<<<<<<
 *         """
 *         effective_f_sigma8(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_73effective_f_sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_72effective_f_sigma8, "\n        effective_f_sigma8(z)\n\n        Returns the time derivative of sigma8(z) computed as (d sigma8/d ln a)\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        z_step : float\n                Default step used for the numerical two-sided derivative. For z < z_step the step is reduced progressively down to z_step/10 while sticking to a double-sided derivative. For z< z_step/10 a single-sided derivative is used instead.\n\n        Returns\n        -------\n        (d ln sigma8/d ln a)(z) (dimensionless)\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_73effective_f_sigma8 = {"effective_f_sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_73effective_f_sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_72effective_f_sigma8};
static PyObject *__pyx_pw_9classy_sz_5Class_73effective_f_sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_z_step = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("effective_f_sigma8 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_step,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_1));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2138, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_step);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2138, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "effective_f_sigma8") < 0)) __PYX_ERR(0, 2138, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z = values[0];
    __pyx_v_z_step = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("effective_f_sigma8", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 2138, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.effective_f_sigma8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_72effective_f_sigma8(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_step);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_72effective_f_sigma8(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_z_step) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("effective_f_sigma8", 0);
  __Pyx_INCREF(__pyx_v_z_step);

  /* "class-sz/python/classy.pyx":2159
 * 
 *         # if possible, use two-sided derivative with default value of z_step
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *             return self.class_szfast.get_effective_f_sigma8(z,z_step=z_step)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2160
 *         # if possible, use two-sided derivative with default value of z_step
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *             return self.class_szfast.get_effective_f_sigma8(z,z_step=z_step)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_effective_f_sigma8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_z);
    __Pyx_GIVEREF(__pyx_v_z);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_z)) __PYX_ERR(0, 2160, __pyx_L1_error);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_z_step, __pyx_v_z_step) < 0) __PYX_ERR(0, 2160, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2159
 * 
 *         # if possible, use two-sided derivative with default value of z_step
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *             return self.class_szfast.get_effective_f_sigma8(z,z_step=z_step)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2163
 * 
 * 
 *         if z >= z_step:             # <<<<<<<<<<<<<<
 *             return (self.sigma(8/self.h(),z-z_step,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/(2.*z_step)*(1+z)
 *         else:
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_z, __pyx_v_z_step, Py_GE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2164
 * 
 *         if z >= z_step:
 *             return (self.sigma(8/self.h(),z-z_step,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/(2.*z_step)*(1+z)             # <<<<<<<<<<<<<<
 *         else:
 *             # if z is between z_step/10 and z_step, reduce z_step to z, and then stick to two-sided derivative
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sigma); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_int_8, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Subtract(__pyx_v_z, __pyx_v_z_step); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(0, 2164, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(0, 2164, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_h_units, Py_True) < 0) __PYX_ERR(0, 2164, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sigma); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_int_8, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_v_z, __pyx_v_z_step); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(0, 2164, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_2)) __PYX_ERR(0, 2164, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_h_units, Py_True) < 0) __PYX_ERR(0, 2164, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Subtract(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Multiply(__pyx_float_2_, __pyx_v_z_step); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyInt_AddCObj(__pyx_int_1, __pyx_v_z, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyNumber_Multiply(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2163
 * 
 * 
 *         if z >= z_step:             # <<<<<<<<<<<<<<
 *             return (self.sigma(8/self.h(),z-z_step,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/(2.*z_step)*(1+z)
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":2167
 *         else:
 *             # if z is between z_step/10 and z_step, reduce z_step to z, and then stick to two-sided derivative
 *             if (z > z_step/10.):             # <<<<<<<<<<<<<<
 *                 z_step = z
 *                 return (self.sigma(8/self.h(),z-z_step,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/(2.*z_step)*(1+z)
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyFloat_TrueDivideObjC(__pyx_v_z_step, __pyx_float_10_, 10., 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_z, __pyx_t_2, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2167, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2167, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":2168
 *             # if z is between z_step/10 and z_step, reduce z_step to z, and then stick to two-sided derivative
 *             if (z > z_step/10.):
 *                 z_step = z             # <<<<<<<<<<<<<<
 *                 return (self.sigma(8/self.h(),z-z_step,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/(2.*z_step)*(1+z)
 *             # if z is between 0 and z_step/10, use single-sided derivative with z_step/10
 */
      __Pyx_INCREF(__pyx_v_z);
      __Pyx_DECREF_SET(__pyx_v_z_step, __pyx_v_z);

      /* "class-sz/python/classy.pyx":2169
 *             if (z > z_step/10.):
 *                 z_step = z
 *                 return (self.sigma(8/self.h(),z-z_step,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/(2.*z_step)*(1+z)             # <<<<<<<<<<<<<<
 *             # if z is between 0 and z_step/10, use single-sided derivative with z_step/10
 *             else:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sigma); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2169, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_int_8, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_Subtract(__pyx_v_z, __pyx_v_z_step); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3)) __PYX_ERR(0, 2169, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_2)) __PYX_ERR(0, 2169, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_h_units, Py_True) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sigma); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2169, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_int_8, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyNumber_Add(__pyx_v_z, __pyx_v_z_step); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_7);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_7)) __PYX_ERR(0, 2169, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_h_units, Py_True) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyNumber_Subtract(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Multiply(__pyx_float_2_, __pyx_v_z_step); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_AddCObj(__pyx_int_1, __pyx_v_z, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = PyNumber_Multiply(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2169, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":2167
 *         else:
 *             # if z is between z_step/10 and z_step, reduce z_step to z, and then stick to two-sided derivative
 *             if (z > z_step/10.):             # <<<<<<<<<<<<<<
 *                 z_step = z
 *                 return (self.sigma(8/self.h(),z-z_step,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/(2.*z_step)*(1+z)
 */
    }

    /* "class-sz/python/classy.pyx":2172
 *             # if z is between 0 and z_step/10, use single-sided derivative with z_step/10
 *             else:
 *                 z_step /=10             # <<<<<<<<<<<<<<
 *                 return (self.sigma(8/self.h(),z,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/z_step*(1+z)
 * 
 */
    /*else*/ {
      __pyx_t_7 = __Pyx_PyInt_TrueDivideObjC(__pyx_v_z_step, __pyx_int_10, 10, 1, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_z_step, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":2173
 *             else:
 *                 z_step /=10
 *                 return (self.sigma(8/self.h(),z,h_units=True)-self.sigma(8/self.h(),z+z_step,h_units=True))/z_step*(1+z)             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sigma); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_int_8, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 2173, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_z);
      __Pyx_GIVEREF(__pyx_v_z);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_z)) __PYX_ERR(0, 2173, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_h_units, Py_True) < 0) __PYX_ERR(0, 2173, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sigma); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_int_8, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Add(__pyx_v_z, __pyx_v_z_step); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_7);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_7)) __PYX_ERR(0, 2173, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error);
      __pyx_t_7 = 0;
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_h_units, Py_True) < 0) __PYX_ERR(0, 2173, __pyx_L1_error)
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Subtract(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_t_5, __pyx_v_z_step); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyInt_AddCObj(__pyx_int_1, __pyx_v_z, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyNumber_Multiply(__pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;
    }
  }

  /* "class-sz/python/classy.pyx":2138
 *     #################################
 *     # gives an estimation of f(z)*sigma8(z) at the scale of 8 h/Mpc, computed as (d sigma8/d ln a)
 *     def effective_f_sigma8(self, z, z_step=0.1):             # <<<<<<<<<<<<<<
 *         """
 *         effective_f_sigma8(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.effective_f_sigma8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_z_step);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2177
 * 
 * 
 *     def age(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.ba.age
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_75age(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_75age = {"age", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_75age, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_75age(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("age (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("age", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "age", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_74age(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_74age(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("age", 1);

  /* "class-sz/python/classy.pyx":2178
 * 
 *     def age(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           return self.ba.age
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2179
 *     def age(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.ba.age             # <<<<<<<<<<<<<<
 *         else:
 *           self.compute(["background"])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_self->ba.age); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2178
 * 
 *     def age(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           return self.ba.age
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":2181
 *           return self.ba.age
 *         else:
 *           self.compute(["background"])             # <<<<<<<<<<<<<<
 *           return self.ba.age
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_u_background);
    __Pyx_GIVEREF(__pyx_n_u_background);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_u_background)) __PYX_ERR(0, 2181, __pyx_L1_error);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2181, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":2182
 *         else:
 *           self.compute(["background"])
 *           return self.ba.age             # <<<<<<<<<<<<<<
 * 
 *     def h(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_self->ba.age); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2177
 * 
 * 
 *     def age(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.ba.age
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.age", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2184
 *           return self.ba.age
 * 
 *     def h(self):             # <<<<<<<<<<<<<<
 *         return self.ba.h
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_77h(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_77h = {"h", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_77h, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_77h(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("h (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("h", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "h", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_76h(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_76h(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("h", 1);

  /* "class-sz/python/classy.pyx":2185
 * 
 *     def h(self):
 *         return self.ba.h             # <<<<<<<<<<<<<<
 * 
 *     def n_s(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2184
 *           return self.ba.age
 * 
 *     def h(self):             # <<<<<<<<<<<<<<
 *         return self.ba.h
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.h", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2187
 *         return self.ba.h
 * 
 *     def n_s(self):             # <<<<<<<<<<<<<<
 *         return self.pm.n_s
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_79n_s(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_79n_s = {"n_s", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_79n_s, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_79n_s(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("n_s (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("n_s", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "n_s", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_78n_s(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_78n_s(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("n_s", 1);

  /* "class-sz/python/classy.pyx":2188
 * 
 *     def n_s(self):
 *         return self.pm.n_s             # <<<<<<<<<<<<<<
 * 
 *     def tau_reio(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->pm.n_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2187
 *         return self.ba.h
 * 
 *     def n_s(self):             # <<<<<<<<<<<<<<
 *         return self.pm.n_s
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.n_s", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2190
 *         return self.pm.n_s
 * 
 *     def tau_reio(self):             # <<<<<<<<<<<<<<
 *         return self.th.tau_reio
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_81tau_reio(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_81tau_reio = {"tau_reio", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_81tau_reio, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_81tau_reio(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tau_reio (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("tau_reio", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tau_reio", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_80tau_reio(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_80tau_reio(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tau_reio", 1);

  /* "class-sz/python/classy.pyx":2191
 * 
 *     def tau_reio(self):
 *         return self.th.tau_reio             # <<<<<<<<<<<<<<
 * 
 *     def Omega_m(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.tau_reio); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2190
 *         return self.pm.n_s
 * 
 *     def tau_reio(self):             # <<<<<<<<<<<<<<
 *         return self.th.tau_reio
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.tau_reio", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2193
 *         return self.th.tau_reio
 * 
 *     def Omega_m(self):             # <<<<<<<<<<<<<<
 * 
 *         if self._pars['skip_background_and_thermo']:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_83Omega_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_83Omega_m = {"Omega_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_83Omega_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_83Omega_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega_m", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega_m", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_82Omega_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_82Omega_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_params_settings = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega_m", 1);

  /* "class-sz/python/classy.pyx":2195
 *     def Omega_m(self):
 * 
 *         if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *           params_settings = self._pars
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_skip_background_and_thermo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "class-sz/python/classy.pyx":2197
 *         if self._pars['skip_background_and_thermo']:
 * 
 *           params_settings = self._pars             # <<<<<<<<<<<<<<
 * 
 *           result = (params_settings['omega_b']+params_settings['omega_cdm'])*(100./params_settings['H0'])**2.
 */
    __pyx_t_1 = __pyx_v_self->_pars;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_params_settings = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2199
 *           params_settings = self._pars
 * 
 *           result = (params_settings['omega_b']+params_settings['omega_cdm'])*(100./params_settings['H0'])**2.             # <<<<<<<<<<<<<<
 * 
 *           return result
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_params_settings, __pyx_n_u_omega_b); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_params_settings, __pyx_n_u_omega_cdm); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_params_settings, __pyx_n_u_H0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyFloat_TrueDivideCObj(__pyx_float_100_, __pyx_t_3, 100., 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Power(__pyx_t_1, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Multiply(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_result = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2201
 *           result = (params_settings['omega_b']+params_settings['omega_cdm'])*(100./params_settings['H0'])**2.
 * 
 *           return result             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2195
 *     def Omega_m(self):
 * 
 *         if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *           params_settings = self._pars
 */
  }

  /* "class-sz/python/classy.pyx":2205
 *         else:
 * 
 *           return self.ba.Omega0_m             # <<<<<<<<<<<<<<
 * 
 *     def Omega_r(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_m); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2193
 *         return self.th.tau_reio
 * 
 *     def Omega_m(self):             # <<<<<<<<<<<<<<
 * 
 *         if self._pars['skip_background_and_thermo']:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.Omega_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_params_settings);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2207
 *           return self.ba.Omega0_m
 * 
 *     def Omega_r(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_r
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_85Omega_r(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_85Omega_r = {"Omega_r", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_85Omega_r, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_85Omega_r(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega_r (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega_r", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega_r", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_84Omega_r(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_84Omega_r(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega_r", 1);

  /* "class-sz/python/classy.pyx":2208
 * 
 *     def Omega_r(self):
 *         return self.ba.Omega0_r             # <<<<<<<<<<<<<<
 * 
 *     def theta_s_100(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_r); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2207
 *           return self.ba.Omega0_m
 * 
 *     def Omega_r(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_r
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega_r", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2210
 *         return self.ba.Omega0_r
 * 
 *     def theta_s_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_87theta_s_100(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_87theta_s_100 = {"theta_s_100", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_87theta_s_100, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_87theta_s_100(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("theta_s_100 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("theta_s_100", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "theta_s_100", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_86theta_s_100(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_86theta_s_100(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("theta_s_100", 1);

  /* "class-sz/python/classy.pyx":2211
 * 
 *     def theta_s_100(self):
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)             # <<<<<<<<<<<<<<
 * 
 *     def theta_star_100(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (100. * __pyx_v_self->th.rs_rec);
  if (unlikely(__pyx_v_self->th.da_rec == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 2211, __pyx_L1_error)
  }
  __pyx_t_2 = (__pyx_t_1 / __pyx_v_self->th.da_rec);
  __pyx_t_1 = (1. + __pyx_v_self->th.z_rec);
  if (unlikely(__pyx_t_1 == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 2211, __pyx_L1_error)
  }
  __pyx_t_3 = PyFloat_FromDouble((__pyx_t_2 / __pyx_t_1)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2210
 *         return self.ba.Omega0_r
 * 
 *     def theta_s_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.theta_s_100", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2213
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 *     def theta_star_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_89theta_star_100(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_89theta_star_100 = {"theta_star_100", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_89theta_star_100, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_89theta_star_100(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("theta_star_100 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("theta_star_100", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "theta_star_100", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_88theta_star_100(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_88theta_star_100(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("theta_star_100", 1);

  /* "class-sz/python/classy.pyx":2214
 * 
 *     def theta_star_100(self):
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)             # <<<<<<<<<<<<<<
 * 
 *     def Omega_Lambda(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (100. * __pyx_v_self->th.rs_star);
  if (unlikely(__pyx_v_self->th.da_star == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 2214, __pyx_L1_error)
  }
  __pyx_t_2 = (__pyx_t_1 / __pyx_v_self->th.da_star);
  __pyx_t_1 = (1. + __pyx_v_self->th.z_star);
  if (unlikely(__pyx_t_1 == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 2214, __pyx_L1_error)
  }
  __pyx_t_3 = PyFloat_FromDouble((__pyx_t_2 / __pyx_t_1)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2213
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 *     def theta_star_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.theta_star_100", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2216
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 *     def Omega_Lambda(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_lambda
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_91Omega_Lambda(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_91Omega_Lambda = {"Omega_Lambda", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_91Omega_Lambda, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_91Omega_Lambda(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega_Lambda (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega_Lambda", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega_Lambda", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_90Omega_Lambda(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_90Omega_Lambda(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega_Lambda", 1);

  /* "class-sz/python/classy.pyx":2217
 * 
 *     def Omega_Lambda(self):
 *         return self.ba.Omega0_lambda             # <<<<<<<<<<<<<<
 * 
 *     def Omega_g(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_lambda); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2216
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 *     def Omega_Lambda(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_lambda
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega_Lambda", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2219
 *         return self.ba.Omega0_lambda
 * 
 *     def Omega_g(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_g
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_93Omega_g(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_93Omega_g = {"Omega_g", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_93Omega_g, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_93Omega_g(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega_g (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega_g", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega_g", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_92Omega_g(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_92Omega_g(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega_g", 1);

  /* "class-sz/python/classy.pyx":2220
 * 
 *     def Omega_g(self):
 *         return self.ba.Omega0_g             # <<<<<<<<<<<<<<
 * 
 *     def Omega_b(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_g); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2219
 *         return self.ba.Omega0_lambda
 * 
 *     def Omega_g(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_g
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega_g", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2222
 *         return self.ba.Omega0_g
 * 
 *     def Omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_95Omega_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_95Omega_b = {"Omega_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_95Omega_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_95Omega_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega_b (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega_b", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega_b", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_94Omega_b(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_94Omega_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega_b", 1);

  /* "class-sz/python/classy.pyx":2223
 * 
 *     def Omega_b(self):
 *         return self.ba.Omega0_b             # <<<<<<<<<<<<<<
 * 
 *     def omega_b(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_b); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2222
 *         return self.ba.Omega0_g
 * 
 *     def Omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega_b", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2225
 *         return self.ba.Omega0_b
 * 
 *     def omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_97omega_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_97omega_b = {"omega_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_97omega_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_97omega_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("omega_b (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("omega_b", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "omega_b", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_96omega_b(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_96omega_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("omega_b", 1);

  /* "class-sz/python/classy.pyx":2226
 * 
 *     def omega_b(self):
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h             # <<<<<<<<<<<<<<
 * 
 *     def omega_cdm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->ba.Omega0_b * __pyx_v_self->ba.h) * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2225
 *         return self.ba.Omega0_b
 * 
 *     def omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.omega_b", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2228
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 *     def omega_cdm(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_99omega_cdm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_99omega_cdm = {"omega_cdm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_99omega_cdm, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_99omega_cdm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("omega_cdm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("omega_cdm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "omega_cdm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_98omega_cdm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_98omega_cdm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("omega_cdm", 1);

  /* "class-sz/python/classy.pyx":2229
 * 
 *     def omega_cdm(self):
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h             # <<<<<<<<<<<<<<
 * 
 *     def Neff(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->ba.Omega0_cdm * __pyx_v_self->ba.h) * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2228
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 *     def omega_cdm(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.omega_cdm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2231
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 *     def Neff(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.Neff_fast
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_101Neff(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_101Neff = {"Neff", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_101Neff, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_101Neff(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Neff (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Neff", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Neff", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_100Neff(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_100Neff(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Neff", 1);

  /* "class-sz/python/classy.pyx":2232
 * 
 *     def Neff(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           return self.Neff_fast
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2233
 *     def Neff(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.Neff_fast             # <<<<<<<<<<<<<<
 *         else:
 *           return self.ba.Neff
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_self->Neff_fast); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2232
 * 
 *     def Neff(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           return self.Neff_fast
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":2235
 *           return self.Neff_fast
 *         else:
 *           return self.ba.Neff             # <<<<<<<<<<<<<<
 * 
 *     def k_eq(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_self->ba.Neff); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2231
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 *     def Neff(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.Neff_fast
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.Neff", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2237
 *           return self.ba.Neff
 * 
 *     def k_eq(self):             # <<<<<<<<<<<<<<
 *         self.compute(["background"])
 *         return self.ba.a_eq*self.ba.H_eq
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_103k_eq(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_103k_eq = {"k_eq", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_103k_eq, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_103k_eq(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("k_eq (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("k_eq", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "k_eq", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_102k_eq(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_102k_eq(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("k_eq", 1);

  /* "class-sz/python/classy.pyx":2238
 * 
 *     def k_eq(self):
 *         self.compute(["background"])             # <<<<<<<<<<<<<<
 *         return self.ba.a_eq*self.ba.H_eq
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_background);
  __Pyx_GIVEREF(__pyx_n_u_background);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_background)) __PYX_ERR(0, 2238, __pyx_L1_error);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2239
 *     def k_eq(self):
 *         self.compute(["background"])
 *         return self.ba.a_eq*self.ba.H_eq             # <<<<<<<<<<<<<<
 * 
 *     def sigma8(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->ba.a_eq * __pyx_v_self->ba.H_eq)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2237
 *           return self.ba.Neff
 * 
 *     def k_eq(self):             # <<<<<<<<<<<<<<
 *         self.compute(["background"])
 *         return self.ba.a_eq*self.ba.H_eq
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.k_eq", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2241
 *         return self.ba.a_eq*self.ba.H_eq
 * 
 *     def sigma8(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.sigma8_fast
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_105sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_105sigma8 = {"sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_105sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_105sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sigma8 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("sigma8", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sigma8", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_104sigma8(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_104sigma8(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sigma8", 1);

  /* "class-sz/python/classy.pyx":2242
 * 
 *     def sigma8(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           return self.sigma8_fast
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2243
 *     def sigma8(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.sigma8_fast             # <<<<<<<<<<<<<<
 *         else:
 *           self.compute(["nonlinear"])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_self->sigma8_fast); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2242
 * 
 *     def sigma8(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           return self.sigma8_fast
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":2245
 *           return self.sigma8_fast
 *         else:
 *           self.compute(["nonlinear"])             # <<<<<<<<<<<<<<
 *           return self.nl.sigma8[self.nl.index_pk_m]
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_u_nonlinear);
    __Pyx_GIVEREF(__pyx_n_u_nonlinear);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_u_nonlinear)) __PYX_ERR(0, 2245, __pyx_L1_error);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2245, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":2246
 *         else:
 *           self.compute(["nonlinear"])
 *           return self.nl.sigma8[self.nl.index_pk_m]             # <<<<<<<<<<<<<<
 * 
 *     def get_sigma8_at_z(self,z):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyFloat_FromDouble((__pyx_v_self->nl.sigma8[__pyx_v_self->nl.index_pk_m])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2241
 *         return self.ba.a_eq*self.ba.H_eq
 * 
 *     def sigma8(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.sigma8_fast
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.sigma8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2248
 *           return self.nl.sigma8[self.nl.index_pk_m]
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_107get_sigma8_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_107get_sigma8_at_z = {"get_sigma8_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_107get_sigma8_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_107get_sigma8_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sigma8_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2248, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_sigma8_at_z") < 0)) __PYX_ERR(0, 2248, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sigma8_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2248, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_sigma8_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_106get_sigma8_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_106get_sigma8_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sigma8_at_z", 1);

  /* "class-sz/python/classy.pyx":2249
 * 
 *     def get_sigma8_at_z(self,z):
 *         return self.class_szfast.get_sigma8_at_z(z)             # <<<<<<<<<<<<<<
 * 
 *     def get_effective_f_sigma8(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_sigma8_at_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2248
 *           return self.nl.sigma8[self.nl.index_pk_m]
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_sigma8_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2251
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 *     def get_effective_f_sigma8(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_effective_f_sigma8(z)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_109get_effective_f_sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_109get_effective_f_sigma8 = {"get_effective_f_sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_109get_effective_f_sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_109get_effective_f_sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_effective_f_sigma8 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2251, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_effective_f_sigma8") < 0)) __PYX_ERR(0, 2251, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_effective_f_sigma8", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2251, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_effective_f_sigma8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_108get_effective_f_sigma8(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_108get_effective_f_sigma8(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_effective_f_sigma8", 1);

  /* "class-sz/python/classy.pyx":2252
 * 
 *     def get_effective_f_sigma8(self,z):
 *         return self.class_szfast.get_effective_f_sigma8(z)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_effective_f_sigma8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2251
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 *     def get_effective_f_sigma8(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_effective_f_sigma8(z)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_effective_f_sigma8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2255
 * 
 * 
 *     def get_fstar_of_m_at_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_fstar_of_m_at_z(m,z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_111get_fstar_of_m_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_111get_fstar_of_m_at_z = {"get_fstar_of_m_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_111get_fstar_of_m_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_111get_fstar_of_m_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_fstar_of_m_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2255, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2255, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_fstar_of_m_at_z", 1, 2, 2, 1); __PYX_ERR(0, 2255, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_fstar_of_m_at_z") < 0)) __PYX_ERR(0, 2255, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_fstar_of_m_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2255, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_fstar_of_m_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_110get_fstar_of_m_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_110get_fstar_of_m_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_fstar_of_m_at_z", 1);

  /* "class-sz/python/classy.pyx":2256
 * 
 *     def get_fstar_of_m_at_z(self,m,z):
 *         return get_fstar_of_m_at_z(m,z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2256, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2256, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_fstar_of_m_at_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2255
 * 
 * 
 *     def get_fstar_of_m_at_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_fstar_of_m_at_z(m,z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_fstar_of_m_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2264
 *     #    return self.sp.neff
 * 
 *     def sigma8_cb(self):             # <<<<<<<<<<<<<<
 *         self.compute(["nonlinear"])
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_113sigma8_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_113sigma8_cb = {"sigma8_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_113sigma8_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_113sigma8_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sigma8_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("sigma8_cb", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sigma8_cb", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_112sigma8_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_112sigma8_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sigma8_cb", 1);

  /* "class-sz/python/classy.pyx":2265
 * 
 *     def sigma8_cb(self):
 *         self.compute(["nonlinear"])             # <<<<<<<<<<<<<<
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_nonlinear);
  __Pyx_GIVEREF(__pyx_n_u_nonlinear);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_nonlinear)) __PYX_ERR(0, 2265, __pyx_L1_error);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2266
 *     def sigma8_cb(self):
 *         self.compute(["nonlinear"])
 *         return self.nl.sigma8[self.nl.index_pk_cb]             # <<<<<<<<<<<<<<
 * 
 *     def rs_drag(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->nl.sigma8[__pyx_v_self->nl.index_pk_cb])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2264
 *     #    return self.sp.neff
 * 
 *     def sigma8_cb(self):             # <<<<<<<<<<<<<<
 *         self.compute(["nonlinear"])
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.sigma8_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2268
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 * 
 *     def rs_drag(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if self.tsz.skip_background_and_thermo:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_115rs_drag(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_115rs_drag = {"rs_drag", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_115rs_drag, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_115rs_drag(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rs_drag (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("rs_drag", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rs_drag", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_114rs_drag(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_114rs_drag(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rs_drag", 1);

  /* "class-sz/python/classy.pyx":2269
 * 
 *     def rs_drag(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           if self.tsz.skip_background_and_thermo:
 *             return self.class_szfast.rs_drag()
 */
  __pyx_t_1 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2270
 *     def rs_drag(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 *             return self.class_szfast.rs_drag()
 *           else:
 */
    __pyx_t_1 = (__pyx_v_self->tsz.skip_background_and_thermo != 0);
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":2271
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if self.tsz.skip_background_and_thermo:
 *             return self.class_szfast.rs_drag()             # <<<<<<<<<<<<<<
 *           else:
 *             return self.th.rs_d
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_rs_drag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2271, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "class-sz/python/classy.pyx":2270
 *     def rs_drag(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 *             return self.class_szfast.rs_drag()
 *           else:
 */
    }

    /* "class-sz/python/classy.pyx":2273
 *             return self.class_szfast.rs_drag()
 *           else:
 *             return self.th.rs_d             # <<<<<<<<<<<<<<
 *         else:
 *           self.compute(["thermodynamics"])
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyFloat_FromDouble(__pyx_v_self->th.rs_d); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;
    }

    /* "class-sz/python/classy.pyx":2269
 * 
 *     def rs_drag(self):
 *         if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *           if self.tsz.skip_background_and_thermo:
 *             return self.class_szfast.rs_drag()
 */
  }

  /* "class-sz/python/classy.pyx":2275
 *             return self.th.rs_d
 *         else:
 *           self.compute(["thermodynamics"])             # <<<<<<<<<<<<<<
 *           return self.th.rs_d
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_n_u_thermodynamics);
    __Pyx_GIVEREF(__pyx_n_u_thermodynamics);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_u_thermodynamics)) __PYX_ERR(0, 2275, __pyx_L1_error);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2275, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":2276
 *         else:
 *           self.compute(["thermodynamics"])
 *           return self.th.rs_d             # <<<<<<<<<<<<<<
 * 
 *     def z_reio(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyFloat_FromDouble(__pyx_v_self->th.rs_d); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2268
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 * 
 *     def rs_drag(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if self.tsz.skip_background_and_thermo:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.rs_drag", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2278
 *           return self.th.rs_d
 * 
 *     def z_reio(self):             # <<<<<<<<<<<<<<
 *         self.compute(["thermodynamics"])
 *         return self.th.z_reio
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_117z_reio(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_117z_reio = {"z_reio", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_117z_reio, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_117z_reio(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("z_reio (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("z_reio", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "z_reio", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_116z_reio(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_116z_reio(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("z_reio", 1);

  /* "class-sz/python/classy.pyx":2279
 * 
 *     def z_reio(self):
 *         self.compute(["thermodynamics"])             # <<<<<<<<<<<<<<
 *         return self.th.z_reio
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_thermodynamics);
  __Pyx_GIVEREF(__pyx_n_u_thermodynamics);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_thermodynamics)) __PYX_ERR(0, 2279, __pyx_L1_error);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2280
 *     def z_reio(self):
 *         self.compute(["thermodynamics"])
 *         return self.th.z_reio             # <<<<<<<<<<<<<<
 * 
 *     def get_chi(self, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.z_reio); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2278
 *           return self.th.rs_d
 * 
 *     def z_reio(self):             # <<<<<<<<<<<<<<
 *         self.compute(["thermodynamics"])
 *         return self.th.z_reio
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.z_reio", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2282
 *         return self.th.z_reio
 * 
 *     def get_chi(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         chi(z) in h-units
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_119get_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_118get_chi, "\n        chi(z) in h-units\n\n        Return the comoving distance (exactly, the quantity defined by Class\n        as index_bg_ang_distance in the background module times (1+z) and multiplied by h)\n\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_119get_chi = {"get_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_119get_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_118get_chi};
static PyObject *__pyx_pw_9classy_sz_5Class_119get_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_chi (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2282, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_chi") < 0)) __PYX_ERR(0, 2282, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_chi", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2282, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_118get_chi(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_118get_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_v_h = NULL;
  PyObject *__pyx_8genexpr4__pyx_v_zi = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_chi", 1);

  /* "class-sz/python/classy.pyx":2295
 *                 Desired redshift
 *         """
 *         h = self.h()             # <<<<<<<<<<<<<<
 *         if np.isscalar(z):
 *             return self.angular_distance(z) * (1. + z) * h
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_h); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_h = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2296
 *         """
 *         h = self.h()
 *         if np.isscalar(z):             # <<<<<<<<<<<<<<
 *             return self.angular_distance(z) * (1. + z) * h
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_isscalar); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":2297
 *         h = self.h()
 *         if np.isscalar(z):
 *             return self.angular_distance(z) * (1. + z) * h             # <<<<<<<<<<<<<<
 *         else:
 *             return np.array([self.angular_distance(zi) * (1. + zi) * h for zi in z])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_angular_distance); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_z};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2297, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyFloat_AddCObj(__pyx_float_1_, __pyx_v_z, 1., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyNumber_Multiply(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_v_h); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2296
 *         """
 *         h = self.h()
 *         if np.isscalar(z):             # <<<<<<<<<<<<<<
 *             return self.angular_distance(z) * (1. + z) * h
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":2299
 *             return self.angular_distance(z) * (1. + z) * h
 *         else:
 *             return np.array([self.angular_distance(zi) * (1. + zi) * h for zi in z])             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    { /* enter inner scope */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2299, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (likely(PyList_CheckExact(__pyx_v_z)) || PyTuple_CheckExact(__pyx_v_z)) {
        __pyx_t_6 = __pyx_v_z; __Pyx_INCREF(__pyx_t_6);
        __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_v_z); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2299, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2299, __pyx_L6_error)
      }
      for (;;) {
        if (likely(!__pyx_t_8)) {
          if (likely(PyList_CheckExact(__pyx_t_6))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2299, __pyx_L6_error)
              #endif
              if (__pyx_t_7 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_9 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_9); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2299, __pyx_L6_error)
            #else
            __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2299, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_9);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2299, __pyx_L6_error)
              #endif
              if (__pyx_t_7 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_9 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_7); __Pyx_INCREF(__pyx_t_9); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 2299, __pyx_L6_error)
            #else
            __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2299, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_9);
            #endif
          }
        } else {
          __pyx_t_9 = __pyx_t_8(__pyx_t_6);
          if (unlikely(!__pyx_t_9)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 2299, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_9);
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr4__pyx_v_zi, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_angular_distance); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2299, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_8genexpr4__pyx_v_zi};
          __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2299, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __pyx_t_10 = __Pyx_PyFloat_AddCObj(__pyx_float_1_, __pyx_8genexpr4__pyx_v_zi, 1., 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2299, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = PyNumber_Multiply(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2299, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = PyNumber_Multiply(__pyx_t_11, __pyx_v_h); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2299, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_10))) __PYX_ERR(0, 2299, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_zi); __pyx_8genexpr4__pyx_v_zi = 0;
      goto __pyx_L10_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_zi); __pyx_8genexpr4__pyx_v_zi = 0;
      goto __pyx_L1_error;
      __pyx_L10_exit_scope:;
    } /* exit inner scope */
    __pyx_t_6 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2299, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2282
 *         return self.th.z_reio
 * 
 *     def get_chi(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         chi(z) in h-units
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("classy_sz.Class.get_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_h);
  __Pyx_XDECREF(__pyx_8genexpr4__pyx_v_zi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2303
 * 
 * 
 *     def angular_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_121angular_distance(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_120angular_distance, "\n        angular_distance(z)\n\n        Return the angular diameter distance (exactly, the quantity defined by Class\n        as index_bg_ang_distance in the background module)\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_121angular_distance = {"angular_distance", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_121angular_distance, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_120angular_distance};
static PyObject *__pyx_pw_9classy_sz_5Class_121angular_distance(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("angular_distance (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2303, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "angular_distance") < 0)) __PYX_ERR(0, 2303, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("angular_distance", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2303, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.angular_distance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_120angular_distance(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_120angular_distance(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  PyObject *__pyx_v_D_A = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  double __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("angular_distance", 1);

  /* "class-sz/python/classy.pyx":2320
 * 
 * 
 *         if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 * 
 *             D_A = self.class_szfast.get_chi(z)/(1.+z)
 */
  __pyx_t_1 = (__pyx_v_self->tsz.skip_background_and_thermo != 0);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2322
 *         if self.tsz.skip_background_and_thermo:
 * 
 *             D_A = self.class_szfast.get_chi(z)/(1.+z)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_chi); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_z};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2322, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyFloat_AddCObj(__pyx_float_1_, __pyx_v_z, 1., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_D_A = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":2320
 * 
 * 
 *         if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 * 
 *             D_A = self.class_szfast.get_chi(z)/(1.+z)
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":2326
 *         else:
 * 
 *             pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

    /* "class-sz/python/classy.pyx":2329
 * 
 * 
 *             if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.ba.error_message)
 * 
 */
    __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2329, __pyx_L1_error)
    __pyx_t_1 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_6, (&__pyx_v_tau)) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":2330
 * 
 *             if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *                 raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *             if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2330, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 2330, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":2329
 * 
 * 
 *             if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.ba.error_message)
 * 
 */
    }

    /* "class-sz/python/classy.pyx":2332
 *                 raise CosmoSevereError(self.ba.error_message)
 * 
 *             if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.ba.error_message)
 * 
 */
    __pyx_t_1 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":2333
 * 
 *             if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *                 raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *             D_A = pvecback[self.ba.index_bg_ang_distance]
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2333, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2333, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2333, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 2333, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":2332
 *                 raise CosmoSevereError(self.ba.error_message)
 * 
 *             if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.ba.error_message)
 * 
 */
    }

    /* "class-sz/python/classy.pyx":2335
 *                 raise CosmoSevereError(self.ba.error_message)
 * 
 *             D_A = pvecback[self.ba.index_bg_ang_distance]             # <<<<<<<<<<<<<<
 * 
 *             free(pvecback)
 */
    __pyx_t_4 = PyFloat_FromDouble((__pyx_v_pvecback[__pyx_v_self->ba.index_bg_ang_distance])); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_D_A = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "class-sz/python/classy.pyx":2337
 *             D_A = pvecback[self.ba.index_bg_ang_distance]
 * 
 *             free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         return D_A
 */
    free(__pyx_v_pvecback);
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":2339
 *             free(pvecback)
 * 
 *         return D_A             # <<<<<<<<<<<<<<
 * 
 *     def get_radial_kernel_W_galaxy_ngal_at_z(self, z, index_g):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_D_A);
  __pyx_r = __pyx_v_D_A;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2303
 * 
 * 
 *     def angular_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.angular_distance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_D_A);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2341
 *         return D_A
 * 
 *     def get_radial_kernel_W_galaxy_ngal_at_z(self, z, index_g):             # <<<<<<<<<<<<<<
 *         """
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_123get_radial_kernel_W_galaxy_ngal_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_122get_radial_kernel_W_galaxy_ngal_at_z, "\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_123get_radial_kernel_W_galaxy_ngal_at_z = {"get_radial_kernel_W_galaxy_ngal_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_123get_radial_kernel_W_galaxy_ngal_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_122get_radial_kernel_W_galaxy_ngal_at_z};
static PyObject *__pyx_pw_9classy_sz_5Class_123get_radial_kernel_W_galaxy_ngal_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_index_g = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_radial_kernel_W_galaxy_ngal_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_index_g,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2341, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_index_g)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2341, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_radial_kernel_W_galaxy_ngal_at_z", 1, 2, 2, 1); __PYX_ERR(0, 2341, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_radial_kernel_W_galaxy_ngal_at_z") < 0)) __PYX_ERR(0, 2341, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_index_g = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_radial_kernel_W_galaxy_ngal_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2341, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_radial_kernel_W_galaxy_ngal_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_122get_radial_kernel_W_galaxy_ngal_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_index_g);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_122get_radial_kernel_W_galaxy_ngal_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_index_g) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double __pyx_v_Wg;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  double __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_radial_kernel_W_galaxy_ngal_at_z", 1);

  /* "class-sz/python/classy.pyx":2353
 *         cdef double * pvecback
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if self.tsz.skip_background_and_thermo:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2355
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 *           raise CosmoSevereError(self.ba.error_message)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->tsz.skip_background_and_thermo != 0);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":2356
 * 
 *         if self.tsz.skip_background_and_thermo:
 *           raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 *         else:
 *           if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2356, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2356, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2356, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2355
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 *           raise CosmoSevereError(self.ba.error_message)
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":2358
 *           raise CosmoSevereError(self.ba.error_message)
 *         else:
 *           if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 */
  /*else*/ {
    __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2358, __pyx_L1_error)
    __pyx_t_1 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_7, (&__pyx_v_tau)) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":2359
 *         else:
 *           if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *               raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *           if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2359, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2359, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 2359, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":2358
 *           raise CosmoSevereError(self.ba.error_message)
 *         else:
 *           if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 */
    }

    /* "class-sz/python/classy.pyx":2361
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 *           if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 */
    __pyx_t_1 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":2362
 * 
 *           if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *               raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *           Wg = radial_kernel_W_galaxy_ngal_at_z(index_g,
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2362, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2362, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2362, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 2362, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":2361
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 *           if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 */
    }

    /* "class-sz/python/classy.pyx":2364
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 *           Wg = radial_kernel_W_galaxy_ngal_at_z(index_g,             # <<<<<<<<<<<<<<
 *                                                 pvecback,
 *                                                 z,
 */
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_index_g); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2364, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2366
 *           Wg = radial_kernel_W_galaxy_ngal_at_z(index_g,
 *                                                 pvecback,
 *                                                 z,             # <<<<<<<<<<<<<<
 *                                                 &self.ba,
 *                                                 &self.tsz)
 */
    __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2366, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2364
 *               raise CosmoSevereError(self.ba.error_message)
 * 
 *           Wg = radial_kernel_W_galaxy_ngal_at_z(index_g,             # <<<<<<<<<<<<<<
 *                                                 pvecback,
 *                                                 z,
 */
    __pyx_v_Wg = radial_kernel_W_galaxy_ngal_at_z(__pyx_t_8, __pyx_v_pvecback, __pyx_t_7, (&__pyx_v_self->ba), (&__pyx_v_self->tsz));
  }

  /* "class-sz/python/classy.pyx":2370
 *                                                 &self.tsz)
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         return Wg
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":2372
 *         free(pvecback)
 * 
 *         return Wg             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_Wg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2341
 *         return D_A
 * 
 *     def get_radial_kernel_W_galaxy_ngal_at_z(self, z, index_g):             # <<<<<<<<<<<<<<
 *         """
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_radial_kernel_W_galaxy_ngal_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2376
 * 
 * 
 *     def scale_independent_growth_factor(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_125scale_independent_growth_factor(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_124scale_independent_growth_factor, "\n        scale_independent_growth_factor(z)\n\n        Return the scale invariant growth factor D(a) for CDM perturbations\n        (exactly, the quantity defined by Class as index_bg_D in the background module)\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_125scale_independent_growth_factor = {"scale_independent_growth_factor", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_125scale_independent_growth_factor, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_124scale_independent_growth_factor};
static PyObject *__pyx_pw_9classy_sz_5Class_125scale_independent_growth_factor(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scale_independent_growth_factor (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2376, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "scale_independent_growth_factor") < 0)) __PYX_ERR(0, 2376, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("scale_independent_growth_factor", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2376, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.scale_independent_growth_factor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_124scale_independent_growth_factor(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_124scale_independent_growth_factor(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double __pyx_v_D;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("scale_independent_growth_factor", 1);

  /* "class-sz/python/classy.pyx":2392
 *         cdef double * pvecback
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2394
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2394, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2395
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2395, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2394
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2397
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2398
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         D = pvecback[self.ba.index_bg_D]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2398, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2397
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2400
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         D = pvecback[self.ba.index_bg_D]             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
  __pyx_v_D = (__pyx_v_pvecback[__pyx_v_self->ba.index_bg_D]);

  /* "class-sz/python/classy.pyx":2402
 *         D = pvecback[self.ba.index_bg_D]
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         return D
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":2404
 *         free(pvecback)
 * 
 *         return D             # <<<<<<<<<<<<<<
 * 
 *     def scale_independent_growth_factor_f(self, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_D); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2376
 * 
 * 
 *     def scale_independent_growth_factor(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.scale_independent_growth_factor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2406
 *         return D
 * 
 *     def scale_independent_growth_factor_f(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor_f(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_127scale_independent_growth_factor_f(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_126scale_independent_growth_factor_f, "\n        scale_independent_growth_factor_f(z)\n\n        Return the scale invariant growth factor f(z)=d ln D / d ln a for CDM perturbations\n        (exactly, the quantity defined by Class as index_bg_f in the background module)\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_127scale_independent_growth_factor_f = {"scale_independent_growth_factor_f", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_127scale_independent_growth_factor_f, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_126scale_independent_growth_factor_f};
static PyObject *__pyx_pw_9classy_sz_5Class_127scale_independent_growth_factor_f(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("scale_independent_growth_factor_f (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2406, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "scale_independent_growth_factor_f") < 0)) __PYX_ERR(0, 2406, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("scale_independent_growth_factor_f", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2406, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.scale_independent_growth_factor_f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_126scale_independent_growth_factor_f(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_126scale_independent_growth_factor_f(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double __pyx_v_f;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("scale_independent_growth_factor_f", 1);

  /* "class-sz/python/classy.pyx":2422
 *         cdef double * pvecback
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2424
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2424, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2425
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2425, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2425, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2424
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2427
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2428
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         f = pvecback[self.ba.index_bg_f]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2428, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2428, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2427
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2430
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         f = pvecback[self.ba.index_bg_f]             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
  __pyx_v_f = (__pyx_v_pvecback[__pyx_v_self->ba.index_bg_f]);

  /* "class-sz/python/classy.pyx":2432
 *         f = pvecback[self.ba.index_bg_f]
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         return f
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":2434
 *         free(pvecback)
 * 
 *         return f             # <<<<<<<<<<<<<<
 * 
 *     def z_of_tau(self, tau):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_f); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2406
 *         return D
 * 
 *     def scale_independent_growth_factor_f(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor_f(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.scale_independent_growth_factor_f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2436
 *         return f
 * 
 *     def z_of_tau(self, tau):             # <<<<<<<<<<<<<<
 *         """
 *         Redshift corresponding to a given conformal time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_129z_of_tau(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_128z_of_tau, "\n        Redshift corresponding to a given conformal time.\n\n        Parameters\n        ----------\n        tau : float\n                Conformal time\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_129z_of_tau = {"z_of_tau", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_129z_of_tau, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_128z_of_tau};
static PyObject *__pyx_pw_9classy_sz_5Class_129z_of_tau(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_tau = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("z_of_tau (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_tau,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tau)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2436, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "z_of_tau") < 0)) __PYX_ERR(0, 2436, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_tau = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("z_of_tau", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2436, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.z_of_tau", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_128z_of_tau(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_tau);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_128z_of_tau(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_tau) {
  double __pyx_v_z;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("z_of_tau", 1);

  /* "class-sz/python/classy.pyx":2449
 *         cdef double * pvecback
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2451
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_tau); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2451, __pyx_L1_error)
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_t_1, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2452
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         z = 1./pvecback[self.ba.index_bg_a]-1.
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2452, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2451
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2454
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         z = 1./pvecback[self.ba.index_bg_a]-1.             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
  if (unlikely((__pyx_v_pvecback[__pyx_v_self->ba.index_bg_a]) == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 2454, __pyx_L1_error)
  }
  __pyx_v_z = ((1. / (__pyx_v_pvecback[__pyx_v_self->ba.index_bg_a])) - 1.);

  /* "class-sz/python/classy.pyx":2456
 *         z = 1./pvecback[self.ba.index_bg_a]-1.
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         return z
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":2458
 *         free(pvecback)
 * 
 *         return z             # <<<<<<<<<<<<<<
 * 
 *     def get_Ez(self, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2436
 *         return f
 * 
 *     def z_of_tau(self, tau):             # <<<<<<<<<<<<<<
 *         """
 *         Redshift corresponding to a given conformal time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.z_of_tau", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2460
 *         return z
 * 
 *     def get_Ez(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         E(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_131get_Ez(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_130get_Ez, "\n        E(z)\n\n        Reduced Hubble rate at z\n\n        Parameters\n        ----------\n        z : float\n              redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_131get_Ez = {"get_Ez", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_131get_Ez, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_130get_Ez};
static PyObject *__pyx_pw_9classy_sz_5Class_131get_Ez(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_Ez (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2460, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_Ez") < 0)) __PYX_ERR(0, 2460, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_Ez", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2460, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_Ez", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_130get_Ez(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_130get_Ez(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_Ez", 1);

  /* "class-sz/python/classy.pyx":2471
 *               redshift
 *         """
 *         return self.Hubble(z)/self.Hubble(0.)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_float_0_};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2460
 *         return z
 * 
 *     def get_Ez(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         E(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_Ez", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2474
 * 
 * 
 *     def Hubble(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Hubble(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_133Hubble(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_132Hubble, "\n        Hubble(z)\n\n        Return the Hubble rate (exactly, the quantity defined by Class as index_bg_H\n        in the background module)\n\n        Parameters\n        ----------\n        z : float or array-like\n            Desired redshift\n\n        Returns\n        -------\n        float or array-like\n            Hubble rate\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_133Hubble = {"Hubble", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_133Hubble, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_132Hubble};
static PyObject *__pyx_pw_9classy_sz_5Class_133Hubble(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Hubble (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2474, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "Hubble") < 0)) __PYX_ERR(0, 2474, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("Hubble", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2474, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.Hubble", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_132Hubble(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_132Hubble(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  PyArrayObject *__pyx_v_z_array = 0;
  PyArrayObject *__pyx_v_H_array = 0;
  npy_intp __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  npy_intp __pyx_t_9;
  npy_intp __pyx_t_10;
  npy_intp __pyx_t_11;
  double __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Hubble", 1);

  /* "class-sz/python/classy.pyx":2497
 *         cdef np.ndarray H_array
 * 
 *         if isinstance(z, (float, int)):             # <<<<<<<<<<<<<<
 * 
 *             z_array = np.array([z], dtype=np.float64)
 */
  __pyx_t_2 = PyFloat_Check(__pyx_v_z); 
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = PyInt_Check(__pyx_v_z); 
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2499
 *         if isinstance(z, (float, int)):
 * 
 *             z_array = np.array([z], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_z);
    __Pyx_GIVEREF(__pyx_v_z);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_z)) __PYX_ERR(0, 2499, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 2499, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2499, __pyx_L1_error)
    __pyx_v_z_array = ((PyArrayObject *)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":2497
 *         cdef np.ndarray H_array
 * 
 *         if isinstance(z, (float, int)):             # <<<<<<<<<<<<<<
 * 
 *             z_array = np.array([z], dtype=np.float64)
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":2503
 *         else:
 * 
 *             z_array = np.array(z, dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         H_array = np.empty_like(z_array)
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_array); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_z);
    __Pyx_GIVEREF(__pyx_v_z);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_z)) __PYX_ERR(0, 2503, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2503, __pyx_L1_error)
    __pyx_v_z_array = ((PyArrayObject *)__pyx_t_6);
    __pyx_t_6 = 0;
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":2505
 *             z_array = np.array(z, dtype=np.float64)
 * 
 *         H_array = np.empty_like(z_array)             # <<<<<<<<<<<<<<
 * 
 *         for i in range(z_array.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty_like); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_z_array)};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2505, __pyx_L1_error)
  __pyx_v_H_array = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":2507
 *         H_array = np.empty_like(z_array)
 * 
 *         for i in range(z_array.size):             # <<<<<<<<<<<<<<
 *             # if self.tsz.use_class_sz_fast_mode == 1:
 *             if self.tsz.skip_background_and_thermo:
 */
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_z_array);
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_i = __pyx_t_11;

    /* "class-sz/python/classy.pyx":2509
 *         for i in range(z_array.size):
 *             # if self.tsz.use_class_sz_fast_mode == 1:
 *             if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 * 
 *                 H_array[i] = self.class_szfast.get_hubble(z_array[i])
 */
    __pyx_t_1 = (__pyx_v_self->tsz.skip_background_and_thermo != 0);
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":2511
 *             if self.tsz.skip_background_and_thermo:
 * 
 *                 H_array[i] = self.class_szfast.get_hubble(z_array[i])             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->class_szfast, __pyx_n_s_get_hubble); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, npy_intp, 1, __Pyx_PyInt_From_npy_intp, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2511, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_H_array), __pyx_v_i, __pyx_t_6, npy_intp, 1, __Pyx_PyInt_From_npy_intp, 0, 1, 1) < 0))) __PYX_ERR(0, 2511, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":2509
 *         for i in range(z_array.size):
 *             # if self.tsz.use_class_sz_fast_mode == 1:
 *             if self.tsz.skip_background_and_thermo:             # <<<<<<<<<<<<<<
 * 
 *                 H_array[i] = self.class_szfast.get_hubble(z_array[i])
 */
      goto __pyx_L8;
    }

    /* "class-sz/python/classy.pyx":2515
 *             else:
 * 
 *                 pvecback = <double*> calloc(self.ba.bg_size, sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *                 if background_tau_of_z(&self.ba, z_array[i], &tau) == _FAILURE_:
 */
    /*else*/ {
      __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

      /* "class-sz/python/classy.pyx":2517
 *                 pvecback = <double*> calloc(self.ba.bg_size, sizeof(double))
 * 
 *                 if background_tau_of_z(&self.ba, z_array[i], &tau) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                     free(pvecback)
 *                     raise CosmoSevereError(self.ba.error_message)
 */
      __pyx_t_6 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, npy_intp, 1, __Pyx_PyInt_From_npy_intp, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2517, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2517, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_1 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_12, (&__pyx_v_tau)) == _FAILURE_);
      if (unlikely(__pyx_t_1)) {

        /* "class-sz/python/classy.pyx":2518
 * 
 *                 if background_tau_of_z(&self.ba, z_array[i], &tau) == _FAILURE_:
 *                     free(pvecback)             # <<<<<<<<<<<<<<
 *                     raise CosmoSevereError(self.ba.error_message)
 * 
 */
        free(__pyx_v_pvecback);

        /* "class-sz/python/classy.pyx":2519
 *                 if background_tau_of_z(&self.ba, z_array[i], &tau) == _FAILURE_:
 *                     free(pvecback)
 *                     raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *                 if background_at_tau(&self.ba, tau, self.ba.long_info, self.ba.inter_normal, &last_index, pvecback) == _FAILURE_:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2519, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2519, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2519, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(0, 2519, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":2517
 *                 pvecback = <double*> calloc(self.ba.bg_size, sizeof(double))
 * 
 *                 if background_tau_of_z(&self.ba, z_array[i], &tau) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                     free(pvecback)
 *                     raise CosmoSevereError(self.ba.error_message)
 */
      }

      /* "class-sz/python/classy.pyx":2521
 *                     raise CosmoSevereError(self.ba.error_message)
 * 
 *                 if background_at_tau(&self.ba, tau, self.ba.long_info, self.ba.inter_normal, &last_index, pvecback) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                     free(pvecback)
 *                     raise CosmoSevereError(self.ba.error_message)
 */
      __pyx_t_1 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
      if (unlikely(__pyx_t_1)) {

        /* "class-sz/python/classy.pyx":2522
 * 
 *                 if background_at_tau(&self.ba, tau, self.ba.long_info, self.ba.inter_normal, &last_index, pvecback) == _FAILURE_:
 *                     free(pvecback)             # <<<<<<<<<<<<<<
 *                     raise CosmoSevereError(self.ba.error_message)
 * 
 */
        free(__pyx_v_pvecback);

        /* "class-sz/python/classy.pyx":2523
 *                 if background_at_tau(&self.ba, tau, self.ba.long_info, self.ba.inter_normal, &last_index, pvecback) == _FAILURE_:
 *                     free(pvecback)
 *                     raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *                 H_array[i] = pvecback[self.ba.index_bg_H]
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2523, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2523, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
          __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2523, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(0, 2523, __pyx_L1_error)

        /* "class-sz/python/classy.pyx":2521
 *                     raise CosmoSevereError(self.ba.error_message)
 * 
 *                 if background_at_tau(&self.ba, tau, self.ba.long_info, self.ba.inter_normal, &last_index, pvecback) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                     free(pvecback)
 *                     raise CosmoSevereError(self.ba.error_message)
 */
      }

      /* "class-sz/python/classy.pyx":2525
 *                     raise CosmoSevereError(self.ba.error_message)
 * 
 *                 H_array[i] = pvecback[self.ba.index_bg_H]             # <<<<<<<<<<<<<<
 * 
 *                 free(pvecback)
 */
      __pyx_t_6 = PyFloat_FromDouble((__pyx_v_pvecback[__pyx_v_self->ba.index_bg_H])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_H_array), __pyx_v_i, __pyx_t_6, npy_intp, 1, __Pyx_PyInt_From_npy_intp, 0, 1, 1) < 0))) __PYX_ERR(0, 2525, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":2527
 *                 H_array[i] = pvecback[self.ba.index_bg_H]
 * 
 *                 free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         if H_array.size == 1:
 */
      free(__pyx_v_pvecback);
    }
    __pyx_L8:;
  }

  /* "class-sz/python/classy.pyx":2529
 *                 free(pvecback)
 * 
 *         if H_array.size == 1:             # <<<<<<<<<<<<<<
 * 
 *             return H_array[0]
 */
  __pyx_t_1 = (__pyx_f_5numpy_7ndarray_4size_size(__pyx_v_H_array) == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2531
 *         if H_array.size == 1:
 * 
 *             return H_array[0]             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __Pyx_GetItemInt(((PyObject *)__pyx_v_H_array), 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2529
 *                 free(pvecback)
 * 
 *         if H_array.size == 1:             # <<<<<<<<<<<<<<
 * 
 *             return H_array[0]
 */
  }

  /* "class-sz/python/classy.pyx":2535
 *         else:
 * 
 *             return H_array             # <<<<<<<<<<<<<<
 * 
 *     def get_H(self, z):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_H_array);
    __pyx_r = ((PyObject *)__pyx_v_H_array);
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2474
 * 
 * 
 *     def Hubble(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Hubble(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.Hubble", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_z_array);
  __Pyx_XDECREF((PyObject *)__pyx_v_H_array);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2537
 *             return H_array
 * 
 *     def get_H(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         get_H(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_135get_H(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_134get_H, "\n        get_H(z)\n\n        Return the Hubble rate divided by the speed of light c\n        in units of h/Mpc. This is a convenience function to convert the output \n        of the Hubble function to the desired units.\n\n        Parameters\n        ----------\n        z : float or array-like\n            Desired redshift\n\n        Returns\n        -------\n        float or array-like\n            Hubble rate divided by h in units of h/Mpc\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_135get_H = {"get_H", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_135get_H, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_134get_H};
static PyObject *__pyx_pw_9classy_sz_5Class_135get_H(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_H (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2537, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_H") < 0)) __PYX_ERR(0, 2537, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_H", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2537, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_H", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_134get_H(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_134get_H(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyArrayObject *__pyx_v_z_array = 0;
  PyArrayObject *__pyx_v_H_over_c_in_h_over_Mpc_array = 0;
  npy_intp __pyx_v_i;
  PyObject *__pyx_v_H = NULL;
  double __pyx_v_h;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  npy_intp __pyx_t_9;
  npy_intp __pyx_t_10;
  npy_intp __pyx_t_11;
  double __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_H", 1);

  /* "class-sz/python/classy.pyx":2558
 *         cdef np.ndarray H_over_c_in_h_over_Mpc_array
 * 
 *         if isinstance(z, (float, int)):             # <<<<<<<<<<<<<<
 *             z_array = np.array([z], dtype=np.float64)
 *         else:
 */
  __pyx_t_2 = PyFloat_Check(__pyx_v_z); 
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = PyInt_Check(__pyx_v_z); 
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2559
 * 
 *         if isinstance(z, (float, int)):
 *             z_array = np.array([z], dtype=np.float64)             # <<<<<<<<<<<<<<
 *         else:
 *             z_array = np.array(z, dtype=np.float64)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_z);
    __Pyx_GIVEREF(__pyx_v_z);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_z)) __PYX_ERR(0, 2559, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 2559, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2559, __pyx_L1_error)
    __pyx_v_z_array = ((PyArrayObject *)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":2558
 *         cdef np.ndarray H_over_c_in_h_over_Mpc_array
 * 
 *         if isinstance(z, (float, int)):             # <<<<<<<<<<<<<<
 *             z_array = np.array([z], dtype=np.float64)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":2561
 *             z_array = np.array([z], dtype=np.float64)
 *         else:
 *             z_array = np.array(z, dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         H_over_c_in_h_over_Mpc_array = np.empty_like(z_array)
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_array); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_z);
    __Pyx_GIVEREF(__pyx_v_z);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_z)) __PYX_ERR(0, 2561, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2561, __pyx_L1_error)
    __pyx_v_z_array = ((PyArrayObject *)__pyx_t_6);
    __pyx_t_6 = 0;
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":2563
 *             z_array = np.array(z, dtype=np.float64)
 * 
 *         H_over_c_in_h_over_Mpc_array = np.empty_like(z_array)             # <<<<<<<<<<<<<<
 * 
 *         for i in range(z_array.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty_like); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_z_array)};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2563, __pyx_L1_error)
  __pyx_v_H_over_c_in_h_over_Mpc_array = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":2565
 *         H_over_c_in_h_over_Mpc_array = np.empty_like(z_array)
 * 
 *         for i in range(z_array.size):             # <<<<<<<<<<<<<<
 *             H = self.Hubble(z_array[i])
 *             h = self.ba.h
 */
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_z_array);
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_i = __pyx_t_11;

    /* "class-sz/python/classy.pyx":2566
 * 
 *         for i in range(z_array.size):
 *             H = self.Hubble(z_array[i])             # <<<<<<<<<<<<<<
 *             h = self.ba.h
 *             H_over_c_in_h_over_Mpc_array[i] = H / h
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_GetItemInt(((PyObject *)__pyx_v_z_array), __pyx_v_i, npy_intp, 1, __Pyx_PyInt_From_npy_intp, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2566, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2566, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_H, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":2567
 *         for i in range(z_array.size):
 *             H = self.Hubble(z_array[i])
 *             h = self.ba.h             # <<<<<<<<<<<<<<
 *             H_over_c_in_h_over_Mpc_array[i] = H / h
 * 
 */
    __pyx_t_12 = __pyx_v_self->ba.h;
    __pyx_v_h = __pyx_t_12;

    /* "class-sz/python/classy.pyx":2568
 *             H = self.Hubble(z_array[i])
 *             h = self.ba.h
 *             H_over_c_in_h_over_Mpc_array[i] = H / h             # <<<<<<<<<<<<<<
 * 
 *         if H_over_c_in_h_over_Mpc_array.size == 1:
 */
    __pyx_t_6 = PyFloat_FromDouble(__pyx_v_h); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_v_H, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_H_over_c_in_h_over_Mpc_array), __pyx_v_i, __pyx_t_7, npy_intp, 1, __Pyx_PyInt_From_npy_intp, 0, 1, 1) < 0))) __PYX_ERR(0, 2568, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }

  /* "class-sz/python/classy.pyx":2570
 *             H_over_c_in_h_over_Mpc_array[i] = H / h
 * 
 *         if H_over_c_in_h_over_Mpc_array.size == 1:             # <<<<<<<<<<<<<<
 *             return H_over_c_in_h_over_Mpc_array[0]
 *         else:
 */
  __pyx_t_1 = (__pyx_f_5numpy_7ndarray_4size_size(__pyx_v_H_over_c_in_h_over_Mpc_array) == 1);
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":2571
 * 
 *         if H_over_c_in_h_over_Mpc_array.size == 1:
 *             return H_over_c_in_h_over_Mpc_array[0]             # <<<<<<<<<<<<<<
 *         else:
 *             return H_over_c_in_h_over_Mpc_array
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __Pyx_GetItemInt(((PyObject *)__pyx_v_H_over_c_in_h_over_Mpc_array), 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2570
 *             H_over_c_in_h_over_Mpc_array[i] = H / h
 * 
 *         if H_over_c_in_h_over_Mpc_array.size == 1:             # <<<<<<<<<<<<<<
 *             return H_over_c_in_h_over_Mpc_array[0]
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":2573
 *             return H_over_c_in_h_over_Mpc_array[0]
 *         else:
 *             return H_over_c_in_h_over_Mpc_array             # <<<<<<<<<<<<<<
 * 
 *     def Om_m(self, z):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_H_over_c_in_h_over_Mpc_array);
    __pyx_r = ((PyObject *)__pyx_v_H_over_c_in_h_over_Mpc_array);
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":2537
 *             return H_array
 * 
 *     def get_H(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         get_H(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.get_H", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_z_array);
  __Pyx_XDECREF((PyObject *)__pyx_v_H_over_c_in_h_over_Mpc_array);
  __Pyx_XDECREF(__pyx_v_H);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2575
 *             return H_over_c_in_h_over_Mpc_array
 * 
 *     def Om_m(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Omega_m(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_137Om_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_136Om_m, "\n        Omega_m(z)\n\n        Return the matter density fraction (exactly, the quantity defined by Class as index_bg_Omega_m\n        in the background module)\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_137Om_m = {"Om_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_137Om_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_136Om_m};
static PyObject *__pyx_pw_9classy_sz_5Class_137Om_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Om_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2575, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "Om_m") < 0)) __PYX_ERR(0, 2575, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("Om_m", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2575, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.Om_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_136Om_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_136Om_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double __pyx_v_Om_m;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Om_m", 1);

  /* "class-sz/python/classy.pyx":2591
 *         cdef double * pvecback
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2593
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2593, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2594
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2594, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2594, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2594, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2593
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2596
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2597
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         Om_m = pvecback[self.ba.index_bg_Omega_m]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2597, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2596
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2599
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         Om_m = pvecback[self.ba.index_bg_Omega_m]             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
  __pyx_v_Om_m = (__pyx_v_pvecback[__pyx_v_self->ba.index_bg_Omega_m]);

  /* "class-sz/python/classy.pyx":2601
 *         Om_m = pvecback[self.ba.index_bg_Omega_m]
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         return Om_m
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":2603
 *         free(pvecback)
 * 
 *         return Om_m             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_Om_m); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2575
 *             return H_over_c_in_h_over_Mpc_array
 * 
 *     def Om_m(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Omega_m(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.Om_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2606
 * 
 * 
 *     def ionization_fraction(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         ionization_fraction(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_139ionization_fraction(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_138ionization_fraction, "\n        ionization_fraction(z)\n\n        Return the ionization fraction for a given redshift z\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_139ionization_fraction = {"ionization_fraction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_139ionization_fraction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_138ionization_fraction};
static PyObject *__pyx_pw_9classy_sz_5Class_139ionization_fraction(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ionization_fraction (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2606, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "ionization_fraction") < 0)) __PYX_ERR(0, 2606, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("ionization_fraction", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2606, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.ionization_fraction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_138ionization_fraction(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_138ionization_fraction(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double *__pyx_v_pvecthermo;
  double __pyx_v_xe;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ionization_fraction", 1);

  /* "class-sz/python/classy.pyx":2622
 *         cdef double * pvecthermo
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))
 * 
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2623
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
  __pyx_v_pvecthermo = ((double *)calloc(__pyx_v_self->th.th_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2625
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2625, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2626
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2626, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2626, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2625
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2628
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2629
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2629, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2629, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2629, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2628
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2631
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2631, __pyx_L1_error)
  __pyx_t_2 = (thermodynamics_at_z((&__pyx_v_self->ba), (&__pyx_v_self->th), __pyx_t_1, __pyx_v_self->th.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback, __pyx_v_pvecthermo) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2632
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:
 *             raise CosmoSevereError(self.th.error_message)             # <<<<<<<<<<<<<<
 * 
 *         xe = pvecthermo[self.th.index_th_xe]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->th.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2632, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2631
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2634
 *             raise CosmoSevereError(self.th.error_message)
 * 
 *         xe = pvecthermo[self.th.index_th_xe]             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
  __pyx_v_xe = (__pyx_v_pvecthermo[__pyx_v_self->th.index_th_xe]);

  /* "class-sz/python/classy.pyx":2636
 *         xe = pvecthermo[self.th.index_th_xe]
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 *         free(pvecthermo)
 * 
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":2637
 * 
 *         free(pvecback)
 *         free(pvecthermo)             # <<<<<<<<<<<<<<
 * 
 *         return xe
 */
  free(__pyx_v_pvecthermo);

  /* "class-sz/python/classy.pyx":2639
 *         free(pvecthermo)
 * 
 *         return xe             # <<<<<<<<<<<<<<
 * 
 *     def baryon_temperature(self, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_xe); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2639, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2606
 * 
 * 
 *     def ionization_fraction(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         ionization_fraction(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.ionization_fraction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2641
 *         return xe
 * 
 *     def baryon_temperature(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         baryon_temperature(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_141baryon_temperature(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_140baryon_temperature, "\n        baryon_temperature(z)\n\n        Give the baryon temperature for a given redshift z\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_141baryon_temperature = {"baryon_temperature", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_141baryon_temperature, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_140baryon_temperature};
static PyObject *__pyx_pw_9classy_sz_5Class_141baryon_temperature(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("baryon_temperature (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2641, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "baryon_temperature") < 0)) __PYX_ERR(0, 2641, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("baryon_temperature", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2641, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.baryon_temperature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_140baryon_temperature(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_140baryon_temperature(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double *__pyx_v_pvecthermo;
  double __pyx_v_Tb;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("baryon_temperature", 1);

  /* "class-sz/python/classy.pyx":2657
 *         cdef double * pvecthermo
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))
 * 
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2658
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
  __pyx_v_pvecthermo = ((double *)calloc(__pyx_v_self->th.th_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":2660
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2660, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2661
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2661, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2660
 *         pvecthermo = <double*> calloc(self.th.th_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2663
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2664
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2664, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2664, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2663
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2666
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2666, __pyx_L1_error)
  __pyx_t_2 = (thermodynamics_at_z((&__pyx_v_self->ba), (&__pyx_v_self->th), __pyx_t_1, __pyx_v_self->th.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback, __pyx_v_pvecthermo) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":2667
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:
 *             raise CosmoSevereError(self.th.error_message)             # <<<<<<<<<<<<<<
 * 
 *         Tb = pvecthermo[self.th.index_th_Tb]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->th.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2667, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2667, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2666
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if thermodynamics_at_z(&self.ba,&self.th,z,self.th.inter_normal,&last_index,pvecback,pvecthermo) == _FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2669
 *             raise CosmoSevereError(self.th.error_message)
 * 
 *         Tb = pvecthermo[self.th.index_th_Tb]             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
  __pyx_v_Tb = (__pyx_v_pvecthermo[__pyx_v_self->th.index_th_Tb]);

  /* "class-sz/python/classy.pyx":2671
 *         Tb = pvecthermo[self.th.index_th_Tb]
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 *         free(pvecthermo)
 * 
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":2672
 * 
 *         free(pvecback)
 *         free(pvecthermo)             # <<<<<<<<<<<<<<
 * 
 *         return Tb
 */
  free(__pyx_v_pvecthermo);

  /* "class-sz/python/classy.pyx":2674
 *         free(pvecthermo)
 * 
 *         return Tb             # <<<<<<<<<<<<<<
 * 
 *     def T_cmb(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_Tb); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2641
 *         return xe
 * 
 *     def baryon_temperature(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         baryon_temperature(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.baryon_temperature", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2676
 *         return Tb
 * 
 *     def T_cmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the CMB temperature
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_143T_cmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_142T_cmb, "\n        Return the CMB temperature\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_143T_cmb = {"T_cmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_143T_cmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_142T_cmb};
static PyObject *__pyx_pw_9classy_sz_5Class_143T_cmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("T_cmb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("T_cmb", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "T_cmb", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_142T_cmb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_142T_cmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("T_cmb", 1);

  /* "class-sz/python/classy.pyx":2680
 *         Return the CMB temperature
 *         """
 *         return self.ba.T_cmb             # <<<<<<<<<<<<<<
 * 
 *     # redundent with a previous Omega_m() funciton,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.T_cmb); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2676
 *         return Tb
 * 
 *     def T_cmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the CMB temperature
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.T_cmb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2684
 *     # redundent with a previous Omega_m() funciton,
 *     # but we leave it not to break compatibility
 *     def Omega0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the sum of Omega0 for all non-relativistic components
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_145Omega0_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_144Omega0_m, "\n        Return the sum of Omega0 for all non-relativistic components\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_145Omega0_m = {"Omega0_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_145Omega0_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_144Omega0_m};
static PyObject *__pyx_pw_9classy_sz_5Class_145Omega0_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega0_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega0_m", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega0_m", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_144Omega0_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_144Omega0_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega0_m", 1);

  /* "class-sz/python/classy.pyx":2688
 *         Return the sum of Omega0 for all non-relativistic components
 *         """
 *         return self.ba.Omega0_m             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_m); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2684
 *     # redundent with a previous Omega_m() funciton,
 *     # but we leave it not to break compatibility
 *     def Omega0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the sum of Omega0 for all non-relativistic components
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega0_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2691
 * 
 * 
 *     def cl_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the 1-halo and 2-halo terms of tSZ power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_147cl_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_146cl_sz, "\n        (SZ) Return the 1-halo and 2-halo terms of tSZ power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_147cl_sz = {"cl_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_147cl_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_146cl_sz};
static PyObject *__pyx_pw_9classy_sz_5Class_147cl_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_sz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_sz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_sz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_146cl_sz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_146cl_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_sz", 1);

  /* "class-sz/python/classy.pyx":2695
 *         (SZ) Return the 1-halo and 2-halo terms of tSZ power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2696
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2697
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2697, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2698
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_sz_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2699
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_sz_1h[index])
 *             cl['2h'].append(self.tsz.cl_sz_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2700
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_sz_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_sz_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_sz_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2700, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2701
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_sz_1h[index])
 *             cl['2h'].append(self.tsz.cl_sz_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_sz_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2701, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2702
 *             cl['1h'].append(self.tsz.cl_sz_1h[index])
 *             cl['2h'].append(self.tsz.cl_sz_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2702, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2702, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2702, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":2703
 *             cl['2h'].append(self.tsz.cl_sz_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2691
 * 
 * 
 *     def cl_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the 1-halo and 2-halo terms of tSZ power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2706
 * 
 * 
 *     def dl_isw_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (ISW x SZ) Return the ISW x tSZ power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_149dl_isw_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_148dl_isw_sz, "\n        (ISW x SZ) Return the ISW x tSZ power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_149dl_isw_sz = {"dl_isw_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_149dl_isw_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_148dl_isw_sz};
static PyObject *__pyx_pw_9classy_sz_5Class_149dl_isw_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dl_isw_sz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("dl_isw_sz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dl_isw_sz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_148dl_isw_sz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_148dl_isw_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_dl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dl_isw_sz", 1);

  /* "class-sz/python/classy.pyx":2710
 *         (ISW x SZ) Return the ISW x tSZ power spectrum
 *         """
 *         dl = {}             # <<<<<<<<<<<<<<
 *         dl['ell'] = []
 *         dl['d_ell'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_dl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2711
 *         """
 *         dl = {}
 *         dl['ell'] = []             # <<<<<<<<<<<<<<
 *         dl['d_ell'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_dl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2712
 *         dl = {}
 *         dl['ell'] = []
 *         dl['d_ell'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             dl['d_ell'].append(self.tsz.cl_isw_tsz[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_dl, __pyx_n_u_d_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2712, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2713
 *         dl['ell'] = []
 *         dl['d_ell'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             dl['d_ell'].append(self.tsz.cl_isw_tsz[index])
 *             dl['ell'].append(self.tsz.ell[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2714
 *         dl['d_ell'] = []
 *         for index in range(self.tsz.nlSZ):
 *             dl['d_ell'].append(self.tsz.cl_isw_tsz[index])             # <<<<<<<<<<<<<<
 *             dl['ell'].append(self.tsz.ell[index])
 *         return dl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_dl, __pyx_n_u_d_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2714, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_isw_tsz[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2714, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2714, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2715
 *         for index in range(self.tsz.nlSZ):
 *             dl['d_ell'].append(self.tsz.cl_isw_tsz[index])
 *             dl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return dl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_dl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2715, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":2716
 *             dl['d_ell'].append(self.tsz.cl_isw_tsz[index])
 *             dl['ell'].append(self.tsz.ell[index])
 *         return dl             # <<<<<<<<<<<<<<
 * 
 *     def cl_sz_at_nu_in_GHz_in_microK2(self,nu_in_GHz):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_dl);
  __pyx_r = __pyx_v_dl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2706
 * 
 * 
 *     def dl_isw_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (ISW x SZ) Return the ISW x tSZ power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.dl_isw_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2718
 *         return dl
 * 
 *     def cl_sz_at_nu_in_GHz_in_microK2(self,nu_in_GHz):             # <<<<<<<<<<<<<<
 *         frequency_in_Hz = nu_in_GHz*1e9
 *         T_cmb = self.T_cmb()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_151cl_sz_at_nu_in_GHz_in_microK2(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_151cl_sz_at_nu_in_GHz_in_microK2 = {"cl_sz_at_nu_in_GHz_in_microK2", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_151cl_sz_at_nu_in_GHz_in_microK2, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_151cl_sz_at_nu_in_GHz_in_microK2(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_nu_in_GHz = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_sz_at_nu_in_GHz_in_microK2 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nu_in_GHz,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu_in_GHz)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2718, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "cl_sz_at_nu_in_GHz_in_microK2") < 0)) __PYX_ERR(0, 2718, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_nu_in_GHz = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cl_sz_at_nu_in_GHz_in_microK2", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2718, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.cl_sz_at_nu_in_GHz_in_microK2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_150cl_sz_at_nu_in_GHz_in_microK2(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_nu_in_GHz);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_150cl_sz_at_nu_in_GHz_in_microK2(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nu_in_GHz) {
  PyObject *__pyx_v_frequency_in_Hz = NULL;
  PyObject *__pyx_v_T_cmb = NULL;
  double __pyx_v__h_P_;
  double __pyx_v__k_B_;
  PyObject *__pyx_v_Tcmb_gNU = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_sz_at_nu_in_GHz_in_microK2", 1);

  /* "class-sz/python/classy.pyx":2719
 * 
 *     def cl_sz_at_nu_in_GHz_in_microK2(self,nu_in_GHz):
 *         frequency_in_Hz = nu_in_GHz*1e9             # <<<<<<<<<<<<<<
 *         T_cmb = self.T_cmb()
 *         _h_P_=6.62606896e-34
 */
  __pyx_t_1 = PyNumber_Multiply(__pyx_v_nu_in_GHz, __pyx_float_1e9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_frequency_in_Hz = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2720
 *     def cl_sz_at_nu_in_GHz_in_microK2(self,nu_in_GHz):
 *         frequency_in_Hz = nu_in_GHz*1e9
 *         T_cmb = self.T_cmb()             # <<<<<<<<<<<<<<
 *         _h_P_=6.62606896e-34
 *         _k_B_=1.3806504e-23
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_T_cmb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_T_cmb = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2721
 *         frequency_in_Hz = nu_in_GHz*1e9
 *         T_cmb = self.T_cmb()
 *         _h_P_=6.62606896e-34             # <<<<<<<<<<<<<<
 *         _k_B_=1.3806504e-23
 *         Tcmb_gNU = T_cmb*((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))*(1./np.tanh((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))/2.))-4.)
 */
  __pyx_v__h_P_ = 6.62606896e-34;

  /* "class-sz/python/classy.pyx":2722
 *         T_cmb = self.T_cmb()
 *         _h_P_=6.62606896e-34
 *         _k_B_=1.3806504e-23             # <<<<<<<<<<<<<<
 *         Tcmb_gNU = T_cmb*((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))*(1./np.tanh((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))/2.))-4.)
 *         r = {}
 */
  __pyx_v__k_B_ = 1.3806504e-23;

  /* "class-sz/python/classy.pyx":2723
 *         _h_P_=6.62606896e-34
 *         _k_B_=1.3806504e-23
 *         Tcmb_gNU = T_cmb*((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))*(1./np.tanh((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))/2.))-4.)             # <<<<<<<<<<<<<<
 *         r = {}
 *         r['ell'] = np.asarray(self.cl_sz()['ell'])
 */
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v__h_P_); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_1, __pyx_v_frequency_in_Hz); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v__k_B_); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_v_T_cmb); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tanh); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v__h_P_); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_2, __pyx_v_frequency_in_Hz); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v__k_B_); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_2, __pyx_v_T_cmb); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_2, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_7};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2723, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyFloat_TrueDivideCObj(__pyx_float_1_, __pyx_t_3, 1., 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyFloat_SubtractObjC(__pyx_t_3, __pyx_float_4_, 4., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_v_T_cmb, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_Tcmb_gNU = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":2724
 *         _k_B_=1.3806504e-23
 *         Tcmb_gNU = T_cmb*((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))*(1./np.tanh((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))/2.))-4.)
 *         r = {}             # <<<<<<<<<<<<<<
 *         r['ell'] = np.asarray(self.cl_sz()['ell'])
 *         r['1h'] = np.asarray(self.cl_sz()['1h'])*Tcmb_gNU**2.
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":2725
 *         Tcmb_gNU = T_cmb*((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))*(1./np.tanh((_h_P_*frequency_in_Hz/(_k_B_*T_cmb))/2.))-4.)
 *         r = {}
 *         r['ell'] = np.asarray(self.cl_sz()['ell'])             # <<<<<<<<<<<<<<
 *         r['1h'] = np.asarray(self.cl_sz()['1h'])*Tcmb_gNU**2.
 *         r['2h'] = np.asarray(self.cl_sz()['2h'])*Tcmb_gNU**2.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_asarray); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cl_sz); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_t_5, __pyx_n_u_ell); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_7};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_r, __pyx_n_u_ell, __pyx_t_3) < 0))) __PYX_ERR(0, 2725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":2726
 *         r = {}
 *         r['ell'] = np.asarray(self.cl_sz()['ell'])
 *         r['1h'] = np.asarray(self.cl_sz()['1h'])*Tcmb_gNU**2.             # <<<<<<<<<<<<<<
 *         r['2h'] = np.asarray(self.cl_sz()['2h'])*Tcmb_gNU**2.
 *         return r
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cl_sz); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_kp_u_1h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = PyNumber_Power(__pyx_v_Tcmb_gNU, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyNumber_Multiply(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely((PyDict_SetItem(__pyx_v_r, __pyx_kp_u_1h, __pyx_t_5) < 0))) __PYX_ERR(0, 2726, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":2727
 *         r['ell'] = np.asarray(self.cl_sz()['ell'])
 *         r['1h'] = np.asarray(self.cl_sz()['1h'])*Tcmb_gNU**2.
 *         r['2h'] = np.asarray(self.cl_sz()['2h'])*Tcmb_gNU**2.             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cl_sz); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2727, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_7, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2727, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Power(__pyx_v_Tcmb_gNU, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyNumber_Multiply(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely((PyDict_SetItem(__pyx_v_r, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2728
 *         r['1h'] = np.asarray(self.cl_sz()['1h'])*Tcmb_gNU**2.
 *         r['2h'] = np.asarray(self.cl_sz()['2h'])*Tcmb_gNU**2.
 *         return r             # <<<<<<<<<<<<<<
 * 
 *     def get_volume_dVdzdOmega_at_z(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_r);
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2718
 *         return dl
 * 
 *     def cl_sz_at_nu_in_GHz_in_microK2(self,nu_in_GHz):             # <<<<<<<<<<<<<<
 *         frequency_in_Hz = nu_in_GHz*1e9
 *         T_cmb = self.T_cmb()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.cl_sz_at_nu_in_GHz_in_microK2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_frequency_in_Hz);
  __Pyx_XDECREF(__pyx_v_T_cmb);
  __Pyx_XDECREF(__pyx_v_Tcmb_gNU);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2730
 *         return r
 * 
 *     def get_volume_dVdzdOmega_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_volume_at_z(z,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_153get_volume_dVdzdOmega_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_153get_volume_dVdzdOmega_at_z = {"get_volume_dVdzdOmega_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_153get_volume_dVdzdOmega_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_153get_volume_dVdzdOmega_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_volume_dVdzdOmega_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2730, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_volume_dVdzdOmega_at_z") < 0)) __PYX_ERR(0, 2730, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_volume_dVdzdOmega_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2730, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_volume_dVdzdOmega_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_152get_volume_dVdzdOmega_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_152get_volume_dVdzdOmega_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_volume_dVdzdOmega_at_z", 1);

  /* "class-sz/python/classy.pyx":2731
 * 
 *     def get_volume_dVdzdOmega_at_z(self,z):
 *         return get_volume_at_z(z,&self.ba)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2731, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_volume_at_z(__pyx_t_1, (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2730
 *         return r
 * 
 *     def get_volume_dVdzdOmega_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_volume_at_z(z,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_volume_dVdzdOmega_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2734
 * 
 * 
 *     def get_z_of_chi_unvectorized(self,chi):             # <<<<<<<<<<<<<<
 *         return get_z_of_chi(chi,&self.tsz,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_155get_z_of_chi_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_155get_z_of_chi_unvectorized = {"get_z_of_chi_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_155get_z_of_chi_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_155get_z_of_chi_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_chi = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_z_of_chi_unvectorized (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_chi,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2734, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_z_of_chi_unvectorized") < 0)) __PYX_ERR(0, 2734, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_chi = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_z_of_chi_unvectorized", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2734, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_z_of_chi_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_154get_z_of_chi_unvectorized(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_chi);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_154get_z_of_chi_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_chi) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_z_of_chi_unvectorized", 1);

  /* "class-sz/python/classy.pyx":2735
 * 
 *     def get_z_of_chi_unvectorized(self,chi):
 *         return get_z_of_chi(chi,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_chi); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2735, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_z_of_chi(__pyx_t_1, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2734
 * 
 * 
 *     def get_z_of_chi_unvectorized(self,chi):             # <<<<<<<<<<<<<<
 *         return get_z_of_chi(chi,&self.tsz,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_z_of_chi_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2738
 * 
 * 
 *     def get_z_of_chi(self,chi):             # <<<<<<<<<<<<<<
 *          # Check if input is a scalar
 *         if isinstance(chi, (float, np.float64)):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_157get_z_of_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_157get_z_of_chi = {"get_z_of_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_157get_z_of_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_157get_z_of_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_chi = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_z_of_chi (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_chi,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2738, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_z_of_chi") < 0)) __PYX_ERR(0, 2738, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_chi = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_z_of_chi", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2738, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_z_of_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_156get_z_of_chi(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_chi);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_156get_z_of_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_chi) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_z_of_chi", 1);

  /* "class-sz/python/classy.pyx":2740
 *     def get_z_of_chi(self,chi):
 *          # Check if input is a scalar
 *         if isinstance(chi, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             return self.get_z_of_chi_unvectorized(chi)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2740, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_chi); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_chi, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":2741
 *          # Check if input is a scalar
 *         if isinstance(chi, (float, np.float64)):
 *             return self.get_z_of_chi_unvectorized(chi)             # <<<<<<<<<<<<<<
 * 
 *         # Check if chi is an array
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_z_of_chi_unvectorized); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_chi};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2741, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2740
 *     def get_z_of_chi(self,chi):
 *          # Check if input is a scalar
 *         if isinstance(chi, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             return self.get_z_of_chi_unvectorized(chi)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2744
 * 
 *         # Check if chi is an array
 *         elif isinstance(chi, np.ndarray) and chi.ndim == 1 and chi.dtype == np.float64:             # <<<<<<<<<<<<<<
 *             n = chi.shape[0]
 *             result = np.empty(n, dtype=np.float64)
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_chi, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_chi, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_chi, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L6_bool_binop_done:;
  if (likely(__pyx_t_3)) {

    /* "class-sz/python/classy.pyx":2745
 *         # Check if chi is an array
 *         elif isinstance(chi, np.ndarray) and chi.ndim == 1 and chi.dtype == np.float64:
 *             n = chi.shape[0]             # <<<<<<<<<<<<<<
 *             result = np.empty(n, dtype=np.float64)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_chi, __pyx_n_s_shape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_n = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2746
 *         elif isinstance(chi, np.ndarray) and chi.ndim == 1 and chi.dtype == np.float64:
 *             n = chi.shape[0]
 *             result = np.empty(n, dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *             for i in range(n):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_n);
    __Pyx_GIVEREF(__pyx_v_n);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_n)) __PYX_ERR(0, 2746, __pyx_L1_error);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_8) < 0) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_result = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":2748
 *             result = np.empty(n, dtype=np.float64)
 * 
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 result[i] = self.get_z_of_chi_unvectorized(chi[i])
 * 
 */
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_n); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (likely(PyList_CheckExact(__pyx_t_8)) || PyTuple_CheckExact(__pyx_t_8)) {
      __pyx_t_2 = __pyx_t_8; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_9 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2748, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2748, __pyx_L1_error)
            #endif
            if (__pyx_t_9 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_8 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 2748, __pyx_L1_error)
          #else
          __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2748, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2748, __pyx_L1_error)
            #endif
            if (__pyx_t_9 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 2748, __pyx_L1_error)
          #else
          __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2748, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          #endif
        }
      } else {
        __pyx_t_8 = __pyx_t_10(__pyx_t_2);
        if (unlikely(!__pyx_t_8)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2748, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_8);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":2749
 * 
 *             for i in range(n):
 *                 result[i] = self.get_z_of_chi_unvectorized(chi[i])             # <<<<<<<<<<<<<<
 * 
 *             return result
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_z_of_chi_unvectorized); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_chi, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      if (unlikely((PyObject_SetItem(__pyx_v_result, __pyx_v_i, __pyx_t_8) < 0))) __PYX_ERR(0, 2749, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":2748
 *             result = np.empty(n, dtype=np.float64)
 * 
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 result[i] = self.get_z_of_chi_unvectorized(chi[i])
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":2751
 *                 result[i] = self.get_z_of_chi_unvectorized(chi[i])
 * 
 *             return result             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2744
 * 
 *         # Check if chi is an array
 *         elif isinstance(chi, np.ndarray) and chi.ndim == 1 and chi.dtype == np.float64:             # <<<<<<<<<<<<<<
 *             n = chi.shape[0]
 *             result = np.empty(n, dtype=np.float64)
 */
  }

  /* "class-sz/python/classy.pyx":2754
 * 
 *         else:
 *             raise TypeError("Input should be a float or a 1D NumPy array of type float64.")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2754, __pyx_L1_error)
  }

  /* "class-sz/python/classy.pyx":2738
 * 
 * 
 *     def get_z_of_chi(self,chi):             # <<<<<<<<<<<<<<
 *          # Check if input is a scalar
 *         if isinstance(chi, (float, np.float64)):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.get_z_of_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2760
 * 
 *     # Define the vectorized method
 *     def get_comoving_volume(self, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the comoving volume at given redshifts.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_159get_comoving_volume(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_158get_comoving_volume, "\n        Vectorized computation of the comoving volume at given redshifts.\n\n        This method handles both scalar and array inputs for redshifts (z_input).\n        It returns the comoving volume for each redshift.\n\n        Parameters:\n        z_input (float or np.ndarray): A scalar or 1D array of redshifts.\n\n        Returns:\n        np.ndarray: An array of comoving volume values corresponding to the input redshifts.\n\n        Raises:\n        TypeError: If the inputs are not floats or 1D arrays of floats.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_159get_comoving_volume = {"get_comoving_volume", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_159get_comoving_volume, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_158get_comoving_volume};
static PyObject *__pyx_pw_9classy_sz_5Class_159get_comoving_volume(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_input = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_comoving_volume (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_input,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2760, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_comoving_volume") < 0)) __PYX_ERR(0, 2760, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z_input = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_comoving_volume", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2760, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_comoving_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_158get_comoving_volume(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_input);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_158get_comoving_volume(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_comoving_volume", 1);

  /* "class-sz/python/classy.pyx":2777
 *         """
 *         # Check if input is a scalar
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             return self.get_volume_dVdzdOmega_at_z(z_input)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_z_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_z_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":2778
 *         # Check if input is a scalar
 *         if isinstance(z_input, (float, np.float64)):
 *             return self.get_volume_dVdzdOmega_at_z(z_input)             # <<<<<<<<<<<<<<
 * 
 *         # Check if z_input is an array
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_volume_dVdzdOmega_at_z); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_z_input};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2777
 *         """
 *         # Check if input is a scalar
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             return self.get_volume_dVdzdOmega_at_z(z_input)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":2781
 * 
 *         # Check if z_input is an array
 *         elif isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64:             # <<<<<<<<<<<<<<
 *             n = z_input.shape[0]
 *             result = np.empty(n, dtype=np.float64)
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_z_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 2781, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L6_bool_binop_done:;
  if (likely(__pyx_t_3)) {

    /* "class-sz/python/classy.pyx":2782
 *         # Check if z_input is an array
 *         elif isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64:
 *             n = z_input.shape[0]             # <<<<<<<<<<<<<<
 *             result = np.empty(n, dtype=np.float64)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_shape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_n = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2783
 *         elif isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64:
 *             n = z_input.shape[0]
 *             result = np.empty(n, dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *             for i in range(n):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_n);
    __Pyx_GIVEREF(__pyx_v_n);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_n)) __PYX_ERR(0, 2783, __pyx_L1_error);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_8) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_result = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":2785
 *             result = np.empty(n, dtype=np.float64)
 * 
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 result[i] = self.get_volume_dVdzdOmega_at_z(z_input[i])
 * 
 */
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_n); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2785, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (likely(PyList_CheckExact(__pyx_t_8)) || PyTuple_CheckExact(__pyx_t_8)) {
      __pyx_t_2 = __pyx_t_8; __Pyx_INCREF(__pyx_t_2);
      __pyx_t_9 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2785, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2785, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_2))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2785, __pyx_L1_error)
            #endif
            if (__pyx_t_9 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_8 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 2785, __pyx_L1_error)
          #else
          __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2785, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2785, __pyx_L1_error)
            #endif
            if (__pyx_t_9 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 2785, __pyx_L1_error)
          #else
          __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2785, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          #endif
        }
      } else {
        __pyx_t_8 = __pyx_t_10(__pyx_t_2);
        if (unlikely(!__pyx_t_8)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 2785, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_8);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":2786
 * 
 *             for i in range(n):
 *                 result[i] = self.get_volume_dVdzdOmega_at_z(z_input[i])             # <<<<<<<<<<<<<<
 * 
 *             return result
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_volume_dVdzdOmega_at_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2786, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_z_input, __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2786, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_1};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2786, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      if (unlikely((PyObject_SetItem(__pyx_v_result, __pyx_v_i, __pyx_t_8) < 0))) __PYX_ERR(0, 2786, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":2785
 *             result = np.empty(n, dtype=np.float64)
 * 
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 result[i] = self.get_volume_dVdzdOmega_at_z(z_input[i])
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":2788
 *                 result[i] = self.get_volume_dVdzdOmega_at_z(z_input[i])
 * 
 *             return result             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":2781
 * 
 *         # Check if z_input is an array
 *         elif isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64:             # <<<<<<<<<<<<<<
 *             n = z_input.shape[0]
 *             result = np.empty(n, dtype=np.float64)
 */
  }

  /* "class-sz/python/classy.pyx":2791
 * 
 *         else:
 *             raise TypeError("Input should be a float or a 1D NumPy array of type float64.")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 2791, __pyx_L1_error)
  }

  /* "class-sz/python/classy.pyx":2760
 * 
 *     # Define the vectorized method
 *     def get_comoving_volume(self, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the comoving volume at given redshifts.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.get_comoving_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2794
 * 
 * 
 *     def get_IA_of_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_IA_of_z(z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_161get_IA_of_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_161get_IA_of_z = {"get_IA_of_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_161get_IA_of_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_161get_IA_of_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_IA_of_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2794, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_IA_of_z") < 0)) __PYX_ERR(0, 2794, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_IA_of_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2794, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_IA_of_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_160get_IA_of_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_160get_IA_of_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_IA_of_z", 1);

  /* "class-sz/python/classy.pyx":2795
 * 
 *     def get_IA_of_z(self,z):
 *         return get_IA_of_z(z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2795, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_IA_of_z(__pyx_t_1, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2794
 * 
 * 
 *     def get_IA_of_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_IA_of_z(z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_IA_of_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2798
 * 
 * 
 *     def get_f_of_sigma_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_163get_f_of_sigma_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_163get_f_of_sigma_at_m_and_z = {"get_f_of_sigma_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_163get_f_of_sigma_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_163get_f_of_sigma_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_f_of_sigma_at_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2798, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2798, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_f_of_sigma_at_m_and_z", 1, 2, 2, 1); __PYX_ERR(0, 2798, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_f_of_sigma_at_m_and_z") < 0)) __PYX_ERR(0, 2798, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_f_of_sigma_at_m_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2798, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_f_of_sigma_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_162get_f_of_sigma_at_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_162get_f_of_sigma_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_f_of_sigma_at_m_and_z", 1);

  /* "class-sz/python/classy.pyx":2799
 * 
 *     def get_f_of_sigma_at_m_and_z(self,m,z):
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_delta_mean_from_delta_crit_at_z(self,delta_crit,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2799, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2799, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_f_of_sigma_at_m_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2798
 * 
 * 
 *     def get_f_of_sigma_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_f_of_sigma_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2801
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_delta_mean_from_delta_crit_at_z(self,delta_crit,z):             # <<<<<<<<<<<<<<
 *         return get_delta_mean_from_delta_crit_at_z(delta_crit,z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_165get_delta_mean_from_delta_crit_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_165get_delta_mean_from_delta_crit_at_z = {"get_delta_mean_from_delta_crit_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_165get_delta_mean_from_delta_crit_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_165get_delta_mean_from_delta_crit_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_delta_crit = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_delta_mean_from_delta_crit_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delta_crit,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delta_crit)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2801, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2801, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_delta_mean_from_delta_crit_at_z", 1, 2, 2, 1); __PYX_ERR(0, 2801, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_delta_mean_from_delta_crit_at_z") < 0)) __PYX_ERR(0, 2801, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_delta_crit = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_delta_mean_from_delta_crit_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 2801, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_delta_mean_from_delta_crit_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_164get_delta_mean_from_delta_crit_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_delta_crit, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_164get_delta_mean_from_delta_crit_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_delta_crit, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_delta_mean_from_delta_crit_at_z", 1);

  /* "class-sz/python/classy.pyx":2802
 * 
 *     def get_delta_mean_from_delta_crit_at_z(self,delta_crit,z):
 *         return get_delta_mean_from_delta_crit_at_z(delta_crit,z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_delta_crit); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2802, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2802, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_delta_mean_from_delta_crit_at_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2801
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_delta_mean_from_delta_crit_at_z(self,delta_crit,z):             # <<<<<<<<<<<<<<
 *         return get_delta_mean_from_delta_crit_at_z(delta_crit,z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_delta_mean_from_delta_crit_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2805
 * 
 * 
 *     def get_galaxy_number_counts(self,z):             # <<<<<<<<<<<<<<
 *         return get_galaxy_number_counts(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_167get_galaxy_number_counts(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_167get_galaxy_number_counts = {"get_galaxy_number_counts", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_167get_galaxy_number_counts, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_167get_galaxy_number_counts(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_galaxy_number_counts (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2805, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_galaxy_number_counts") < 0)) __PYX_ERR(0, 2805, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_galaxy_number_counts", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2805, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_galaxy_number_counts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_166get_galaxy_number_counts(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_166get_galaxy_number_counts(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_galaxy_number_counts", 1);

  /* "class-sz/python/classy.pyx":2806
 * 
 *     def get_galaxy_number_counts(self,z):
 *         return get_galaxy_number_counts(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 2806, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_galaxy_number_counts(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2805
 * 
 * 
 *     def get_galaxy_number_counts(self,z):             # <<<<<<<<<<<<<<
 *         return get_galaxy_number_counts(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_galaxy_number_counts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2809
 * 
 * 
 *     def get_cov_N_N(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the covariance of cluster number counts
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_169get_cov_N_N(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_168get_cov_N_N, "\n        (class_sz) Return the covariance of cluster number counts\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_169get_cov_N_N = {"get_cov_N_N", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_169get_cov_N_N, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_168get_cov_N_N};
static PyObject *__pyx_pw_9classy_sz_5Class_169get_cov_N_N(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_cov_N_N (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_cov_N_N", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_cov_N_N", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_168get_cov_N_N(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_168get_cov_N_N(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index_M_bins;
  int __pyx_v_index_M_bins_prime;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  unsigned int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_cov_N_N", 1);

  /* "class-sz/python/classy.pyx":2813
 *         (class_sz) Return the covariance of cluster number counts
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['poisson'] = []
 *         cl['hsv'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2814
 *         """
 *         cl = {}
 *         cl['poisson'] = []             # <<<<<<<<<<<<<<
 *         cl['hsv'] = []
 *         cl['r'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_poisson, __pyx_t_1) < 0))) __PYX_ERR(0, 2814, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2815
 *         cl = {}
 *         cl['poisson'] = []
 *         cl['hsv'] = []             # <<<<<<<<<<<<<<
 *         cl['r'] = []
 *         cl['mass_bin_edges'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hsv, __pyx_t_1) < 0))) __PYX_ERR(0, 2815, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2816
 *         cl['poisson'] = []
 *         cl['hsv'] = []
 *         cl['r'] = []             # <<<<<<<<<<<<<<
 *         cl['mass_bin_edges'] = []
 *         for index_M_bins in range(self.tsz.nbins_M):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_r, __pyx_t_1) < 0))) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2817
 *         cl['hsv'] = []
 *         cl['r'] = []
 *         cl['mass_bin_edges'] = []             # <<<<<<<<<<<<<<
 *         for index_M_bins in range(self.tsz.nbins_M):
 *             cl['poisson'].append(self.tsz.cov_N_N[index_M_bins])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2817, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_mass_bin_edges, __pyx_t_1) < 0))) __PYX_ERR(0, 2817, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2818
 *         cl['r'] = []
 *         cl['mass_bin_edges'] = []
 *         for index_M_bins in range(self.tsz.nbins_M):             # <<<<<<<<<<<<<<
 *             cl['poisson'].append(self.tsz.cov_N_N[index_M_bins])
 *             cl['hsv'].append([])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nbins_M;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index_M_bins = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2819
 *         cl['mass_bin_edges'] = []
 *         for index_M_bins in range(self.tsz.nbins_M):
 *             cl['poisson'].append(self.tsz.cov_N_N[index_M_bins])             # <<<<<<<<<<<<<<
 *             cl['hsv'].append([])
 *             cl['r'].append([])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_poisson); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cov_N_N[__pyx_v_index_M_bins])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2819, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2820
 *         for index_M_bins in range(self.tsz.nbins_M):
 *             cl['poisson'].append(self.tsz.cov_N_N[index_M_bins])
 *             cl['hsv'].append([])             # <<<<<<<<<<<<<<
 *             cl['r'].append([])
 *             cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[index_M_bins])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hsv); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2820, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2821
 *             cl['poisson'].append(self.tsz.cov_N_N[index_M_bins])
 *             cl['hsv'].append([])
 *             cl['r'].append([])             # <<<<<<<<<<<<<<
 *             cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[index_M_bins])
 *             for index_M_bins_prime in range(self.tsz.nbins_M):
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_r); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2821, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2822
 *             cl['hsv'].append([])
 *             cl['r'].append([])
 *             cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[index_M_bins])             # <<<<<<<<<<<<<<
 *             for index_M_bins_prime in range(self.tsz.nbins_M):
 *                 cl['hsv'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_mass_bin_edges); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cov_Y_N_mass_bin_edges[__pyx_v_index_M_bins])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2822, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2822, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2823
 *             cl['r'].append([])
 *             cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[index_M_bins])
 *             for index_M_bins_prime in range(self.tsz.nbins_M):             # <<<<<<<<<<<<<<
 *                 cl['hsv'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime])
 *                 cl['r'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime]/np.sqrt(self.tsz.cov_N_N[index_M_bins]+self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins])/np.sqrt(self.tsz.cov_N_N[index_M_bins_prime]+self.tsz.cov_N_N_hsv[index_M_bins_prime][index_M_bins_prime]))
 */
    __pyx_t_7 = __pyx_v_self->tsz.nbins_M;
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_index_M_bins_prime = __pyx_t_9;

      /* "class-sz/python/classy.pyx":2824
 *             cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[index_M_bins])
 *             for index_M_bins_prime in range(self.tsz.nbins_M):
 *                 cl['hsv'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime])             # <<<<<<<<<<<<<<
 *                 cl['r'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime]/np.sqrt(self.tsz.cov_N_N[index_M_bins]+self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins])/np.sqrt(self.tsz.cov_N_N[index_M_bins_prime]+self.tsz.cov_N_N_hsv[index_M_bins_prime][index_M_bins_prime]))
 *         cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[self.tsz.nbins_M])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hsv); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_index_M_bins, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cov_N_N_hsv[__pyx_v_index_M_bins])[__pyx_v_index_M_bins_prime])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2824, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":2825
 *             for index_M_bins_prime in range(self.tsz.nbins_M):
 *                 cl['hsv'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime])
 *                 cl['r'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime]/np.sqrt(self.tsz.cov_N_N[index_M_bins]+self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins])/np.sqrt(self.tsz.cov_N_N[index_M_bins_prime]+self.tsz.cov_N_N_hsv[index_M_bins_prime][index_M_bins_prime]))             # <<<<<<<<<<<<<<
 *         cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[self.tsz.nbins_M])
 * 
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_r); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_index_M_bins, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cov_N_N_hsv[__pyx_v_index_M_bins])[__pyx_v_index_M_bins_prime])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_sqrt); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = PyFloat_FromDouble(((__pyx_v_self->tsz.cov_N_N[__pyx_v_index_M_bins]) + ((__pyx_v_self->tsz.cov_N_N_hsv[__pyx_v_index_M_bins])[__pyx_v_index_M_bins]))); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_13 = NULL;
      __pyx_t_14 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
          __pyx_t_14 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_11};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __pyx_t_12 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_sqrt); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cov_N_N[__pyx_v_index_M_bins_prime]) + ((__pyx_v_self->tsz.cov_N_N_hsv[__pyx_v_index_M_bins_prime])[__pyx_v_index_M_bins_prime]))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_13 = NULL;
      __pyx_t_14 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
          __pyx_t_14 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_1};
        __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __pyx_t_11 = __Pyx_PyNumber_Divide(__pyx_t_12, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_11); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2825, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
  }

  /* "class-sz/python/classy.pyx":2826
 *                 cl['hsv'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime])
 *                 cl['r'][index_M_bins].append(self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins_prime]/np.sqrt(self.tsz.cov_N_N[index_M_bins]+self.tsz.cov_N_N_hsv[index_M_bins][index_M_bins])/np.sqrt(self.tsz.cov_N_N[index_M_bins_prime]+self.tsz.cov_N_N_hsv[index_M_bins_prime][index_M_bins_prime]))
 *         cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[self.tsz.nbins_M])             # <<<<<<<<<<<<<<
 * 
 *         cl['poisson'] = np.array(cl['poisson'])
 */
  __pyx_t_11 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_mass_bin_edges); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cov_Y_N_mass_bin_edges[__pyx_v_self->tsz.nbins_M])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_11, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":2828
 *         cl['mass_bin_edges'].append(self.tsz.cov_Y_N_mass_bin_edges[self.tsz.nbins_M])
 * 
 *         cl['poisson'] = np.array(cl['poisson'])             # <<<<<<<<<<<<<<
 *         cl['hsv'] = np.array(cl['hsv'])
 *         cl['r'] = np.array(cl['r'])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_array); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_poisson); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_11};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_poisson, __pyx_t_5) < 0))) __PYX_ERR(0, 2828, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":2829
 * 
 *         cl['poisson'] = np.array(cl['poisson'])
 *         cl['hsv'] = np.array(cl['hsv'])             # <<<<<<<<<<<<<<
 *         cl['r'] = np.array(cl['r'])
 *         cl['mass_bin_edges'] = np.array(cl['mass_bin_edges'])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_np); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_array); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hsv); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_12 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_10};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hsv, __pyx_t_5) < 0))) __PYX_ERR(0, 2829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":2830
 *         cl['poisson'] = np.array(cl['poisson'])
 *         cl['hsv'] = np.array(cl['hsv'])
 *         cl['r'] = np.array(cl['r'])             # <<<<<<<<<<<<<<
 *         cl['mass_bin_edges'] = np.array(cl['mass_bin_edges'])
 *         return cl
 */
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_array); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_r); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_11};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_10, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_r, __pyx_t_5) < 0))) __PYX_ERR(0, 2830, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":2831
 *         cl['hsv'] = np.array(cl['hsv'])
 *         cl['r'] = np.array(cl['r'])
 *         cl['mass_bin_edges'] = np.array(cl['mass_bin_edges'])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_np); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_array); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_mass_bin_edges); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_12 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_10};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2831, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_mass_bin_edges, __pyx_t_5) < 0))) __PYX_ERR(0, 2831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":2832
 *         cl['r'] = np.array(cl['r'])
 *         cl['mass_bin_edges'] = np.array(cl['mass_bin_edges'])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_kg_kg(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2809
 * 
 * 
 *     def get_cov_N_N(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the covariance of cluster number counts
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("classy_sz.Class.get_cov_N_N", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2834
 *         return cl
 * 
 *     def cl_kg_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x galaxy-lensing power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_171cl_kg_kg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_170cl_kg_kg, "\n        (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x galaxy-lensing power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_171cl_kg_kg = {"cl_kg_kg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_171cl_kg_kg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_170cl_kg_kg};
static PyObject *__pyx_pw_9classy_sz_5Class_171cl_kg_kg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kg_kg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kg_kg", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kg_kg", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_170cl_kg_kg(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_170cl_kg_kg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kg_kg", 1);

  /* "class-sz/python/classy.pyx":2838
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x galaxy-lensing power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2839
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2839, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2840
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2841
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_gallens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2841, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2842
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gallens_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_gallens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2843
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_gallens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gallens_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gallens_gallens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2843, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2844
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_gallens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2844, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gallens_gallens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2844, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2844, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2845
 *             cl['1h'].append(self.tsz.cl_gallens_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2845, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":2846
 *             cl['2h'].append(self.tsz.cl_gallens_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_kg_k(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2834
 *         return cl
 * 
 *     def cl_kg_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x galaxy-lensing power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kg_kg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2848
 *         return cl
 * 
 *     def cl_kg_k(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x cmb-lensing power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_173cl_kg_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_172cl_kg_k, "\n        (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x cmb-lensing power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_173cl_kg_k = {"cl_kg_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_173cl_kg_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_172cl_kg_k};
static PyObject *__pyx_pw_9classy_sz_5Class_173cl_kg_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kg_k (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kg_k", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kg_k", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_172cl_kg_k(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_172cl_kg_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kg_k", 1);

  /* "class-sz/python/classy.pyx":2852
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x cmb-lensing power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2853
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2853, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2853, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2854
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2854, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2855
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_lens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2855, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2855, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2856
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gallens_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_lens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2857
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_lens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gallens_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gallens_lens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2857, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2858
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_lens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gallens_lens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2859
 *             cl['1h'].append(self.tsz.cl_gallens_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2859, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2859, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":2860
 *             cl['2h'].append(self.tsz.cl_gallens_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_yg(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2848
 *         return cl
 * 
 *     def cl_kg_k(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x cmb-lensing power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kg_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2862
 *         return cl
 * 
 *     def cl_yg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x g power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_175cl_yg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_174cl_yg, "\n        (class_sz) Return the 1-halo and 2-halo terms of y x g power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_175cl_yg = {"cl_yg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_175cl_yg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_174cl_yg};
static PyObject *__pyx_pw_9classy_sz_5Class_175cl_yg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_yg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_yg", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_yg", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_174cl_yg(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_174cl_yg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_yg", 1);

  /* "class-sz/python/classy.pyx":2866
 *         (class_sz) Return the 1-halo and 2-halo terms of y x g power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2867
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2867, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2868
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2869
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_gal_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2870
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_tSZ_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_gal_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2871
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_gal_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_tSZ_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_gal_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2871, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2872
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_gal_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2872, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_gal_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2872, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2872, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2873
 *             cl['1h'].append(self.tsz.cl_tSZ_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2873, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":2874
 *             cl['2h'].append(self.tsz.cl_tSZ_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_IA_g(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2862
 *         return cl
 * 
 *     def cl_yg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x g power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_yg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2876
 *         return cl
 * 
 *     def cl_IA_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of IA x g power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_177cl_IA_g(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_176cl_IA_g, "\n        (class_sz) Return the 1-halo and 2-halo terms of IA x g power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_177cl_IA_g = {"cl_IA_g", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_177cl_IA_g, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_176cl_IA_g};
static PyObject *__pyx_pw_9classy_sz_5Class_177cl_IA_g(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_IA_g (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_IA_g", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_IA_g", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_176cl_IA_g(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_176cl_IA_g(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_IA_g", 1);

  /* "class-sz/python/classy.pyx":2880
 *         (class_sz) Return the 1-halo and 2-halo terms of IA x g power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2881
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2881, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2882
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2882, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2883
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(0.)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2883, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2884
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(0.)
 *             cl['2h'].append(self.tsz.cl_IA_gal_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2885
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(0.)             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_IA_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_float_0_); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2885, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2886
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(0.)
 *             cl['2h'].append(self.tsz.cl_IA_gal_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_IA_gal_2h[__pyx_v_index])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_6); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2886, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":2887
 *             cl['1h'].append(0.)
 *             cl['2h'].append(self.tsz.cl_IA_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_Append(__pyx_t_6, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 2887, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":2888
 *             cl['2h'].append(self.tsz.cl_IA_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_kg_m(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2876
 *         return cl
 * 
 *     def cl_IA_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of IA x g power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.cl_IA_g", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2890
 *         return cl
 * 
 *     def cl_kg_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy lensing x lensing magnifications spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_179cl_kg_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_178cl_kg_m, "\n        (class_sz) Return the 1-halo and 2-halo terms of galaxy lensing x lensing magnifications spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_179cl_kg_m = {"cl_kg_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_179cl_kg_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_178cl_kg_m};
static PyObject *__pyx_pw_9classy_sz_5Class_179cl_kg_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kg_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kg_m", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kg_m", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_178cl_kg_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_178cl_kg_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kg_m", 1);

  /* "class-sz/python/classy.pyx":2894
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy lensing x lensing magnifications spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2895
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2895, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2896
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2897
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_lensmag_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2897, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2898
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gallens_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_lensmag_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2899
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_lensmag_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gallens_lensmag_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gallens_lensmag_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2899, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2900
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gallens_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_lensmag_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gallens_lensmag_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2900, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2901
 *             cl['1h'].append(self.tsz.cl_gallens_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_gallens_lensmag_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2901, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2901, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2901, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":2902
 *             cl['2h'].append(self.tsz.cl_gallens_lensmag_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_ykg(self,
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2890
 *         return cl
 * 
 *     def cl_kg_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy lensing x lensing magnifications spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kg_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2904
 *         return cl
 * 
 *     def cl_ykg(self,             # <<<<<<<<<<<<<<
 *                Nmcfit = 1024,
 *                log10xmin_mcfit = -6,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_181cl_ykg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_180cl_ykg, "\n        (class_sz) Return the 1-halo and 2-halo terms of y x kg power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_181cl_ykg = {"cl_ykg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_181cl_ykg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_180cl_ykg};
static PyObject *__pyx_pw_9classy_sz_5Class_181cl_ykg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_Nmcfit = 0;
  PyObject *__pyx_v_log10xmin_mcfit = 0;
  PyObject *__pyx_v_log10xmax_mcfit = 0;
  PyObject *__pyx_v_log10x_num = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_ykg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_Nmcfit,&__pyx_n_s_log10xmin_mcfit,&__pyx_n_s_log10xmax_mcfit,&__pyx_n_s_log10x_num,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_1024));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_6));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_6));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_600));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_Nmcfit);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2904, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_log10xmin_mcfit);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2904, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_log10xmax_mcfit);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2904, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_log10x_num);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2904, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "cl_ykg") < 0)) __PYX_ERR(0, 2904, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_Nmcfit = values[0];
    __pyx_v_log10xmin_mcfit = values[1];
    __pyx_v_log10xmax_mcfit = values[2];
    __pyx_v_log10x_num = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cl_ykg", 0, 0, 4, __pyx_nargs); __PYX_ERR(0, 2904, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.cl_ykg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_180cl_ykg(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_Nmcfit, __pyx_v_log10xmin_mcfit, __pyx_v_log10xmax_mcfit, __pyx_v_log10x_num);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_180cl_ykg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_Nmcfit, PyObject *__pyx_v_log10xmin_mcfit, PyObject *__pyx_v_log10xmax_mcfit, PyObject *__pyx_v_log10x_num) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_v_cl_g_gamma_ell = NULL;
  PyObject *__pyx_v_cl_g_gamma_1h = NULL;
  PyObject *__pyx_v_cl_g_gamma_2h = NULL;
  PyObject *__pyx_v_fac = NULL;
  PyObject *__pyx_v_cltot = NULL;
  PyObject *__pyx_v_cltotfunc = NULL;
  PyObject *__pyx_v_mcfitx = NULL;
  PyObject *__pyx_v_F = NULL;
  PyObject *__pyx_v_H = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_G = NULL;
  PyObject *__pyx_v_theta_mcfit = NULL;
  PyObject *__pyx_v_xi_mcfit = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  unsigned int __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_ykg", 1);

  /* "class-sz/python/classy.pyx":2912
 *         (class_sz) Return the 1-halo and 2-halo terms of y x kg power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2913
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2913, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2914
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2914, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2915
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_gallens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2916
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_tSZ_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_gallens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2917
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_gallens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_tSZ_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_gallens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2917, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2918
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_gallens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_gallens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2918, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2919
 *             cl['1h'].append(self.tsz.cl_tSZ_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         if self.tsz.do_real_space_with_mcfit:
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2919, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":2920
 *             cl['2h'].append(self.tsz.cl_tSZ_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:             # <<<<<<<<<<<<<<
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 */
  __pyx_t_7 = (__pyx_v_self->tsz.do_real_space_with_mcfit != 0);
  if (__pyx_t_7) {

    /* "class-sz/python/classy.pyx":2921
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:
 *             cl_g_gamma_ell = np.asarray(cl['ell'])             # <<<<<<<<<<<<<<
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2921, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2921, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2921, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2921, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_v_cl_g_gamma_ell = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2922
 *         if self.tsz.do_real_space_with_mcfit:
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])             # <<<<<<<<<<<<<<
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_asarray); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2922, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_cl_g_gamma_1h = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2923
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 *             cl_g_gamma_2h = np.asarray(cl['2h'])             # <<<<<<<<<<<<<<
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2923, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_v_cl_g_gamma_2h = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2924
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi             # <<<<<<<<<<<<<<
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',
 */
    __pyx_t_5 = __Pyx_PyFloat_AddObjC(__pyx_v_cl_g_gamma_ell, __pyx_float_1_, 1., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = PyNumber_Multiply(__pyx_v_cl_g_gamma_ell, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_8, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_pi); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyNumber_Divide(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_fac = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":2925
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac             # <<<<<<<<<<<<<<
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',
 *                                              axis=-1,
 */
    __pyx_t_8 = __Pyx_PyNumber_Divide(__pyx_v_cl_g_gamma_1h, __pyx_v_fac); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_v_cl_g_gamma_2h, __pyx_v_fac); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyNumber_Add(__pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_cltot = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2926
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',             # <<<<<<<<<<<<<<
 *                                              axis=-1,
 *                                              copy=True,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_interpolate); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_interp1d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_cl_g_gamma_ell);
    __Pyx_GIVEREF(__pyx_v_cl_g_gamma_ell);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_cl_g_gamma_ell)) __PYX_ERR(0, 2926, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_cltot);
    __Pyx_GIVEREF(__pyx_v_cltot);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_cltot)) __PYX_ERR(0, 2926, __pyx_L1_error);
    __pyx_t_8 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_kind, __pyx_n_u_cubic) < 0) __PYX_ERR(0, 2926, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_axis, __pyx_int_neg_1) < 0) __PYX_ERR(0, 2926, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2928
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',
 *                                              axis=-1,
 *                                              copy=True,             # <<<<<<<<<<<<<<
 *                                              bounds_error=False,
 *                                              fill_value=1e-100,
 */
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_copy, Py_True) < 0) __PYX_ERR(0, 2926, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2929
 *                                              axis=-1,
 *                                              copy=True,
 *                                              bounds_error=False,             # <<<<<<<<<<<<<<
 *                                              fill_value=1e-100,
 *                                              assume_sorted=False)
 */
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_bounds_error, Py_False) < 0) __PYX_ERR(0, 2926, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_fill_value, __pyx_float_1eneg_100) < 0) __PYX_ERR(0, 2926, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2931
 *                                              bounds_error=False,
 *                                              fill_value=1e-100,
 *                                              assume_sorted=False)             # <<<<<<<<<<<<<<
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)
 *             F = cltotfunc(mcfitx)
 */
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_assume_sorted, Py_False) < 0) __PYX_ERR(0, 2926, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2926
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',             # <<<<<<<<<<<<<<
 *                                              axis=-1,
 *                                              copy=True,
 */
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_cltotfunc = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "class-sz/python/classy.pyx":2932
 *                                              fill_value=1e-100,
 *                                              assume_sorted=False)
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)             # <<<<<<<<<<<<<<
 *             F = cltotfunc(mcfitx)
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True) # nu = 0 for gg, (and yg)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_logspace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v_log10xmin_mcfit);
    __Pyx_GIVEREF(__pyx_v_log10xmin_mcfit);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_log10xmin_mcfit)) __PYX_ERR(0, 2932, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_log10xmax_mcfit);
    __Pyx_GIVEREF(__pyx_v_log10xmax_mcfit);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_log10xmax_mcfit)) __PYX_ERR(0, 2932, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_num, __pyx_v_log10x_num) < 0) __PYX_ERR(0, 2932, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_endpoint, Py_False) < 0) __PYX_ERR(0, 2932, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_mcfitx = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2933
 *                                              assume_sorted=False)
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)
 *             F = cltotfunc(mcfitx)             # <<<<<<<<<<<<<<
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True) # nu = 0 for gg, (and yg)
 *             y, G = H(F, extrap=True)
 */
    __Pyx_INCREF(__pyx_v_cltotfunc);
    __pyx_t_5 = __pyx_v_cltotfunc; __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_mcfitx};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2933, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_F = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2934
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)
 *             F = cltotfunc(mcfitx)
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True) # nu = 0 for gg, (and yg)             # <<<<<<<<<<<<<<
 *             y, G = H(F, extrap=True)
 *             theta_mcfit = y*(60.*180.)/np.pi
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_mcfit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_transforms); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Hankel); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_mcfitx);
    __Pyx_GIVEREF(__pyx_v_mcfitx);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_mcfitx)) __PYX_ERR(0, 2934, __pyx_L1_error);
    __pyx_t_9 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_nu, __pyx_int_2) < 0) __PYX_ERR(0, 2934, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_q, __pyx_int_1) < 0) __PYX_ERR(0, 2934, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_N, __pyx_v_Nmcfit) < 0) __PYX_ERR(0, 2934, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_lowring, Py_True) < 0) __PYX_ERR(0, 2934, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_H = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":2935
 *             F = cltotfunc(mcfitx)
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True) # nu = 0 for gg, (and yg)
 *             y, G = H(F, extrap=True)             # <<<<<<<<<<<<<<
 *             theta_mcfit = y*(60.*180.)/np.pi
 *             xi_mcfit = G/2./np.pi
 */
    __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_v_F);
    __Pyx_GIVEREF(__pyx_v_F);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_F)) __PYX_ERR(0, 2935, __pyx_L1_error);
    __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_extrap, Py_True) < 0) __PYX_ERR(0, 2935, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_H, __pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
      PyObject* sequence = __pyx_t_5;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 2935, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      #else
      __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
      index = 0; __pyx_t_9 = __pyx_t_11(__pyx_t_1); if (unlikely(!__pyx_t_9)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_9);
      index = 1; __pyx_t_8 = __pyx_t_11(__pyx_t_1); if (unlikely(!__pyx_t_8)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_1), 2) < 0) __PYX_ERR(0, 2935, __pyx_L1_error)
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 2935, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __pyx_v_y = __pyx_t_9;
    __pyx_t_9 = 0;
    __pyx_v_G = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":2936
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True) # nu = 0 for gg, (and yg)
 *             y, G = H(F, extrap=True)
 *             theta_mcfit = y*(60.*180.)/np.pi             # <<<<<<<<<<<<<<
 *             xi_mcfit = G/2./np.pi
 *             cl['theta'] = theta_mcfit
 */
    __pyx_t_5 = PyFloat_FromDouble((60. * 180.)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = PyNumber_Multiply(__pyx_v_y, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_pi); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_theta_mcfit = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2937
 *             y, G = H(F, extrap=True)
 *             theta_mcfit = y*(60.*180.)/np.pi
 *             xi_mcfit = G/2./np.pi             # <<<<<<<<<<<<<<
 *             cl['theta'] = theta_mcfit
 *             cl['xi'] = xi_mcfit
 */
    __pyx_t_5 = __Pyx_PyFloat_TrueDivideObjC(__pyx_v_G, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_pi); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyNumber_Divide(__pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_xi_mcfit = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "class-sz/python/classy.pyx":2938
 *             theta_mcfit = y*(60.*180.)/np.pi
 *             xi_mcfit = G/2./np.pi
 *             cl['theta'] = theta_mcfit             # <<<<<<<<<<<<<<
 *             cl['xi'] = xi_mcfit
 *         return cl
 */
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_theta, __pyx_v_theta_mcfit) < 0))) __PYX_ERR(0, 2938, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2939
 *             xi_mcfit = G/2./np.pi
 *             cl['theta'] = theta_mcfit
 *             cl['xi'] = xi_mcfit             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_xi, __pyx_v_xi_mcfit) < 0))) __PYX_ERR(0, 2939, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":2920
 *             cl['2h'].append(self.tsz.cl_tSZ_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:             # <<<<<<<<<<<<<<
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 */
  }

  /* "class-sz/python/classy.pyx":2940
 *             cl['theta'] = theta_mcfit
 *             cl['xi'] = xi_mcfit
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2904
 *         return cl
 * 
 *     def cl_ykg(self,             # <<<<<<<<<<<<<<
 *                Nmcfit = 1024,
 *                log10xmin_mcfit = -6,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("classy_sz.Class.cl_ykg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XDECREF(__pyx_v_cl_g_gamma_ell);
  __Pyx_XDECREF(__pyx_v_cl_g_gamma_1h);
  __Pyx_XDECREF(__pyx_v_cl_g_gamma_2h);
  __Pyx_XDECREF(__pyx_v_fac);
  __Pyx_XDECREF(__pyx_v_cltot);
  __Pyx_XDECREF(__pyx_v_cltotfunc);
  __Pyx_XDECREF(__pyx_v_mcfitx);
  __Pyx_XDECREF(__pyx_v_F);
  __Pyx_XDECREF(__pyx_v_H);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_G);
  __Pyx_XDECREF(__pyx_v_theta_mcfit);
  __Pyx_XDECREF(__pyx_v_xi_mcfit);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2943
 * 
 * 
 *     def cl_kSZ_kSZ_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x g power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_183cl_kSZ_kSZ_g(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_182cl_kSZ_kSZ_g, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x g power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_183cl_kSZ_kSZ_g = {"cl_kSZ_kSZ_g", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_183cl_kSZ_kSZ_g, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_182cl_kSZ_kSZ_g};
static PyObject *__pyx_pw_9classy_sz_5Class_183cl_kSZ_kSZ_g(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kSZ_kSZ_g (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kSZ_kSZ_g", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kSZ_kSZ_g", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_182cl_kSZ_kSZ_g(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_182cl_kSZ_kSZ_g(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kSZ_kSZ_g", 1);

  /* "class-sz/python/classy.pyx":2947
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x g power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2948
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2948, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2949
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2949, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2950
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         cl['1h (slow)'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2950, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2951
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         cl['1h (slow)'] = []
 *         cl['2h (slow)'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 2951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2952
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         cl['1h (slow)'] = []             # <<<<<<<<<<<<<<
 *         cl['2h (slow)'] = []
 *         cl['3h (slow)'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h_slow, __pyx_t_1) < 0))) __PYX_ERR(0, 2952, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2953
 *         cl['3h'] = []
 *         cl['1h (slow)'] = []
 *         cl['2h (slow)'] = []             # <<<<<<<<<<<<<<
 *         cl['3h (slow)'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h_slow, __pyx_t_1) < 0))) __PYX_ERR(0, 2953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2954
 *         cl['1h (slow)'] = []
 *         cl['2h (slow)'] = []
 *         cl['3h (slow)'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         cl['covmat'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h_slow, __pyx_t_1) < 0))) __PYX_ERR(0, 2954, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2955
 *         cl['2h (slow)'] = []
 *         cl['3h (slow)'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         cl['covmat'] = []
 *         cl['lensing term'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 2955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2956
 *         cl['3h (slow)'] = []
 *         cl['hf'] = []
 *         cl['covmat'] = []             # <<<<<<<<<<<<<<
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_covmat, __pyx_t_1) < 0))) __PYX_ERR(0, 2956, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2957
 *         cl['hf'] = []
 *         cl['covmat'] = []
 *         cl['lensing term'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_lensing_term, __pyx_t_1) < 0))) __PYX_ERR(0, 2957, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2958
 *         cl['covmat'] = []
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_1h[index])
 *             cl['2h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2959
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_2h[index])
 *             cl['3h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_3h[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h_slow); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2959, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2960
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_1h[index])
 *             cl['2h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_2h[index])             # <<<<<<<<<<<<<<
 *             cl['3h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_3h[index])
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gal_hf[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h_slow); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2960, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2961
 *             cl['1h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_1h[index])
 *             cl['2h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_2h[index])
 *             cl['3h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_3h[index])             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gal_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gal_1h_fft[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h_slow); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_3h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2961, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2962
 *             cl['2h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_2h[index])
 *             cl['3h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_3h[index])
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gal_hf[index])             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gal_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gal_2h_fft[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_hf[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2962, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2963
 *             cl['3h (slow)'].append(self.tsz.cl_kSZ_kSZ_gal_3h[index])
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gal_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gal_1h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gal_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gal_3h_fft[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_1h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2963, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2963, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2964
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gal_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gal_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gal_2h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gal_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gal_lensing_term[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_2h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2964, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2965
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gal_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gal_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gal_3h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gal_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gal[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_3h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2965, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2966
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gal_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gal_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gal_lensing_term[index])             # <<<<<<<<<<<<<<
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gal[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_lensing_term); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gal_lensing_term[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2966, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2966, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2967
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gal_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gal_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gal[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_covmat); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cov_ll_kSZ_kSZ_gal[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2967, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2968
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gal_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gal[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2968, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":2969
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gal[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_kSZ_kSZ_kg(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2943
 * 
 * 
 *     def cl_kSZ_kSZ_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x g power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kSZ_kSZ_g", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2971
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kg power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_185cl_kSZ_kSZ_kg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_184cl_kSZ_kSZ_kg, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kg power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_185cl_kSZ_kSZ_kg = {"cl_kSZ_kSZ_kg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_185cl_kSZ_kSZ_kg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_184cl_kSZ_kSZ_kg};
static PyObject *__pyx_pw_9classy_sz_5Class_185cl_kSZ_kSZ_kg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kSZ_kSZ_kg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kSZ_kSZ_kg", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kSZ_kSZ_kg", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_184cl_kSZ_kSZ_kg(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_184cl_kSZ_kSZ_kg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kSZ_kSZ_kg", 1);

  /* "class-sz/python/classy.pyx":2975
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kg power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2976
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2977
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2977, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2978
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 2978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2979
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         cl['covmat'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 2979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2980
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         cl['covmat'] = []
 *         cl['lensing term'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 2980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2981
 *         cl['3h'] = []
 *         cl['hf'] = []
 *         cl['covmat'] = []             # <<<<<<<<<<<<<<
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_covmat, __pyx_t_1) < 0))) __PYX_ERR(0, 2981, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2982
 *         cl['hf'] = []
 *         cl['covmat'] = []
 *         cl['lensing term'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gallens_hf[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_lensing_term, __pyx_t_1) < 0))) __PYX_ERR(0, 2982, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2983
 *         cl['covmat'] = []
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gallens_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gallens_1h_fft[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":2984
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gallens_hf[index])             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gallens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gallens_2h_fft[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gallens_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2984, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2985
 *         for index in range(self.tsz.nlSZ):
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gallens_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gallens_1h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gallens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gallens_3h_fft[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gallens_1h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2985, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2986
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_gallens_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gallens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gallens_2h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gallens_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gallens_lensing_term[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gallens_2h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2986, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2987
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_gallens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gallens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gallens_3h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gallens_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gallens[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gallens_3h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2987, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2988
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_gallens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gallens_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gallens_lensing_term[index])             # <<<<<<<<<<<<<<
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gallens[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_lensing_term); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_gallens_lensing_term[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2988, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":2989
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_gallens_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gallens_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gallens[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_covmat); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cov_ll_kSZ_kSZ_gallens[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2989, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":2990
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_gallens_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gallens[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 2990, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":2991
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_gallens[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_kSZ_kSZ_kcmb(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2971
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kg power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kSZ_kSZ_kg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":2993
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kcmb power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_187cl_kSZ_kSZ_kcmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_186cl_kSZ_kSZ_kcmb, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kcmb power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_187cl_kSZ_kSZ_kcmb = {"cl_kSZ_kSZ_kcmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_187cl_kSZ_kSZ_kcmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_186cl_kSZ_kSZ_kcmb};
static PyObject *__pyx_pw_9classy_sz_5Class_187cl_kSZ_kSZ_kcmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kSZ_kSZ_kcmb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kSZ_kSZ_kcmb", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kSZ_kSZ_kcmb", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_186cl_kSZ_kSZ_kcmb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_186cl_kSZ_kSZ_kcmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kSZ_kSZ_kcmb", 1);

  /* "class-sz/python/classy.pyx":2997
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kcmb power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2998
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 2998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":2999
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 2999, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3000
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3001
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         cl['covmat'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 3001, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3002
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         cl['covmat'] = []
 *         cl['lensing term'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3002, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3003
 *         cl['3h'] = []
 *         cl['hf'] = []
 *         cl['covmat'] = []             # <<<<<<<<<<<<<<
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_covmat, __pyx_t_1) < 0))) __PYX_ERR(0, 3003, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3004
 *         cl['hf'] = []
 *         cl['covmat'] = []
 *         cl['lensing term'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_lens_hf[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_lensing_term, __pyx_t_1) < 0))) __PYX_ERR(0, 3004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3005
 *         cl['covmat'] = []
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_lens_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_lens_1h_fft[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3006
 *         cl['lensing term'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_lens_hf[index])             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_lens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_lens_2h_fft[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_lens_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3006, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3006, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3007
 *         for index in range(self.tsz.nlSZ):
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_lens_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_lens_1h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_lens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_lens_3h_fft[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_lens_1h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3007, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3008
 *             cl['hf'].append(self.tsz.cl_kSZ_kSZ_lens_hf[index])
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_lens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_lens_2h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_lens_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_lens_lensing_term[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_lens_2h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3008, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3009
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_lens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_lens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_lens_3h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_lens_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_lens[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_lens_3h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3009, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3010
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_lens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_lens_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_lens_lensing_term[index])             # <<<<<<<<<<<<<<
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_lens[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_lensing_term); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3010, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_lens_lensing_term[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3010, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3010, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3011
 *             cl['3h'].append(self.tsz.cl_kSZ_kSZ_lens_3h_fft[index])
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_lens_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_lens[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_covmat); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cov_ll_kSZ_kSZ_lens[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3012
 *             cl['lensing term'].append(self.tsz.cl_kSZ_kSZ_lens_lensing_term[index])
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_lens[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3012, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3013
 *             cl['covmat'].append(self.tsz.cov_ll_kSZ_kSZ_lens[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_gal_gal_kcmb(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":2993
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kcmb power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kSZ_kSZ_kcmb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3015
 *         return cl
 * 
 *     def cl_gal_gal_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of gal x gal x kcmb power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_189cl_gal_gal_kcmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_188cl_gal_gal_kcmb, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of gal x gal x kcmb power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_189cl_gal_gal_kcmb = {"cl_gal_gal_kcmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_189cl_gal_gal_kcmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_188cl_gal_gal_kcmb};
static PyObject *__pyx_pw_9classy_sz_5Class_189cl_gal_gal_kcmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_gal_gal_kcmb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_gal_gal_kcmb", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_gal_gal_kcmb", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_188cl_gal_gal_kcmb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_188cl_gal_gal_kcmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_gal_gal_kcmb", 1);

  /* "class-sz/python/classy.pyx":3019
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of gal x gal x kcmb power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3020
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3021
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3022
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3022, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3023
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gal_lens_1h_fft[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 3023, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3024
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gal_gal_lens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_gal_gal_lens_2h_fft[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3025
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gal_lens_1h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gal_gal_lens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_gal_gal_lens_3h_fft[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3025, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gal_lens_1h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3025, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3025, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3026
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gal_lens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_gal_gal_lens_2h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.cl_gal_gal_lens_3h_fft[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gal_lens_2h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3026, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3027
 *             cl['1h'].append(self.tsz.cl_gal_gal_lens_1h_fft[index])
 *             cl['2h'].append(self.tsz.cl_gal_gal_lens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_gal_gal_lens_3h_fft[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gal_lens_3h_fft[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3027, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3028
 *             cl['2h'].append(self.tsz.cl_gal_gal_lens_2h_fft[index])
 *             cl['3h'].append(self.tsz.cl_gal_gal_lens_3h_fft[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3028, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3028, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3028, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3029
 *             cl['3h'].append(self.tsz.cl_gal_gal_lens_3h_fft[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3015
 *         return cl
 * 
 *     def cl_gal_gal_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of gal x gal x kcmb power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_gal_gal_kcmb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3032
 * 
 * 
 *     def cl_te_y_y(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return Te x y x y power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_191cl_te_y_y(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_190cl_te_y_y, "\n        (class_sz) Return Te x y x y power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_191cl_te_y_y = {"cl_te_y_y", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_191cl_te_y_y, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_190cl_te_y_y};
static PyObject *__pyx_pw_9classy_sz_5Class_191cl_te_y_y(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_te_y_y (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_te_y_y", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_te_y_y", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_190cl_te_y_y(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_190cl_te_y_y(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_te_y_y", 1);

  /* "class-sz/python/classy.pyx":3036
 *         (class_sz) Return Te x y x y power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['teyy'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3037
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['teyy'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3037, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3038
 *         cl = {}
 *         cl['ell'] = []
 *         cl['teyy'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['teyy'].append(self.tsz.cl_te_y_y[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_teyy, __pyx_t_1) < 0))) __PYX_ERR(0, 3038, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3039
 *         cl['ell'] = []
 *         cl['teyy'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['teyy'].append(self.tsz.cl_te_y_y[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3040
 *         cl['teyy'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['teyy'].append(self.tsz.cl_te_y_y[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_teyy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_te_y_y[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3040, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3041
 *         for index in range(self.tsz.nlSZ):
 *             cl['teyy'].append(self.tsz.cl_te_y_y[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3041, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3041, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3041, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3042
 *             cl['teyy'].append(self.tsz.cl_te_y_y[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_ym(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3032
 * 
 * 
 *     def cl_te_y_y(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return Te x y x y power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_te_y_y", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3044
 *         return cl
 * 
 *     def cl_ym(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x mu (lensing magnification) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_193cl_ym(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_192cl_ym, "\n        (class_sz) Return the 1-halo and 2-halo terms of y x mu (lensing magnification) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_193cl_ym = {"cl_ym", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_193cl_ym, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_192cl_ym};
static PyObject *__pyx_pw_9classy_sz_5Class_193cl_ym(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_ym (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_ym", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_ym", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_192cl_ym(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_192cl_ym(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_ym", 1);

  /* "class-sz/python/classy.pyx":3048
 *         (class_sz) Return the 1-halo and 2-halo terms of y x mu (lensing magnification) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3049
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3049, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3050
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3050, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3051
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_lensmag_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3051, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3052
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_tSZ_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_lensmag_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3053
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_lensmag_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_tSZ_lensmag_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3053, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_lensmag_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3053, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3053, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3054
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_lensmag_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_lensmag_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3054, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3055
 *             cl['1h'].append(self.tsz.cl_tSZ_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_lensmag_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3055, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3056
 *             cl['2h'].append(self.tsz.cl_tSZ_lensmag_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3044
 *         return cl
 * 
 *     def cl_ym(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x mu (lensing magnification) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_ym", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3059
 * 
 * 
 *     def cl_y_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x k (cmb lensing) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_195cl_y_kcmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_194cl_y_kcmb, "\n        (class_sz) Return the 1-halo and 2-halo terms of y x k (cmb lensing) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_195cl_y_kcmb = {"cl_y_kcmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_195cl_y_kcmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_194cl_y_kcmb};
static PyObject *__pyx_pw_9classy_sz_5Class_195cl_y_kcmb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_y_kcmb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_y_kcmb", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_y_kcmb", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_194cl_y_kcmb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_194cl_y_kcmb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_y_kcmb", 1);

  /* "class-sz/python/classy.pyx":3063
 *         (class_sz) Return the 1-halo and 2-halo terms of y x k (cmb lensing) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3064
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3064, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3065
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3065, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3066
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_lens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3066, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3067
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_tSZ_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_lens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3068
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_lens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_tSZ_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_lens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3068, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3069
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tSZ_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_lens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3069, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tSZ_lens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3069, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3069, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3070
 *             cl['1h'].append(self.tsz.cl_tSZ_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_tSZ_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3070, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3071
 *             cl['2h'].append(self.tsz.cl_tSZ_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_t2t2f(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3059
 * 
 * 
 *     def cl_y_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x k (cmb lensing) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_y_kcmb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3073
 *         return cl
 * 
 *     def cl_t2t2f(self):             # <<<<<<<<<<<<<<
 *         cl = {}
 *         cl['ell'] = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_197cl_t2t2f(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_197cl_t2t2f = {"cl_t2t2f", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_197cl_t2t2f, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_197cl_t2t2f(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_t2t2f (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_t2t2f", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_t2t2f", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_196cl_t2t2f(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_196cl_t2t2f(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_t2t2f", 1);

  /* "class-sz/python/classy.pyx":3074
 * 
 *     def cl_t2t2f(self):
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['t2t2f'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3075
 *     def cl_t2t2f(self):
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['t2t2f'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3075, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3076
 *         cl = {}
 *         cl['ell'] = []
 *         cl['t2t2f'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['ell'].append(self.tsz.ell[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_t2t2f, __pyx_t_1) < 0))) __PYX_ERR(0, 3076, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3077
 *         cl['ell'] = []
 *         cl['t2t2f'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *             cl['t2t2f'].append(self.tsz.cl_t2t2f[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3078
 *         cl['t2t2f'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl['t2t2f'].append(self.tsz.cl_t2t2f[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3078, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3078, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3078, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3079
 *         for index in range(self.tsz.nlSZ):
 *             cl['ell'].append(self.tsz.ell[index])
 *             cl['t2t2f'].append(self.tsz.cl_t2t2f[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_t2t2f); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3079, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_t2t2f[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3079, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3079, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3080
 *             cl['ell'].append(self.tsz.ell[index])
 *             cl['t2t2f'].append(self.tsz.cl_t2t2f[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3073
 *         return cl
 * 
 *     def cl_t2t2f(self):             # <<<<<<<<<<<<<<
 *         cl = {}
 *         cl['ell'] = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_t2t2f", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3084
 * 
 * 
 *     def cl_gg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gxg power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_199cl_gg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_198cl_gg, "\n        (class_sz) Return the 1-halo and 2-halo terms of gxg power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_199cl_gg = {"cl_gg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_199cl_gg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_198cl_gg};
static PyObject *__pyx_pw_9classy_sz_5Class_199cl_gg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_gg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_gg", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_gg", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_198cl_gg(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_198cl_gg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_gg", 1);

  /* "class-sz/python/classy.pyx":3088
 *         (class_sz) Return the 1-halo and 2-halo terms of gxg power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3088, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3089
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3089, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3090
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3090, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3091
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3092
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gal_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3092, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3093
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gal_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_gal_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3094
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gal_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gal_gal_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_gal_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gal_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3094, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3095
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_gal_2h[index])             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_gal_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gal_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3095, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3096
 *             cl['1h'].append(self.tsz.cl_gal_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_gal_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_gal_hf[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3096, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gal_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3096, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3096, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3097
 *             cl['2h'].append(self.tsz.cl_gal_gal_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3097, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3098
 *             cl['hf'].append(self.tsz.cl_gal_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3084
 * 
 * 
 *     def cl_gg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gxg power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_gg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3101
 * 
 * 
 *     def cl_ksz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kszxksz power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_201cl_ksz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_200cl_ksz, "\n        (class_sz) Return the 1-halo and 2-halo terms of kszxksz power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_201cl_ksz = {"cl_ksz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_201cl_ksz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_200cl_ksz};
static PyObject *__pyx_pw_9classy_sz_5Class_201cl_ksz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_ksz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_ksz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_ksz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_200cl_ksz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_200cl_ksz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_ksz", 1);

  /* "class-sz/python/classy.pyx":3105
 *         (class_sz) Return the 1-halo and 2-halo terms of kszxksz power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3106
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3107
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3108
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3109
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_1h[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3110
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3110, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3111
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_1h[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_kSZ_kSZ_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3112
 *             cl['1h'].append(self.tsz.cl_kSZ_kSZ_1h[index])
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3112, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3113
 *             cl['2h'].append(self.tsz.cl_kSZ_kSZ_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3101
 * 
 * 
 *     def cl_ksz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kszxksz power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_ksz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3116
 * 
 * 
 *     def cl_ggamma(self,             # <<<<<<<<<<<<<<
 *                   Nmcfit = 1024,
 *                   log10xmin_mcfit = -6,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_203cl_ggamma(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_202cl_ggamma, "\n        (class_sz) Return the 1-halo and 2-halo terms of galaxy x galaxy lensing power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_203cl_ggamma = {"cl_ggamma", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_203cl_ggamma, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_202cl_ggamma};
static PyObject *__pyx_pw_9classy_sz_5Class_203cl_ggamma(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_Nmcfit = 0;
  PyObject *__pyx_v_log10xmin_mcfit = 0;
  PyObject *__pyx_v_log10xmax_mcfit = 0;
  PyObject *__pyx_v_log10x_num = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_ggamma (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_Nmcfit,&__pyx_n_s_log10xmin_mcfit,&__pyx_n_s_log10xmax_mcfit,&__pyx_n_s_log10x_num,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_1024));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_6));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_6));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_600));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_Nmcfit);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3116, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_log10xmin_mcfit);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3116, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_log10xmax_mcfit);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3116, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_log10x_num);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3116, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "cl_ggamma") < 0)) __PYX_ERR(0, 3116, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_Nmcfit = values[0];
    __pyx_v_log10xmin_mcfit = values[1];
    __pyx_v_log10xmax_mcfit = values[2];
    __pyx_v_log10x_num = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cl_ggamma", 0, 0, 4, __pyx_nargs); __PYX_ERR(0, 3116, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.cl_ggamma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_202cl_ggamma(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_Nmcfit, __pyx_v_log10xmin_mcfit, __pyx_v_log10xmax_mcfit, __pyx_v_log10x_num);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_202cl_ggamma(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_Nmcfit, PyObject *__pyx_v_log10xmin_mcfit, PyObject *__pyx_v_log10xmax_mcfit, PyObject *__pyx_v_log10x_num) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_v_cl_g_gamma_ell = NULL;
  PyObject *__pyx_v_cl_g_gamma_1h = NULL;
  PyObject *__pyx_v_cl_g_gamma_2h = NULL;
  PyObject *__pyx_v_fac = NULL;
  PyObject *__pyx_v_cltot = NULL;
  PyObject *__pyx_v_cltotfunc = NULL;
  PyObject *__pyx_v_mcfitx = NULL;
  PyObject *__pyx_v_F = NULL;
  PyObject *__pyx_v_H = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_G = NULL;
  PyObject *__pyx_v_theta_mcfit = NULL;
  PyObject *__pyx_v_xi_mcfit = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  unsigned int __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_ggamma", 1);

  /* "class-sz/python/classy.pyx":3124
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x galaxy lensing power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3125
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3126
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3127
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gallens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3127, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3128
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gal_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_gallens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3129
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gallens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gal_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gallens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3129, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3130
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_gallens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_gallens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3130, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3131
 *             cl['1h'].append(self.tsz.cl_gal_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         if self.tsz.do_real_space_with_mcfit:
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3132
 *             cl['2h'].append(self.tsz.cl_gal_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:             # <<<<<<<<<<<<<<
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 */
  __pyx_t_7 = (__pyx_v_self->tsz.do_real_space_with_mcfit != 0);
  if (__pyx_t_7) {

    /* "class-sz/python/classy.pyx":3133
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:
 *             cl_g_gamma_ell = np.asarray(cl['ell'])             # <<<<<<<<<<<<<<
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_v_cl_g_gamma_ell = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3134
 *         if self.tsz.do_real_space_with_mcfit:
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])             # <<<<<<<<<<<<<<
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_asarray); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3134, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_cl_g_gamma_1h = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3135
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 *             cl_g_gamma_2h = np.asarray(cl['2h'])             # <<<<<<<<<<<<<<
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_asarray); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_1};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3135, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_v_cl_g_gamma_2h = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3136
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi             # <<<<<<<<<<<<<<
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',
 */
    __pyx_t_5 = __Pyx_PyFloat_AddObjC(__pyx_v_cl_g_gamma_ell, __pyx_float_1_, 1., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = PyNumber_Multiply(__pyx_v_cl_g_gamma_ell, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_8, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_pi); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyNumber_Divide(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_fac = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":3137
 *             cl_g_gamma_2h = np.asarray(cl['2h'])
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac             # <<<<<<<<<<<<<<
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',
 *                                              axis=-1,
 */
    __pyx_t_8 = __Pyx_PyNumber_Divide(__pyx_v_cl_g_gamma_1h, __pyx_v_fac); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_v_cl_g_gamma_2h, __pyx_v_fac); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyNumber_Add(__pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_cltot = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3138
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',             # <<<<<<<<<<<<<<
 *                                              axis=-1,
 *                                              copy=True,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_interpolate); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_interp1d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_cl_g_gamma_ell);
    __Pyx_GIVEREF(__pyx_v_cl_g_gamma_ell);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_cl_g_gamma_ell)) __PYX_ERR(0, 3138, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_cltot);
    __Pyx_GIVEREF(__pyx_v_cltot);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_cltot)) __PYX_ERR(0, 3138, __pyx_L1_error);
    __pyx_t_8 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_kind, __pyx_n_u_cubic) < 0) __PYX_ERR(0, 3138, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_axis, __pyx_int_neg_1) < 0) __PYX_ERR(0, 3138, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3140
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',
 *                                              axis=-1,
 *                                              copy=True,             # <<<<<<<<<<<<<<
 *                                              bounds_error=False,
 *                                              fill_value=1e-100,
 */
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_copy, Py_True) < 0) __PYX_ERR(0, 3138, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3141
 *                                              axis=-1,
 *                                              copy=True,
 *                                              bounds_error=False,             # <<<<<<<<<<<<<<
 *                                              fill_value=1e-100,
 *                                              assume_sorted=False)
 */
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_bounds_error, Py_False) < 0) __PYX_ERR(0, 3138, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_fill_value, __pyx_float_1eneg_100) < 0) __PYX_ERR(0, 3138, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3143
 *                                              bounds_error=False,
 *                                              fill_value=1e-100,
 *                                              assume_sorted=False)             # <<<<<<<<<<<<<<
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)
 *             F = cltotfunc(mcfitx)
 */
    if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_assume_sorted, Py_False) < 0) __PYX_ERR(0, 3138, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3138
 *             fac = cl_g_gamma_ell*(cl_g_gamma_ell+1.)/2./np.pi
 *             cltot = cl_g_gamma_1h/fac+cl_g_gamma_2h/fac
 *             cltotfunc = interpolate.interp1d(cl_g_gamma_ell,cltot,kind='cubic',             # <<<<<<<<<<<<<<
 *                                              axis=-1,
 *                                              copy=True,
 */
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_cltotfunc = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "class-sz/python/classy.pyx":3144
 *                                              fill_value=1e-100,
 *                                              assume_sorted=False)
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)             # <<<<<<<<<<<<<<
 *             F = cltotfunc(mcfitx)
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_logspace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v_log10xmin_mcfit);
    __Pyx_GIVEREF(__pyx_v_log10xmin_mcfit);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_log10xmin_mcfit)) __PYX_ERR(0, 3144, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_log10xmax_mcfit);
    __Pyx_GIVEREF(__pyx_v_log10xmax_mcfit);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_log10xmax_mcfit)) __PYX_ERR(0, 3144, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_num, __pyx_v_log10x_num) < 0) __PYX_ERR(0, 3144, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_endpoint, Py_False) < 0) __PYX_ERR(0, 3144, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_mcfitx = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3145
 *                                              assume_sorted=False)
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)
 *             F = cltotfunc(mcfitx)             # <<<<<<<<<<<<<<
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True)
 *             y, G = H(F, extrap=True)
 */
    __Pyx_INCREF(__pyx_v_cltotfunc);
    __pyx_t_5 = __pyx_v_cltotfunc; __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_mcfitx};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_F = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3146
 *             mcfitx = np.logspace(log10xmin_mcfit, log10xmax_mcfit, num=log10x_num, endpoint=False)
 *             F = cltotfunc(mcfitx)
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True)             # <<<<<<<<<<<<<<
 *             y, G = H(F, extrap=True)
 *             theta_mcfit = y*(60.*180.)/np.pi
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_mcfit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_transforms); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Hankel); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_mcfitx);
    __Pyx_GIVEREF(__pyx_v_mcfitx);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_mcfitx)) __PYX_ERR(0, 3146, __pyx_L1_error);
    __pyx_t_9 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_nu, __pyx_int_2) < 0) __PYX_ERR(0, 3146, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_q, __pyx_int_1) < 0) __PYX_ERR(0, 3146, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_N, __pyx_v_Nmcfit) < 0) __PYX_ERR(0, 3146, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_lowring, Py_True) < 0) __PYX_ERR(0, 3146, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_H = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":3147
 *             F = cltotfunc(mcfitx)
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True)
 *             y, G = H(F, extrap=True)             # <<<<<<<<<<<<<<
 *             theta_mcfit = y*(60.*180.)/np.pi
 *             xi_mcfit = G/2./np.pi
 */
    __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_v_F);
    __Pyx_GIVEREF(__pyx_v_F);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_F)) __PYX_ERR(0, 3147, __pyx_L1_error);
    __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_extrap, Py_True) < 0) __PYX_ERR(0, 3147, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_H, __pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
      PyObject* sequence = __pyx_t_5;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 3147, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      #else
      __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_1 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
      index = 0; __pyx_t_9 = __pyx_t_11(__pyx_t_1); if (unlikely(!__pyx_t_9)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_9);
      index = 1; __pyx_t_8 = __pyx_t_11(__pyx_t_1); if (unlikely(!__pyx_t_8)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_1), 2) < 0) __PYX_ERR(0, 3147, __pyx_L1_error)
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 3147, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __pyx_v_y = __pyx_t_9;
    __pyx_t_9 = 0;
    __pyx_v_G = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":3148
 *             H = mcfit.transforms.Hankel(mcfitx, nu=2, q=1, N=Nmcfit, lowring=True)
 *             y, G = H(F, extrap=True)
 *             theta_mcfit = y*(60.*180.)/np.pi             # <<<<<<<<<<<<<<
 *             xi_mcfit = G/2./np.pi
 *             cl['theta'] = theta_mcfit
 */
    __pyx_t_5 = PyFloat_FromDouble((60. * 180.)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = PyNumber_Multiply(__pyx_v_y, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_pi); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_theta_mcfit = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3149
 *             y, G = H(F, extrap=True)
 *             theta_mcfit = y*(60.*180.)/np.pi
 *             xi_mcfit = G/2./np.pi             # <<<<<<<<<<<<<<
 *             cl['theta'] = theta_mcfit
 *             cl['xi'] = xi_mcfit
 */
    __pyx_t_5 = __Pyx_PyFloat_TrueDivideObjC(__pyx_v_G, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_pi); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyNumber_Divide(__pyx_t_5, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_xi_mcfit = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "class-sz/python/classy.pyx":3150
 *             theta_mcfit = y*(60.*180.)/np.pi
 *             xi_mcfit = G/2./np.pi
 *             cl['theta'] = theta_mcfit             # <<<<<<<<<<<<<<
 *             cl['xi'] = xi_mcfit
 *         return cl
 */
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_theta, __pyx_v_theta_mcfit) < 0))) __PYX_ERR(0, 3150, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3151
 *             xi_mcfit = G/2./np.pi
 *             cl['theta'] = theta_mcfit
 *             cl['xi'] = xi_mcfit             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_xi, __pyx_v_xi_mcfit) < 0))) __PYX_ERR(0, 3151, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3132
 *             cl['2h'].append(self.tsz.cl_gal_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         if self.tsz.do_real_space_with_mcfit:             # <<<<<<<<<<<<<<
 *             cl_g_gamma_ell = np.asarray(cl['ell'])
 *             cl_g_gamma_1h = np.asarray(cl['1h'])
 */
  }

  /* "class-sz/python/classy.pyx":3152
 *             cl['theta'] = theta_mcfit
 *             cl['xi'] = xi_mcfit
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def gamma_ggamma(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3116
 * 
 * 
 *     def cl_ggamma(self,             # <<<<<<<<<<<<<<
 *                   Nmcfit = 1024,
 *                   log10xmin_mcfit = -6,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("classy_sz.Class.cl_ggamma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XDECREF(__pyx_v_cl_g_gamma_ell);
  __Pyx_XDECREF(__pyx_v_cl_g_gamma_1h);
  __Pyx_XDECREF(__pyx_v_cl_g_gamma_2h);
  __Pyx_XDECREF(__pyx_v_fac);
  __Pyx_XDECREF(__pyx_v_cltot);
  __Pyx_XDECREF(__pyx_v_cltotfunc);
  __Pyx_XDECREF(__pyx_v_mcfitx);
  __Pyx_XDECREF(__pyx_v_F);
  __Pyx_XDECREF(__pyx_v_H);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_G);
  __Pyx_XDECREF(__pyx_v_theta_mcfit);
  __Pyx_XDECREF(__pyx_v_xi_mcfit);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3154
 *         return cl
 * 
 *     def gamma_ggamma(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tangential shear
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_205gamma_ggamma(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_204gamma_ggamma, "\n        (class_sz) Return the 1-halo and 2-halo terms of tangential shear\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_205gamma_ggamma = {"gamma_ggamma", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_205gamma_ggamma, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_204gamma_ggamma};
static PyObject *__pyx_pw_9classy_sz_5Class_205gamma_ggamma(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gamma_ggamma (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("gamma_ggamma", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "gamma_ggamma", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_204gamma_ggamma(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_204gamma_ggamma(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("gamma_ggamma", 1);

  /* "class-sz/python/classy.pyx":3158
 *         (class_sz) Return the 1-halo and 2-halo terms of tangential shear
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['thetas'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3159
 *         """
 *         cl = {}
 *         cl['thetas'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_thetas, __pyx_t_1) < 0))) __PYX_ERR(0, 3159, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3160
 *         cl = {}
 *         cl['thetas'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3161
 *         cl['thetas'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.gamma_gal_gallens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3162
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.gamma_gal_gallens_1h[index])
 *             cl['2h'].append(self.tsz.gamma_gal_gallens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3163
 *         cl['2h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.gamma_gal_gallens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.gamma_gal_gallens_2h[index])
 *             cl['thetas'].append(self.tsz.thetas_arcmin[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.gamma_gal_gallens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3163, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3164
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.gamma_gal_gallens_1h[index])
 *             cl['2h'].append(self.tsz.gamma_gal_gallens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['thetas'].append(self.tsz.thetas_arcmin[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.gamma_gal_gallens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3164, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3165
 *             cl['1h'].append(self.tsz.gamma_gal_gallens_1h[index])
 *             cl['2h'].append(self.tsz.gamma_gal_gallens_2h[index])
 *             cl['thetas'].append(self.tsz.thetas_arcmin[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_thetas); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.thetas_arcmin[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3165, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3166
 *             cl['2h'].append(self.tsz.gamma_gal_gallens_2h[index])
 *             cl['thetas'].append(self.tsz.thetas_arcmin[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_ee(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3154
 *         return cl
 * 
 *     def gamma_ggamma(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tangential shear
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.gamma_ggamma", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3168
 *         return cl
 * 
 *     def cl_ee(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x electron power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_207cl_ee(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_206cl_ee, "\n        (class_sz) Return the 1-halo and 2-halo terms of electron x electron power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_207cl_ee = {"cl_ee", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_207cl_ee, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_206cl_ee};
static PyObject *__pyx_pw_9classy_sz_5Class_207cl_ee(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_ee (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_ee", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_ee", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_206cl_ee(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_206cl_ee(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_ee", 1);

  /* "class-sz/python/classy.pyx":3172
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x electron power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3173
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3173, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3174
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         # cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3175
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         # cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3175, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3177
 *         cl['2h'] = []
 *         # cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_tau_tau_1h[index])
 *             cl['2h'].append(self.tsz.cl_tau_tau_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3178
 *         # cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tau_tau_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_tau_tau_2h[index])
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tau_tau_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3178, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3179
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tau_tau_1h[index])
 *             cl['2h'].append(self.tsz.cl_tau_tau_2h[index])             # <<<<<<<<<<<<<<
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tau_tau_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3179, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3181
 *             cl['2h'].append(self.tsz.cl_tau_tau_2h[index])
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3181, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3182
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3168
 *         return cl
 * 
 *     def cl_ee(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x electron power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_ee", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3185
 * 
 * 
 *     def cl_eg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x galaxy power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_209cl_eg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_208cl_eg, "\n        (class_sz) Return the 1-halo and 2-halo terms of electron x galaxy power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_209cl_eg = {"cl_eg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_209cl_eg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_208cl_eg};
static PyObject *__pyx_pw_9classy_sz_5Class_209cl_eg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_eg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_eg", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_eg", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_208cl_eg(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_208cl_eg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_eg", 1);

  /* "class-sz/python/classy.pyx":3189
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x galaxy power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3190
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3191
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         # cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3192
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         # cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3194
 *         cl['2h'] = []
 *         # cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_tau_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_tau_gal_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3195
 *         # cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tau_gal_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_tau_gal_2h[index])
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tau_gal_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3195, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3196
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_tau_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_tau_gal_2h[index])             # <<<<<<<<<<<<<<
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_tau_gal_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3196, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3198
 *             cl['2h'].append(self.tsz.cl_tau_gal_2h[index])
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3199
 *             # cl['hf'].append(self.tsz.cl_tau_gal_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_kg(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3185
 * 
 * 
 *     def cl_eg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x galaxy power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_eg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3201
 *         return cl
 * 
 *     def cl_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x galaxy power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_211cl_kg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_210cl_kg, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x galaxy power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_211cl_kg = {"cl_kg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_211cl_kg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_210cl_kg};
static PyObject *__pyx_pw_9classy_sz_5Class_211cl_kg(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kg (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kg", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kg", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_210cl_kg(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_210cl_kg(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kg", 1);

  /* "class-sz/python/classy.pyx":3205
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x galaxy power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3206
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3207
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3208
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3209
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_lens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3210
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gal_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_lens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3211
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_lens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gal_lens_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_lens_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_lens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3211, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3212
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_lens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_gal_lens_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_lens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3212, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3213
 *             cl['1h'].append(self.tsz.cl_gal_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_lens_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_lens_hf[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_lens_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3213, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3214
 *             cl['2h'].append(self.tsz.cl_gal_lens_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_lens_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3214, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3215
 *             cl['hf'].append(self.tsz.cl_gal_lens_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def pk_at_z_hm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3201
 *         return cl
 * 
 *     def cl_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x galaxy power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3217
 *         return cl
 * 
 *     def pk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) matter power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_213pk_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_212pk_at_z_hm, "\n        (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) matter power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_213pk_at_z_hm = {"pk_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_213pk_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_212pk_at_z_hm};
static PyObject *__pyx_pw_9classy_sz_5Class_213pk_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_at_z_hm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("pk_at_z_hm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pk_at_z_hm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_212pk_at_z_hm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_212pk_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_at_z_hm", 1);

  /* "class-sz/python/classy.pyx":3221
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) matter power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['k'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3222
 *         """
 *         cl = {}
 *         cl['k'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_k, __pyx_t_1) < 0))) __PYX_ERR(0, 3222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3223
 *         cl = {}
 *         cl['k'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3224
 *         cl['k'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_at_z_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3225
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.pk_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_at_z_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_k_for_pk_hm;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3226
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_at_z_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.pk_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_at_z_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3226, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3227
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_at_z_2h[index])             # <<<<<<<<<<<<<<
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_at_z_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3227, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3228
 *             cl['1h'].append(self.tsz.pk_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.k_for_pk_hm[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3228, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3229
 *             cl['2h'].append(self.tsz.pk_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3217
 *         return cl
 * 
 *     def pk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) matter power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.pk_at_z_hm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3232
 * 
 * 
 *     def bk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) matter bispectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_215bk_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_214bk_at_z_hm, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) matter bispectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_215bk_at_z_hm = {"bk_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_215bk_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_214bk_at_z_hm};
static PyObject *__pyx_pw_9classy_sz_5Class_215bk_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bk_at_z_hm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("bk_at_z_hm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bk_at_z_hm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_214bk_at_z_hm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_214bk_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bk_at_z_hm", 1);

  /* "class-sz/python/classy.pyx":3236
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) matter bispectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['k'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3237
 *         """
 *         cl = {}
 *         cl['k'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_k, __pyx_t_1) < 0))) __PYX_ERR(0, 3237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3238
 *         cl = {}
 *         cl['k'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3239
 *         cl['k'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3240
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.bk_at_z_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 3240, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3241
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.bk_at_z_1h[index])
 *             cl['2h'].append(self.tsz.bk_at_z_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_k_for_pk_hm;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3242
 *         cl['3h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.bk_at_z_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.bk_at_z_2h[index])
 *             cl['3h'].append(self.tsz.bk_at_z_3h[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.bk_at_z_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3242, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3243
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.bk_at_z_1h[index])
 *             cl['2h'].append(self.tsz.bk_at_z_2h[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.bk_at_z_3h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.bk_at_z_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3243, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3244
 *             cl['1h'].append(self.tsz.bk_at_z_1h[index])
 *             cl['2h'].append(self.tsz.bk_at_z_2h[index])
 *             cl['3h'].append(self.tsz.bk_at_z_3h[index])             # <<<<<<<<<<<<<<
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.bk_at_z_3h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3244, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3245
 *             cl['2h'].append(self.tsz.bk_at_z_2h[index])
 *             cl['3h'].append(self.tsz.bk_at_z_3h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_k); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.k_for_pk_hm[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3246
 *             cl['3h'].append(self.tsz.bk_at_z_3h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3232
 * 
 * 
 *     def bk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) matter bispectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.bk_at_z_hm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3249
 * 
 * 
 *     def bk_ttg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) ttg bispectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_217bk_ttg_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_216bk_ttg_at_z_hm, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) ttg bispectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_217bk_ttg_at_z_hm = {"bk_ttg_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_217bk_ttg_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_216bk_ttg_at_z_hm};
static PyObject *__pyx_pw_9classy_sz_5Class_217bk_ttg_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bk_ttg_at_z_hm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("bk_ttg_at_z_hm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bk_ttg_at_z_hm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_216bk_ttg_at_z_hm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_216bk_ttg_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("bk_ttg_at_z_hm", 1);

  /* "class-sz/python/classy.pyx":3253
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) ttg bispectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['k'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3254
 *         """
 *         cl = {}
 *         cl['k'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_k, __pyx_t_1) < 0))) __PYX_ERR(0, 3254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3255
 *         cl = {}
 *         cl['k'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3256
 *         cl['k'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3257
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.bk_ttg_at_z_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 3257, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3258
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.bk_ttg_at_z_1h[index])
 *             cl['2h'].append(self.tsz.bk_ttg_at_z_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_k_for_pk_hm;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3259
 *         cl['3h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.bk_ttg_at_z_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.bk_ttg_at_z_2h[index])
 *             cl['3h'].append(self.tsz.bk_ttg_at_z_3h[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.bk_ttg_at_z_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3259, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3260
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.bk_ttg_at_z_1h[index])
 *             cl['2h'].append(self.tsz.bk_ttg_at_z_2h[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.bk_ttg_at_z_3h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.bk_ttg_at_z_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3260, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3261
 *             cl['1h'].append(self.tsz.bk_ttg_at_z_1h[index])
 *             cl['2h'].append(self.tsz.bk_ttg_at_z_2h[index])
 *             cl['3h'].append(self.tsz.bk_ttg_at_z_3h[index])             # <<<<<<<<<<<<<<
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.bk_ttg_at_z_3h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3261, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3262
 *             cl['2h'].append(self.tsz.bk_ttg_at_z_2h[index])
 *             cl['3h'].append(self.tsz.bk_ttg_at_z_3h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_k); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.k_for_pk_hm[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3262, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3263
 *             cl['3h'].append(self.tsz.bk_ttg_at_z_3h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def b_yyy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3249
 * 
 * 
 *     def bk_ttg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) ttg bispectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.bk_ttg_at_z_hm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3265
 *         return cl
 * 
 *     def b_yyy(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of tsz bispectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_219b_yyy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_218b_yyy, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of tsz bispectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_219b_yyy = {"b_yyy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_219b_yyy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_218b_yyy};
static PyObject *__pyx_pw_9classy_sz_5Class_219b_yyy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("b_yyy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("b_yyy", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "b_yyy", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_218b_yyy(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_218b_yyy(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("b_yyy", 1);

  /* "class-sz/python/classy.pyx":3269
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of tsz bispectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3270
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3271
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3271, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3272
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3272, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3273
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.b_tSZ_tSZ_tSZ_1halo[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 3273, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3274
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.b_tSZ_tSZ_tSZ_1halo[index])
 *             cl['2h'].append(self.tsz.b_tSZ_tSZ_tSZ_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3275
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.b_tSZ_tSZ_tSZ_1halo[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.b_tSZ_tSZ_tSZ_2h[index])
 *             cl['3h'].append(self.tsz.b_tSZ_tSZ_tSZ_3h[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.b_tSZ_tSZ_tSZ_1halo[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3275, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3276
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.b_tSZ_tSZ_tSZ_1halo[index])
 *             cl['2h'].append(self.tsz.b_tSZ_tSZ_tSZ_2h[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.b_tSZ_tSZ_tSZ_3h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.b_tSZ_tSZ_tSZ_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3276, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3277
 *             cl['1h'].append(self.tsz.b_tSZ_tSZ_tSZ_1halo[index])
 *             cl['2h'].append(self.tsz.b_tSZ_tSZ_tSZ_2h[index])
 *             cl['3h'].append(self.tsz.b_tSZ_tSZ_tSZ_3h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.b_tSZ_tSZ_tSZ_3h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3277, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3278
 *             cl['2h'].append(self.tsz.b_tSZ_tSZ_tSZ_2h[index])
 *             cl['3h'].append(self.tsz.b_tSZ_tSZ_tSZ_3h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3278, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3279
 *             cl['3h'].append(self.tsz.b_tSZ_tSZ_tSZ_3h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def b_tty(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3265
 *         return cl
 * 
 *     def b_yyy(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of tsz bispectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.b_yyy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3281
 *         return cl
 * 
 *     def b_tty(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of ksz-ksz-tsz bispectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_221b_tty(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_220b_tty, "\n        (class_sz) Return the 1-halo, 2-halo and 3-halo terms of ksz-ksz-tsz bispectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_221b_tty = {"b_tty", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_221b_tty, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_220b_tty};
static PyObject *__pyx_pw_9classy_sz_5Class_221b_tty(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("b_tty (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("b_tty", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "b_tty", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_220b_tty(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_220b_tty(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("b_tty", 1);

  /* "class-sz/python/classy.pyx":3285
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of ksz-ksz-tsz bispectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3286
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3287
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['3h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3288
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3289
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['3h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.b_kSZ_kSZ_tSZ_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_3h, __pyx_t_1) < 0))) __PYX_ERR(0, 3289, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3290
 *         cl['2h'] = []
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.b_kSZ_kSZ_tSZ_1h[index])
 *             cl['2h'].append(self.tsz.b_kSZ_kSZ_tSZ_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3291
 *         cl['3h'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.b_kSZ_kSZ_tSZ_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.b_kSZ_kSZ_tSZ_2h[index])
 *             cl['3h'].append(self.tsz.b_kSZ_kSZ_tSZ_3h[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.b_kSZ_kSZ_tSZ_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3292
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.b_kSZ_kSZ_tSZ_1h[index])
 *             cl['2h'].append(self.tsz.b_kSZ_kSZ_tSZ_2h[index])             # <<<<<<<<<<<<<<
 *             cl['3h'].append(self.tsz.b_kSZ_kSZ_tSZ_3h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.b_kSZ_kSZ_tSZ_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3292, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3292, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3293
 *             cl['1h'].append(self.tsz.b_kSZ_kSZ_tSZ_1h[index])
 *             cl['2h'].append(self.tsz.b_kSZ_kSZ_tSZ_2h[index])
 *             cl['3h'].append(self.tsz.b_kSZ_kSZ_tSZ_3h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_3h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.b_kSZ_kSZ_tSZ_3h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3294
 *             cl['2h'].append(self.tsz.b_kSZ_kSZ_tSZ_2h[index])
 *             cl['3h'].append(self.tsz.b_kSZ_kSZ_tSZ_3h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3294, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3295
 *             cl['3h'].append(self.tsz.b_kSZ_kSZ_tSZ_3h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def pk_gg_at_z_hm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3281
 *         return cl
 * 
 *     def b_tty(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of ksz-ksz-tsz bispectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.b_tty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3297
 *         return cl
 * 
 *     def pk_gg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) gg power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_223pk_gg_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_222pk_gg_at_z_hm, "\n        (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) gg power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_223pk_gg_at_z_hm = {"pk_gg_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_223pk_gg_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_222pk_gg_at_z_hm};
static PyObject *__pyx_pw_9classy_sz_5Class_223pk_gg_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_gg_at_z_hm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("pk_gg_at_z_hm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pk_gg_at_z_hm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_222pk_gg_at_z_hm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_222pk_gg_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_gg_at_z_hm", 1);

  /* "class-sz/python/classy.pyx":3301
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) gg power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['k'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3302
 *         """
 *         cl = {}
 *         cl['k'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_k, __pyx_t_1) < 0))) __PYX_ERR(0, 3302, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3303
 *         cl = {}
 *         cl['k'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3304
 *         cl['k'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_gg_at_z_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3304, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3305
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.pk_gg_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_gg_at_z_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_k_for_pk_hm;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3306
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_gg_at_z_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.pk_gg_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_gg_at_z_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3306, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3307
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_gg_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_gg_at_z_2h[index])             # <<<<<<<<<<<<<<
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_gg_at_z_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3308
 *             cl['1h'].append(self.tsz.pk_gg_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_gg_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.k_for_pk_hm[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3308, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3309
 *             cl['2h'].append(self.tsz.pk_gg_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def pk_b_at_z_2h(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3297
 *         return cl
 * 
 *     def pk_gg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) gg power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.pk_gg_at_z_hm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3311
 *         return cl
 * 
 *     def pk_b_at_z_2h(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_225pk_b_at_z_2h(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_224pk_b_at_z_2h, "\n        (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_225pk_b_at_z_2h = {"pk_b_at_z_2h", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_225pk_b_at_z_2h, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_224pk_b_at_z_2h};
static PyObject *__pyx_pw_9classy_sz_5Class_225pk_b_at_z_2h(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_b_at_z_2h (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("pk_b_at_z_2h", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pk_b_at_z_2h", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_224pk_b_at_z_2h(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_224pk_b_at_z_2h(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_b_at_z_2h", 1);

  /* "class-sz/python/classy.pyx":3315
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['k'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3316
 *         """
 *         cl = {}
 *         cl['k'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_k, __pyx_t_1) < 0))) __PYX_ERR(0, 3316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3317
 *         cl = {}
 *         cl['k'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['2h'].append(self.tsz.pk_b_at_z_2h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3318
 *         cl['k'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.pk_b_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_k_for_pk_hm;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3319
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['2h'].append(self.tsz.pk_b_at_z_2h[index])             # <<<<<<<<<<<<<<
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_b_at_z_2h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3319, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3320
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['2h'].append(self.tsz.pk_b_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_k); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.k_for_pk_hm[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3320, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3321
 *             cl['2h'].append(self.tsz.pk_b_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def pk_bb_at_z_hm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3311
 *         return cl
 * 
 *     def pk_b_at_z_2h(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.pk_b_at_z_2h", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3323
 *         return cl
 * 
 *     def pk_bb_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_227pk_bb_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_226pk_bb_at_z_hm, "\n        (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_227pk_bb_at_z_hm = {"pk_bb_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_227pk_bb_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_226pk_bb_at_z_hm};
static PyObject *__pyx_pw_9classy_sz_5Class_227pk_bb_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_bb_at_z_hm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("pk_bb_at_z_hm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pk_bb_at_z_hm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_226pk_bb_at_z_hm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_226pk_bb_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_bb_at_z_hm", 1);

  /* "class-sz/python/classy.pyx":3327
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['k'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3328
 *         """
 *         cl = {}
 *         cl['k'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_k, __pyx_t_1) < 0))) __PYX_ERR(0, 3328, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3329
 *         cl = {}
 *         cl['k'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3330
 *         cl['k'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_bb_at_z_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3330, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3331
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.pk_bb_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_bb_at_z_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_k_for_pk_hm;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3332
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_bb_at_z_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.pk_bb_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3332, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_bb_at_z_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3332, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3332, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3333
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_bb_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_bb_at_z_2h[index])             # <<<<<<<<<<<<<<
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_bb_at_z_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3333, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3333, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3334
 *             cl['1h'].append(self.tsz.pk_bb_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_bb_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.k_for_pk_hm[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3334, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3335
 *             cl['2h'].append(self.tsz.pk_bb_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def pk_em_at_z_hm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3323
 *         return cl
 * 
 *     def pk_bb_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.pk_bb_at_z_hm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3337
 *         return cl
 * 
 *     def pk_em_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) electron-matter power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_229pk_em_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_228pk_em_at_z_hm, "\n        (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) electron-matter power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_229pk_em_at_z_hm = {"pk_em_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_229pk_em_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_228pk_em_at_z_hm};
static PyObject *__pyx_pw_9classy_sz_5Class_229pk_em_at_z_hm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pk_em_at_z_hm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("pk_em_at_z_hm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "pk_em_at_z_hm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_228pk_em_at_z_hm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_228pk_em_at_z_hm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pk_em_at_z_hm", 1);

  /* "class-sz/python/classy.pyx":3341
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) electron-matter power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['k'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3342
 *         """
 *         cl = {}
 *         cl['k'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_k, __pyx_t_1) < 0))) __PYX_ERR(0, 3342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3343
 *         cl = {}
 *         cl['k'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3344
 *         cl['k'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_em_at_z_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3344, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3345
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.pk_em_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_em_at_z_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_k_for_pk_hm;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3346
 *         cl['2h'] = []
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_em_at_z_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.pk_em_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_em_at_z_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3346, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3347
 *         for index in range(self.tsz.n_k_for_pk_hm):
 *             cl['1h'].append(self.tsz.pk_em_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_em_at_z_2h[index])             # <<<<<<<<<<<<<<
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.pk_em_at_z_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3347, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3348
 *             cl['1h'].append(self.tsz.pk_em_at_z_1h[index])
 *             cl['2h'].append(self.tsz.pk_em_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.k_for_pk_hm[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3348, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3349
 *             cl['2h'].append(self.tsz.pk_em_at_z_2h[index])
 *             cl['k'].append(self.tsz.k_for_pk_hm[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_kk(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3337
 *         return cl
 * 
 *     def pk_em_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) electron-matter power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.pk_em_at_z_hm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3351
 *         return cl
 * 
 *     def cl_kk(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_231cl_kk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_230cl_kk, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_231cl_kk = {"cl_kk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_231cl_kk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_230cl_kk};
static PyObject *__pyx_pw_9classy_sz_5Class_231cl_kk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kk (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kk", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kk", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_230cl_kk(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_230cl_kk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kk", 1);

  /* "class-sz/python/classy.pyx":3355
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3356
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3357
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3358
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3359
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lens_lens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3359, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3360
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_lens_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_lens_lens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3361
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lens_lens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_lens_lens_2h[index])
 *             cl['hf'].append(self.tsz.cl_lens_lens_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3361, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lens_lens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3361, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3361, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3362
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lens_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_lens_lens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_lens_lens_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lens_lens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3363
 *             cl['1h'].append(self.tsz.cl_lens_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_lens_lens_2h[index])
 *             cl['hf'].append(self.tsz.cl_lens_lens_hf[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lens_lens_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3363, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3364
 *             cl['2h'].append(self.tsz.cl_lens_lens_2h[index])
 *             cl['hf'].append(self.tsz.cl_lens_lens_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3364, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3365
 *             cl['hf'].append(self.tsz.cl_lens_lens_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_c1c1(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3351
 *         return cl
 * 
 *     def cl_kk(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_kk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3367
 *         return cl
 * 
 *     def cl_c1c1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_233cl_c1c1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_232cl_c1c1, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_233cl_c1c1 = {"cl_c1c1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_233cl_c1c1, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_232cl_c1c1};
static PyObject *__pyx_pw_9classy_sz_5Class_233cl_c1c1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_c1c1 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_c1c1", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_c1c1", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_232cl_c1c1(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_232cl_c1c1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_c1c1", 1);

  /* "class-sz/python/classy.pyx":3371
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3372
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3373
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3374
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3375
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_custom1_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3376
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_custom1_custom1_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_custom1_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3377
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_custom1_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_custom1_custom1_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_custom1_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3377, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3378
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_custom1_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_custom1_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_custom1_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3378, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3379
 *             cl['1h'].append(self.tsz.cl_custom1_custom1_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_custom1_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3379, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3380
 *             cl['2h'].append(self.tsz.cl_custom1_custom1_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_c1_lens(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3367
 *         return cl
 * 
 *     def cl_c1c1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_c1c1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3382
 *         return cl
 * 
 *     def cl_c1_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_235cl_c1_lens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_234cl_c1_lens, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_235cl_c1_lens = {"cl_c1_lens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_235cl_c1_lens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_234cl_c1_lens};
static PyObject *__pyx_pw_9classy_sz_5Class_235cl_c1_lens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_c1_lens (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_c1_lens", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_c1_lens", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_234cl_c1_lens(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_234cl_c1_lens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_c1_lens", 1);

  /* "class-sz/python/classy.pyx":3386
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3387
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3388
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3389
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3390
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_lens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3391
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_custom1_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_lens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3392
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_lens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_custom1_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_lens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3392, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3393
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_lens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_lens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3393, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3394
 *             cl['1h'].append(self.tsz.cl_custom1_lens_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3394, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3395
 *             cl['2h'].append(self.tsz.cl_custom1_lens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_c1_tSZ(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3382
 *         return cl
 * 
 *     def cl_c1_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_c1_lens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3397
 *         return cl
 * 
 *     def cl_c1_tSZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_237cl_c1_tSZ(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_236cl_c1_tSZ, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_237cl_c1_tSZ = {"cl_c1_tSZ", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_237cl_c1_tSZ, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_236cl_c1_tSZ};
static PyObject *__pyx_pw_9classy_sz_5Class_237cl_c1_tSZ(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_c1_tSZ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_c1_tSZ", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_c1_tSZ", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_236cl_c1_tSZ(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_236cl_c1_tSZ(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_c1_tSZ", 1);

  /* "class-sz/python/classy.pyx":3401
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3402
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3403
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3403, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3404
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3405
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_tSZ_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3406
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_custom1_tSZ_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_tSZ_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3407
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_tSZ_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_custom1_tSZ_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_tSZ_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3407, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3408
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_tSZ_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_tSZ_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_tSZ_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3408, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3409
 *             cl['1h'].append(self.tsz.cl_custom1_tSZ_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_tSZ_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3409, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3410
 *             cl['2h'].append(self.tsz.cl_custom1_tSZ_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_c1_gal(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3397
 *         return cl
 * 
 *     def cl_c1_tSZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_c1_tSZ", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3412
 *         return cl
 * 
 *     def cl_c1_gal(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_239cl_c1_gal(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_238cl_c1_gal, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_239cl_c1_gal = {"cl_c1_gal", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_239cl_c1_gal, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_238cl_c1_gal};
static PyObject *__pyx_pw_9classy_sz_5Class_239cl_c1_gal(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_c1_gal (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_c1_gal", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_c1_gal", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_238cl_c1_gal(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_238cl_c1_gal(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_c1_gal", 1);

  /* "class-sz/python/classy.pyx":3416
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3417
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3417, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3418
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3419
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3420
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_gal_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3421
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_custom1_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_gal_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3422
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_gal_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_custom1_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_gal_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3422, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3422, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3423
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_gal_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_gal_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3423, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3424
 *             cl['1h'].append(self.tsz.cl_custom1_gal_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3424, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3425
 *             cl['2h'].append(self.tsz.cl_custom1_gal_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_c1_gallens(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3412
 *         return cl
 * 
 *     def cl_c1_gal(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_c1_gal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3427
 *         return cl
 * 
 *     def cl_c1_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_241cl_c1_gallens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_240cl_c1_gallens, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_241cl_c1_gallens = {"cl_c1_gallens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_241cl_c1_gallens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_240cl_c1_gallens};
static PyObject *__pyx_pw_9classy_sz_5Class_241cl_c1_gallens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_c1_gallens (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_c1_gallens", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_c1_gallens", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_240cl_c1_gallens(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_240cl_c1_gallens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_c1_gallens", 1);

  /* "class-sz/python/classy.pyx":3431
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3432
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3432, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3433
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3434
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3435
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_gallens_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3435, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3436
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_custom1_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_gallens_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3437
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_gallens_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_custom1_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_gallens_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3437, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3438
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_custom1_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_gallens_2h[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_custom1_gallens_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3438, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3439
 *             cl['1h'].append(self.tsz.cl_custom1_gallens_1h[index])
 *             cl['2h'].append(self.tsz.cl_custom1_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3439, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "class-sz/python/classy.pyx":3440
 *             cl['2h'].append(self.tsz.cl_custom1_gallens_2h[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cib_monopole(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3427
 *         return cl
 * 
 *     def cl_c1_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_c1_gallens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3442
 *         return cl
 * 
 *     def cib_monopole(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib monopole as a function of frequency
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_243cib_monopole(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_242cib_monopole, "\n        (class_sz) Return the cib monopole as a function of frequency\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_243cib_monopole = {"cib_monopole", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_243cib_monopole, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_242cib_monopole};
static PyObject *__pyx_pw_9classy_sz_5Class_243cib_monopole(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cib_monopole (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cib_monopole", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cib_monopole", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_242cib_monopole(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_242cib_monopole(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cib_monopole", 1);

  /* "class-sz/python/classy.pyx":3446
 *         (class_sz) Return the cib monopole as a function of frequency
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['nu'] = []
 *         cl['I0'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3447
 *         """
 *         cl = {}
 *         cl['nu'] = []             # <<<<<<<<<<<<<<
 *         cl['I0'] = []
 *         for index in range(self.tsz.n_frequencies_for_cib):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_nu, __pyx_t_1) < 0))) __PYX_ERR(0, 3447, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3448
 *         cl = {}
 *         cl['nu'] = []
 *         cl['I0'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.n_frequencies_for_cib):
 *             cl['nu'].append(self.tsz.frequencies_for_cib[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_I0, __pyx_t_1) < 0))) __PYX_ERR(0, 3448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3449
 *         cl['nu'] = []
 *         cl['I0'] = []
 *         for index in range(self.tsz.n_frequencies_for_cib):             # <<<<<<<<<<<<<<
 *             cl['nu'].append(self.tsz.frequencies_for_cib[index])
 *             cl['I0'].append(self.tsz.cib_monopole[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.n_frequencies_for_cib;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3450
 *         cl['I0'] = []
 *         for index in range(self.tsz.n_frequencies_for_cib):
 *             cl['nu'].append(self.tsz.frequencies_for_cib[index])             # <<<<<<<<<<<<<<
 *             cl['I0'].append(self.tsz.cib_monopole[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_nu); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.frequencies_for_cib[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3450, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3451
 *         for index in range(self.tsz.n_frequencies_for_cib):
 *             cl['nu'].append(self.tsz.frequencies_for_cib[index])
 *             cl['I0'].append(self.tsz.cib_monopole[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_I0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cib_monopole[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3451, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3452
 *             cl['nu'].append(self.tsz.frequencies_for_cib[index])
 *             cl['I0'].append(self.tsz.cib_monopole[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cib_shotnoise(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3442
 *         return cl
 * 
 *     def cib_monopole(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib monopole as a function of frequency
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cib_monopole", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3454
 *         return cl
 * 
 *     def cib_shotnoise(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib shotnoise as a function of frequency
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_245cib_shotnoise(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_244cib_shotnoise, "\n        (class_sz) Return the cib shotnoise as a function of frequency\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_245cib_shotnoise = {"cib_shotnoise", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_245cib_shotnoise, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_244cib_shotnoise};
static PyObject *__pyx_pw_9classy_sz_5Class_245cib_shotnoise(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cib_shotnoise (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cib_shotnoise", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cib_shotnoise", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_244cib_shotnoise(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_244cib_shotnoise(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_id_nu1;
  double __pyx_v_nu1;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cib_shotnoise", 1);

  /* "class-sz/python/classy.pyx":3458
 *         (class_sz) Return the cib shotnoise as a function of frequency
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['nu'] = []
 *         cl['shotnoise'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3459
 *         """
 *         cl = {}
 *         cl['nu'] = []             # <<<<<<<<<<<<<<
 *         cl['shotnoise'] = []
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_nu, __pyx_t_1) < 0))) __PYX_ERR(0, 3459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3460
 *         cl = {}
 *         cl['nu'] = []
 *         cl['shotnoise'] = []             # <<<<<<<<<<<<<<
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_shotnoise, __pyx_t_1) < 0))) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3461
 *         cl['nu'] = []
 *         cl['shotnoise'] = []
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl['nu'].append(nu1)
 */
  __pyx_t_2 = __pyx_v_self->tsz.cib_frequency_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3462
 *         cl['shotnoise'] = []
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl['nu'].append(nu1)
 *             cl['shotnoise'].append(self.tsz.cib_shotnoise[id_nu1])
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.cib_frequency_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3463
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl['nu'].append(nu1)             # <<<<<<<<<<<<<<
 *             cl['shotnoise'].append(self.tsz.cib_shotnoise[id_nu1])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_nu); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble(__pyx_v_nu1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3463, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3464
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl['nu'].append(nu1)
 *             cl['shotnoise'].append(self.tsz.cib_shotnoise[id_nu1])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_shotnoise); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cib_shotnoise[__pyx_v_id_nu1])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3464, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3464, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3465
 *             cl['nu'].append(nu1)
 *             cl['shotnoise'].append(self.tsz.cib_shotnoise[id_nu1])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_cib_cib(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3454
 *         return cl
 * 
 *     def cib_shotnoise(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib shotnoise as a function of frequency
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cib_shotnoise", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3467
 *         return cl
 * 
 *     def cl_cib_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of cib x cib power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_247cl_cib_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_246cl_cib_cib, "\n        (class_sz) Return the 1-halo and 2-halo terms of cib x cib power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_247cl_cib_cib = {"cl_cib_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_247cl_cib_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_246cl_cib_cib};
static PyObject *__pyx_pw_9classy_sz_5Class_247cl_cib_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_cib_cib (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_cib_cib", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_cib_cib", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_246cl_cib_cib(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_246cl_cib_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_cib = NULL;
  PyObject *__pyx_v_id_nu1 = NULL;
  PyObject *__pyx_v_id_nu2 = NULL;
  PyObject *__pyx_v_nu1 = NULL;
  PyObject *__pyx_v_nu2 = NULL;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_cib_cib", 1);

  /* "class-sz/python/classy.pyx":3471
 *         (class_sz) Return the 1-halo and 2-halo terms of cib x cib power spectrum
 *         """
 *         cl_cib = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_cib = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3473
 *         cl_cib = {}
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.cib_frequency_list[id_nu1]
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.cib_frequency_list_num); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3473, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3473, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 3473, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3473, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3473, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 3473, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3473, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3473, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_id_nu1, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":3474
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             for id_nu2 in range(0,id_nu1+1):             # <<<<<<<<<<<<<<
 *                 nu1 = self.tsz.cib_frequency_list[id_nu1]
 *                 nu2 = self.tsz.cib_frequency_list[id_nu2]
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_id_nu1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_0)) __PYX_ERR(0, 3474, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 3474, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3474, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_5 = __pyx_t_2; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3474, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3474, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3474, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 3474, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3474, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3474, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 3474, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3474, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_7(__pyx_t_5);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3474, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_id_nu2, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3475
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.cib_frequency_list[id_nu1]             # <<<<<<<<<<<<<<
 *                 nu2 = self.tsz.cib_frequency_list[id_nu2]
 * 
 */
      __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu1); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3475, __pyx_L1_error)
      __pyx_t_2 = PyFloat_FromDouble((__pyx_v_self->tsz.cib_frequency_list[__pyx_t_8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3475, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_nu1, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3476
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.cib_frequency_list[id_nu1]
 *                 nu2 = self.tsz.cib_frequency_list[id_nu2]             # <<<<<<<<<<<<<<
 * 
 *                 cl = {}
 */
      __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu2); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3476, __pyx_L1_error)
      __pyx_t_2 = PyFloat_FromDouble((__pyx_v_self->tsz.cib_frequency_list[__pyx_t_8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_nu2, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3478
 *                 nu2 = self.tsz.cib_frequency_list[id_nu2]
 * 
 *                 cl = {}             # <<<<<<<<<<<<<<
 *                 cl['ell'] = []
 *                 cl['1h'] = []
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3478, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3479
 * 
 *                 cl = {}
 *                 cl['ell'] = []             # <<<<<<<<<<<<<<
 *                 cl['1h'] = []
 *                 cl['2h'] = []
 */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_2) < 0))) __PYX_ERR(0, 3479, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3480
 *                 cl = {}
 *                 cl['ell'] = []
 *                 cl['1h'] = []             # <<<<<<<<<<<<<<
 *                 cl['2h'] = []
 *                 for index in range(self.tsz.nlSZ):
 */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_2) < 0))) __PYX_ERR(0, 3480, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3481
 *                 cl['ell'] = []
 *                 cl['1h'] = []
 *                 cl['2h'] = []             # <<<<<<<<<<<<<<
 *                 for index in range(self.tsz.nlSZ):
 *                     cl['1h'].append(self.tsz.cl_cib_cib_1h[id_nu1][id_nu2][index])
 */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3481, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_2) < 0))) __PYX_ERR(0, 3481, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3482
 *                 cl['1h'] = []
 *                 cl['2h'] = []
 *                 for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                     cl['1h'].append(self.tsz.cl_cib_cib_1h[id_nu1][id_nu2][index])
 *                     cl['2h'].append(self.tsz.cl_cib_cib_2h[id_nu1][id_nu2][index])
 */
      __pyx_t_9 = __pyx_v_self->tsz.nlSZ;
      __pyx_t_10 = __pyx_t_9;
      for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
        __pyx_v_index = __pyx_t_11;

        /* "class-sz/python/classy.pyx":3483
 *                 cl['2h'] = []
 *                 for index in range(self.tsz.nlSZ):
 *                     cl['1h'].append(self.tsz.cl_cib_cib_1h[id_nu1][id_nu2][index])             # <<<<<<<<<<<<<<
 *                     cl['2h'].append(self.tsz.cl_cib_cib_2h[id_nu1][id_nu2][index])
 *                     cl['ell'].append(self.tsz.ell[index])
 */
        __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3483, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu1); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3483, __pyx_L1_error)
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu2); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3483, __pyx_L1_error)
        __pyx_t_13 = PyFloat_FromDouble((((__pyx_v_self->tsz.cl_cib_cib_1h[__pyx_t_8])[__pyx_t_12])[__pyx_v_index])); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3483, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_13); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 3483, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "class-sz/python/classy.pyx":3484
 *                 for index in range(self.tsz.nlSZ):
 *                     cl['1h'].append(self.tsz.cl_cib_cib_1h[id_nu1][id_nu2][index])
 *                     cl['2h'].append(self.tsz.cl_cib_cib_2h[id_nu1][id_nu2][index])             # <<<<<<<<<<<<<<
 *                     cl['ell'].append(self.tsz.ell[index])
 *                 cl_cib[str(int(nu1))+'x'+str(int(nu2))] = cl
 */
        __pyx_t_13 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu1); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3484, __pyx_L1_error)
        __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu2); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3484, __pyx_L1_error)
        __pyx_t_2 = PyFloat_FromDouble((((__pyx_v_self->tsz.cl_cib_cib_2h[__pyx_t_12])[__pyx_t_8])[__pyx_v_index])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_13, __pyx_t_2); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 3484, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "class-sz/python/classy.pyx":3485
 *                     cl['1h'].append(self.tsz.cl_cib_cib_1h[id_nu1][id_nu2][index])
 *                     cl['2h'].append(self.tsz.cl_cib_cib_2h[id_nu1][id_nu2][index])
 *                     cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *                 cl_cib[str(int(nu1))+'x'+str(int(nu2))] = cl
 *         return cl_cib
 */
        __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3485, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_13 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3485, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_13); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 3485, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }

      /* "class-sz/python/classy.pyx":3486
 *                     cl['2h'].append(self.tsz.cl_cib_cib_2h[id_nu1][id_nu2][index])
 *                     cl['ell'].append(self.tsz.ell[index])
 *                 cl_cib[str(int(nu1))+'x'+str(int(nu2))] = cl             # <<<<<<<<<<<<<<
 *         return cl_cib
 * 
 */
      __pyx_t_13 = __Pyx_PyNumber_Int(__pyx_v_nu1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_n_u_x); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_nu2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_15 = __Pyx_PyObject_Unicode(__pyx_t_2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_13, __pyx_t_15); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      if (unlikely((PyDict_SetItem(__pyx_v_cl_cib, __pyx_t_2, __pyx_v_cl) < 0))) __PYX_ERR(0, 3486, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3474
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             for id_nu2 in range(0,id_nu1+1):             # <<<<<<<<<<<<<<
 *                 nu1 = self.tsz.cib_frequency_list[id_nu1]
 *                 nu2 = self.tsz.cib_frequency_list[id_nu2]
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3473
 *         cl_cib = {}
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.cib_frequency_list[id_nu1]
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3487
 *                     cl['ell'].append(self.tsz.ell[index])
 *                 cl_cib[str(int(nu1))+'x'+str(int(nu2))] = cl
 *         return cl_cib             # <<<<<<<<<<<<<<
 * 
 *     def cl_galn_galn(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_cib);
  __pyx_r = __pyx_v_cl_cib;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3467
 *         return cl
 * 
 *     def cl_cib_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of cib x cib power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("classy_sz.Class.cl_cib_cib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_cib);
  __Pyx_XDECREF(__pyx_v_id_nu1);
  __Pyx_XDECREF(__pyx_v_id_nu2);
  __Pyx_XDECREF(__pyx_v_nu1);
  __Pyx_XDECREF(__pyx_v_nu2);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3489
 *         return cl_cib
 * 
 *     def cl_galn_galn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x gal power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_249cl_galn_galn(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_248cl_galn_galn, "\n        (class_sz) Return the 1-halo and 2-halo terms of gal x gal power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_249cl_galn_galn = {"cl_galn_galn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_249cl_galn_galn, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_248cl_galn_galn};
static PyObject *__pyx_pw_9classy_sz_5Class_249cl_galn_galn(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_galn_galn (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_galn_galn", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_galn_galn", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_248cl_galn_galn(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_248cl_galn_galn(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_gg = NULL;
  PyObject *__pyx_v_id_nu1 = NULL;
  PyObject *__pyx_v_id_nu2 = NULL;
  PyObject *__pyx_v_nu1 = NULL;
  PyObject *__pyx_v_nu2 = NULL;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_galn_galn", 1);

  /* "class-sz/python/classy.pyx":3493
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x gal power spectrum
 *         """
 *         cl_gg = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_gg = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3495
 *         cl_gg = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.galaxy_samples_list[id_nu1]
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.galaxy_samples_list_num); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3495, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3495, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 3495, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3495, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3495, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 3495, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3495, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3495, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_id_nu1, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":3496
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             for id_nu2 in range(0,id_nu1+1):             # <<<<<<<<<<<<<<
 *                 nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *                 nu2 = self.tsz.galaxy_samples_list[id_nu2]
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_id_nu1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_0)) __PYX_ERR(0, 3496, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 3496, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_5 = __pyx_t_2; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3496, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3496, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3496, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 3496, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3496, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3496, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 3496, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3496, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_7(__pyx_t_5);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3496, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_id_nu2, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3497
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.galaxy_samples_list[id_nu1]             # <<<<<<<<<<<<<<
 *                 nu2 = self.tsz.galaxy_samples_list[id_nu2]
 * 
 */
      __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu1); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3497, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyInt_From_int((__pyx_v_self->tsz.galaxy_samples_list[__pyx_t_8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3497, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_nu1, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3498
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *                 nu2 = self.tsz.galaxy_samples_list[id_nu2]             # <<<<<<<<<<<<<<
 * 
 *                 cl = {}
 */
      __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu2); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3498, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyInt_From_int((__pyx_v_self->tsz.galaxy_samples_list[__pyx_t_8])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3498, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_nu2, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3500
 *                 nu2 = self.tsz.galaxy_samples_list[id_nu2]
 * 
 *                 cl = {}             # <<<<<<<<<<<<<<
 *                 cl['ell'] = []
 *                 cl['1h'] = []
 */
      __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3500, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3501
 * 
 *                 cl = {}
 *                 cl['ell'] = []             # <<<<<<<<<<<<<<
 *                 cl['1h'] = []
 *                 cl['2h'] = []
 */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_2) < 0))) __PYX_ERR(0, 3501, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3502
 *                 cl = {}
 *                 cl['ell'] = []
 *                 cl['1h'] = []             # <<<<<<<<<<<<<<
 *                 cl['2h'] = []
 *                 cl['hf'] = []
 */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_2) < 0))) __PYX_ERR(0, 3502, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3503
 *                 cl['ell'] = []
 *                 cl['1h'] = []
 *                 cl['2h'] = []             # <<<<<<<<<<<<<<
 *                 cl['hf'] = []
 *                 for index in range(self.tsz.nlSZ):
 */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3503, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_2) < 0))) __PYX_ERR(0, 3503, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3504
 *                 cl['1h'] = []
 *                 cl['2h'] = []
 *                 cl['hf'] = []             # <<<<<<<<<<<<<<
 *                 for index in range(self.tsz.nlSZ):
 *                     cl['1h'].append(self.tsz.cl_ngal_ngal_1h[id_nu1][id_nu2][index])
 */
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_2) < 0))) __PYX_ERR(0, 3504, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":3505
 *                 cl['2h'] = []
 *                 cl['hf'] = []
 *                 for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                     cl['1h'].append(self.tsz.cl_ngal_ngal_1h[id_nu1][id_nu2][index])
 *                     cl['2h'].append(self.tsz.cl_ngal_ngal_2h[id_nu1][id_nu2][index])
 */
      __pyx_t_9 = __pyx_v_self->tsz.nlSZ;
      __pyx_t_10 = __pyx_t_9;
      for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
        __pyx_v_index = __pyx_t_11;

        /* "class-sz/python/classy.pyx":3506
 *                 cl['hf'] = []
 *                 for index in range(self.tsz.nlSZ):
 *                     cl['1h'].append(self.tsz.cl_ngal_ngal_1h[id_nu1][id_nu2][index])             # <<<<<<<<<<<<<<
 *                     cl['2h'].append(self.tsz.cl_ngal_ngal_2h[id_nu1][id_nu2][index])
 *                     cl['hf'].append(self.tsz.cl_ngal_ngal_hf[id_nu1][id_nu2][index])
 */
        __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3506, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu1); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3506, __pyx_L1_error)
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu2); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3506, __pyx_L1_error)
        __pyx_t_13 = PyFloat_FromDouble((((__pyx_v_self->tsz.cl_ngal_ngal_1h[__pyx_t_8])[__pyx_t_12])[__pyx_v_index])); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3506, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_13); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 3506, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "class-sz/python/classy.pyx":3507
 *                 for index in range(self.tsz.nlSZ):
 *                     cl['1h'].append(self.tsz.cl_ngal_ngal_1h[id_nu1][id_nu2][index])
 *                     cl['2h'].append(self.tsz.cl_ngal_ngal_2h[id_nu1][id_nu2][index])             # <<<<<<<<<<<<<<
 *                     cl['hf'].append(self.tsz.cl_ngal_ngal_hf[id_nu1][id_nu2][index])
 *                     cl['ell'].append(self.tsz.ell[index])
 */
        __pyx_t_13 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3507, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu1); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3507, __pyx_L1_error)
        __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu2); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3507, __pyx_L1_error)
        __pyx_t_2 = PyFloat_FromDouble((((__pyx_v_self->tsz.cl_ngal_ngal_2h[__pyx_t_12])[__pyx_t_8])[__pyx_v_index])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3507, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_13, __pyx_t_2); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 3507, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "class-sz/python/classy.pyx":3508
 *                     cl['1h'].append(self.tsz.cl_ngal_ngal_1h[id_nu1][id_nu2][index])
 *                     cl['2h'].append(self.tsz.cl_ngal_ngal_2h[id_nu1][id_nu2][index])
 *                     cl['hf'].append(self.tsz.cl_ngal_ngal_hf[id_nu1][id_nu2][index])             # <<<<<<<<<<<<<<
 *                     cl['ell'].append(self.tsz.ell[index])
 *                 cl_gg[str(int(nu1))+'x'+str(int(nu2))] = cl
 */
        __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3508, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu1); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3508, __pyx_L1_error)
        __pyx_t_12 = __Pyx_PyIndex_AsSsize_t(__pyx_v_id_nu2); if (unlikely((__pyx_t_12 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 3508, __pyx_L1_error)
        __pyx_t_13 = PyFloat_FromDouble((((__pyx_v_self->tsz.cl_ngal_ngal_hf[__pyx_t_8])[__pyx_t_12])[__pyx_v_index])); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3508, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_13); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 3508, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "class-sz/python/classy.pyx":3509
 *                     cl['2h'].append(self.tsz.cl_ngal_ngal_2h[id_nu1][id_nu2][index])
 *                     cl['hf'].append(self.tsz.cl_ngal_ngal_hf[id_nu1][id_nu2][index])
 *                     cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *                 cl_gg[str(int(nu1))+'x'+str(int(nu2))] = cl
 *         return cl_gg
 */
        __pyx_t_13 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3509, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_2 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3509, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_14 = __Pyx_PyObject_Append(__pyx_t_13, __pyx_t_2); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 3509, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }

      /* "class-sz/python/classy.pyx":3510
 *                     cl['hf'].append(self.tsz.cl_ngal_ngal_hf[id_nu1][id_nu2][index])
 *                     cl['ell'].append(self.tsz.ell[index])
 *                 cl_gg[str(int(nu1))+'x'+str(int(nu2))] = cl             # <<<<<<<<<<<<<<
 *         return cl_gg
 * 
 */
      __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_nu1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_13 = __Pyx_PyObject_Unicode(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_13, __pyx_n_u_x); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyNumber_Int(__pyx_v_nu2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_15 = __Pyx_PyObject_Unicode(__pyx_t_13); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_t_15); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      if (unlikely((PyDict_SetItem(__pyx_v_cl_gg, __pyx_t_13, __pyx_v_cl) < 0))) __PYX_ERR(0, 3510, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":3496
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             for id_nu2 in range(0,id_nu1+1):             # <<<<<<<<<<<<<<
 *                 nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *                 nu2 = self.tsz.galaxy_samples_list[id_nu2]
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3495
 *         cl_gg = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             for id_nu2 in range(0,id_nu1+1):
 *                 nu1 = self.tsz.galaxy_samples_list[id_nu1]
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3511
 *                     cl['ell'].append(self.tsz.ell[index])
 *                 cl_gg[str(int(nu1))+'x'+str(int(nu2))] = cl
 *         return cl_gg             # <<<<<<<<<<<<<<
 * 
 *     def cl_galn_lens(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_gg);
  __pyx_r = __pyx_v_cl_gg;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3489
 *         return cl_cib
 * 
 *     def cl_galn_galn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x gal power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("classy_sz.Class.cl_galn_galn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_gg);
  __Pyx_XDECREF(__pyx_v_id_nu1);
  __Pyx_XDECREF(__pyx_v_id_nu2);
  __Pyx_XDECREF(__pyx_v_nu1);
  __Pyx_XDECREF(__pyx_v_nu2);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3513
 *         return cl_gg
 * 
 *     def cl_galn_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_251cl_galn_lens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_250cl_galn_lens, "\n        (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_251cl_galn_lens = {"cl_galn_lens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_251cl_galn_lens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_250cl_galn_lens};
static PyObject *__pyx_pw_9classy_sz_5Class_251cl_galn_lens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_galn_lens (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_galn_lens", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_galn_lens", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_250cl_galn_lens(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_250cl_galn_lens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_gk = NULL;
  int __pyx_v_id_nu1;
  int __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_galn_lens", 1);

  /* "class-sz/python/classy.pyx":3517
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 *         """
 *         cl_gk = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_gk = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3519
 *         cl_gk = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.galaxy_samples_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3520
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.galaxy_samples_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3521
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3522
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3522, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3523
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             cl['hf'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3523, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3524
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             cl['hf'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3524, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3524, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3525
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             cl['hf'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_lens_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3525, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3526
 *             cl['2h'] = []
 *             cl['hf'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_ngal_lens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_lens_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3527
 *             cl['hf'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_lens_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_ngal_lens_2h[id_nu1][index])
 *                 cl['hf'].append(self.tsz.cl_ngal_lens_hf[id_nu1][index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3527, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_lens_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3527, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3527, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3528
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_lens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_lens_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['hf'].append(self.tsz.cl_ngal_lens_hf[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_lens_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3529
 *                 cl['1h'].append(self.tsz.cl_ngal_lens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_lens_2h[id_nu1][index])
 *                 cl['hf'].append(self.tsz.cl_ngal_lens_hf[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gk[str(int(nu1))] = cl
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_lens_hf[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3529, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3530
 *                 cl['2h'].append(self.tsz.cl_ngal_lens_2h[id_nu1][index])
 *                 cl['hf'].append(self.tsz.cl_ngal_lens_hf[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_gk[str(int(nu1))] = cl
 *         return cl_gk
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3530, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "class-sz/python/classy.pyx":3531
 *                 cl['hf'].append(self.tsz.cl_ngal_lens_hf[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gk[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_gk
 * 
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_nu1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyInt_Type)), __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_gk, __pyx_t_1, __pyx_v_cl) < 0))) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3532
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gk[str(int(nu1))] = cl
 *         return cl_gk             # <<<<<<<<<<<<<<
 * 
 *     def cl_galn_gallens(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_gk);
  __pyx_r = __pyx_v_cl_gk;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3513
 *         return cl_gg
 * 
 *     def cl_galn_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_galn_lens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_gk);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3534
 *         return cl_gk
 * 
 *     def cl_galn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_253cl_galn_gallens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_252cl_galn_gallens, "\n        (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_253cl_galn_gallens = {"cl_galn_gallens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_253cl_galn_gallens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_252cl_galn_gallens};
static PyObject *__pyx_pw_9classy_sz_5Class_253cl_galn_gallens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_galn_gallens (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_galn_gallens", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_galn_gallens", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_252cl_galn_gallens(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_252cl_galn_gallens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_gkg = NULL;
  int __pyx_v_id_nu1;
  int __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_galn_gallens", 1);

  /* "class-sz/python/classy.pyx":3538
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 *         """
 *         cl_gkg = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_gkg = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3540
 *         cl_gkg = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.galaxy_samples_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3541
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.galaxy_samples_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3542
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3543
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3543, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3544
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3544, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3545
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_gallens_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3545, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3546
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_ngal_gallens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_gallens_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3547
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_gallens_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_ngal_gallens_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3547, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_gallens_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3547, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3547, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3548
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_gallens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_gallens_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gkg[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_gallens_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3548, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3549
 *                 cl['1h'].append(self.tsz.cl_ngal_gallens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_gallens_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_gkg[str(int(nu1))] = cl
 *         return cl_gkg
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3549, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3549, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3550
 *                 cl['2h'].append(self.tsz.cl_ngal_gallens_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gkg[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_gkg
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyInt_Type)), __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Unicode(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_gkg, __pyx_t_8, __pyx_v_cl) < 0))) __PYX_ERR(0, 3550, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }

  /* "class-sz/python/classy.pyx":3551
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gkg[str(int(nu1))] = cl
 *         return cl_gkg             # <<<<<<<<<<<<<<
 * 
 *     def cl_galn_tsz(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_gkg);
  __pyx_r = __pyx_v_cl_gkg;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3534
 *         return cl_gk
 * 
 *     def cl_galn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_galn_gallens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_gkg);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3553
 *         return cl_gkg
 * 
 *     def cl_galn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_255cl_galn_tsz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_254cl_galn_tsz, "\n        (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_255cl_galn_tsz = {"cl_galn_tsz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_255cl_galn_tsz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_254cl_galn_tsz};
static PyObject *__pyx_pw_9classy_sz_5Class_255cl_galn_tsz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_galn_tsz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_galn_tsz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_galn_tsz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_254cl_galn_tsz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_254cl_galn_tsz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_gy = NULL;
  int __pyx_v_id_nu1;
  int __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_galn_tsz", 1);

  /* "class-sz/python/classy.pyx":3557
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 *         """
 *         cl_gy = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_gy = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3559
 *         cl_gy = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.galaxy_samples_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3560
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.galaxy_samples_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3561
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3562
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3562, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3563
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3563, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3564
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_tsz_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3565
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_ngal_tsz_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_tsz_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3566
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_tsz_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_ngal_tsz_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3566, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_tsz_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3566, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3566, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3567
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_ngal_tsz_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_tsz_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gy[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_tsz_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3567, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3567, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3568
 *                 cl['1h'].append(self.tsz.cl_ngal_tsz_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_ngal_tsz_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_gy[str(int(nu1))] = cl
 *         return cl_gy
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3568, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3569
 *                 cl['2h'].append(self.tsz.cl_ngal_tsz_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gy[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_gy
 *     def cl_galn_IA(self):
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyInt_Type)), __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Unicode(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_gy, __pyx_t_8, __pyx_v_cl) < 0))) __PYX_ERR(0, 3569, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }

  /* "class-sz/python/classy.pyx":3570
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gy[str(int(nu1))] = cl
 *         return cl_gy             # <<<<<<<<<<<<<<
 *     def cl_galn_IA(self):
 *         """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_gy);
  __pyx_r = __pyx_v_cl_gy;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3553
 *         return cl_gkg
 * 
 *     def cl_galn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_galn_tsz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_gy);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3571
 *             cl_gy[str(int(nu1))] = cl
 *         return cl_gy
 *     def cl_galn_IA(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 2-halo terms of gal x lens power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_257cl_galn_IA(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_256cl_galn_IA, "\n        (class_sz) Return the 2-halo terms of gal x lens power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_257cl_galn_IA = {"cl_galn_IA", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_257cl_galn_IA, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_256cl_galn_IA};
static PyObject *__pyx_pw_9classy_sz_5Class_257cl_galn_IA(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_galn_IA (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_galn_IA", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_galn_IA", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_256cl_galn_IA(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_256cl_galn_IA(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_gIA = NULL;
  int __pyx_v_id_nu1;
  int __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_galn_IA", 1);

  /* "class-sz/python/classy.pyx":3575
 *         (class_sz) Return the 2-halo terms of gal x lens power spectrum
 *         """
 *         cl_gIA = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_gIA = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3577
 *         cl_gIA = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.galaxy_samples_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3578
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.galaxy_samples_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3579
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3579, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3580
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3580, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3581
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3581, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3582
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(0.0)
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3582, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3583
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(0.0)
 *                 cl['2h'].append(self.tsz.cl_ngal_IA_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3584
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(0.0)             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_ngal_IA_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_float_0_0); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 3584, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3585
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(0.0)
 *                 cl['2h'].append(self.tsz.cl_ngal_IA_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gIA[str(int(nu1))] = cl
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3585, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_ngal_IA_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3585, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_9); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 3585, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "class-sz/python/classy.pyx":3586
 *                 cl['1h'].append(0.0)
 *                 cl['2h'].append(self.tsz.cl_ngal_IA_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_gIA[str(int(nu1))] = cl
 *         return cl_gIA
 */
      __pyx_t_9 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyObject_Append(__pyx_t_9, __pyx_t_1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 3586, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "class-sz/python/classy.pyx":3587
 *                 cl['2h'].append(self.tsz.cl_ngal_IA_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gIA[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_gIA
 * 
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_nu1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyInt_Type)), __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_gIA, __pyx_t_1, __pyx_v_cl) < 0))) __PYX_ERR(0, 3587, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3588
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_gIA[str(int(nu1))] = cl
 *         return cl_gIA             # <<<<<<<<<<<<<<
 * 
 *     def cl_lensmagn_gallens(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_gIA);
  __pyx_r = __pyx_v_cl_gIA;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3571
 *             cl_gy[str(int(nu1))] = cl
 *         return cl_gy
 *     def cl_galn_IA(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 2-halo terms of gal x lens power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("classy_sz.Class.cl_galn_IA", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_gIA);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3590
 *         return cl_gIA
 * 
 *     def cl_lensmagn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_259cl_lensmagn_gallens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_258cl_lensmagn_gallens, "\n        (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_259cl_lensmagn_gallens = {"cl_lensmagn_gallens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_259cl_lensmagn_gallens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_258cl_lensmagn_gallens};
static PyObject *__pyx_pw_9classy_sz_5Class_259cl_lensmagn_gallens(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_lensmagn_gallens (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_lensmagn_gallens", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_lensmagn_gallens", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_258cl_lensmagn_gallens(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_258cl_lensmagn_gallens(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_mkg = NULL;
  int __pyx_v_id_nu1;
  int __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_lensmagn_gallens", 1);

  /* "class-sz/python/classy.pyx":3594
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 *         """
 *         cl_mkg = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_mkg = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3596
 *         cl_mkg = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.galaxy_samples_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3597
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.galaxy_samples_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3598
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3599
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3599, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3600
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3600, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3601
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_nlensmag_gallens_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3601, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3602
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_nlensmag_gallens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_nlensmag_gallens_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3603
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_nlensmag_gallens_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_nlensmag_gallens_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_nlensmag_gallens_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3603, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3604
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_nlensmag_gallens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_nlensmag_gallens_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_mkg[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_nlensmag_gallens_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3604, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3605
 *                 cl['1h'].append(self.tsz.cl_nlensmag_gallens_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_nlensmag_gallens_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_mkg[str(int(nu1))] = cl
 *         return cl_mkg
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3605, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3605, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3606
 *                 cl['2h'].append(self.tsz.cl_nlensmag_gallens_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_mkg[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_mkg
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyInt_Type)), __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Unicode(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3606, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_mkg, __pyx_t_8, __pyx_v_cl) < 0))) __PYX_ERR(0, 3606, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }

  /* "class-sz/python/classy.pyx":3607
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_mkg[str(int(nu1))] = cl
 *         return cl_mkg             # <<<<<<<<<<<<<<
 * 
 *     def cl_lensmagn_tsz(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_mkg);
  __pyx_r = __pyx_v_cl_mkg;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3590
 *         return cl_gIA
 * 
 *     def cl_lensmagn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_lensmagn_gallens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_mkg);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3609
 *         return cl_mkg
 * 
 *     def cl_lensmagn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_261cl_lensmagn_tsz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_260cl_lensmagn_tsz, "\n        (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_261cl_lensmagn_tsz = {"cl_lensmagn_tsz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_261cl_lensmagn_tsz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_260cl_lensmagn_tsz};
static PyObject *__pyx_pw_9classy_sz_5Class_261cl_lensmagn_tsz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_lensmagn_tsz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_lensmagn_tsz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_lensmagn_tsz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_260cl_lensmagn_tsz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_260cl_lensmagn_tsz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_my = NULL;
  int __pyx_v_id_nu1;
  int __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_lensmagn_tsz", 1);

  /* "class-sz/python/classy.pyx":3613
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 *         """
 *         cl_my = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_my = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3615
 *         cl_my = {}
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.galaxy_samples_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3616
 * 
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.galaxy_samples_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3617
 *         for id_nu1 in range(self.tsz.galaxy_samples_list_num):
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3617, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3618
 *             nu1 = self.tsz.galaxy_samples_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3618, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3619
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3619, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3620
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_nlensmag_tsz_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3620, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3621
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_nlensmag_tsz_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_nlensmag_tsz_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3622
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_nlensmag_tsz_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_nlensmag_tsz_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3622, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_nlensmag_tsz_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3622, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3622, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3623
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_nlensmag_tsz_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_nlensmag_tsz_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_my[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_nlensmag_tsz_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3623, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3624
 *                 cl['1h'].append(self.tsz.cl_nlensmag_tsz_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_nlensmag_tsz_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_my[str(int(nu1))] = cl
 *         return cl_my
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3624, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3624, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3625
 *                 cl['2h'].append(self.tsz.cl_nlensmag_tsz_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_my[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_my
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyInt_Type)), __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_Unicode(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_my, __pyx_t_8, __pyx_v_cl) < 0))) __PYX_ERR(0, 3625, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }

  /* "class-sz/python/classy.pyx":3626
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_my[str(int(nu1))] = cl
 *         return cl_my             # <<<<<<<<<<<<<<
 * 
 *     def cl_kg_cib(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_my);
  __pyx_r = __pyx_v_cl_my;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3609
 *         return cl_mkg
 * 
 *     def cl_lensmagn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_lensmagn_tsz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_my);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3628
 *         return cl_my
 * 
 *     def cl_kg_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kg x cib power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_263cl_kg_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_262cl_kg_cib, "\n        (class_sz) Return the 1-halo and 2-halo terms of kg x cib power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_263cl_kg_cib = {"cl_kg_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_263cl_kg_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_262cl_kg_cib};
static PyObject *__pyx_pw_9classy_sz_5Class_263cl_kg_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_kg_cib (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_kg_cib", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_kg_cib", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_262cl_kg_cib(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_262cl_kg_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_y_cib = NULL;
  int __pyx_v_id_nu1;
  double __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_kg_cib", 1);

  /* "class-sz/python/classy.pyx":3632
 *         (class_sz) Return the 1-halo and 2-halo terms of kg x cib power spectrum
 *         """
 *         cl_y_cib = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_y_cib = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3634
 *         cl_y_cib = {}
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.cib_frequency_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3635
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.cib_frequency_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3636
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3637
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3637, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3638
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3638, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3639
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_gallens_cib_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3639, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3639, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3640
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_gallens_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_gallens_cib_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3641
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_gallens_cib_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_gallens_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_gallens_cib_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3641, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3642
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_gallens_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_gallens_cib_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_gallens_cib_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3642, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3643
 *                 cl['1h'].append(self.tsz.cl_gallens_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_gallens_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_y_cib[str(int(nu1))] = cl
 *         return cl_y_cib
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3643, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3643, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3643, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3644
 *                 cl['2h'].append(self.tsz.cl_gallens_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_y_cib
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_FromDouble(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_y_cib, __pyx_t_1, __pyx_v_cl) < 0))) __PYX_ERR(0, 3644, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3645
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl
 *         return cl_y_cib             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_y_cib);
  __pyx_r = __pyx_v_cl_y_cib;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3628
 *         return cl_my
 * 
 *     def cl_kg_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kg x cib power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_kg_cib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_y_cib);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3648
 * 
 * 
 *     def cl_custom1_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of custom1 x cib power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_265cl_custom1_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_264cl_custom1_cib, "\n        (class_sz) Return the 1-halo and 2-halo terms of custom1 x cib power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_265cl_custom1_cib = {"cl_custom1_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_265cl_custom1_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_264cl_custom1_cib};
static PyObject *__pyx_pw_9classy_sz_5Class_265cl_custom1_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_custom1_cib (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_custom1_cib", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_custom1_cib", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_264cl_custom1_cib(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_264cl_custom1_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_y_cib = NULL;
  int __pyx_v_id_nu1;
  double __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_custom1_cib", 1);

  /* "class-sz/python/classy.pyx":3652
 *         (class_sz) Return the 1-halo and 2-halo terms of custom1 x cib power spectrum
 *         """
 *         cl_y_cib = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_y_cib = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3654
 *         cl_y_cib = {}
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.cib_frequency_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3655
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.cib_frequency_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3656
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3657
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3657, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3658
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3658, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3659
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_custom1_cib_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3659, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3660
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_custom1_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_custom1_cib_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3661
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_custom1_cib_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_custom1_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_custom1_cib_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3661, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3661, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3662
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_custom1_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_custom1_cib_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_custom1_cib_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3662, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3663
 *                 cl['1h'].append(self.tsz.cl_custom1_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_custom1_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_y_cib[str(int(nu1))] = cl
 *         return cl_y_cib
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3663, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3663, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3663, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3664
 *                 cl['2h'].append(self.tsz.cl_custom1_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_y_cib
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_FromDouble(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_y_cib, __pyx_t_1, __pyx_v_cl) < 0))) __PYX_ERR(0, 3664, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3665
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl
 *         return cl_y_cib             # <<<<<<<<<<<<<<
 * 
 *     def cl_tSZ_cib(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_y_cib);
  __pyx_r = __pyx_v_cl_y_cib;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3648
 * 
 * 
 *     def cl_custom1_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of custom1 x cib power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_custom1_cib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_y_cib);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3667
 *         return cl_y_cib
 * 
 *     def cl_tSZ_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tSZ x cib power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_267cl_tSZ_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_266cl_tSZ_cib, "\n        (class_sz) Return the 1-halo and 2-halo terms of tSZ x cib power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_267cl_tSZ_cib = {"cl_tSZ_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_267cl_tSZ_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_266cl_tSZ_cib};
static PyObject *__pyx_pw_9classy_sz_5Class_267cl_tSZ_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_tSZ_cib (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_tSZ_cib", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_tSZ_cib", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_266cl_tSZ_cib(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_266cl_tSZ_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_y_cib = NULL;
  int __pyx_v_id_nu1;
  double __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_tSZ_cib", 1);

  /* "class-sz/python/classy.pyx":3671
 *         (class_sz) Return the 1-halo and 2-halo terms of tSZ x cib power spectrum
 *         """
 *         cl_y_cib = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_y_cib = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3673
 *         cl_y_cib = {}
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.cib_frequency_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3674
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.cib_frequency_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3675
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3676
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3676, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3677
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3677, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3678
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_tSZ_cib_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3678, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3679
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_tSZ_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_tSZ_cib_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3680
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_tSZ_cib_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_tSZ_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3680, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_tSZ_cib_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3680, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3680, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3681
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_tSZ_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_tSZ_cib_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3681, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_tSZ_cib_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3681, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3681, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3682
 *                 cl['1h'].append(self.tsz.cl_tSZ_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_tSZ_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_y_cib[str(int(nu1))] = cl
 *         return cl_y_cib
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3682, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3682, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3683
 *                 cl['2h'].append(self.tsz.cl_tSZ_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_y_cib
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_FromDouble(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_y_cib, __pyx_t_1, __pyx_v_cl) < 0))) __PYX_ERR(0, 3683, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3684
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_y_cib[str(int(nu1))] = cl
 *         return cl_y_cib             # <<<<<<<<<<<<<<
 * 
 *     def cl_gal_cib(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_y_cib);
  __pyx_r = __pyx_v_cl_y_cib;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3667
 *         return cl_y_cib
 * 
 *     def cl_tSZ_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tSZ x cib power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_tSZ_cib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_y_cib);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3686
 *         return cl_y_cib
 * 
 *     def cl_gal_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x cib power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_269cl_gal_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_268cl_gal_cib, "\n        (class_sz) Return the 1-halo and 2-halo terms of galaxy x cib power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_269cl_gal_cib = {"cl_gal_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_269cl_gal_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_268cl_gal_cib};
static PyObject *__pyx_pw_9classy_sz_5Class_269cl_gal_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_gal_cib (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_gal_cib", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_gal_cib", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_268cl_gal_cib(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_268cl_gal_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_g_cib = NULL;
  int __pyx_v_id_nu1;
  double __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_gal_cib", 1);

  /* "class-sz/python/classy.pyx":3690
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x cib power spectrum
 *         """
 *         cl_g_cib = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_g_cib = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3692
 *         cl_g_cib = {}
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.cib_frequency_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3693
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.cib_frequency_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3694
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3695
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3695, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3696
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3696, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3697
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_gal_cib_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3698
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_gal_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_gal_cib_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3699
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_gal_cib_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_gal_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_gal_cib_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3699, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3700
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_gal_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_gal_cib_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_g_cib[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3700, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_gal_cib_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3700, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3700, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3701
 *                 cl['1h'].append(self.tsz.cl_gal_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_gal_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_g_cib[str(int(nu1))] = cl
 *         return cl_g_cib
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3701, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3702
 *                 cl['2h'].append(self.tsz.cl_gal_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_g_cib[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_g_cib
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_FromDouble(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3702, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3702, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_g_cib, __pyx_t_1, __pyx_v_cl) < 0))) __PYX_ERR(0, 3702, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3703
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_g_cib[str(int(nu1))] = cl
 *         return cl_g_cib             # <<<<<<<<<<<<<<
 * 
 *     def cl_lens_cib(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_g_cib);
  __pyx_r = __pyx_v_cl_g_cib;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3686
 *         return cl_y_cib
 * 
 *     def cl_gal_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x cib power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_gal_cib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_g_cib);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3705
 *         return cl_g_cib
 * 
 *     def cl_lens_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of lens x cib power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_271cl_lens_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_270cl_lens_cib, "\n        (class_sz) Return the 1-halo and 2-halo terms of lens x cib power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_271cl_lens_cib = {"cl_lens_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_271cl_lens_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_270cl_lens_cib};
static PyObject *__pyx_pw_9classy_sz_5Class_271cl_lens_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_lens_cib (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_lens_cib", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_lens_cib", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_270cl_lens_cib(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_270cl_lens_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl_phi_cib = NULL;
  int __pyx_v_id_nu1;
  double __pyx_v_nu1;
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_lens_cib", 1);

  /* "class-sz/python/classy.pyx":3709
 *         (class_sz) Return the 1-halo and 2-halo terms of lens x cib power spectrum
 *         """
 *         cl_phi_cib = {}             # <<<<<<<<<<<<<<
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl_phi_cib = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3711
 *         cl_phi_cib = {}
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):             # <<<<<<<<<<<<<<
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 */
  __pyx_t_2 = __pyx_v_self->tsz.cib_frequency_list_num;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_id_nu1 = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3712
 * 
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]             # <<<<<<<<<<<<<<
 *             cl = {}
 *             cl['ell'] = []
 */
    __pyx_v_nu1 = (__pyx_v_self->tsz.cib_frequency_list[__pyx_v_id_nu1]);

    /* "class-sz/python/classy.pyx":3713
 *         for id_nu1 in range(self.tsz.cib_frequency_list_num):
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}             # <<<<<<<<<<<<<<
 *             cl['ell'] = []
 *             cl['1h'] = []
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3713, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_cl, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3714
 *             nu1 = self.tsz.cib_frequency_list[id_nu1]
 *             cl = {}
 *             cl['ell'] = []             # <<<<<<<<<<<<<<
 *             cl['1h'] = []
 *             cl['2h'] = []
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3714, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3714, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3715
 *             cl = {}
 *             cl['ell'] = []
 *             cl['1h'] = []             # <<<<<<<<<<<<<<
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3715, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3716
 *             cl['ell'] = []
 *             cl['1h'] = []
 *             cl['2h'] = []             # <<<<<<<<<<<<<<
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_lens_cib_1h[id_nu1][index])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3716, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3716, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3717
 *             cl['1h'] = []
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *                 cl['1h'].append(self.tsz.cl_lens_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_lens_cib_2h[id_nu1][index])
 */
    __pyx_t_5 = __pyx_v_self->tsz.nlSZ;
    __pyx_t_6 = __pyx_t_5;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_index = __pyx_t_7;

      /* "class-sz/python/classy.pyx":3718
 *             cl['2h'] = []
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_lens_cib_1h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['2h'].append(self.tsz.cl_lens_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_lens_cib_1h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3718, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":3719
 *             for index in range(self.tsz.nlSZ):
 *                 cl['1h'].append(self.tsz.cl_lens_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_lens_cib_2h[id_nu1][index])             # <<<<<<<<<<<<<<
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_phi_cib[str(int(nu1))] = cl
 */
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3719, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.cl_lens_cib_2h[__pyx_v_id_nu1])[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3719, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_8, __pyx_t_1); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3719, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3720
 *                 cl['1h'].append(self.tsz.cl_lens_cib_1h[id_nu1][index])
 *                 cl['2h'].append(self.tsz.cl_lens_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *             cl_phi_cib[str(int(nu1))] = cl
 *         return cl_phi_cib
 */
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3720, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3720, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_8); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 3720, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }

    /* "class-sz/python/classy.pyx":3721
 *                 cl['2h'].append(self.tsz.cl_lens_cib_2h[id_nu1][index])
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_phi_cib[str(int(nu1))] = cl             # <<<<<<<<<<<<<<
 *         return cl_phi_cib
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_FromDouble(__pyx_v_nu1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3721, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_cl_phi_cib, __pyx_t_1, __pyx_v_cl) < 0))) __PYX_ERR(0, 3721, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3722
 *                 cl['ell'].append(self.tsz.ell[index])
 *             cl_phi_cib[str(int(nu1))] = cl
 *         return cl_phi_cib             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl_phi_cib);
  __pyx_r = __pyx_v_cl_phi_cib;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3705
 *         return cl_g_cib
 * 
 *     def cl_lens_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of lens x cib power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.cl_lens_cib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl_phi_cib);
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3725
 * 
 * 
 *     def cl_km(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x mu (lensing magnification) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_273cl_km(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_272cl_km, "\n        (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x mu (lensing magnification) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_273cl_km = {"cl_km", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_273cl_km, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_272cl_km};
static PyObject *__pyx_pw_9classy_sz_5Class_273cl_km(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_km (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_km", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_km", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_272cl_km(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_272cl_km(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_km", 1);

  /* "class-sz/python/classy.pyx":3729
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x mu (lensing magnification) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3730
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3731
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3732
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3732, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3733
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lens_lensmag_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3733, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3734
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_lens_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_lens_lensmag_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3735
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lens_lensmag_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_lens_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_lens_lensmag_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lens_lensmag_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3735, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3736
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lens_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_lens_lensmag_2h[index])             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_lens_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lens_lensmag_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3736, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3737
 *             cl['1h'].append(self.tsz.cl_lens_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_lens_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_lens_lensmag_hf[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3737, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lens_lensmag_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3737, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3737, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3738
 *             cl['2h'].append(self.tsz.cl_lens_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_lens_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3738, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3739
 *             cl['hf'].append(self.tsz.cl_lens_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_mm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3725
 * 
 * 
 *     def cl_km(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x mu (lensing magnification) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_km", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3741
 *         return cl
 * 
 *     def cl_mm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of mu x mu (lensing magnification) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_275cl_mm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_274cl_mm, "\n        (class_sz) Return the 1-halo and 2-halo terms of mu x mu (lensing magnification) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_275cl_mm = {"cl_mm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_275cl_mm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_274cl_mm};
static PyObject *__pyx_pw_9classy_sz_5Class_275cl_mm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_mm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_mm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_mm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_274cl_mm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_274cl_mm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_mm", 1);

  /* "class-sz/python/classy.pyx":3745
 *         (class_sz) Return the 1-halo and 2-halo terms of mu x mu (lensing magnification) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3746
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3747
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3748
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3748, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3749
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lensmag_lensmag_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3750
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_lensmag_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_lensmag_lensmag_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3751
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lensmag_lensmag_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_lensmag_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_lensmag_lensmag_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lensmag_lensmag_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3751, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3751, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3752
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_lensmag_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_lensmag_lensmag_2h[index])             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_lensmag_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lensmag_lensmag_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3752, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3753
 *             cl['1h'].append(self.tsz.cl_lensmag_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_lensmag_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_lensmag_lensmag_hf[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_lensmag_lensmag_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3753, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3754
 *             cl['2h'].append(self.tsz.cl_lensmag_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_lensmag_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3754, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3755
 *             cl['hf'].append(self.tsz.cl_lensmag_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 *     def cl_gm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3741
 *         return cl
 * 
 *     def cl_mm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of mu x mu (lensing magnification) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_mm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3757
 *         return cl
 * 
 *     def cl_gm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x mu (lensing magnification) power spectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_277cl_gm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_276cl_gm, "\n        (class_sz) Return the 1-halo and 2-halo terms of galaxy x mu (lensing magnification) power spectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_277cl_gm = {"cl_gm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_277cl_gm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_276cl_gm};
static PyObject *__pyx_pw_9classy_sz_5Class_277cl_gm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cl_gm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cl_gm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cl_gm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_276cl_gm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_276cl_gm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_cl = NULL;
  int __pyx_v_index;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cl_gm", 1);

  /* "class-sz/python/classy.pyx":3761
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x mu (lensing magnification) power spectrum
 *         """
 *         cl = {}             # <<<<<<<<<<<<<<
 *         cl['ell'] = []
 *         cl['1h'] = []
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cl = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3762
 *         """
 *         cl = {}
 *         cl['ell'] = []             # <<<<<<<<<<<<<<
 *         cl['1h'] = []
 *         cl['2h'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_ell, __pyx_t_1) < 0))) __PYX_ERR(0, 3762, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3763
 *         cl = {}
 *         cl['ell'] = []
 *         cl['1h'] = []             # <<<<<<<<<<<<<<
 *         cl['2h'] = []
 *         cl['hf'] = []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_1h, __pyx_t_1) < 0))) __PYX_ERR(0, 3763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3764
 *         cl['ell'] = []
 *         cl['1h'] = []
 *         cl['2h'] = []             # <<<<<<<<<<<<<<
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_kp_u_2h, __pyx_t_1) < 0))) __PYX_ERR(0, 3764, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3765
 *         cl['1h'] = []
 *         cl['2h'] = []
 *         cl['hf'] = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_lensmag_1h[index])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_cl, __pyx_n_u_hf_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3765, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3766
 *         cl['2h'] = []
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             cl['1h'].append(self.tsz.cl_gal_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_lensmag_2h[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index = __pyx_t_4;

    /* "class-sz/python/classy.pyx":3767
 *         cl['hf'] = []
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_lensmag_1h[index])             # <<<<<<<<<<<<<<
 *             cl['2h'].append(self.tsz.cl_gal_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_lensmag_hf[index])
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_1h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_lensmag_1h[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3767, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3768
 *         for index in range(self.tsz.nlSZ):
 *             cl['1h'].append(self.tsz.cl_gal_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_lensmag_2h[index])             # <<<<<<<<<<<<<<
 *             cl['hf'].append(self.tsz.cl_gal_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_kp_u_2h); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3768, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_lensmag_2h[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3768, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3768, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3769
 *             cl['1h'].append(self.tsz.cl_gal_lensmag_1h[index])
 *             cl['2h'].append(self.tsz.cl_gal_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_lensmag_hf[index])             # <<<<<<<<<<<<<<
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_hf_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.cl_gal_lensmag_hf[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_5); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3769, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":3770
 *             cl['2h'].append(self.tsz.cl_gal_lensmag_2h[index])
 *             cl['hf'].append(self.tsz.cl_gal_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])             # <<<<<<<<<<<<<<
 *         return cl
 * 
 */
    __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_cl, __pyx_n_u_ell); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3770, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.ell[__pyx_v_index])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3770, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_Append(__pyx_t_5, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 3770, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":3771
 *             cl['hf'].append(self.tsz.cl_gal_lensmag_hf[index])
 *             cl['ell'].append(self.tsz.ell[index])
 *         return cl             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_cl);
  __pyx_r = __pyx_v_cl;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3757
 *         return cl
 * 
 *     def cl_gm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x mu (lensing magnification) power spectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.cl_gm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cl);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3774
 * 
 * 
 *     def get_scale_dependent_bias_at_z_and_k(self,z_asked,k_asked,bh):             # <<<<<<<<<<<<<<
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_279get_scale_dependent_bias_at_z_and_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_279get_scale_dependent_bias_at_z_and_k = {"get_scale_dependent_bias_at_z_and_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_279get_scale_dependent_bias_at_z_and_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_279get_scale_dependent_bias_at_z_and_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_k_asked = 0;
  PyObject *__pyx_v_bh = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_scale_dependent_bias_at_z_and_k (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_k_asked,&__pyx_n_s_bh,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3774, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3774, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_scale_dependent_bias_at_z_and_k", 1, 3, 3, 1); __PYX_ERR(0, 3774, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_bh)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3774, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_scale_dependent_bias_at_z_and_k", 1, 3, 3, 2); __PYX_ERR(0, 3774, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_scale_dependent_bias_at_z_and_k") < 0)) __PYX_ERR(0, 3774, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_z_asked = values[0];
    __pyx_v_k_asked = values[1];
    __pyx_v_bh = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_scale_dependent_bias_at_z_and_k", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 3774, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_scale_dependent_bias_at_z_and_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_278get_scale_dependent_bias_at_z_and_k(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_k_asked, __pyx_v_bh);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_278get_scale_dependent_bias_at_z_and_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_k_asked, PyObject *__pyx_v_bh) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_scale_dependent_bias_at_z_and_k", 1);

  /* "class-sz/python/classy.pyx":3775
 * 
 *     def get_scale_dependent_bias_at_z_and_k(self,z_asked,k_asked,bh):
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_szcounts_dndzdq_at_z_q(self,z_asked,qobs_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3775, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3775, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_bh); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3775, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_scale_dependent_bias_at_z_and_k(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3774
 * 
 * 
 *     def get_scale_dependent_bias_at_z_and_k(self,z_asked,k_asked,bh):             # <<<<<<<<<<<<<<
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_scale_dependent_bias_at_z_and_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3777
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 *     def get_szcounts_dndzdq_at_z_q(self,z_asked,qobs_asked):             # <<<<<<<<<<<<<<
 *         return get_szcounts_dndzdq_at_z_q(z_asked, qobs_asked, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_281get_szcounts_dndzdq_at_z_q(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_281get_szcounts_dndzdq_at_z_q = {"get_szcounts_dndzdq_at_z_q", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_281get_szcounts_dndzdq_at_z_q, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_281get_szcounts_dndzdq_at_z_q(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_qobs_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_szcounts_dndzdq_at_z_q (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_qobs_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3777, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_qobs_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3777, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_szcounts_dndzdq_at_z_q", 1, 2, 2, 1); __PYX_ERR(0, 3777, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_szcounts_dndzdq_at_z_q") < 0)) __PYX_ERR(0, 3777, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z_asked = values[0];
    __pyx_v_qobs_asked = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_szcounts_dndzdq_at_z_q", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3777, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_szcounts_dndzdq_at_z_q", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_280get_szcounts_dndzdq_at_z_q(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_qobs_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_280get_szcounts_dndzdq_at_z_q(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_qobs_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_szcounts_dndzdq_at_z_q", 1);

  /* "class-sz/python/classy.pyx":3778
 * 
 *     def get_szcounts_dndzdq_at_z_q(self,z_asked,qobs_asked):
 *         return get_szcounts_dndzdq_at_z_q(z_asked, qobs_asked, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3778, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_qobs_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3778, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_szcounts_dndzdq_at_z_q(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3778, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3777
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 *     def get_szcounts_dndzdq_at_z_q(self,z_asked,qobs_asked):             # <<<<<<<<<<<<<<
 *         return get_szcounts_dndzdq_at_z_q(z_asked, qobs_asked, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_szcounts_dndzdq_at_z_q", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3782
 * 
 * 
 *     def get_params_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the current parameters
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_283get_params_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_282get_params_sz, "\n        (SZ) Return the current parameters\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_283get_params_sz = {"get_params_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_283get_params_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_282get_params_sz};
static PyObject *__pyx_pw_9classy_sz_5Class_283get_params_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_params_sz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_params_sz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_params_sz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_282get_params_sz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_282get_params_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_params_sz", 1);

  /* "class-sz/python/classy.pyx":3786
 *         (SZ) Return the current parameters
 *         """
 *         return self._pars             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_pars);
  __pyx_r = __pyx_v_self->_pars;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3782
 * 
 * 
 *     def get_params_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the current parameters
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3789
 * 
 * 
 *     def tllprime_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the trispectrum
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_285tllprime_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_284tllprime_sz, "\n        (SZ) Return the trispectrum\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_285tllprime_sz = {"tllprime_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_285tllprime_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_284tllprime_sz};
static PyObject *__pyx_pw_9classy_sz_5Class_285tllprime_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tllprime_sz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("tllprime_sz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "tllprime_sz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_284tllprime_sz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_284tllprime_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  int __pyx_v_index_l;
  int __pyx_v_index_l_prime;
  PyObject *__pyx_v_T_ll_arr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  long __pyx_t_10;
  long __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tllprime_sz", 1);

  /* "class-sz/python/classy.pyx":3795
 *         #T_ll = defaultdict(list)
 *         cdef int index_l,index_l_prime
 *         T_ll_arr = np.zeros((self.tsz.nlSZ,self.tsz.nlSZ))             # <<<<<<<<<<<<<<
 *         for index_l in range(self.tsz.nlSZ):
 *             for index_l_prime in range(index_l+1):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.nlSZ); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.nlSZ); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 3795, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4)) __PYX_ERR(0, 3795, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_T_ll_arr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3796
 *         cdef int index_l,index_l_prime
 *         T_ll_arr = np.zeros((self.tsz.nlSZ,self.tsz.nlSZ))
 *         for index_l in range(self.tsz.nlSZ):             # <<<<<<<<<<<<<<
 *             for index_l_prime in range(index_l+1):
 *                 # T_ll[index_l].append(self.tsz.tllprime_sz[index_l][index_l_prime])
 */
  __pyx_t_7 = __pyx_v_self->tsz.nlSZ;
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_index_l = __pyx_t_9;

    /* "class-sz/python/classy.pyx":3797
 *         T_ll_arr = np.zeros((self.tsz.nlSZ,self.tsz.nlSZ))
 *         for index_l in range(self.tsz.nlSZ):
 *             for index_l_prime in range(index_l+1):             # <<<<<<<<<<<<<<
 *                 # T_ll[index_l].append(self.tsz.tllprime_sz[index_l][index_l_prime])
 *                 T_ll_arr[index_l][index_l_prime] = self.tsz.tllprime_sz[index_l][index_l_prime]
 */
    __pyx_t_10 = (__pyx_v_index_l + 1);
    __pyx_t_11 = __pyx_t_10;
    for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
      __pyx_v_index_l_prime = __pyx_t_12;

      /* "class-sz/python/classy.pyx":3799
 *             for index_l_prime in range(index_l+1):
 *                 # T_ll[index_l].append(self.tsz.tllprime_sz[index_l][index_l_prime])
 *                 T_ll_arr[index_l][index_l_prime] = self.tsz.tllprime_sz[index_l][index_l_prime]             # <<<<<<<<<<<<<<
 *                 T_ll_arr[index_l_prime][index_l] = T_ll_arr[index_l][index_l_prime]
 *         return T_ll_arr
 */
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->tsz.tllprime_sz[__pyx_v_index_l])[__pyx_v_index_l_prime])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3799, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_T_ll_arr, __pyx_v_index_l, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3799, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely((__Pyx_SetItemInt(__pyx_t_3, __pyx_v_index_l_prime, __pyx_t_1, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 3799, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":3800
 *                 # T_ll[index_l].append(self.tsz.tllprime_sz[index_l][index_l_prime])
 *                 T_ll_arr[index_l][index_l_prime] = self.tsz.tllprime_sz[index_l][index_l_prime]
 *                 T_ll_arr[index_l_prime][index_l] = T_ll_arr[index_l][index_l_prime]             # <<<<<<<<<<<<<<
 *         return T_ll_arr
 * 
 */
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_T_ll_arr, __pyx_v_index_l, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3800, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_index_l_prime, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3800, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_T_ll_arr, __pyx_v_index_l_prime, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3800, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely((__Pyx_SetItemInt(__pyx_t_1, __pyx_v_index_l, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0))) __PYX_ERR(0, 3800, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
  }

  /* "class-sz/python/classy.pyx":3801
 *                 T_ll_arr[index_l][index_l_prime] = self.tsz.tllprime_sz[index_l][index_l_prime]
 *                 T_ll_arr[index_l_prime][index_l] = T_ll_arr[index_l][index_l_prime]
 *         return T_ll_arr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_T_ll_arr);
  __pyx_r = __pyx_v_T_ll_arr;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3789
 * 
 * 
 *     def tllprime_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the trispectrum
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.tllprime_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_T_ll_arr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3804
 * 
 * 
 *     def A_rs(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_rs coefficient
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_287A_rs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_286A_rs, "\n        (SZ) Return the foreground A_rs coefficient\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_287A_rs = {"A_rs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_287A_rs, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_286A_rs};
static PyObject *__pyx_pw_9classy_sz_5Class_287A_rs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("A_rs (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("A_rs", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "A_rs", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_286A_rs(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_286A_rs(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("A_rs", 1);

  /* "class-sz/python/classy.pyx":3808
 *         (SZ) Return the foreground A_rs coefficient
 *         """
 *         return self.tsz.A_rs             # <<<<<<<<<<<<<<
 * 
 *     def B_sz(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.A_rs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3804
 * 
 * 
 *     def A_rs(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_rs coefficient
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.A_rs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3810
 *         return self.tsz.A_rs
 * 
 *     def B_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the mass bias
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_289B_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_288B_sz, "\n        (SZ) Return the mass bias\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_289B_sz = {"B_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_289B_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_288B_sz};
static PyObject *__pyx_pw_9classy_sz_5Class_289B_sz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("B_sz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("B_sz", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "B_sz", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_288B_sz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_288B_sz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("B_sz", 1);

  /* "class-sz/python/classy.pyx":3814
 *         (SZ) Return the mass bias
 *         """
 *         return self.tsz.HSEbias             # <<<<<<<<<<<<<<
 * 
 *     def Rho_crit_0(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.HSEbias); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3810
 *         return self.tsz.A_rs
 * 
 *     def B_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the mass bias
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.B_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3816
 *         return self.tsz.HSEbias
 * 
 *     def Rho_crit_0(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in Mpc/h, Msun/h units
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_291Rho_crit_0(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_290Rho_crit_0, "\n        (class_sz) Return the critical density in Mpc/h, Msun/h units\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_291Rho_crit_0 = {"Rho_crit_0", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_291Rho_crit_0, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_290Rho_crit_0};
static PyObject *__pyx_pw_9classy_sz_5Class_291Rho_crit_0(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Rho_crit_0 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Rho_crit_0", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Rho_crit_0", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_290Rho_crit_0(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_290Rho_crit_0(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Rho_crit_0", 1);

  /* "class-sz/python/classy.pyx":3820
 *         (class_sz) Return the critical density in Mpc/h, Msun/h units
 *         """
 *         return self.tsz.Rho_crit_0             # <<<<<<<<<<<<<<
 * 
 *     def rho0_crit(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.Rho_crit_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3816
 *         return self.tsz.HSEbias
 * 
 *     def Rho_crit_0(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in Mpc/h, Msun/h units
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Rho_crit_0", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3822
 *         return self.tsz.Rho_crit_0
 * 
 *     def rho0_crit(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in mpc/h, msun/h units at present time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_293rho0_crit(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_292rho0_crit, "\n        (class_sz) Return the critical density in mpc/h, msun/h units at present time.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_293rho0_crit = {"rho0_crit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_293rho0_crit, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_292rho0_crit};
static PyObject *__pyx_pw_9classy_sz_5Class_293rho0_crit(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rho0_crit (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("rho0_crit", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rho0_crit", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_292rho0_crit(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_292rho0_crit(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rho0_crit", 1);

  /* "class-sz/python/classy.pyx":3826
 *         (class_sz) Return the critical density in mpc/h, msun/h units at present time.
 *         """
 *         return self.Rho_crit_0()             # <<<<<<<<<<<<<<
 * 
 *     def rho0_cb(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Rho_crit_0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3822
 *         return self.tsz.Rho_crit_0
 * 
 *     def rho0_crit(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in mpc/h, msun/h units at present time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.rho0_crit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3828
 *         return self.Rho_crit_0()
 * 
 *     def rho0_cb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cdm+baryon density in mpc/h, msun/h units at present time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_295rho0_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_294rho0_cb, "\n        (class_sz) Return the cdm+baryon density in mpc/h, msun/h units at present time.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_295rho0_cb = {"rho0_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_295rho0_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_294rho0_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_295rho0_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rho0_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("rho0_cb", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rho0_cb", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_294rho0_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_294rho0_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rho0_cb", 1);

  /* "class-sz/python/classy.pyx":3832
 *         (class_sz) Return the cdm+baryon density in mpc/h, msun/h units at present time.
 *         """
 *         return self.rho0_crit()*(self.Omega0_b()+self.Omega0_cdm())             # <<<<<<<<<<<<<<
 * 
 *     def rho0_m(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rho0_crit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Omega0_b); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Omega0_cdm); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3828
 *         return self.Rho_crit_0()
 * 
 *     def rho0_cb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cdm+baryon density in mpc/h, msun/h units at present time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.rho0_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3834
 *         return self.rho0_crit()*(self.Omega0_b()+self.Omega0_cdm())
 * 
 *     def rho0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the mean density of the sum of Omega0 for all non-relativistic components in mpc/h, msun/h units at present time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_297rho0_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_296rho0_m, "\n        (class_sz) Return the mean density of the sum of Omega0 for all non-relativistic components in mpc/h, msun/h units at present time.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_297rho0_m = {"rho0_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_297rho0_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_296rho0_m};
static PyObject *__pyx_pw_9classy_sz_5Class_297rho0_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rho0_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("rho0_m", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "rho0_m", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_296rho0_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_296rho0_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rho0_m", 1);

  /* "class-sz/python/classy.pyx":3838
 *         (class_sz) Return the mean density of the sum of Omega0 for all non-relativistic components in mpc/h, msun/h units at present time.
 *         """
 *         return self.rho0_crit()*(self.Omega0_m())             # <<<<<<<<<<<<<<
 * 
 *     def chi_star(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rho0_crit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Omega0_m); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3834
 *         return self.rho0_crit()*(self.Omega0_b()+self.Omega0_cdm())
 * 
 *     def rho0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the mean density of the sum of Omega0 for all non-relativistic components in mpc/h, msun/h units at present time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.rho0_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3840
 *         return self.rho0_crit()*(self.Omega0_m())
 * 
 *     def chi_star(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the comoving distance to recombination in Mpc/h
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_299chi_star(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_298chi_star, "\n        (class_sz) Return the comoving distance to recombination in Mpc/h\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_299chi_star = {"chi_star", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_299chi_star, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_298chi_star};
static PyObject *__pyx_pw_9classy_sz_5Class_299chi_star(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("chi_star (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("chi_star", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "chi_star", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_298chi_star(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_298chi_star(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("chi_star", 1);

  /* "class-sz/python/classy.pyx":3844
 *         (class_sz) Return the comoving distance to recombination in Mpc/h
 *         """
 *         return self.tsz.chi_star             # <<<<<<<<<<<<<<
 * 
 *     def delta_def_custom1(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.chi_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3840
 *         return self.rho0_crit()*(self.Omega0_m())
 * 
 *     def chi_star(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the comoving distance to recombination in Mpc/h
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.chi_star", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3846
 *         return self.tsz.chi_star
 * 
 *     def delta_def_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the overdensity definition for custom1 profile
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_301delta_def_custom1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_300delta_def_custom1, "\n        (class_sz) Return the overdensity definition for custom1 profile\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_301delta_def_custom1 = {"delta_def_custom1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_301delta_def_custom1, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_300delta_def_custom1};
static PyObject *__pyx_pw_9classy_sz_5Class_301delta_def_custom1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delta_def_custom1 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("delta_def_custom1", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "delta_def_custom1", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_300delta_def_custom1(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_300delta_def_custom1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delta_def_custom1", 1);

  /* "class-sz/python/classy.pyx":3850
 *         (class_sz) Return the overdensity definition for custom1 profile
 *         """
 *         return self.tsz.delta_def_custom1             # <<<<<<<<<<<<<<
 * 
 *     def effective_galaxy_bias(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.delta_def_custom1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3846
 *         return self.tsz.chi_star
 * 
 *     def delta_def_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the overdensity definition for custom1 profile
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.delta_def_custom1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3852
 *         return self.tsz.delta_def_custom1
 * 
 *     def effective_galaxy_bias(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the effective galaxy bias
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_303effective_galaxy_bias(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_302effective_galaxy_bias, "\n        (class_sz) Return the effective galaxy bias\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_303effective_galaxy_bias = {"effective_galaxy_bias", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_303effective_galaxy_bias, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_302effective_galaxy_bias};
static PyObject *__pyx_pw_9classy_sz_5Class_303effective_galaxy_bias(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("effective_galaxy_bias (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("effective_galaxy_bias", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "effective_galaxy_bias", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_302effective_galaxy_bias(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_302effective_galaxy_bias(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("effective_galaxy_bias", 1);

  /* "class-sz/python/classy.pyx":3856
 *         (class_sz) Return the effective galaxy bias
 *         """
 *         return self.tsz.effective_galaxy_bias             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.effective_galaxy_bias); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3852
 *         return self.tsz.delta_def_custom1
 * 
 *     def effective_galaxy_bias(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the effective galaxy bias
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.effective_galaxy_bias", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3860
 * 
 * 
 *     def x_out_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the truncation for custom1 profile, r_cut = x_out*r_delta
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_305x_out_custom1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_304x_out_custom1, "\n        (class_sz) Return the truncation for custom1 profile, r_cut = x_out*r_delta\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_305x_out_custom1 = {"x_out_custom1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_305x_out_custom1, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_304x_out_custom1};
static PyObject *__pyx_pw_9classy_sz_5Class_305x_out_custom1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("x_out_custom1 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("x_out_custom1", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "x_out_custom1", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_304x_out_custom1(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_304x_out_custom1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("x_out_custom1", 1);

  /* "class-sz/python/classy.pyx":3864
 *         (class_sz) Return the truncation for custom1 profile, r_cut = x_out*r_delta
 *         """
 *         return self.tsz.x_out_custom1             # <<<<<<<<<<<<<<
 * 
 *     def M1SZ(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.x_out_custom1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3860
 * 
 * 
 *     def x_out_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the truncation for custom1 profile, r_cut = x_out*r_delta
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.x_out_custom1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3866
 *         return self.tsz.x_out_custom1
 * 
 *     def M1SZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the lower mass bound
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_307M1SZ(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_306M1SZ, "\n        (SZ) Return the lower mass bound\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_307M1SZ = {"M1SZ", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_307M1SZ, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_306M1SZ};
static PyObject *__pyx_pw_9classy_sz_5Class_307M1SZ(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("M1SZ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("M1SZ", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "M1SZ", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_306M1SZ(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_306M1SZ(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("M1SZ", 1);

  /* "class-sz/python/classy.pyx":3870
 *         (SZ) Return the lower mass bound
 *         """
 *         return self.tsz.M1SZ             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.M1SZ); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3866
 *         return self.tsz.x_out_custom1
 * 
 *     def M1SZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the lower mass bound
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.M1SZ", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3873
 * 
 * 
 *     def ystar(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return ystar
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_309ystar(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_308ystar, "\n        (SZ) Return ystar\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_309ystar = {"ystar", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_309ystar, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_308ystar};
static PyObject *__pyx_pw_9classy_sz_5Class_309ystar(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ystar (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("ystar", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ystar", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_308ystar(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_308ystar(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ystar", 1);

  /* "class-sz/python/classy.pyx":3877
 *         (SZ) Return ystar
 *         """
 *         return self.csz.ystar             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->csz.ystar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3873
 * 
 * 
 *     def ystar(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return ystar
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.ystar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3880
 * 
 * 
 *     def alpha(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return alpha
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_311alpha(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_310alpha, "\n        (SZ) Return alpha\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_311alpha = {"alpha", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_311alpha, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_310alpha};
static PyObject *__pyx_pw_9classy_sz_5Class_311alpha(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("alpha (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("alpha", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "alpha", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_310alpha(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_310alpha(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("alpha", 1);

  /* "class-sz/python/classy.pyx":3884
 *         (SZ) Return alpha
 *         """
 *         return self.csz.alpha             # <<<<<<<<<<<<<<
 * 
 *     def sigmaM(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->csz.alpha); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3880
 * 
 * 
 *     def alpha(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return alpha
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.alpha", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3886
 *         return self.csz.alpha
 * 
 *     def sigmaM(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return sigmaM
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_313sigmaM(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_312sigmaM, "\n        (SZ) Return sigmaM\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_313sigmaM = {"sigmaM", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_313sigmaM, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_312sigmaM};
static PyObject *__pyx_pw_9classy_sz_5Class_313sigmaM(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sigmaM (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("sigmaM", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sigmaM", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_312sigmaM(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_312sigmaM(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sigmaM", 1);

  /* "class-sz/python/classy.pyx":3890
 *         (SZ) Return sigmaM
 *         """
 *         return self.csz.sigmaM             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->csz.sigmaM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3886
 *         return self.csz.alpha
 * 
 *     def sigmaM(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return sigmaM
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.sigmaM", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3893
 * 
 * 
 *     def sigma8_Pcb(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.sigma8_Pcb
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_315sigma8_Pcb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_315sigma8_Pcb = {"sigma8_Pcb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_315sigma8_Pcb, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_315sigma8_Pcb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sigma8_Pcb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("sigma8_Pcb", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sigma8_Pcb", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_314sigma8_Pcb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_314sigma8_Pcb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sigma8_Pcb", 1);

  /* "class-sz/python/classy.pyx":3894
 * 
 *     def sigma8_Pcb(self):
 *         return self.tsz.sigma8_Pcb             # <<<<<<<<<<<<<<
 * 
 *     def A_cib(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.sigma8_Pcb); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3893
 * 
 * 
 *     def sigma8_Pcb(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.sigma8_Pcb
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.sigma8_Pcb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3896
 *         return self.tsz.sigma8_Pcb
 * 
 *     def A_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_317A_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_316A_cib, "\n        (SZ) Return the foreground A_cib coefficient\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_317A_cib = {"A_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_317A_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_316A_cib};
static PyObject *__pyx_pw_9classy_sz_5Class_317A_cib(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("A_cib (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("A_cib", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "A_cib", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_316A_cib(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_316A_cib(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("A_cib", 1);

  /* "class-sz/python/classy.pyx":3900
 *         (SZ) Return the foreground A_cib coefficient
 *         """
 *         return self.tsz.A_cib             # <<<<<<<<<<<<<<
 * 
 *     def A_sn(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.A_cib); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3896
 *         return self.tsz.sigma8_Pcb
 * 
 *     def A_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.A_cib", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3902
 *         return self.tsz.A_cib
 * 
 *     def A_sn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_319A_sn(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_318A_sn, "\n        (SZ) Return the foreground A_cib coefficient\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_319A_sn = {"A_sn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_319A_sn, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_318A_sn};
static PyObject *__pyx_pw_9classy_sz_5Class_319A_sn(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("A_sn (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("A_sn", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "A_sn", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_318A_sn(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_318A_sn(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("A_sn", 1);

  /* "class-sz/python/classy.pyx":3906
 *         (SZ) Return the foreground A_cib coefficient
 *         """
 *         return self.tsz.cl_gal_gal_A_sn             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.cl_gal_gal_A_sn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3902
 *         return self.tsz.A_cib
 * 
 *     def A_sn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.A_sn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3909
 * 
 * 
 *     def A_ir(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_ir coefficient
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_321A_ir(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_320A_ir, "\n        (SZ) Return the foreground A_ir coefficient\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_321A_ir = {"A_ir", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_321A_ir, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_320A_ir};
static PyObject *__pyx_pw_9classy_sz_5Class_321A_ir(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("A_ir (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("A_ir", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "A_ir", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_320A_ir(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_320A_ir(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("A_ir", 1);

  /* "class-sz/python/classy.pyx":3913
 *         (SZ) Return the foreground A_ir coefficient
 *         """
 *         return self.tsz.A_ir             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.A_ir); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3909
 * 
 * 
 *     def A_ir(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_ir coefficient
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.A_ir", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3916
 * 
 * 
 *     def A_cn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the correlated noise A_cn coefficient
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_323A_cn(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_322A_cn, "\n        (SZ) Return the correlated noise A_cn coefficient\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_323A_cn = {"A_cn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_323A_cn, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_322A_cn};
static PyObject *__pyx_pw_9classy_sz_5Class_323A_cn(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("A_cn (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("A_cn", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "A_cn", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_322A_cn(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_322A_cn(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("A_cn", 1);

  /* "class-sz/python/classy.pyx":3920
 *         (SZ) Return the correlated noise A_cn coefficient
 *         """
 *         return self.tsz.A_cn             # <<<<<<<<<<<<<<
 * 
 *     def get_te_of_m500c_at_z_arnaud(self,m,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.A_cn); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3916
 * 
 * 
 *     def A_cn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the correlated noise A_cn coefficient
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.A_cn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3922
 *         return self.tsz.A_cn
 * 
 *     def get_te_of_m500c_at_z_arnaud(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_325get_te_of_m500c_at_z_arnaud(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_325get_te_of_m500c_at_z_arnaud = {"get_te_of_m500c_at_z_arnaud", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_325get_te_of_m500c_at_z_arnaud, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_325get_te_of_m500c_at_z_arnaud(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_te_of_m500c_at_z_arnaud (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3922, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3922, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_te_of_m500c_at_z_arnaud", 1, 2, 2, 1); __PYX_ERR(0, 3922, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_te_of_m500c_at_z_arnaud") < 0)) __PYX_ERR(0, 3922, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_te_of_m500c_at_z_arnaud", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3922, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_te_of_m500c_at_z_arnaud", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_324get_te_of_m500c_at_z_arnaud(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_324get_te_of_m500c_at_z_arnaud(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_te_of_m500c_at_z_arnaud", 1);

  /* "class-sz/python/classy.pyx":3923
 * 
 *     def get_te_of_m500c_at_z_arnaud(self,m,z):
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_lensing_noise_at_ell(self,l):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3923, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3923, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_te_of_m500c_at_z_arnaud(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3922
 *         return self.tsz.A_cn
 * 
 *     def get_te_of_m500c_at_z_arnaud(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_te_of_m500c_at_z_arnaud", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3925
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 *     def get_lensing_noise_at_ell(self,l):             # <<<<<<<<<<<<<<
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_327get_lensing_noise_at_ell(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_327get_lensing_noise_at_ell = {"get_lensing_noise_at_ell", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_327get_lensing_noise_at_ell, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_327get_lensing_noise_at_ell(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_l = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_lensing_noise_at_ell (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_l,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3925, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_lensing_noise_at_ell") < 0)) __PYX_ERR(0, 3925, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_l = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_lensing_noise_at_ell", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3925, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_lensing_noise_at_ell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_326get_lensing_noise_at_ell(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_l);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_326get_lensing_noise_at_ell(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_l) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_lensing_noise_at_ell", 1);

  /* "class-sz/python/classy.pyx":3926
 * 
 *     def get_lensing_noise_at_ell(self,l):
 *         return get_lensing_noise_at_ell(l,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_te_of_m500c_at_z_lee(self,m,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_l); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3926, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_lensing_noise_at_ell(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3925
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 *     def get_lensing_noise_at_ell(self,l):             # <<<<<<<<<<<<<<
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_lensing_noise_at_ell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3928
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 *     def get_te_of_m500c_at_z_lee(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_329get_te_of_m500c_at_z_lee(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_329get_te_of_m500c_at_z_lee = {"get_te_of_m500c_at_z_lee", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_329get_te_of_m500c_at_z_lee, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_329get_te_of_m500c_at_z_lee(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_te_of_m500c_at_z_lee (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3928, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3928, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_te_of_m500c_at_z_lee", 1, 2, 2, 1); __PYX_ERR(0, 3928, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_te_of_m500c_at_z_lee") < 0)) __PYX_ERR(0, 3928, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_te_of_m500c_at_z_lee", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3928, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_te_of_m500c_at_z_lee", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_328get_te_of_m500c_at_z_lee(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_328get_te_of_m500c_at_z_lee(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_te_of_m500c_at_z_lee", 1);

  /* "class-sz/python/classy.pyx":3929
 * 
 *     def get_te_of_m500c_at_z_lee(self,m,z):
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_f_tinker10_at_nu_and_z(self,nu,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3929, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3929, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_te_of_m500c_at_z_lee(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3928
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 *     def get_te_of_m500c_at_z_lee(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_te_of_m500c_at_z_lee", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3931
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 *     def get_f_tinker10_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_331get_f_tinker10_at_nu_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_331get_f_tinker10_at_nu_and_z = {"get_f_tinker10_at_nu_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_331get_f_tinker10_at_nu_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_331get_f_tinker10_at_nu_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_nu = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_f_tinker10_at_nu_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nu,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3931, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3931, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_f_tinker10_at_nu_and_z", 1, 2, 2, 1); __PYX_ERR(0, 3931, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_f_tinker10_at_nu_and_z") < 0)) __PYX_ERR(0, 3931, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_nu = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_f_tinker10_at_nu_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3931, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_f_tinker10_at_nu_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_330get_f_tinker10_at_nu_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_nu, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_330get_f_tinker10_at_nu_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nu, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_f_tinker10_at_nu_and_z", 1);

  /* "class-sz/python/classy.pyx":3932
 * 
 *     def get_f_tinker10_at_nu_and_z(self,nu,z):
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_f_tinker08_at_nu_and_z(self,nu,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_nu); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3932, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3932, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_f_tinker10_at_nu_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3931
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 *     def get_f_tinker10_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_f_tinker10_at_nu_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3934
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 *     def get_f_tinker08_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker08_at_nu_and_z(nu,z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_333get_f_tinker08_at_nu_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_333get_f_tinker08_at_nu_and_z = {"get_f_tinker08_at_nu_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_333get_f_tinker08_at_nu_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_333get_f_tinker08_at_nu_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_nu = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_f_tinker08_at_nu_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nu,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3934, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3934, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_f_tinker08_at_nu_and_z", 1, 2, 2, 1); __PYX_ERR(0, 3934, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_f_tinker08_at_nu_and_z") < 0)) __PYX_ERR(0, 3934, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_nu = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_f_tinker08_at_nu_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3934, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_f_tinker08_at_nu_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_332get_f_tinker08_at_nu_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_nu, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_332get_f_tinker08_at_nu_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_nu, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_f_tinker08_at_nu_and_z", 1);

  /* "class-sz/python/classy.pyx":3935
 * 
 *     def get_f_tinker08_at_nu_and_z(self,nu,z):
 *         return get_f_tinker08_at_nu_and_z(nu,z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_nu); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3935, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3935, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_f_tinker08_at_nu_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3934
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 *     def get_f_tinker08_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker08_at_nu_and_z(nu,z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_f_tinker08_at_nu_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3938
 * 
 * 
 *     def get_T10_alpha_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_335get_T10_alpha_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_335get_T10_alpha_at_z = {"get_T10_alpha_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_335get_T10_alpha_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_335get_T10_alpha_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_T10_alpha_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3938, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_T10_alpha_at_z") < 0)) __PYX_ERR(0, 3938, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_T10_alpha_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3938, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_T10_alpha_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_334get_T10_alpha_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_334get_T10_alpha_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_T10_alpha_at_z", 1);

  /* "class-sz/python/classy.pyx":3939
 * 
 *     def get_T10_alpha_at_z(self,z):
 *         return get_T10_alpha_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_dndlnM_at_z_and_M(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3939, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_T10_alpha_at_z(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3938
 * 
 * 
 *     def get_T10_alpha_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_T10_alpha_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3941
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 *     def get_dndlnM_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 * 
 *         r = get_dndlnM_at_z_and_M(z,m,&self.tsz)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_337get_dndlnM_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_337get_dndlnM_at_z_and_M = {"get_dndlnM_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_337get_dndlnM_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_337get_dndlnM_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dndlnM_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3941, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3941, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_dndlnM_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 3941, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dndlnM_at_z_and_M") < 0)) __PYX_ERR(0, 3941, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dndlnM_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3941, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dndlnM_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_336get_dndlnM_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_336get_dndlnM_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  double __pyx_v_r;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dndlnM_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":3943
 *     def get_dndlnM_at_z_and_M(self,z,m):
 * 
 *         r = get_dndlnM_at_z_and_M(z,m,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *         return r
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3943, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 3943, __pyx_L1_error)
  __pyx_v_r = get_dndlnM_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz));

  /* "class-sz/python/classy.pyx":3945
 *         r = get_dndlnM_at_z_and_M(z,m,&self.tsz)
 * 
 *         return r             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_r); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3941
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 *     def get_dndlnM_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 * 
 *         r = get_dndlnM_at_z_and_M(z,m,&self.tsz)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_dndlnM_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":3948
 * 
 * 
 *     def get_dndlnm(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of dndlnM at given redshifts and masses.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_339get_dndlnm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_338get_dndlnm, "\n        Vectorized computation of dndlnM at given redshifts and masses.\n\n        This method handles both scalar and array inputs for redshifts (z_input) and masses (m_input).\n        It returns dndlnM for each pair of redshift and mass.\n\n        Parameters:\n        z_input (float or np.ndarray): A scalar or 1D array of redshifts.\n        m_input (float or np.ndarray): A scalar or 1D array of masses.\n\n        Returns:\n        np.ndarray: An array of dndlnM values corresponding to the input redshifts and masses.\n\n        Raises:\n        TypeError: If the inputs are not floats or 1D arrays of floats.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_339get_dndlnm = {"get_dndlnm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_339get_dndlnm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_338get_dndlnm};
static PyObject *__pyx_pw_9classy_sz_5Class_339get_dndlnm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_input = 0;
  PyObject *__pyx_v_m_input = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dndlnm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_input,&__pyx_n_s_m_input,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3948, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3948, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_dndlnm", 1, 2, 2, 1); __PYX_ERR(0, 3948, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dndlnm") < 0)) __PYX_ERR(0, 3948, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z_input = values[0];
    __pyx_v_m_input = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dndlnm", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 3948, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dndlnm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_338get_dndlnm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_input, __pyx_v_m_input);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_338get_dndlnm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_m_input) {
  PyObject *__pyx_v_z_broadcasted = NULL;
  PyObject *__pyx_v_m_broadcasted = NULL;
  PyObject *__pyx_v_z_flattened = NULL;
  PyObject *__pyx_v_m_flattened = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dndlnm", 0);
  __Pyx_INCREF(__pyx_v_z_input);
  __Pyx_INCREF(__pyx_v_m_input);

  /* "class-sz/python/classy.pyx":3966
 *         """
 *         # Convert scalar inputs to arrays
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_z_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_z_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":3967
 *         # Convert scalar inputs to arrays
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 *         if isinstance(m_input, (float, np.float64)):
 *             m_input = np.array([m_input], dtype=np.float64)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_z_input);
    __Pyx_GIVEREF(__pyx_v_z_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_z_input)) __PYX_ERR(0, 3967, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 3967, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_z_input, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":3966
 *         """
 *         # Convert scalar inputs to arrays
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 */
  }

  /* "class-sz/python/classy.pyx":3968
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             m_input = np.array([m_input], dtype=np.float64)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_m_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_m_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":3969
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 *             m_input = np.array([m_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         # Ensure inputs are 1D arrays of type float64
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_m_input);
    __Pyx_GIVEREF(__pyx_v_m_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_m_input)) __PYX_ERR(0, 3969, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 3969, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_m_input, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":3968
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             m_input = np.array([m_input], dtype=np.float64)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":3972
 * 
 *         # Ensure inputs are 1D arrays of type float64
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_z_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_6, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3972, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_6, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3972, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 3972, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L10_bool_binop_done:;
  __pyx_t_4 = (!__pyx_t_3);
  if (unlikely(__pyx_t_4)) {

    /* "class-sz/python/classy.pyx":3973
 *         # Ensure inputs are 1D arrays of type float64
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")             # <<<<<<<<<<<<<<
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3973, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3972
 * 
 *         # Ensure inputs are 1D arrays of type float64
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 */
  }

  /* "class-sz/python/classy.pyx":3974
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")
 * 
 */
  __pyx_t_3 = __Pyx_TypeCheck(__pyx_v_m_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __pyx_t_3;
  __pyx_L14_bool_binop_done:;
  __pyx_t_3 = (!__pyx_t_4);
  if (unlikely(__pyx_t_3)) {

    /* "class-sz/python/classy.pyx":3975
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")             # <<<<<<<<<<<<<<
 * 
 *         # Use broadcasting to handle different sizes
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 3975, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":3974
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":3978
 * 
 *         # Use broadcasting to handle different sizes
 *         z_broadcasted, m_broadcasted = np.broadcast_arrays(z_input[:, np.newaxis], m_input)             # <<<<<<<<<<<<<<
 * 
 *         # Flatten the broadcasted arrays for iteration
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_broadcast_arrays); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_newaxis); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_slice__5);
  __Pyx_GIVEREF(__pyx_slice__5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_slice__5)) __PYX_ERR(0, 3978, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_7)) __PYX_ERR(0, 3978, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_z_input, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3978, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_7, __pyx_v_m_input};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
    PyObject* sequence = __pyx_t_5;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3978, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_7);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    #endif
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L17_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_6); if (unlikely(!__pyx_t_7)) goto __pyx_L17_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_6), 2) < 0) __PYX_ERR(0, 3978, __pyx_L1_error)
    __pyx_t_9 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L18_unpacking_done;
    __pyx_L17_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 3978, __pyx_L1_error)
    __pyx_L18_unpacking_done:;
  }
  __pyx_v_z_broadcasted = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_m_broadcasted = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":3981
 * 
 *         # Flatten the broadcasted arrays for iteration
 *         z_flattened = z_broadcasted.flatten()             # <<<<<<<<<<<<<<
 *         m_flattened = m_broadcasted.flatten()
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_broadcasted, __pyx_n_s_flatten); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_z_flattened = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":3982
 *         # Flatten the broadcasted arrays for iteration
 *         z_flattened = z_broadcasted.flatten()
 *         m_flattened = m_broadcasted.flatten()             # <<<<<<<<<<<<<<
 * 
 *         # Initialize result array
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_broadcasted, __pyx_n_s_flatten); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_m_flattened = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":3985
 * 
 *         # Initialize result array
 *         result = np.empty(z_flattened.shape[0], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         # Compute dndlnM for each pair
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_flattened, __pyx_n_s_shape); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 3985, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":3988
 * 
 *         # Compute dndlnM for each pair
 *         for i in range(z_flattened.shape[0]):             # <<<<<<<<<<<<<<
 *             result[i] = self.get_dndlnM_at_z_and_M(z_flattened[i], m_flattened[i])
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_flattened, __pyx_n_s_shape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_10 = 0;
    __pyx_t_11 = NULL;
  } else {
    __pyx_t_10 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3988, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_11)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3988, __pyx_L1_error)
          #endif
          if (__pyx_t_10 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely((0 < 0))) __PYX_ERR(0, 3988, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3988, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3988, __pyx_L1_error)
          #endif
          if (__pyx_t_10 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely((0 < 0))) __PYX_ERR(0, 3988, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3988, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_11(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3988, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3989
 *         # Compute dndlnM for each pair
 *         for i in range(z_flattened.shape[0]):
 *             result[i] = self.get_dndlnM_at_z_and_M(z_flattened[i], m_flattened[i])             # <<<<<<<<<<<<<<
 * 
 *         # Reshape the result to match the broadcasted shape
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_dndlnM_at_z_and_M); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_z_flattened, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_m_flattened, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_12 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_12, __pyx_t_7, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3989, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_v_result, __pyx_v_i, __pyx_t_1) < 0))) __PYX_ERR(0, 3989, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":3988
 * 
 *         # Compute dndlnM for each pair
 *         for i in range(z_flattened.shape[0]):             # <<<<<<<<<<<<<<
 *             result[i] = self.get_dndlnM_at_z_and_M(z_flattened[i], m_flattened[i])
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":3992
 * 
 *         # Reshape the result to match the broadcasted shape
 *         result = result.reshape(z_broadcasted.shape)             # <<<<<<<<<<<<<<
 * 
 *         return result
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_reshape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_broadcasted, __pyx_n_s_shape); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":3994
 *         result = result.reshape(z_broadcasted.shape)
 * 
 *         return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":3948
 * 
 * 
 *     def get_dndlnm(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of dndlnM at given redshifts and masses.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("classy_sz.Class.get_dndlnm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_z_broadcasted);
  __Pyx_XDECREF(__pyx_v_m_broadcasted);
  __Pyx_XDECREF(__pyx_v_z_flattened);
  __Pyx_XDECREF(__pyx_v_m_flattened);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_z_input);
  __Pyx_XDECREF(__pyx_v_m_input);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4059
 * 
 * 
 *     def get_dcib0dz_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         r = get_dcib0dz_at_z_and_nu(z,nu,&self.tsz)
 *         return r
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_341get_dcib0dz_at_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_341get_dcib0dz_at_z_and_nu = {"get_dcib0dz_at_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_341get_dcib0dz_at_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_341get_dcib0dz_at_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_nu = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dcib0dz_at_z_and_nu (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_nu,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4059, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4059, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_dcib0dz_at_z_and_nu", 1, 2, 2, 1); __PYX_ERR(0, 4059, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dcib0dz_at_z_and_nu") < 0)) __PYX_ERR(0, 4059, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_nu = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dcib0dz_at_z_and_nu", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4059, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dcib0dz_at_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_340get_dcib0dz_at_z_and_nu(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_nu);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_340get_dcib0dz_at_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu) {
  double __pyx_v_r;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dcib0dz_at_z_and_nu", 1);

  /* "class-sz/python/classy.pyx":4060
 * 
 *     def get_dcib0dz_at_z_and_nu(self,z,nu):
 *         r = get_dcib0dz_at_z_and_nu(z,nu,&self.tsz)             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4060, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_nu); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4060, __pyx_L1_error)
  __pyx_v_r = get_dcib0dz_at_z_and_nu(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz));

  /* "class-sz/python/classy.pyx":4061
 *     def get_dcib0dz_at_z_and_nu(self,z,nu):
 *         r = get_dcib0dz_at_z_and_nu(z,nu,&self.tsz)
 *         return r             # <<<<<<<<<<<<<<
 * 
 *     def get_dydz_at_z(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_r); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4059
 * 
 * 
 *     def get_dcib0dz_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         r = get_dcib0dz_at_z_and_nu(z,nu,&self.tsz)
 *         return r
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_dcib0dz_at_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4063
 *         return r
 * 
 *     def get_dydz_at_z(self,z):             # <<<<<<<<<<<<<<
 *         r = get_dydz_at_z(z,&self.tsz)
 *         return r
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_343get_dydz_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_343get_dydz_at_z = {"get_dydz_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_343get_dydz_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_343get_dydz_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dydz_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4063, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dydz_at_z") < 0)) __PYX_ERR(0, 4063, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dydz_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4063, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dydz_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_342get_dydz_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_342get_dydz_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_r;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dydz_at_z", 1);

  /* "class-sz/python/classy.pyx":4064
 * 
 *     def get_dydz_at_z(self,z):
 *         r = get_dydz_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4064, __pyx_L1_error)
  __pyx_v_r = get_dydz_at_z(__pyx_t_1, (&__pyx_v_self->tsz));

  /* "class-sz/python/classy.pyx":4065
 *     def get_dydz_at_z(self,z):
 *         r = get_dydz_at_z(z,&self.tsz)
 *         return r             # <<<<<<<<<<<<<<
 * 
 *     def get_mean_y(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_r); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4063
 *         return r
 * 
 *     def get_dydz_at_z(self,z):             # <<<<<<<<<<<<<<
 *         r = get_dydz_at_z(z,&self.tsz)
 *         return r
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_dydz_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4067
 *         return r
 * 
 *     def get_mean_y(self):             # <<<<<<<<<<<<<<
 *         r = self.tsz.y_monopole
 *         return r
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_345get_mean_y(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_345get_mean_y = {"get_mean_y", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_345get_mean_y, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_345get_mean_y(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_mean_y (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_mean_y", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_mean_y", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_344get_mean_y(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_344get_mean_y(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  double __pyx_v_r;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_mean_y", 1);

  /* "class-sz/python/classy.pyx":4068
 * 
 *     def get_mean_y(self):
 *         r = self.tsz.y_monopole             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_t_1 = __pyx_v_self->tsz.y_monopole;
  __pyx_v_r = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4069
 *     def get_mean_y(self):
 *         r = self.tsz.y_monopole
 *         return r             # <<<<<<<<<<<<<<
 * 
 *     def get_mean_galaxy_bias_at_z(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_r); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4067
 *         return r
 * 
 *     def get_mean_y(self):             # <<<<<<<<<<<<<<
 *         r = self.tsz.y_monopole
 *         return r
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_mean_y", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4071
 *         return r
 * 
 *     def get_mean_galaxy_bias_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_mean_galaxy_bias_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_347get_mean_galaxy_bias_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_347get_mean_galaxy_bias_at_z = {"get_mean_galaxy_bias_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_347get_mean_galaxy_bias_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_347get_mean_galaxy_bias_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_mean_galaxy_bias_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4071, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_mean_galaxy_bias_at_z") < 0)) __PYX_ERR(0, 4071, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_mean_galaxy_bias_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4071, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_mean_galaxy_bias_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_346get_mean_galaxy_bias_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_346get_mean_galaxy_bias_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_mean_galaxy_bias_at_z", 1);

  /* "class-sz/python/classy.pyx":4072
 * 
 *     def get_mean_galaxy_bias_at_z(self,z):
 *         return get_mean_galaxy_bias_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4072, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_mean_galaxy_bias_at_z(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4071
 *         return r
 * 
 *     def get_mean_galaxy_bias_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_mean_galaxy_bias_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_mean_galaxy_bias_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4075
 * 
 * 
 *     def get_gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb):             # <<<<<<<<<<<<<<
 *         r = gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb)
 *         return r
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_349get_gnu_tsz_of_nu_in_ghz(PyObject *__pyx_v_nu_in_ghz, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_349get_gnu_tsz_of_nu_in_ghz = {"get_gnu_tsz_of_nu_in_ghz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_349get_gnu_tsz_of_nu_in_ghz, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_349get_gnu_tsz_of_nu_in_ghz(PyObject *__pyx_v_nu_in_ghz, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_Tcmb = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gnu_tsz_of_nu_in_ghz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_Tcmb,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_Tcmb)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4075, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_gnu_tsz_of_nu_in_ghz") < 0)) __PYX_ERR(0, 4075, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_Tcmb = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_gnu_tsz_of_nu_in_ghz", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4075, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_gnu_tsz_of_nu_in_ghz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_348get_gnu_tsz_of_nu_in_ghz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_nu_in_ghz), __pyx_v_Tcmb);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_348get_gnu_tsz_of_nu_in_ghz(struct __pyx_obj_9classy_sz_Class *__pyx_v_nu_in_ghz, PyObject *__pyx_v_Tcmb) {
  double __pyx_v_r;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_gnu_tsz_of_nu_in_ghz", 1);

  /* "class-sz/python/classy.pyx":4076
 * 
 *     def get_gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb):
 *         r = gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb)             # <<<<<<<<<<<<<<
 *         return r
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(((PyObject *)__pyx_v_nu_in_ghz)); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4076, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_Tcmb); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4076, __pyx_L1_error)
  __pyx_v_r = gnu_tsz_of_nu_in_ghz(__pyx_t_1, __pyx_t_2);

  /* "class-sz/python/classy.pyx":4077
 *     def get_gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb):
 *         r = gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb)
 *         return r             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_r); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4075
 * 
 * 
 *     def get_gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb):             # <<<<<<<<<<<<<<
 *         r = gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb)
 *         return r
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_gnu_tsz_of_nu_in_ghz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4080
 * 
 * 
 *     def get_hmf_counter_term_nmin_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_351get_hmf_counter_term_nmin_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_351get_hmf_counter_term_nmin_at_z = {"get_hmf_counter_term_nmin_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_351get_hmf_counter_term_nmin_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_351get_hmf_counter_term_nmin_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_hmf_counter_term_nmin_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4080, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_hmf_counter_term_nmin_at_z") < 0)) __PYX_ERR(0, 4080, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_hmf_counter_term_nmin_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4080, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_hmf_counter_term_nmin_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_350get_hmf_counter_term_nmin_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_350get_hmf_counter_term_nmin_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_hmf_counter_term_nmin_at_z", 1);

  /* "class-sz/python/classy.pyx":4081
 * 
 *     def get_hmf_counter_term_nmin_at_z(self,z):
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_hmf_counter_term_b1min_at_z(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4081, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_hmf_counter_term_nmin_at_z(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4080
 * 
 * 
 *     def get_hmf_counter_term_nmin_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_hmf_counter_term_nmin_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4083
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b1min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_353get_hmf_counter_term_b1min_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_353get_hmf_counter_term_b1min_at_z = {"get_hmf_counter_term_b1min_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_353get_hmf_counter_term_b1min_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_353get_hmf_counter_term_b1min_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_hmf_counter_term_b1min_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4083, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_hmf_counter_term_b1min_at_z") < 0)) __PYX_ERR(0, 4083, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_hmf_counter_term_b1min_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4083, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_hmf_counter_term_b1min_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_352get_hmf_counter_term_b1min_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_352get_hmf_counter_term_b1min_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_hmf_counter_term_b1min_at_z", 1);

  /* "class-sz/python/classy.pyx":4084
 * 
 *     def get_hmf_counter_term_b1min_at_z(self,z):
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_hmf_counter_term_b2min_at_z(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4084, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_hmf_counter_term_b1min_at_z(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4083
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b1min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_hmf_counter_term_b1min_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4086
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b2min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_355get_hmf_counter_term_b2min_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_355get_hmf_counter_term_b2min_at_z = {"get_hmf_counter_term_b2min_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_355get_hmf_counter_term_b2min_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_355get_hmf_counter_term_b2min_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_hmf_counter_term_b2min_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4086, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_hmf_counter_term_b2min_at_z") < 0)) __PYX_ERR(0, 4086, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_hmf_counter_term_b2min_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4086, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_hmf_counter_term_b2min_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_354get_hmf_counter_term_b2min_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_354get_hmf_counter_term_b2min_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_hmf_counter_term_b2min_at_z", 1);

  /* "class-sz/python/classy.pyx":4087
 * 
 *     def get_hmf_counter_term_b2min_at_z(self,z):
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_gas_density_profile_at_k_M_z(self,l_asked,m_asked,z_asked, normalize = 0):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4087, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_hmf_counter_term_b2min_at_z(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4086
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b2min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_hmf_counter_term_b2min_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4089
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 *     def get_gas_density_profile_at_k_M_z(self,l_asked,m_asked,z_asked, normalize = 0):             # <<<<<<<<<<<<<<
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_357get_gas_density_profile_at_k_M_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_357get_gas_density_profile_at_k_M_z = {"get_gas_density_profile_at_k_M_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_357get_gas_density_profile_at_k_M_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_357get_gas_density_profile_at_k_M_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_l_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_normalize = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gas_density_profile_at_k_M_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_l_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,&__pyx_n_s_normalize,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_0));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4089, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4089, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_density_profile_at_k_M_z", 0, 3, 4, 1); __PYX_ERR(0, 4089, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4089, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_density_profile_at_k_M_z", 0, 3, 4, 2); __PYX_ERR(0, 4089, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4089, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_gas_density_profile_at_k_M_z") < 0)) __PYX_ERR(0, 4089, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_l_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
    __pyx_v_normalize = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_gas_density_profile_at_k_M_z", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4089, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_gas_density_profile_at_k_M_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_356get_gas_density_profile_at_k_M_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_l_asked, __pyx_v_m_asked, __pyx_v_z_asked, __pyx_v_normalize);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_356get_gas_density_profile_at_k_M_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_l_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_normalize) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_gas_density_profile_at_k_M_z", 1);

  /* "class-sz/python/classy.pyx":4090
 * 
 *     def get_gas_density_profile_at_k_M_z(self,l_asked,m_asked,z_asked, normalize = 0):
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_rho_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_l_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4090, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4090, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4090, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_normalize); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4090, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_gas_density_profile_at_k_M_z(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4089
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 *     def get_gas_density_profile_at_k_M_z(self,l_asked,m_asked,z_asked, normalize = 0):             # <<<<<<<<<<<<<<
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_gas_density_profile_at_k_M_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4092
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 *     def get_rho_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_359get_rho_2h_at_r_and_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_359get_rho_2h_at_r_and_m_and_z = {"get_rho_2h_at_r_and_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_359get_rho_2h_at_r_and_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_359get_rho_2h_at_r_and_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_r_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_rho_2h_at_r_and_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_r_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4092, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4092, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_rho_2h_at_r_and_m_and_z", 1, 3, 3, 1); __PYX_ERR(0, 4092, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4092, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_rho_2h_at_r_and_m_and_z", 1, 3, 3, 2); __PYX_ERR(0, 4092, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_rho_2h_at_r_and_m_and_z") < 0)) __PYX_ERR(0, 4092, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_r_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_rho_2h_at_r_and_m_and_z", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4092, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_rho_2h_at_r_and_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_358get_rho_2h_at_r_and_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_r_asked, __pyx_v_m_asked, __pyx_v_z_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_358get_rho_2h_at_r_and_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_rho_2h_at_r_and_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4093
 * 
 *     def get_rho_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):
 *         return get_rho_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_r_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4093, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4093, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4093, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_rho_2h_at_r_and_m_and_z(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4092
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 *     def get_rho_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_rho_2h_at_r_and_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4096
 * 
 * 
 *     def get_P_delta_at_m_and_z_b12(self,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         # this is in ev/cm3, see https://arxiv.org/pdf/2202.02275.pdf
 *         # return get_P_delta_at_m_and_z_b12(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_361get_P_delta_at_m_and_z_b12(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_361get_P_delta_at_m_and_z_b12 = {"get_P_delta_at_m_and_z_b12", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_361get_P_delta_at_m_and_z_b12, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_361get_P_delta_at_m_and_z_b12(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_P_delta_at_m_and_z_b12 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4096, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4096, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_P_delta_at_m_and_z_b12", 1, 2, 2, 1); __PYX_ERR(0, 4096, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_P_delta_at_m_and_z_b12") < 0)) __PYX_ERR(0, 4096, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m_asked = values[0];
    __pyx_v_z_asked = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_P_delta_at_m_and_z_b12", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4096, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_P_delta_at_m_and_z_b12", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_360get_P_delta_at_m_and_z_b12(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m_asked, __pyx_v_z_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_360get_P_delta_at_m_and_z_b12(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked) {
  PyObject *__pyx_v_r200c = NULL;
  PyObject *__pyx_v_f_b = NULL;
  PyObject *__pyx_v_Eh = NULL;
  PyObject *__pyx_v_P200 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_P_delta_at_m_and_z_b12", 1);

  /* "class-sz/python/classy.pyx":4099
 *         # this is in ev/cm3, see https://arxiv.org/pdf/2202.02275.pdf
 *         # return get_P_delta_at_m_and_z_b12(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 *         r200c = self.get_r_delta_of_m_delta_at_z(200,m_asked,z_asked)             # <<<<<<<<<<<<<<
 *         f_b =  self.get_f_b()
 *         Eh = self.Hubble(z_asked)/self.Hubble(0)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_r_delta_of_m_delta_at_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_int_200, __pyx_v_m_asked, __pyx_v_z_asked};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_r200c = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4100
 *         # return get_P_delta_at_m_and_z_b12(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 *         r200c = self.get_r_delta_of_m_delta_at_z(200,m_asked,z_asked)
 *         f_b =  self.get_f_b()             # <<<<<<<<<<<<<<
 *         Eh = self.Hubble(z_asked)/self.Hubble(0)
 *         P200 = m_asked/r200c*f_b*2.61051e-18*(100.*self.ba.h*Eh)**2.
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_f_b); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_f_b = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4101
 *         r200c = self.get_r_delta_of_m_delta_at_z(200,m_asked,z_asked)
 *         f_b =  self.get_f_b()
 *         Eh = self.Hubble(z_asked)/self.Hubble(0)             # <<<<<<<<<<<<<<
 *         P200 = m_asked/r200c*f_b*2.61051e-18*(100.*self.ba.h*Eh)**2.
 *         return P200
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z_asked};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_int_0};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_Eh = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4102
 *         f_b =  self.get_f_b()
 *         Eh = self.Hubble(z_asked)/self.Hubble(0)
 *         P200 = m_asked/r200c*f_b*2.61051e-18*(100.*self.ba.h*Eh)**2.             # <<<<<<<<<<<<<<
 *         return P200
 * 
 */
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_v_m_asked, __pyx_v_r200c); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_3, __pyx_v_f_b); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_float_2_61051eneg_18); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyFloat_FromDouble((100. * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Multiply(__pyx_t_2, __pyx_v_Eh); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Power(__pyx_t_1, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Multiply(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_P200 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4103
 *         Eh = self.Hubble(z_asked)/self.Hubble(0)
 *         P200 = m_asked/r200c*f_b*2.61051e-18*(100.*self.ba.h*Eh)**2.
 *         return P200             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_P200);
  __pyx_r = __pyx_v_P200;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4096
 * 
 * 
 *     def get_P_delta_at_m_and_z_b12(self,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         # this is in ev/cm3, see https://arxiv.org/pdf/2202.02275.pdf
 *         # return get_P_delta_at_m_and_z_b12(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_P_delta_at_m_and_z_b12", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_r200c);
  __Pyx_XDECREF(__pyx_v_f_b);
  __Pyx_XDECREF(__pyx_v_Eh);
  __Pyx_XDECREF(__pyx_v_P200);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4106
 * 
 * 
 *     def get_gas_pressure_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_363get_gas_pressure_2h_at_r_and_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_363get_gas_pressure_2h_at_r_and_m_and_z = {"get_gas_pressure_2h_at_r_and_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_363get_gas_pressure_2h_at_r_and_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_363get_gas_pressure_2h_at_r_and_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_r_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gas_pressure_2h_at_r_and_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_r_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4106, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4106, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_pressure_2h_at_r_and_m_and_z", 1, 3, 3, 1); __PYX_ERR(0, 4106, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4106, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_pressure_2h_at_r_and_m_and_z", 1, 3, 3, 2); __PYX_ERR(0, 4106, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_gas_pressure_2h_at_r_and_m_and_z") < 0)) __PYX_ERR(0, 4106, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_r_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_gas_pressure_2h_at_r_and_m_and_z", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4106, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_gas_pressure_2h_at_r_and_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_362get_gas_pressure_2h_at_r_and_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_r_asked, __pyx_v_m_asked, __pyx_v_z_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_362get_gas_pressure_2h_at_r_and_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_gas_pressure_2h_at_r_and_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4107
 * 
 *     def get_gas_pressure_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_r_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4107, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4107, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4107, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_gas_pressure_2h_at_r_and_m_and_z(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4106
 * 
 * 
 *     def get_gas_pressure_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_gas_pressure_2h_at_r_and_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4109
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):             # <<<<<<<<<<<<<<
 *         if use_pklin == 1:
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_365get_dkappacmbdz_at_l_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_365get_dkappacmbdz_at_l_and_z = {"get_dkappacmbdz_at_l_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_365get_dkappacmbdz_at_l_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_365get_dkappacmbdz_at_l_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_l = 0;
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_use_pklin = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dkappacmbdz_at_l_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_l,&__pyx_n_s_z,&__pyx_n_s_use_pklin,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_0));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4109, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4109, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_dkappacmbdz_at_l_and_z", 0, 2, 3, 1); __PYX_ERR(0, 4109, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_pklin);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4109, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dkappacmbdz_at_l_and_z") < 0)) __PYX_ERR(0, 4109, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_l = values[0];
    __pyx_v_z = values[1];
    __pyx_v_use_pklin = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dkappacmbdz_at_l_and_z", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4109, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dkappacmbdz_at_l_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_364get_dkappacmbdz_at_l_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_l, __pyx_v_z, __pyx_v_use_pklin);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_364get_dkappacmbdz_at_l_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_l, PyObject *__pyx_v_z, PyObject *__pyx_v_use_pklin) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dkappacmbdz_at_l_and_z", 1);

  /* "class-sz/python/classy.pyx":4110
 * 
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):
 *         if use_pklin == 1:             # <<<<<<<<<<<<<<
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 *         else:
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_use_pklin, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4110, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4111
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):
 *         if use_pklin == 1:
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 *         else:
 *             return get_dkappacmbdz_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_l); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4111, __pyx_L1_error)
    __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4111, __pyx_L1_error)
    __pyx_t_4 = PyFloat_FromDouble(get_dkappacmbdz_pklin_at_l_and_z(__pyx_t_2, __pyx_t_3, (&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":4110
 * 
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):
 *         if use_pklin == 1:             # <<<<<<<<<<<<<<
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":4113
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 *         else:
 *             return get_dkappacmbdz_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_dydzdlnm_at_z_and_m(self,z,m,l=0):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_l); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4113, __pyx_L1_error)
    __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4113, __pyx_L1_error)
    __pyx_t_4 = PyFloat_FromDouble(get_dkappacmbdz_at_l_and_z(__pyx_t_3, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4113, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "class-sz/python/classy.pyx":4109
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):             # <<<<<<<<<<<<<<
 *         if use_pklin == 1:
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_dkappacmbdz_at_l_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4115
 *             return get_dkappacmbdz_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_dydzdlnm_at_z_and_m(self,z,m,l=0):             # <<<<<<<<<<<<<<
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_367get_dydzdlnm_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_367get_dydzdlnm_at_z_and_m = {"get_dydzdlnm_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_367get_dydzdlnm_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_367get_dydzdlnm_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_l = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dydzdlnm_at_z_and_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,&__pyx_n_s_l,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_0));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4115, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4115, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_dydzdlnm_at_z_and_m", 0, 2, 3, 1); __PYX_ERR(0, 4115, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4115, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dydzdlnm_at_z_and_m") < 0)) __PYX_ERR(0, 4115, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
    __pyx_v_l = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dydzdlnm_at_z_and_m", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4115, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dydzdlnm_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_366get_dydzdlnm_at_z_and_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m, __pyx_v_l);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_366get_dydzdlnm_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_l) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dydzdlnm_at_z_and_m", 1);

  /* "class-sz/python/classy.pyx":4116
 * 
 *     def get_dydzdlnm_at_z_and_m(self,z,m,l=0):
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_l); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4116, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4116, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4116, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_dyldzdlnm_at_l_z_and_m(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4115
 *             return get_dkappacmbdz_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_dydzdlnm_at_z_and_m(self,z,m,l=0):             # <<<<<<<<<<<<<<
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_dydzdlnm_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4118
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_369get_c_delta_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_369get_c_delta_at_m_and_z = {"get_c_delta_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_369get_c_delta_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_369get_c_delta_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_delta_def = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_c_delta_at_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,&__pyx_n_s_delta_def,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4118, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4118, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c_delta_at_m_and_z", 1, 3, 3, 1); __PYX_ERR(0, 4118, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delta_def)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4118, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c_delta_at_m_and_z", 1, 3, 3, 2); __PYX_ERR(0, 4118, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_c_delta_at_m_and_z") < 0)) __PYX_ERR(0, 4118, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
    __pyx_v_delta_def = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_c_delta_at_m_and_z", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4118, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_c_delta_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_368get_c_delta_at_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z, __pyx_v_delta_def);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_368get_c_delta_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z, PyObject *__pyx_v_delta_def) {
  PyObject *__pyx_v_c_delta = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_c_delta_at_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4119
 * 
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):
 *         if delta_def == 0:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 *         if delta_def == 1:
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4119, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4120
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):
 *         if delta_def == 0:
 *           c_delta = self.get_c200m_at_m_and_z(m,z)             # <<<<<<<<<<<<<<
 *         if delta_def == 1:
 *           c_delta = self.get_c200c_at_m_and_z(m,z)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_c200m_at_m_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_m, __pyx_v_z};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_c_delta = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4119
 * 
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):
 *         if delta_def == 0:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 *         if delta_def == 1:
 */
  }

  /* "class-sz/python/classy.pyx":4121
 *         if delta_def == 0:
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 *         if delta_def == 1:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_c200c_at_m_and_z(m,z)
 *         if delta_def == 2:
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4121, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4122
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 *         if delta_def == 1:
 *           c_delta = self.get_c200c_at_m_and_z(m,z)             # <<<<<<<<<<<<<<
 *         if delta_def == 2:
 *           c_delta = self.get_c500c_at_m_and_z(m,z)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_c200c_at_m_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_m, __pyx_v_z};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4122, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_c_delta, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4121
 *         if delta_def == 0:
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 *         if delta_def == 1:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_c200c_at_m_and_z(m,z)
 *         if delta_def == 2:
 */
  }

  /* "class-sz/python/classy.pyx":4123
 *         if delta_def == 1:
 *           c_delta = self.get_c200c_at_m_and_z(m,z)
 *         if delta_def == 2:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_c500c_at_m_and_z(m,z)
 *         if delta_def == 3:
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_2, 2, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4123, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4124
 *           c_delta = self.get_c200c_at_m_and_z(m,z)
 *         if delta_def == 2:
 *           c_delta = self.get_c500c_at_m_and_z(m,z)             # <<<<<<<<<<<<<<
 *         if delta_def == 3:
 *           c_delta = self.get_cvir_of_mvir_at_z(m,z)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_c500c_at_m_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_m, __pyx_v_z};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_c_delta, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4123
 *         if delta_def == 1:
 *           c_delta = self.get_c200c_at_m_and_z(m,z)
 *         if delta_def == 2:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_c500c_at_m_and_z(m,z)
 *         if delta_def == 3:
 */
  }

  /* "class-sz/python/classy.pyx":4125
 *         if delta_def == 2:
 *           c_delta = self.get_c500c_at_m_and_z(m,z)
 *         if delta_def == 3:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_cvir_of_mvir_at_z(m,z)
 *         return c_delta
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_3, 3, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4125, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4126
 *           c_delta = self.get_c500c_at_m_and_z(m,z)
 *         if delta_def == 3:
 *           c_delta = self.get_cvir_of_mvir_at_z(m,z)             # <<<<<<<<<<<<<<
 *         return c_delta
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_cvir_of_mvir_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_m, __pyx_v_z};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_c_delta, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4125
 *         if delta_def == 2:
 *           c_delta = self.get_c500c_at_m_and_z(m,z)
 *         if delta_def == 3:             # <<<<<<<<<<<<<<
 *           c_delta = self.get_cvir_of_mvir_at_z(m,z)
 *         return c_delta
 */
  }

  /* "class-sz/python/classy.pyx":4127
 *         if delta_def == 3:
 *           c_delta = self.get_cvir_of_mvir_at_z(m,z)
 *         return c_delta             # <<<<<<<<<<<<<<
 * 
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_c_delta)) { __Pyx_RaiseUnboundLocalError("c_delta"); __PYX_ERR(0, 4127, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_v_c_delta);
  __pyx_r = __pyx_v_c_delta;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4118
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_c_delta_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_c_delta);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4129
 *         return c_delta
 * 
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           Omega_m = self.get_Omega_m_at_z(z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_371get_delta_from_delta_def_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_371get_delta_from_delta_def_at_z = {"get_delta_from_delta_def_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_371get_delta_from_delta_def_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_371get_delta_from_delta_def_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_delta_def = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_delta_from_delta_def_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delta_def,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delta_def)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4129, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4129, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_delta_from_delta_def_at_z", 1, 2, 2, 1); __PYX_ERR(0, 4129, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_delta_from_delta_def_at_z") < 0)) __PYX_ERR(0, 4129, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_delta_def = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_delta_from_delta_def_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4129, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_delta_from_delta_def_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_370get_delta_from_delta_def_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_delta_def, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_370get_delta_from_delta_def_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_delta_def, PyObject *__pyx_v_z) {
  PyObject *__pyx_v_Omega_m = NULL;
  PyObject *__pyx_v_delta = NULL;
  PyObject *__pyx_v_Delta_c = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_delta_from_delta_def_at_z", 1);

  /* "class-sz/python/classy.pyx":4130
 * 
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):
 *         if delta_def == 0:             # <<<<<<<<<<<<<<
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           delta = 200.*Omega_m
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4130, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4131
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):
 *         if delta_def == 0:
 *           Omega_m = self.get_Omega_m_at_z(z)             # <<<<<<<<<<<<<<
 *           delta = 200.*Omega_m
 *         if delta_def == 1:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_Omega_m_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_z};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_Omega_m = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4132
 *         if delta_def == 0:
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           delta = 200.*Omega_m             # <<<<<<<<<<<<<<
 *         if delta_def == 1:
 *           delta = 200.
 */
    __pyx_t_2 = PyNumber_Multiply(__pyx_float_200_, __pyx_v_Omega_m); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_delta = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4130
 * 
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):
 *         if delta_def == 0:             # <<<<<<<<<<<<<<
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           delta = 200.*Omega_m
 */
  }

  /* "class-sz/python/classy.pyx":4133
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           delta = 200.*Omega_m
 *         if delta_def == 1:             # <<<<<<<<<<<<<<
 *           delta = 200.
 *         if delta_def == 2:
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4133, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4134
 *           delta = 200.*Omega_m
 *         if delta_def == 1:
 *           delta = 200.             # <<<<<<<<<<<<<<
 *         if delta_def == 2:
 *           delta = 500.
 */
    __Pyx_INCREF(__pyx_float_200_);
    __Pyx_XDECREF_SET(__pyx_v_delta, __pyx_float_200_);

    /* "class-sz/python/classy.pyx":4133
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           delta = 200.*Omega_m
 *         if delta_def == 1:             # <<<<<<<<<<<<<<
 *           delta = 200.
 *         if delta_def == 2:
 */
  }

  /* "class-sz/python/classy.pyx":4135
 *         if delta_def == 1:
 *           delta = 200.
 *         if delta_def == 2:             # <<<<<<<<<<<<<<
 *           delta = 500.
 *         if delta_def == 3:
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_2, 2, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4135, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4136
 *           delta = 200.
 *         if delta_def == 2:
 *           delta = 500.             # <<<<<<<<<<<<<<
 *         if delta_def == 3:
 *           Omega_m = self.get_Omega_m_at_z(z)
 */
    __Pyx_INCREF(__pyx_float_500_);
    __Pyx_XDECREF_SET(__pyx_v_delta, __pyx_float_500_);

    /* "class-sz/python/classy.pyx":4135
 *         if delta_def == 1:
 *           delta = 200.
 *         if delta_def == 2:             # <<<<<<<<<<<<<<
 *           delta = 500.
 *         if delta_def == 3:
 */
  }

  /* "class-sz/python/classy.pyx":4137
 *         if delta_def == 2:
 *           delta = 500.
 *         if delta_def == 3:             # <<<<<<<<<<<<<<
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           Delta_c = self.get_Delta_c_of_Omega_m(Omega_m)
 */
  __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_delta_def, __pyx_int_3, 3, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4137, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4138
 *           delta = 500.
 *         if delta_def == 3:
 *           Omega_m = self.get_Omega_m_at_z(z)             # <<<<<<<<<<<<<<
 *           Delta_c = self.get_Delta_c_of_Omega_m(Omega_m)
 *           delta = Delta_c
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_Omega_m_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_z};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_Omega_m, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4139
 *         if delta_def == 3:
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           Delta_c = self.get_Delta_c_of_Omega_m(Omega_m)             # <<<<<<<<<<<<<<
 *           delta = Delta_c
 *         return delta
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_Delta_c_of_Omega_m); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_Omega_m};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_Delta_c = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":4140
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           Delta_c = self.get_Delta_c_of_Omega_m(Omega_m)
 *           delta = Delta_c             # <<<<<<<<<<<<<<
 *         return delta
 * 
 */
    __Pyx_INCREF(__pyx_v_Delta_c);
    __Pyx_XDECREF_SET(__pyx_v_delta, __pyx_v_Delta_c);

    /* "class-sz/python/classy.pyx":4137
 *         if delta_def == 2:
 *           delta = 500.
 *         if delta_def == 3:             # <<<<<<<<<<<<<<
 *           Omega_m = self.get_Omega_m_at_z(z)
 *           Delta_c = self.get_Delta_c_of_Omega_m(Omega_m)
 */
  }

  /* "class-sz/python/classy.pyx":4141
 *           Delta_c = self.get_Delta_c_of_Omega_m(Omega_m)
 *           delta = Delta_c
 *         return delta             # <<<<<<<<<<<<<<
 * 
 *     def get_r_delta_of_m_delta_at_z(self,delta,m_delta,z):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_delta)) { __Pyx_RaiseUnboundLocalError("delta"); __PYX_ERR(0, 4141, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_v_delta);
  __pyx_r = __pyx_v_delta;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4129
 *         return c_delta
 * 
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           Omega_m = self.get_Omega_m_at_z(z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_delta_from_delta_def_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_Omega_m);
  __Pyx_XDECREF(__pyx_v_delta);
  __Pyx_XDECREF(__pyx_v_Delta_c);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4143
 *         return delta
 * 
 *     def get_r_delta_of_m_delta_at_z(self,delta,m_delta,z):             # <<<<<<<<<<<<<<
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_373get_r_delta_of_m_delta_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_373get_r_delta_of_m_delta_at_z = {"get_r_delta_of_m_delta_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_373get_r_delta_of_m_delta_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_373get_r_delta_of_m_delta_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_delta = 0;
  PyObject *__pyx_v_m_delta = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_r_delta_of_m_delta_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delta,&__pyx_n_s_m_delta,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delta)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4143, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_delta)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4143, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_r_delta_of_m_delta_at_z", 1, 3, 3, 1); __PYX_ERR(0, 4143, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4143, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_r_delta_of_m_delta_at_z", 1, 3, 3, 2); __PYX_ERR(0, 4143, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_r_delta_of_m_delta_at_z") < 0)) __PYX_ERR(0, 4143, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_delta = values[0];
    __pyx_v_m_delta = values[1];
    __pyx_v_z = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_r_delta_of_m_delta_at_z", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4143, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_r_delta_of_m_delta_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_372get_r_delta_of_m_delta_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_delta, __pyx_v_m_delta, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_372get_r_delta_of_m_delta_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_delta, PyObject *__pyx_v_m_delta, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_r_delta_of_m_delta_at_z", 1);

  /* "class-sz/python/classy.pyx":4144
 * 
 *     def get_r_delta_of_m_delta_at_z(self,delta,m_delta,z):
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)             # <<<<<<<<<<<<<<
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z_asked,m_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Multiply(__pyx_v_m_delta, __pyx_float_3_); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_1, __pyx_float_4_, 4., 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_pi); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_v_delta); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_rho_crit_at_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyFloat_FromDouble((1. / 3.)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Power(__pyx_t_2, __pyx_t_1, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4143
 *         return delta
 * 
 *     def get_r_delta_of_m_delta_at_z(self,delta,m_delta,z):             # <<<<<<<<<<<<<<
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_r_delta_of_m_delta_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4146
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_375get_m200m_to_m200c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_375get_m200m_to_m200c_at_z_and_M = {"get_m200m_to_m200c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_375get_m200m_to_m200c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_375get_m200m_to_m200c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m200m_to_m200c_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_m_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4146, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4146, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m200m_to_m200c_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 4146, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m200m_to_m200c_at_z_and_M") < 0)) __PYX_ERR(0, 4146, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z_asked = values[0];
    __pyx_v_m_asked = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m200m_to_m200c_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4146, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m200m_to_m200c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_374get_m200m_to_m200c_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_m_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_374get_m200m_to_m200c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_m_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m200m_to_m200c_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":4147
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z_asked,m_asked):
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_normalization_gas_density_profile(self,z_asked,m_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4147, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4147, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m200m_to_m200c_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4146
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m200m_to_m200c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4149
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 *     def get_normalization_gas_density_profile(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_377get_normalization_gas_density_profile(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_377get_normalization_gas_density_profile = {"get_normalization_gas_density_profile", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_377get_normalization_gas_density_profile, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_377get_normalization_gas_density_profile(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_normalization_gas_density_profile (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_m_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4149, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4149, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_normalization_gas_density_profile", 1, 2, 2, 1); __PYX_ERR(0, 4149, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_normalization_gas_density_profile") < 0)) __PYX_ERR(0, 4149, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z_asked = values[0];
    __pyx_v_m_asked = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_normalization_gas_density_profile", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4149, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_normalization_gas_density_profile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_376get_normalization_gas_density_profile(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_m_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_376get_normalization_gas_density_profile(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_m_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_normalization_gas_density_profile", 1);

  /* "class-sz/python/classy.pyx":4150
 * 
 *     def get_normalization_gas_density_profile(self,z_asked,m_asked):
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_m_to_xout_at_z_and_m(self,z_asked,m_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4150, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4150, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_normalization_gas_density_profile(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4149
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 *     def get_normalization_gas_density_profile(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_normalization_gas_density_profile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4152
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 *     def get_m_to_xout_at_z_and_m(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_379get_m_to_xout_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_379get_m_to_xout_at_z_and_m = {"get_m_to_xout_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_379get_m_to_xout_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_379get_m_to_xout_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m_to_xout_at_z_and_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_m_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4152, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4152, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m_to_xout_at_z_and_m", 1, 2, 2, 1); __PYX_ERR(0, 4152, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m_to_xout_at_z_and_m") < 0)) __PYX_ERR(0, 4152, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z_asked = values[0];
    __pyx_v_m_asked = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m_to_xout_at_z_and_m", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4152, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m_to_xout_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_378get_m_to_xout_at_z_and_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_m_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_378get_m_to_xout_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_m_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m_to_xout_at_z_and_m", 1);

  /* "class-sz/python/classy.pyx":4153
 * 
 *     def get_m_to_xout_at_z_and_m(self,z_asked,m_asked):
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_c200m_at_m_and_z(self,m,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4153, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4153, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m_to_xout_at_z_and_m(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4152
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 *     def get_m_to_xout_at_z_and_m(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m_to_xout_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4155
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_381get_c200m_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_381get_c200m_at_m_and_z = {"get_c200m_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_381get_c200m_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_381get_c200m_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_c200m_at_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4155, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4155, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c200m_at_m_and_z", 1, 2, 2, 1); __PYX_ERR(0, 4155, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_c200m_at_m_and_z") < 0)) __PYX_ERR(0, 4155, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_c200m_at_m_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4155, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_c200m_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_380get_c200m_at_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_380get_c200m_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_c200m_at_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4156
 * 
 *     def get_c200m_at_m_and_z(self,m,z):
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_c200c_at_m_and_z(self,m,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4156, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4156, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_c200m_at_m_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4155
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_c200m_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4158
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_383get_c200c_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_383get_c200c_at_m_and_z = {"get_c200c_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_383get_c200c_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_383get_c200c_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_c200c_at_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4158, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4158, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c200c_at_m_and_z", 1, 2, 2, 1); __PYX_ERR(0, 4158, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_c200c_at_m_and_z") < 0)) __PYX_ERR(0, 4158, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_c200c_at_m_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4158, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_c200c_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_382get_c200c_at_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_382get_c200c_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_c200c_at_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4159
 * 
 *     def get_c200c_at_m_and_z(self,m,z):
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_c500c_at_m_and_z(self,m,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4159, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4159, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_c200c_at_m_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4158
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_c200c_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4161
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c500c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_385get_c500c_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_385get_c500c_at_m_and_z = {"get_c500c_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_385get_c500c_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_385get_c500c_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_c500c_at_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4161, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4161, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c500c_at_m_and_z", 1, 2, 2, 1); __PYX_ERR(0, 4161, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_c500c_at_m_and_z") < 0)) __PYX_ERR(0, 4161, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_c500c_at_m_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4161, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_c500c_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_384get_c500c_at_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_384get_c500c_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_c500c_at_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4162
 * 
 *     def get_c500c_at_m_and_z(self,m,z):
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_c200m_at_m_and_z_D08(self,M,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4162, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4162, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_c500c_at_m_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4161
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c500c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_c500c_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4164
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_387get_c200m_at_m_and_z_D08(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_387get_c200m_at_m_and_z_D08 = {"get_c200m_at_m_and_z_D08", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_387get_c200m_at_m_and_z_D08, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_387get_c200m_at_m_and_z_D08(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_M = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_c200m_at_m_and_z_D08 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_M,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4164, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4164, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c200m_at_m_and_z_D08", 1, 2, 2, 1); __PYX_ERR(0, 4164, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_c200m_at_m_and_z_D08") < 0)) __PYX_ERR(0, 4164, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_M = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_c200m_at_m_and_z_D08", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4164, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_c200m_at_m_and_z_D08", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_386get_c200m_at_m_and_z_D08(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_M, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_386get_c200m_at_m_and_z_D08(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_M, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_c200m_at_m_and_z_D08", 1);

  /* "class-sz/python/classy.pyx":4165
 * 
 *     def get_c200m_at_m_and_z_D08(self,M,z):
 *         return get_c200m_at_m_and_z_D08(M,z)             # <<<<<<<<<<<<<<
 * 
 *     def get_c200c_at_m_and_z_D08(self,M,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_M); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4165, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4165, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_c200m_at_m_and_z_D08(__pyx_t_1, __pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4164
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_c200m_at_m_and_z_D08", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4167
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_389get_c200c_at_m_and_z_D08(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_389get_c200c_at_m_and_z_D08 = {"get_c200c_at_m_and_z_D08", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_389get_c200c_at_m_and_z_D08, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_389get_c200c_at_m_and_z_D08(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_M = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_c200c_at_m_and_z_D08 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_M,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4167, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4167, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c200c_at_m_and_z_D08", 1, 2, 2, 1); __PYX_ERR(0, 4167, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_c200c_at_m_and_z_D08") < 0)) __PYX_ERR(0, 4167, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_M = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_c200c_at_m_and_z_D08", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4167, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_c200c_at_m_and_z_D08", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_388get_c200c_at_m_and_z_D08(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_M, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_388get_c200c_at_m_and_z_D08(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_M, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_c200c_at_m_and_z_D08", 1);

  /* "class-sz/python/classy.pyx":4168
 * 
 *     def get_c200c_at_m_and_z_D08(self,M,z):
 *         return get_c200c_at_m_and_z_D08(M,z)             # <<<<<<<<<<<<<<
 * 
 *     def get_c200c_at_m_and_z_B13(self,M,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_M); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4168, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4168, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_c200c_at_m_and_z_D08(__pyx_t_1, __pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4167
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_c200c_at_m_and_z_D08", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4170
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_B13(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_391get_c200c_at_m_and_z_B13(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_391get_c200c_at_m_and_z_B13 = {"get_c200c_at_m_and_z_B13", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_391get_c200c_at_m_and_z_B13, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_391get_c200c_at_m_and_z_B13(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_M = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_c200c_at_m_and_z_B13 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_M,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4170, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4170, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_c200c_at_m_and_z_B13", 1, 2, 2, 1); __PYX_ERR(0, 4170, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_c200c_at_m_and_z_B13") < 0)) __PYX_ERR(0, 4170, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_M = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_c200c_at_m_and_z_B13", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4170, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_c200c_at_m_and_z_B13", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_390get_c200c_at_m_and_z_B13(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_M, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_390get_c200c_at_m_and_z_B13(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_M, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_c200c_at_m_and_z_B13", 1);

  /* "class-sz/python/classy.pyx":4171
 * 
 *     def get_c200c_at_m_and_z_B13(self,M,z):
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_f_b(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_M); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4171, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4171, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_c200c_at_m_and_z_B13(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4170
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_B13(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_c200c_at_m_and_z_B13", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4173
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 *     def get_f_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_393get_f_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_393get_f_b = {"get_f_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_393get_f_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_393get_f_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_f_b (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_f_b", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_f_b", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_392get_f_b(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_392get_f_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_f_b", 1);

  /* "class-sz/python/classy.pyx":4174
 * 
 *     def get_f_b(self):
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0             # <<<<<<<<<<<<<<
 * 
 *     def get_f_free(self):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->tsz.Omega_m_0 == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 4174, __pyx_L1_error)
  }
  __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->ba.Omega0_b / __pyx_v_self->tsz.Omega_m_0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4173
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 *     def get_f_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_f_b", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4176
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 *     def get_f_free(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.f_free
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_395get_f_free(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_395get_f_free = {"get_f_free", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_395get_f_free, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_395get_f_free(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_f_free (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_f_free", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_f_free", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_394get_f_free(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_394get_f_free(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_f_free", 1);

  /* "class-sz/python/classy.pyx":4177
 * 
 *     def get_f_free(self):
 *         return self.tsz.f_free             # <<<<<<<<<<<<<<
 * 
 *     def get_mu_e(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.f_free); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4176
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 *     def get_f_free(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.f_free
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_f_free", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4179
 *         return self.tsz.f_free
 * 
 *     def get_mu_e(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.mu_e
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_397get_mu_e(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_397get_mu_e = {"get_mu_e", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_397get_mu_e, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_397get_mu_e(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_mu_e (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_mu_e", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_mu_e", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_396get_mu_e(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_396get_mu_e(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_mu_e", 1);

  /* "class-sz/python/classy.pyx":4180
 * 
 *     def get_mu_e(self):
 *         return self.tsz.mu_e             # <<<<<<<<<<<<<<
 * 
 *     def get_Omega_m_0(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.mu_e); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4179
 *         return self.tsz.f_free
 * 
 *     def get_mu_e(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.mu_e
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_mu_e", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4182
 *         return self.tsz.mu_e
 * 
 *     def get_Omega_m_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_399get_Omega_m_0(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_399get_Omega_m_0 = {"get_Omega_m_0", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_399get_Omega_m_0, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_399get_Omega_m_0(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_Omega_m_0 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_Omega_m_0", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_Omega_m_0", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_398get_Omega_m_0(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_398get_Omega_m_0(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_Omega_m_0", 1);

  /* "class-sz/python/classy.pyx":4183
 * 
 *     def get_Omega_m_0(self):
 *         return self.tsz.Omega_m_0             # <<<<<<<<<<<<<<
 *     def get_Omega_r_0(self):
 *         return self.tsz.Omega_r_0
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.Omega_m_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4182
 *         return self.tsz.mu_e
 * 
 *     def get_Omega_m_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_Omega_m_0", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4184
 *     def get_Omega_m_0(self):
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_r_0
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_401get_Omega_r_0(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_401get_Omega_r_0 = {"get_Omega_r_0", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_401get_Omega_r_0, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_401get_Omega_r_0(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_Omega_r_0 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_Omega_r_0", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_Omega_r_0", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_400get_Omega_r_0(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_400get_Omega_r_0(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_Omega_r_0", 1);

  /* "class-sz/python/classy.pyx":4185
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):
 *         return self.tsz.Omega_r_0             # <<<<<<<<<<<<<<
 * 
 *     def get_m_nfw(self,x):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.Omega_r_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4184
 *     def get_Omega_m_0(self):
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_r_0
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_Omega_r_0", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4187
 *         return self.tsz.Omega_r_0
 * 
 *     def get_m_nfw(self,x):             # <<<<<<<<<<<<<<
 *         return m_nfw(x)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_403get_m_nfw(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_403get_m_nfw = {"get_m_nfw", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_403get_m_nfw, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_403get_m_nfw(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_x = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m_nfw (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4187, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m_nfw") < 0)) __PYX_ERR(0, 4187, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_x = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m_nfw", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4187, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m_nfw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_402get_m_nfw(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_x);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_402get_m_nfw(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m_nfw", 1);

  /* "class-sz/python/classy.pyx":4188
 * 
 *     def get_m_nfw(self,x):
 *         return m_nfw(x)             # <<<<<<<<<<<<<<
 * 
 *     def get_rho_crit_at_z(self,z_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4188, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(m_nfw(__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4187
 *         return self.tsz.Omega_r_0
 * 
 *     def get_m_nfw(self,x):             # <<<<<<<<<<<<<<
 *         return m_nfw(x)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_m_nfw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4190
 *         return m_nfw(x)
 * 
 *     def get_rho_crit_at_z(self,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_crit_at_z(z_asked,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_405get_rho_crit_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_405get_rho_crit_at_z = {"get_rho_crit_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_405get_rho_crit_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_405get_rho_crit_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_rho_crit_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4190, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_rho_crit_at_z") < 0)) __PYX_ERR(0, 4190, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z_asked = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_rho_crit_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4190, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_rho_crit_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_404get_rho_crit_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_404get_rho_crit_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_rho_crit_at_z", 1);

  /* "class-sz/python/classy.pyx":4191
 * 
 *     def get_rho_crit_at_z(self,z_asked):
 *         return get_rho_crit_at_z(z_asked,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4191, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_rho_crit_at_z(__pyx_t_1, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4190
 *         return m_nfw(x)
 * 
 *     def get_rho_crit_at_z(self,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_crit_at_z(z_asked,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_rho_crit_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4194
 * 
 * 
 *     def get_pkl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the linear power spectrum at a given scale and redshift.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_407get_pkl_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_406get_pkl_unvectorized, "\n        Compute the linear power spectrum at a given scale and redshift.\n         \n        Parameters\n        ----------\n        kh : float\n            The wavenumber in units of h/Mpc.\n        z : float\n            The redshift at which the power spectrum is evaluated.\n\n        Returns\n        -------\n        float\n            The value of the linear power spectrum at the given wavenumber and redshift in (Mpc/h)**3.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_407get_pkl_unvectorized = {"get_pkl_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_407get_pkl_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_406get_pkl_unvectorized};
static PyObject *__pyx_pw_9classy_sz_5Class_407get_pkl_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_kh = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pkl_unvectorized (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4194, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4194, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pkl_unvectorized", 1, 2, 2, 1); __PYX_ERR(0, 4194, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pkl_unvectorized") < 0)) __PYX_ERR(0, 4194, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pkl_unvectorized", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4194, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pkl_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_406get_pkl_unvectorized(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_kh, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_406get_pkl_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh, PyObject *__pyx_v_z) {
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pkl_unvectorized", 1);

  /* "class-sz/python/classy.pyx":4210
 *             The value of the linear power spectrum at the given wavenumber and redshift in (Mpc/h)**3.
 *         """
 *         k = kh*self.ba.h             # <<<<<<<<<<<<<<
 *         return self.pk_lin(k,z)*self.ba.h**3
 * 
 */
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Multiply(__pyx_v_kh, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_k = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4211
 *         """
 *         k = kh*self.ba.h
 *         return self.pk_lin(k,z)*self.ba.h**3             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pk_lin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_k, __pyx_v_z};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyFloat_FromDouble(pow(__pyx_v_self->ba.h, 3.0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4194
 * 
 * 
 *     def get_pkl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the linear power spectrum at a given scale and redshift.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_pkl_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4214
 * 
 * 
 *     def get_pknl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the non-linear power spectrum at a given scale and redshift.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_409get_pknl_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_408get_pknl_unvectorized, "\n        Compute the non-linear power spectrum at a given scale and redshift.\n         \n        Parameters\n        ----------\n        kh : float\n            The wavenumber in units of h/Mpc.\n        z : float\n            The redshift at which the power spectrum is evaluated.\n\n        Returns\n        -------\n        float\n            The value of the non-linear power spectrum at the given wavenumber and redshift in (Mpc/h)**3.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_409get_pknl_unvectorized = {"get_pknl_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_409get_pknl_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_408get_pknl_unvectorized};
static PyObject *__pyx_pw_9classy_sz_5Class_409get_pknl_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_kh = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pknl_unvectorized (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4214, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4214, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pknl_unvectorized", 1, 2, 2, 1); __PYX_ERR(0, 4214, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pknl_unvectorized") < 0)) __PYX_ERR(0, 4214, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pknl_unvectorized", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4214, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pknl_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_408get_pknl_unvectorized(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_kh, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_408get_pknl_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh, PyObject *__pyx_v_z) {
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pknl_unvectorized", 1);

  /* "class-sz/python/classy.pyx":4230
 *             The value of the non-linear power spectrum at the given wavenumber and redshift in (Mpc/h)**3.
 *         """
 *         k = kh*self.ba.h             # <<<<<<<<<<<<<<
 *         return self.pk(k,z)*self.ba.h**3
 * 
 */
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Multiply(__pyx_v_kh, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_k = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4231
 *         """
 *         k = kh*self.ba.h
 *         return self.pk(k,z)*self.ba.h**3             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_pk); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_k, __pyx_v_z};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyFloat_FromDouble(pow(__pyx_v_self->ba.h, 3.0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4214
 * 
 * 
 *     def get_pknl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the non-linear power spectrum at a given scale and redshift.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_pknl_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4234
 * 
 * 
 *     def get_pkl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the linear power spectrum at given wavenumbers and redshifts.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_411get_pkl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_410get_pkl, "\n        Vectorized computation of the linear power spectrum at given wavenumbers and redshifts.\n        \n        Parameters\n        ----------\n        kh_input : float or np.ndarray\n            The wavenumber in units of h/Mpc.\n        z_input : float or np.ndarray\n            The redshift at which the power spectrum is evaluated.\n\n        Returns\n        -------\n        np.ndarray\n            An array of the linear power spectrum values.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_411get_pkl = {"get_pkl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_411get_pkl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_410get_pkl};
static PyObject *__pyx_pw_9classy_sz_5Class_411get_pkl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_kh_input = 0;
  PyObject *__pyx_v_z_input = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pkl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh_input,&__pyx_n_s_z_input,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4234, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4234, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pkl", 1, 2, 2, 1); __PYX_ERR(0, 4234, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pkl") < 0)) __PYX_ERR(0, 4234, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh_input = values[0];
    __pyx_v_z_input = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pkl", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4234, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pkl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_410get_pkl(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_kh_input, __pyx_v_z_input);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4251
 *         """
 *         # Helper function to compute the linear power spectrum for given kh and z
 *         def compute_pkl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk_lin(k, z) * self.ba.h**3
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_7get_pkl_1compute_pkl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_7get_pkl_1compute_pkl = {"compute_pkl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_7get_pkl_1compute_pkl, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_7get_pkl_1compute_pkl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_kh;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("compute_pkl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4251, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4251, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("compute_pkl", 1, 2, 2, 1); __PYX_ERR(0, 4251, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "compute_pkl") < 0)) __PYX_ERR(0, 4251, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_kh == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4251, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4251, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("compute_pkl", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4251, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pkl.compute_pkl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_7get_pkl_compute_pkl(__pyx_self, __pyx_v_kh, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_7get_pkl_compute_pkl(PyObject *__pyx_self, double __pyx_v_kh, double __pyx_v_z) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *__pyx_cur_scope;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *__pyx_outer_scope;
  double __pyx_v_k;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("compute_pkl", 1);
  __pyx_outer_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "class-sz/python/classy.pyx":4252
 *         # Helper function to compute the linear power spectrum for given kh and z
 *         def compute_pkl(double kh, double z):
 *             k = kh * self.ba.h             # <<<<<<<<<<<<<<
 *             return self.pk_lin(k, z) * self.ba.h**3
 * 
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4252, __pyx_L1_error) }
  __pyx_v_k = (__pyx_v_kh * __pyx_cur_scope->__pyx_v_self->ba.h);

  /* "class-sz/python/classy.pyx":4253
 *         def compute_pkl(double kh, double z):
 *             k = kh * self.ba.h
 *             return self.pk_lin(k, z) * self.ba.h**3             # <<<<<<<<<<<<<<
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4253, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_pk_lin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_k); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_3, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4253, __pyx_L1_error) }
  __pyx_t_2 = PyFloat_FromDouble(pow(__pyx_cur_scope->__pyx_v_self->ba.h, 3.0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4251
 *         """
 *         # Helper function to compute the linear power spectrum for given kh and z
 *         def compute_pkl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk_lin(k, z) * self.ba.h**3
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_pkl.compute_pkl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4267
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_7get_pkl_3handle_combinations(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_7get_pkl_3handle_combinations = {"handle_combinations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_7get_pkl_3handle_combinations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_7get_pkl_3handle_combinations(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_kh_vals = 0;
  PyObject *__pyx_v_z_vals = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("handle_combinations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh_vals,&__pyx_n_s_z_vals,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh_vals)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4267, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_vals)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4267, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("handle_combinations", 1, 2, 2, 1); __PYX_ERR(0, 4267, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "handle_combinations") < 0)) __PYX_ERR(0, 4267, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh_vals = values[0];
    __pyx_v_z_vals = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("handle_combinations", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4267, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pkl.handle_combinations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_7get_pkl_2handle_combinations(__pyx_self, __pyx_v_kh_vals, __pyx_v_z_vals);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_7get_pkl_2handle_combinations(PyObject *__pyx_self, PyObject *__pyx_v_kh_vals, PyObject *__pyx_v_z_vals) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *__pyx_cur_scope;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *__pyx_outer_scope;
  Py_ssize_t __pyx_v_kh_len;
  Py_ssize_t __pyx_v_z_len;
  PyObject *__pyx_v_result = NULL;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_j;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  double __pyx_t_12;
  double __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("handle_combinations", 1);
  __pyx_outer_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "class-sz/python/classy.pyx":4268
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):
 *             kh_len = len(kh_vals)             # <<<<<<<<<<<<<<
 *             z_len = len(z_vals)
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_kh_vals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4268, __pyx_L1_error)
  __pyx_v_kh_len = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4269
 *         def handle_combinations(kh_vals, z_vals):
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)             # <<<<<<<<<<<<<<
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 *             for i in range(kh_len):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_z_vals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4269, __pyx_L1_error)
  __pyx_v_z_len = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4270
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 *             result = np.empty((kh_len, z_len), dtype=np.float64)             # <<<<<<<<<<<<<<
 *             for i in range(kh_len):
 *                 for j in range(z_len):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_kh_len); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_z_len); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4270, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4)) __PYX_ERR(0, 4270, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(0, 4270, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_result = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4271
 *             z_len = len(z_vals)
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 *             for i in range(kh_len):             # <<<<<<<<<<<<<<
 *                 for j in range(z_len):
 *                     result[i, j] = compute_pkl(kh_vals[i], z_vals[j])
 */
  __pyx_t_1 = __pyx_v_kh_len;
  __pyx_t_7 = __pyx_t_1;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "class-sz/python/classy.pyx":4272
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 *             for i in range(kh_len):
 *                 for j in range(z_len):             # <<<<<<<<<<<<<<
 *                     result[i, j] = compute_pkl(kh_vals[i], z_vals[j])
 *             return result
 */
    __pyx_t_9 = __pyx_v_z_len;
    __pyx_t_10 = __pyx_t_9;
    for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
      __pyx_v_j = __pyx_t_11;

      /* "class-sz/python/classy.pyx":4273
 *             for i in range(kh_len):
 *                 for j in range(z_len):
 *                     result[i, j] = compute_pkl(kh_vals[i], z_vals[j])             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_kh_vals, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_z_vals, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_cur_scope->__pyx_v_compute_pkl)) { __Pyx_RaiseClosureNameError("compute_pkl"); __PYX_ERR(0, 4273, __pyx_L1_error) }
      __pyx_t_6 = __pyx_pf_9classy_sz_5Class_7get_pkl_compute_pkl(__pyx_cur_scope->__pyx_v_compute_pkl, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_j); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5)) __PYX_ERR(0, 4273, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4)) __PYX_ERR(0, 4273, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_t_4 = 0;
      if (unlikely((PyObject_SetItem(__pyx_v_result, __pyx_t_3, __pyx_t_6) < 0))) __PYX_ERR(0, 4273, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }

  /* "class-sz/python/classy.pyx":4274
 *                 for j in range(z_len):
 *                     result[i, j] = compute_pkl(kh_vals[i], z_vals[j])
 *             return result             # <<<<<<<<<<<<<<
 * 
 *         # Compute the linear power spectrum for all combinations of inputs
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4267
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.get_pkl.handle_combinations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4234
 * 
 * 
 *     def get_pkl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the linear power spectrum at given wavenumbers and redshifts.
 */

static PyObject *__pyx_pf_9classy_sz_5Class_410get_pkl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh_input, PyObject *__pyx_v_z_input) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *__pyx_cur_scope;
  PyObject *__pyx_v_handle_combinations = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pkl", 0);
  __pyx_cur_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *)__pyx_tp_new_9classy_sz___pyx_scope_struct_3_get_pkl(__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4234, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_kh_input);
  __Pyx_INCREF(__pyx_v_z_input);

  /* "class-sz/python/classy.pyx":4251
 *         """
 *         # Helper function to compute the linear power spectrum for given kh and z
 *         def compute_pkl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk_lin(k, z) * self.ba.h**3
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_7get_pkl_1compute_pkl, 0, __pyx_n_s_get_pkl_locals_compute_pkl, ((PyObject*)__pyx_cur_scope), __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__32)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_compute_pkl = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4256
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(kh_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_kh_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_kh_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4257
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(kh_input, (float, np.float64)):
 *             kh_input = np.array([kh_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_kh_input);
    __Pyx_GIVEREF(__pyx_v_kh_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_kh_input)) __PYX_ERR(0, 4257, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4257, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_kh_input, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":4256
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(kh_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):
 */
  }

  /* "class-sz/python/classy.pyx":4258
 *         if isinstance(kh_input, (float, np.float64)):
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_z_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_z_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4259
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         # Ensure all inputs are 1D numpy arrays
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_z_input);
    __Pyx_GIVEREF(__pyx_v_z_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_z_input)) __PYX_ERR(0, 4259, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4259, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_z_input, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":4258
 *         if isinstance(kh_input, (float, np.float64)):
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4262
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_kh_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_kh_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_6, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_kh_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_6, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }

  /* "class-sz/python/classy.pyx":4263
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 * 
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_z_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4263, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L10_bool_binop_done:;

  /* "class-sz/python/classy.pyx":4262
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 */
  __pyx_t_4 = (!__pyx_t_3);
  if (unlikely(__pyx_t_4)) {

    /* "class-sz/python/classy.pyx":4264
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")             # <<<<<<<<<<<<<<
 * 
 *         # Function to handle all combinations of inputs
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4264, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4262
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 */
  }

  /* "class-sz/python/classy.pyx":4267
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_7get_pkl_3handle_combinations, 0, __pyx_n_s_get_pkl_locals_handle_combinatio, ((PyObject*)__pyx_cur_scope), __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__35)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_handle_combinations = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":4277
 * 
 *         # Compute the linear power spectrum for all combinations of inputs
 *         return handle_combinations(kh_input, z_input)             # <<<<<<<<<<<<<<
 * 
 *     def get_pknl(self, kh_input, z_input):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_pf_9classy_sz_5Class_7get_pkl_2handle_combinations(__pyx_v_handle_combinations, __pyx_v_kh_input, __pyx_v_z_input); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4234
 * 
 * 
 *     def get_pkl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the linear power spectrum at given wavenumbers and redshifts.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.get_pkl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handle_combinations);
  __Pyx_XDECREF(__pyx_v_kh_input);
  __Pyx_XDECREF(__pyx_v_z_input);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4279
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pknl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the non-linear power spectrum at given wavenumbers and redshifts.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_413get_pknl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_412get_pknl, "\n        Vectorized computation of the non-linear power spectrum at given wavenumbers and redshifts.\n        \n        Parameters\n        ----------\n        kh_input : float or np.ndarray\n            The wavenumber in units of h/Mpc.\n        z_input : float or np.ndarray\n            The redshift at which the power spectrum is evaluated.\n\n        Returns\n        -------\n        np.ndarray\n            An array of the non-linear power spectrum values.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_413get_pknl = {"get_pknl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_413get_pknl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_412get_pknl};
static PyObject *__pyx_pw_9classy_sz_5Class_413get_pknl(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_kh_input = 0;
  PyObject *__pyx_v_z_input = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pknl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh_input,&__pyx_n_s_z_input,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4279, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4279, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pknl", 1, 2, 2, 1); __PYX_ERR(0, 4279, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pknl") < 0)) __PYX_ERR(0, 4279, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh_input = values[0];
    __pyx_v_z_input = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pknl", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4279, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pknl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_412get_pknl(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_kh_input, __pyx_v_z_input);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4296
 *         """
 *         # Helper function to compute the non-linear power spectrum for given kh and z
 *         def compute_pknl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk(k, z) * self.ba.h**3
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_8get_pknl_1compute_pknl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_8get_pknl_1compute_pknl = {"compute_pknl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_8get_pknl_1compute_pknl, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_8get_pknl_1compute_pknl(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_kh;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("compute_pknl (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4296, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4296, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("compute_pknl", 1, 2, 2, 1); __PYX_ERR(0, 4296, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "compute_pknl") < 0)) __PYX_ERR(0, 4296, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_kh == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4296, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4296, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("compute_pknl", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4296, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pknl.compute_pknl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_8get_pknl_compute_pknl(__pyx_self, __pyx_v_kh, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_8get_pknl_compute_pknl(PyObject *__pyx_self, double __pyx_v_kh, double __pyx_v_z) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *__pyx_cur_scope;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *__pyx_outer_scope;
  double __pyx_v_k;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("compute_pknl", 1);
  __pyx_outer_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "class-sz/python/classy.pyx":4297
 *         # Helper function to compute the non-linear power spectrum for given kh and z
 *         def compute_pknl(double kh, double z):
 *             k = kh * self.ba.h             # <<<<<<<<<<<<<<
 *             return self.pk(k, z) * self.ba.h**3
 * 
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4297, __pyx_L1_error) }
  __pyx_v_k = (__pyx_v_kh * __pyx_cur_scope->__pyx_v_self->ba.h);

  /* "class-sz/python/classy.pyx":4298
 *         def compute_pknl(double kh, double z):
 *             k = kh * self.ba.h
 *             return self.pk(k, z) * self.ba.h**3             # <<<<<<<<<<<<<<
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4298, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_pk); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_k); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_3, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4298, __pyx_L1_error) }
  __pyx_t_2 = PyFloat_FromDouble(pow(__pyx_cur_scope->__pyx_v_self->ba.h, 3.0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4296
 *         """
 *         # Helper function to compute the non-linear power spectrum for given kh and z
 *         def compute_pknl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk(k, z) * self.ba.h**3
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_pknl.compute_pknl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4312
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_8get_pknl_3handle_combinations(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_8get_pknl_3handle_combinations = {"handle_combinations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_8get_pknl_3handle_combinations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_8get_pknl_3handle_combinations(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_kh_vals = 0;
  PyObject *__pyx_v_z_vals = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("handle_combinations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh_vals,&__pyx_n_s_z_vals,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh_vals)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4312, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_vals)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4312, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("handle_combinations", 1, 2, 2, 1); __PYX_ERR(0, 4312, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "handle_combinations") < 0)) __PYX_ERR(0, 4312, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_kh_vals = values[0];
    __pyx_v_z_vals = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("handle_combinations", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4312, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pknl.handle_combinations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_8get_pknl_2handle_combinations(__pyx_self, __pyx_v_kh_vals, __pyx_v_z_vals);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_8get_pknl_2handle_combinations(PyObject *__pyx_self, PyObject *__pyx_v_kh_vals, PyObject *__pyx_v_z_vals) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *__pyx_cur_scope;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *__pyx_outer_scope;
  Py_ssize_t __pyx_v_kh_len;
  Py_ssize_t __pyx_v_z_len;
  PyObject *__pyx_v_result = NULL;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_j;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  double __pyx_t_12;
  double __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("handle_combinations", 1);
  __pyx_outer_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "class-sz/python/classy.pyx":4313
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):
 *             kh_len = len(kh_vals)             # <<<<<<<<<<<<<<
 *             z_len = len(z_vals)
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_kh_vals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4313, __pyx_L1_error)
  __pyx_v_kh_len = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4314
 *         def handle_combinations(kh_vals, z_vals):
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)             # <<<<<<<<<<<<<<
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 *             for i in range(kh_len):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_z_vals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4314, __pyx_L1_error)
  __pyx_v_z_len = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4315
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 *             result = np.empty((kh_len, z_len), dtype=np.float64)             # <<<<<<<<<<<<<<
 *             for i in range(kh_len):
 *                 for j in range(z_len):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_kh_len); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_z_len); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4315, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4)) __PYX_ERR(0, 4315, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(0, 4315, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_result = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4316
 *             z_len = len(z_vals)
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 *             for i in range(kh_len):             # <<<<<<<<<<<<<<
 *                 for j in range(z_len):
 *                     result[i, j] = compute_pknl(kh_vals[i], z_vals[j])
 */
  __pyx_t_1 = __pyx_v_kh_len;
  __pyx_t_7 = __pyx_t_1;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "class-sz/python/classy.pyx":4317
 *             result = np.empty((kh_len, z_len), dtype=np.float64)
 *             for i in range(kh_len):
 *                 for j in range(z_len):             # <<<<<<<<<<<<<<
 *                     result[i, j] = compute_pknl(kh_vals[i], z_vals[j])
 *             return result
 */
    __pyx_t_9 = __pyx_v_z_len;
    __pyx_t_10 = __pyx_t_9;
    for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
      __pyx_v_j = __pyx_t_11;

      /* "class-sz/python/classy.pyx":4318
 *             for i in range(kh_len):
 *                 for j in range(z_len):
 *                     result[i, j] = compute_pknl(kh_vals[i], z_vals[j])             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_kh_vals, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_z_vals, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_t_6); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_cur_scope->__pyx_v_compute_pknl)) { __Pyx_RaiseClosureNameError("compute_pknl"); __PYX_ERR(0, 4318, __pyx_L1_error) }
      __pyx_t_6 = __pyx_pf_9classy_sz_5Class_8get_pknl_compute_pknl(__pyx_cur_scope->__pyx_v_compute_pknl, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_j); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5)) __PYX_ERR(0, 4318, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4)) __PYX_ERR(0, 4318, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_t_4 = 0;
      if (unlikely((PyObject_SetItem(__pyx_v_result, __pyx_t_3, __pyx_t_6) < 0))) __PYX_ERR(0, 4318, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }

  /* "class-sz/python/classy.pyx":4319
 *                 for j in range(z_len):
 *                     result[i, j] = compute_pknl(kh_vals[i], z_vals[j])
 *             return result             # <<<<<<<<<<<<<<
 * 
 *         # Compute the non-linear power spectrum for all combinations of inputs
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4312
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.get_pknl.handle_combinations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4279
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pknl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the non-linear power spectrum at given wavenumbers and redshifts.
 */

static PyObject *__pyx_pf_9classy_sz_5Class_412get_pknl(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh_input, PyObject *__pyx_v_z_input) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *__pyx_cur_scope;
  PyObject *__pyx_v_handle_combinations = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pknl", 0);
  __pyx_cur_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *)__pyx_tp_new_9classy_sz___pyx_scope_struct_4_get_pknl(__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4279, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_kh_input);
  __Pyx_INCREF(__pyx_v_z_input);

  /* "class-sz/python/classy.pyx":4296
 *         """
 *         # Helper function to compute the non-linear power spectrum for given kh and z
 *         def compute_pknl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk(k, z) * self.ba.h**3
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_8get_pknl_1compute_pknl, 0, __pyx_n_s_get_pknl_locals_compute_pknl, ((PyObject*)__pyx_cur_scope), __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__36)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_compute_pknl = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4301
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(kh_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_kh_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_kh_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4302
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(kh_input, (float, np.float64)):
 *             kh_input = np.array([kh_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_kh_input);
    __Pyx_GIVEREF(__pyx_v_kh_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_kh_input)) __PYX_ERR(0, 4302, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4302, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4302, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_kh_input, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":4301
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(kh_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):
 */
  }

  /* "class-sz/python/classy.pyx":4303
 *         if isinstance(kh_input, (float, np.float64)):
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_z_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_z_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4304
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         # Ensure all inputs are 1D numpy arrays
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_z_input);
    __Pyx_GIVEREF(__pyx_v_z_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_z_input)) __PYX_ERR(0, 4304, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4304, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_z_input, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":4303
 *         if isinstance(kh_input, (float, np.float64)):
 *             kh_input = np.array([kh_input], dtype=np.float64)
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4307
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_kh_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_kh_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_6, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_kh_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_6, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }

  /* "class-sz/python/classy.pyx":4308
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 * 
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_z_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L10_bool_binop_done:;

  /* "class-sz/python/classy.pyx":4307
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 */
  __pyx_t_4 = (!__pyx_t_3);
  if (unlikely(__pyx_t_4)) {

    /* "class-sz/python/classy.pyx":4309
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")             # <<<<<<<<<<<<<<
 * 
 *         # Function to handle all combinations of inputs
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4309, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4307
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 */
  }

  /* "class-sz/python/classy.pyx":4312
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_8get_pknl_3handle_combinations, 0, __pyx_n_s_get_pknl_locals_handle_combinati, ((PyObject*)__pyx_cur_scope), __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__37)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_handle_combinations = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":4322
 * 
 *         # Compute the non-linear power spectrum for all combinations of inputs
 *         return handle_combinations(kh_input, z_input)             # <<<<<<<<<<<<<<
 * 
 *     def get_pk(self, kh_input, z_input, type="lin"):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_pf_9classy_sz_5Class_8get_pknl_2handle_combinations(__pyx_v_handle_combinations, __pyx_v_kh_input, __pyx_v_z_input); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4279
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pknl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the non-linear power spectrum at given wavenumbers and redshifts.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.get_pknl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handle_combinations);
  __Pyx_XDECREF(__pyx_v_kh_input);
  __Pyx_XDECREF(__pyx_v_z_input);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4324
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pk(self, kh_input, z_input, type="lin"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the power spectrum at given wavenumbers and redshifts.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_415get_pk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_414get_pk, "\n        General computation of the power spectrum at given wavenumbers and redshifts.\n\n        This method handles both scalar and array inputs for wavenumbers (kh_input) and redshifts (z_input).\n        It returns the corresponding power spectrum based on the specified power spectrum type.\n\n        Parameters\n        ----------\n        kh_input : float or np.ndarray\n            The wavenumber in units of h/Mpc.\n        z_input : float or np.ndarray\n            The redshift at which the power spectrum is evaluated.\n        type : str\n            Optional; the type, default is \"lin\". Available types are \"lin\" and \"nonlin\".\n\n        Returns\n        -------\n        np.ndarray\n            An array of power spectrum values corresponding to the input wavenumbers and redshifts for the specified power spcetrum type.\n\n        Raises\n        ------\n        TypeError\n            If the inputs are not floats or 1D arrays of floats.\n        NotImplementedError\n            If the specified type is not implemented.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_415get_pk = {"get_pk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_415get_pk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_414get_pk};
static PyObject *__pyx_pw_9classy_sz_5Class_415get_pk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_kh_input = 0;
  PyObject *__pyx_v_z_input = 0;
  PyObject *__pyx_v_type = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_kh_input,&__pyx_n_s_z_input,&__pyx_n_s_type,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_n_u_lin));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kh_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4324, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4324, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk", 0, 2, 3, 1); __PYX_ERR(0, 4324, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_type);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4324, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk") < 0)) __PYX_ERR(0, 4324, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_kh_input = values[0];
    __pyx_v_z_input = values[1];
    __pyx_v_type = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4324, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_414get_pk(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_kh_input, __pyx_v_z_input, __pyx_v_type);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_414get_pk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_kh_input, PyObject *__pyx_v_z_input, PyObject *__pyx_v_type) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk", 1);

  /* "class-sz/python/classy.pyx":4352
 *             If the specified type is not implemented.
 *         """
 *         if type == "lin":             # <<<<<<<<<<<<<<
 *             return self.get_pkl(kh_input, z_input)
 *         elif type == "nonlin":
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_type, __pyx_n_u_lin, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4352, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":4353
 *         """
 *         if type == "lin":
 *             return self.get_pkl(kh_input, z_input)             # <<<<<<<<<<<<<<
 *         elif type == "nonlin":
 *             return self.get_pknl(kh_input, z_input)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_pkl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_kh_input, __pyx_v_z_input};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4353, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":4352
 *             If the specified type is not implemented.
 *         """
 *         if type == "lin":             # <<<<<<<<<<<<<<
 *             return self.get_pkl(kh_input, z_input)
 *         elif type == "nonlin":
 */
  }

  /* "class-sz/python/classy.pyx":4354
 *         if type == "lin":
 *             return self.get_pkl(kh_input, z_input)
 *         elif type == "nonlin":             # <<<<<<<<<<<<<<
 *             return self.get_pknl(kh_input, z_input)
 *         else:
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_type, __pyx_n_u_nonlin, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4354, __pyx_L1_error)
  if (likely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":4355
 *             return self.get_pkl(kh_input, z_input)
 *         elif type == "nonlin":
 *             return self.get_pknl(kh_input, z_input)             # <<<<<<<<<<<<<<
 *         else:
 *             raise NotImplementedError(f"Type '{type}' is not implemented yet. Available types are 'lin' and 'nonlin'.")
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_pknl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4355, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_kh_input, __pyx_v_z_input};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":4354
 *         if type == "lin":
 *             return self.get_pkl(kh_input, z_input)
 *         elif type == "nonlin":             # <<<<<<<<<<<<<<
 *             return self.get_pknl(kh_input, z_input)
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":4357
 *             return self.get_pknl(kh_input, z_input)
 *         else:
 *             raise NotImplementedError(f"Type '{type}' is not implemented yet. Available types are 'lin' and 'nonlin'.")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_7 = 127;
    __Pyx_INCREF(__pyx_kp_u_Type);
    __pyx_t_6 += 6;
    __Pyx_GIVEREF(__pyx_kp_u_Type);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_Type);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_type, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
    __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_is_not_implemented_yet_Availabl);
    __pyx_t_6 += 65;
    __Pyx_GIVEREF(__pyx_kp_u_is_not_implemented_yet_Availabl);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_is_not_implemented_yet_Availabl);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_NotImplementedError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4357, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4357, __pyx_L1_error)
  }

  /* "class-sz/python/classy.pyx":4324
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pk(self, kh_input, z_input, type="lin"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the power spectrum at given wavenumbers and redshifts.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_pk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4360
 * 
 * 
 *     def get_pk_nonlin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_417get_pk_nonlin_at_k_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_417get_pk_nonlin_at_k_and_z = {"get_pk_nonlin_at_k_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_417get_pk_nonlin_at_k_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_417get_pk_nonlin_at_k_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_nonlin_at_k_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4360, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4360, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_nonlin_at_k_and_z", 1, 2, 2, 1); __PYX_ERR(0, 4360, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_nonlin_at_k_and_z") < 0)) __PYX_ERR(0, 4360, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_nonlin_at_k_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4360, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_nonlin_at_k_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_416get_pk_nonlin_at_k_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_416get_pk_nonlin_at_k_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_nonlin_at_k_and_z", 1);

  /* "class-sz/python/classy.pyx":4361
 * 
 *     def get_pk_nonlin_at_k_and_z(self,k, z):
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_lin_at_k_and_z(self,k, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4361, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4361, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_pk_nonlin_at_k_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4360
 * 
 * 
 *     def get_pk_nonlin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_pk_nonlin_at_k_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4363
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_419get_pk_lin_at_k_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_419get_pk_lin_at_k_and_z = {"get_pk_lin_at_k_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_419get_pk_lin_at_k_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_419get_pk_lin_at_k_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_lin_at_k_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4363, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4363, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_lin_at_k_and_z", 1, 2, 2, 1); __PYX_ERR(0, 4363, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_lin_at_k_and_z") < 0)) __PYX_ERR(0, 4363, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_lin_at_k_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4363, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_lin_at_k_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_418get_pk_lin_at_k_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_418get_pk_lin_at_k_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_lin_at_k_and_z", 1);

  /* "class-sz/python/classy.pyx":4364
 * 
 *     def get_pk_lin_at_k_and_z(self,k, z):
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_nonlin_at_k_and_z_fast(self,k, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4364, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4364, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_pk_lin_at_k_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4363
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_pk_lin_at_k_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4366
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_nonlin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_421get_pk_nonlin_at_k_and_z_fast(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_421get_pk_nonlin_at_k_and_z_fast = {"get_pk_nonlin_at_k_and_z_fast", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_421get_pk_nonlin_at_k_and_z_fast, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_421get_pk_nonlin_at_k_and_z_fast(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_nonlin_at_k_and_z_fast (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4366, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4366, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_nonlin_at_k_and_z_fast", 1, 2, 2, 1); __PYX_ERR(0, 4366, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_nonlin_at_k_and_z_fast") < 0)) __PYX_ERR(0, 4366, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_nonlin_at_k_and_z_fast", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4366, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_nonlin_at_k_and_z_fast", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_420get_pk_nonlin_at_k_and_z_fast(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_420get_pk_nonlin_at_k_and_z_fast(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_nonlin_at_k_and_z_fast", 1);

  /* "class-sz/python/classy.pyx":4367
 * 
 *     def get_pk_nonlin_at_k_and_z_fast(self,k, z):
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_lin_at_k_and_z_fast(self,k, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4367, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4367, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_pk_nonlin_at_k_and_z_fast(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4366
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_nonlin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_pk_nonlin_at_k_and_z_fast", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4369
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_423get_pk_lin_at_k_and_z_fast(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_423get_pk_lin_at_k_and_z_fast = {"get_pk_lin_at_k_and_z_fast", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_423get_pk_lin_at_k_and_z_fast, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_423get_pk_lin_at_k_and_z_fast(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_lin_at_k_and_z_fast (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4369, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4369, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_lin_at_k_and_z_fast", 1, 2, 2, 1); __PYX_ERR(0, 4369, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_lin_at_k_and_z_fast") < 0)) __PYX_ERR(0, 4369, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_k = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_lin_at_k_and_z_fast", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4369, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_lin_at_k_and_z_fast", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_422get_pk_lin_at_k_and_z_fast(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_422get_pk_lin_at_k_and_z_fast(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_lin_at_k_and_z_fast", 1);

  /* "class-sz/python/classy.pyx":4370
 * 
 *     def get_pk_lin_at_k_and_z_fast(self,k, z):
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_gas_profile_at_x_M_z_b16_200c(self,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4370, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4370, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_pk_lin_at_k_and_z_fast(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->pm), (&__pyx_v_self->nl), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4369
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_pk_lin_at_k_and_z_fast", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4372
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_b16_200c(self,             # <<<<<<<<<<<<<<
 *                                           r_asked,
 *                                           m_asked,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_425get_gas_profile_at_x_M_z_b16_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_425get_gas_profile_at_x_M_z_b16_200c = {"get_gas_profile_at_x_M_z_b16_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_425get_gas_profile_at_x_M_z_b16_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_425get_gas_profile_at_x_M_z_b16_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_r_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_c_asked = 0;
  PyObject *__pyx_v_A_rho0 = 0;
  PyObject *__pyx_v_A_alpha = 0;
  PyObject *__pyx_v_A_beta = 0;
  PyObject *__pyx_v_alpha_m_rho0 = 0;
  PyObject *__pyx_v_alpha_m_alpha = 0;
  PyObject *__pyx_v_alpha_m_beta = 0;
  PyObject *__pyx_v_alpha_z_rho0 = 0;
  PyObject *__pyx_v_alpha_z_alpha = 0;
  PyObject *__pyx_v_alpha_z_beta = 0;
  PyObject *__pyx_v_mcut = 0;
  PyObject *__pyx_v_alphap_m_rho0 = 0;
  PyObject *__pyx_v_alphap_m_alpha = 0;
  PyObject *__pyx_v_alphap_m_beta = 0;
  PyObject *__pyx_v_alpha_c_rho0 = 0;
  PyObject *__pyx_v_alpha_c_alpha = 0;
  PyObject *__pyx_v_alpha_c_beta = 0;
  PyObject *__pyx_v_gamma = 0;
  PyObject *__pyx_v_xc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[22] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_b16_200c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_r_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,&__pyx_n_s_c_asked,&__pyx_n_s_A_rho0,&__pyx_n_s_A_alpha,&__pyx_n_s_A_beta,&__pyx_n_s_alpha_m_rho0,&__pyx_n_s_alpha_m_alpha,&__pyx_n_s_alpha_m_beta,&__pyx_n_s_alpha_z_rho0,&__pyx_n_s_alpha_z_alpha,&__pyx_n_s_alpha_z_beta,&__pyx_n_s_mcut,&__pyx_n_s_alphap_m_rho0,&__pyx_n_s_alphap_m_alpha,&__pyx_n_s_alphap_m_beta,&__pyx_n_s_alpha_c_rho0,&__pyx_n_s_alpha_c_alpha,&__pyx_n_s_alpha_c_beta,&__pyx_n_s_gamma,&__pyx_n_s_xc,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_4_e3));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_88));
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_3_83));
    values[7] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_29));
    values[8] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_03));
    values[9] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_04));
    values[10] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_66));
    values[11] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_19));
    values[12] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_025));
    values[13] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_1e14));
    values[14] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_29));
    values[15] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_03));
    values[16] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_04));
    values[17] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[18] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[19] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[20] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_2));
    values[21] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_5));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case 22: values[21] = __Pyx_Arg_FASTCALL(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = __Pyx_Arg_FASTCALL(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = __Pyx_Arg_FASTCALL(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = __Pyx_Arg_FASTCALL(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = __Pyx_Arg_FASTCALL(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = __Pyx_Arg_FASTCALL(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = __Pyx_Arg_FASTCALL(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = __Pyx_Arg_FASTCALL(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = __Pyx_Arg_FASTCALL(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = __Pyx_Arg_FASTCALL(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_b16_200c", 0, 3, 22, 1); __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_b16_200c", 0, 3, 22, 2); __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_c_asked);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A_rho0);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A_alpha);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A_beta);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_m_rho0);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_m_alpha);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_m_beta);
          if (value) { values[9] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_z_rho0);
          if (value) { values[10] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_z_alpha);
          if (value) { values[11] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_z_beta);
          if (value) { values[12] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mcut);
          if (value) { values[13] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alphap_m_rho0);
          if (value) { values[14] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alphap_m_alpha);
          if (value) { values[15] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alphap_m_beta);
          if (value) { values[16] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 17:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_c_rho0);
          if (value) { values[17] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 18:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_c_alpha);
          if (value) { values[18] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 19:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_c_beta);
          if (value) { values[19] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 20:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_gamma);
          if (value) { values[20] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 21:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xc);
          if (value) { values[21] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4372, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_gas_profile_at_x_M_z_b16_200c") < 0)) __PYX_ERR(0, 4372, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case 22: values[21] = __Pyx_Arg_FASTCALL(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = __Pyx_Arg_FASTCALL(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = __Pyx_Arg_FASTCALL(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = __Pyx_Arg_FASTCALL(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = __Pyx_Arg_FASTCALL(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = __Pyx_Arg_FASTCALL(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = __Pyx_Arg_FASTCALL(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = __Pyx_Arg_FASTCALL(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = __Pyx_Arg_FASTCALL(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = __Pyx_Arg_FASTCALL(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_r_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
    __pyx_v_c_asked = values[3];
    __pyx_v_A_rho0 = values[4];
    __pyx_v_A_alpha = values[5];
    __pyx_v_A_beta = values[6];
    __pyx_v_alpha_m_rho0 = values[7];
    __pyx_v_alpha_m_alpha = values[8];
    __pyx_v_alpha_m_beta = values[9];
    __pyx_v_alpha_z_rho0 = values[10];
    __pyx_v_alpha_z_alpha = values[11];
    __pyx_v_alpha_z_beta = values[12];
    __pyx_v_mcut = values[13];
    __pyx_v_alphap_m_rho0 = values[14];
    __pyx_v_alphap_m_alpha = values[15];
    __pyx_v_alphap_m_beta = values[16];
    __pyx_v_alpha_c_rho0 = values[17];
    __pyx_v_alpha_c_alpha = values[18];
    __pyx_v_alpha_c_beta = values[19];
    __pyx_v_gamma = values[20];
    __pyx_v_xc = values[21];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_b16_200c", 0, 3, 22, __pyx_nargs); __PYX_ERR(0, 4372, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_b16_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_424get_gas_profile_at_x_M_z_b16_200c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_r_asked, __pyx_v_m_asked, __pyx_v_z_asked, __pyx_v_c_asked, __pyx_v_A_rho0, __pyx_v_A_alpha, __pyx_v_A_beta, __pyx_v_alpha_m_rho0, __pyx_v_alpha_m_alpha, __pyx_v_alpha_m_beta, __pyx_v_alpha_z_rho0, __pyx_v_alpha_z_alpha, __pyx_v_alpha_z_beta, __pyx_v_mcut, __pyx_v_alphap_m_rho0, __pyx_v_alphap_m_alpha, __pyx_v_alphap_m_beta, __pyx_v_alpha_c_rho0, __pyx_v_alpha_c_alpha, __pyx_v_alpha_c_beta, __pyx_v_gamma, __pyx_v_xc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_424get_gas_profile_at_x_M_z_b16_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_c_asked, PyObject *__pyx_v_A_rho0, PyObject *__pyx_v_A_alpha, PyObject *__pyx_v_A_beta, PyObject *__pyx_v_alpha_m_rho0, PyObject *__pyx_v_alpha_m_alpha, PyObject *__pyx_v_alpha_m_beta, PyObject *__pyx_v_alpha_z_rho0, PyObject *__pyx_v_alpha_z_alpha, PyObject *__pyx_v_alpha_z_beta, PyObject *__pyx_v_mcut, PyObject *__pyx_v_alphap_m_rho0, PyObject *__pyx_v_alphap_m_alpha, PyObject *__pyx_v_alphap_m_beta, PyObject *__pyx_v_alpha_c_rho0, PyObject *__pyx_v_alpha_c_alpha, PyObject *__pyx_v_alpha_c_beta, PyObject *__pyx_v_gamma, PyObject *__pyx_v_xc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  double __pyx_t_5;
  double __pyx_t_6;
  double __pyx_t_7;
  double __pyx_t_8;
  double __pyx_t_9;
  double __pyx_t_10;
  double __pyx_t_11;
  double __pyx_t_12;
  double __pyx_t_13;
  double __pyx_t_14;
  double __pyx_t_15;
  double __pyx_t_16;
  double __pyx_t_17;
  double __pyx_t_18;
  double __pyx_t_19;
  double __pyx_t_20;
  double __pyx_t_21;
  double __pyx_t_22;
  PyObject *__pyx_t_23 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_b16_200c", 1);

  /* "class-sz/python/classy.pyx":4396
 *                                           xc = 0.5
 *                                           ):
 *         return get_gas_profile_at_x_M_z_b16_200c(r_asked,             # <<<<<<<<<<<<<<
 *                                                  m_asked,
 *                                                  z_asked,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_r_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4396, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4397
 *                                           ):
 *         return get_gas_profile_at_x_M_z_b16_200c(r_asked,
 *                                                  m_asked,             # <<<<<<<<<<<<<<
 *                                                  z_asked,
 *                                                  c_asked,
 */
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4397, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4398
 *         return get_gas_profile_at_x_M_z_b16_200c(r_asked,
 *                                                  m_asked,
 *                                                  z_asked,             # <<<<<<<<<<<<<<
 *                                                  c_asked,
 *                                                  A_rho0,
 */
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4398, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4399
 *                                                  m_asked,
 *                                                  z_asked,
 *                                                  c_asked,             # <<<<<<<<<<<<<<
 *                                                  A_rho0,
 *                                                  A_alpha,
 */
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_c_asked); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4399, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4400
 *                                                  z_asked,
 *                                                  c_asked,
 *                                                  A_rho0,             # <<<<<<<<<<<<<<
 *                                                  A_alpha,
 *                                                  A_beta,
 */
  __pyx_t_5 = __pyx_PyFloat_AsDouble(__pyx_v_A_rho0); if (unlikely((__pyx_t_5 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4400, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4401
 *                                                  c_asked,
 *                                                  A_rho0,
 *                                                  A_alpha,             # <<<<<<<<<<<<<<
 *                                                  A_beta,
 *                                                  alpha_m_rho0,
 */
  __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_v_A_alpha); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4401, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4402
 *                                                  A_rho0,
 *                                                  A_alpha,
 *                                                  A_beta,             # <<<<<<<<<<<<<<
 *                                                  alpha_m_rho0,
 *                                                  alpha_m_alpha,
 */
  __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_v_A_beta); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4402, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4403
 *                                                  A_alpha,
 *                                                  A_beta,
 *                                                  alpha_m_rho0,             # <<<<<<<<<<<<<<
 *                                                  alpha_m_alpha,
 *                                                  alpha_m_beta,
 */
  __pyx_t_8 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_m_rho0); if (unlikely((__pyx_t_8 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4403, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4404
 *                                                  A_beta,
 *                                                  alpha_m_rho0,
 *                                                  alpha_m_alpha,             # <<<<<<<<<<<<<<
 *                                                  alpha_m_beta,
 *                                                  alpha_z_rho0,
 */
  __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_m_alpha); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4404, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4405
 *                                                  alpha_m_rho0,
 *                                                  alpha_m_alpha,
 *                                                  alpha_m_beta,             # <<<<<<<<<<<<<<
 *                                                  alpha_z_rho0,
 *                                                  alpha_z_alpha,
 */
  __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_m_beta); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4405, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4406
 *                                                  alpha_m_alpha,
 *                                                  alpha_m_beta,
 *                                                  alpha_z_rho0,             # <<<<<<<<<<<<<<
 *                                                  alpha_z_alpha,
 *                                                  alpha_z_beta,
 */
  __pyx_t_11 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_z_rho0); if (unlikely((__pyx_t_11 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4406, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4407
 *                                                  alpha_m_beta,
 *                                                  alpha_z_rho0,
 *                                                  alpha_z_alpha,             # <<<<<<<<<<<<<<
 *                                                  alpha_z_beta,
 *                                                  mcut,
 */
  __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_z_alpha); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4407, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4408
 *                                                  alpha_z_rho0,
 *                                                  alpha_z_alpha,
 *                                                  alpha_z_beta,             # <<<<<<<<<<<<<<
 *                                                  mcut,
 *                                                  alphap_m_rho0,
 */
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_z_beta); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4408, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4409
 *                                                  alpha_z_alpha,
 *                                                  alpha_z_beta,
 *                                                  mcut,             # <<<<<<<<<<<<<<
 *                                                  alphap_m_rho0,
 *                                                  alphap_m_alpha,
 */
  __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_v_mcut); if (unlikely((__pyx_t_14 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4409, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4410
 *                                                  alpha_z_beta,
 *                                                  mcut,
 *                                                  alphap_m_rho0,             # <<<<<<<<<<<<<<
 *                                                  alphap_m_alpha,
 *                                                  alphap_m_beta,
 */
  __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_alphap_m_rho0); if (unlikely((__pyx_t_15 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4410, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4411
 *                                                  mcut,
 *                                                  alphap_m_rho0,
 *                                                  alphap_m_alpha,             # <<<<<<<<<<<<<<
 *                                                  alphap_m_beta,
 *                                                  alpha_c_rho0,
 */
  __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_alphap_m_alpha); if (unlikely((__pyx_t_16 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4411, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4412
 *                                                  alphap_m_rho0,
 *                                                  alphap_m_alpha,
 *                                                  alphap_m_beta,             # <<<<<<<<<<<<<<
 *                                                  alpha_c_rho0,
 *                                                  alpha_c_alpha,
 */
  __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_v_alphap_m_beta); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4412, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4413
 *                                                  alphap_m_alpha,
 *                                                  alphap_m_beta,
 *                                                  alpha_c_rho0,             # <<<<<<<<<<<<<<
 *                                                  alpha_c_alpha,
 *                                                  alpha_c_beta,
 */
  __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_c_rho0); if (unlikely((__pyx_t_18 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4413, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4414
 *                                                  alphap_m_beta,
 *                                                  alpha_c_rho0,
 *                                                  alpha_c_alpha,             # <<<<<<<<<<<<<<
 *                                                  alpha_c_beta,
 *                                                  gamma,
 */
  __pyx_t_19 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_c_alpha); if (unlikely((__pyx_t_19 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4414, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4415
 *                                                  alpha_c_rho0,
 *                                                  alpha_c_alpha,
 *                                                  alpha_c_beta,             # <<<<<<<<<<<<<<
 *                                                  gamma,
 *                                                  xc,
 */
  __pyx_t_20 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_c_beta); if (unlikely((__pyx_t_20 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4415, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4416
 *                                                  alpha_c_alpha,
 *                                                  alpha_c_beta,
 *                                                  gamma,             # <<<<<<<<<<<<<<
 *                                                  xc,
 *                                                  &self.ba,
 */
  __pyx_t_21 = __pyx_PyFloat_AsDouble(__pyx_v_gamma); if (unlikely((__pyx_t_21 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4416, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4417
 *                                                  alpha_c_beta,
 *                                                  gamma,
 *                                                  xc,             # <<<<<<<<<<<<<<
 *                                                  &self.ba,
 *                                                  &self.tsz)
 */
  __pyx_t_22 = __pyx_PyFloat_AsDouble(__pyx_v_xc); if (unlikely((__pyx_t_22 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4417, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4396
 *                                           xc = 0.5
 *                                           ):
 *         return get_gas_profile_at_x_M_z_b16_200c(r_asked,             # <<<<<<<<<<<<<<
 *                                                  m_asked,
 *                                                  z_asked,
 */
  __pyx_t_23 = PyFloat_FromDouble(get_gas_profile_at_x_M_z_b16_200c(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8, __pyx_t_9, __pyx_t_10, __pyx_t_11, __pyx_t_12, __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, __pyx_t_20, __pyx_t_21, __pyx_t_22, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 4396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __pyx_r = __pyx_t_23;
  __pyx_t_23 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4372
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_b16_200c(self,             # <<<<<<<<<<<<<<
 *                                           r_asked,
 *                                           m_asked,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_b16_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4421
 *                                                  &self.tsz)
 * 
 *     def get_pressure_P_over_P_delta_at_x_M_z_b12_200c(self,             # <<<<<<<<<<<<<<
 *                                                         x_asked,
 *                                                         m_asked,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_427get_pressure_P_over_P_delta_at_x_M_z_b12_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_427get_pressure_P_over_P_delta_at_x_M_z_b12_200c = {"get_pressure_P_over_P_delta_at_x_M_z_b12_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_427get_pressure_P_over_P_delta_at_x_M_z_b12_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_427get_pressure_P_over_P_delta_at_x_M_z_b12_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_x_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  PyObject *__pyx_v_c_asked = 0;
  PyObject *__pyx_v_A_P0 = 0;
  PyObject *__pyx_v_A_xc = 0;
  PyObject *__pyx_v_A_beta = 0;
  PyObject *__pyx_v_alpha_m_P0 = 0;
  PyObject *__pyx_v_alpha_m_xc = 0;
  PyObject *__pyx_v_alpha_m_beta = 0;
  PyObject *__pyx_v_alpha_z_P0 = 0;
  PyObject *__pyx_v_alpha_z_xc = 0;
  PyObject *__pyx_v_alpha_z_beta = 0;
  PyObject *__pyx_v_mcut = 0;
  PyObject *__pyx_v_alphap_m_P0 = 0;
  PyObject *__pyx_v_alphap_m_xc = 0;
  PyObject *__pyx_v_alphap_m_beta = 0;
  PyObject *__pyx_v_alpha_c_P0 = 0;
  PyObject *__pyx_v_alpha_c_xc = 0;
  PyObject *__pyx_v_alpha_c_beta = 0;
  PyObject *__pyx_v_alpha = 0;
  PyObject *__pyx_v_gamma = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[22] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pressure_P_over_P_delta_at_x_M_z_b12_200c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,&__pyx_n_s_c_asked,&__pyx_n_s_A_P0,&__pyx_n_s_A_xc,&__pyx_n_s_A_beta,&__pyx_n_s_alpha_m_P0,&__pyx_n_s_alpha_m_xc,&__pyx_n_s_alpha_m_beta,&__pyx_n_s_alpha_z_P0,&__pyx_n_s_alpha_z_xc,&__pyx_n_s_alpha_z_beta,&__pyx_n_s_mcut,&__pyx_n_s_alphap_m_P0,&__pyx_n_s_alphap_m_xc,&__pyx_n_s_alphap_m_beta,&__pyx_n_s_alpha_c_P0,&__pyx_n_s_alpha_c_xc,&__pyx_n_s_alpha_c_beta,&__pyx_n_s_alpha,&__pyx_n_s_gamma,0};
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_18_1));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_497));
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_4_35));
    values[7] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_154));
    values[8] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_00865));
    values[9] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_0393));
    values[10] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_758));
    values[11] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_731));
    values[12] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_415));
    values[13] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_1e14));
    values[14] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_154));
    values[15] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_00865));
    values[16] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_0393));
    values[17] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[18] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[19] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[20] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_1_));
    values[21] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_neg_0_3));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case 22: values[21] = __Pyx_Arg_FASTCALL(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = __Pyx_Arg_FASTCALL(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = __Pyx_Arg_FASTCALL(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = __Pyx_Arg_FASTCALL(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = __Pyx_Arg_FASTCALL(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = __Pyx_Arg_FASTCALL(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = __Pyx_Arg_FASTCALL(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = __Pyx_Arg_FASTCALL(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = __Pyx_Arg_FASTCALL(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = __Pyx_Arg_FASTCALL(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pressure_P_over_P_delta_at_x_M_z_b12_200c", 0, 3, 22, 1); __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pressure_P_over_P_delta_at_x_M_z_b12_200c", 0, 3, 22, 2); __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_c_asked);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A_P0);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A_xc);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A_beta);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_m_P0);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_m_xc);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_m_beta);
          if (value) { values[9] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_z_P0);
          if (value) { values[10] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_z_xc);
          if (value) { values[11] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_z_beta);
          if (value) { values[12] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mcut);
          if (value) { values[13] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alphap_m_P0);
          if (value) { values[14] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alphap_m_xc);
          if (value) { values[15] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alphap_m_beta);
          if (value) { values[16] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 17:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_c_P0);
          if (value) { values[17] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 18:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_c_xc);
          if (value) { values[18] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 19:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_c_beta);
          if (value) { values[19] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 20:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha);
          if (value) { values[20] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 21:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_gamma);
          if (value) { values[21] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4421, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pressure_P_over_P_delta_at_x_M_z_b12_200c") < 0)) __PYX_ERR(0, 4421, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case 22: values[21] = __Pyx_Arg_FASTCALL(__pyx_args, 21);
        CYTHON_FALLTHROUGH;
        case 21: values[20] = __Pyx_Arg_FASTCALL(__pyx_args, 20);
        CYTHON_FALLTHROUGH;
        case 20: values[19] = __Pyx_Arg_FASTCALL(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = __Pyx_Arg_FASTCALL(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = __Pyx_Arg_FASTCALL(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = __Pyx_Arg_FASTCALL(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = __Pyx_Arg_FASTCALL(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = __Pyx_Arg_FASTCALL(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = __Pyx_Arg_FASTCALL(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = __Pyx_Arg_FASTCALL(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = __Pyx_Arg_FASTCALL(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = __Pyx_Arg_FASTCALL(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_FASTCALL(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_x_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
    __pyx_v_c_asked = values[3];
    __pyx_v_A_P0 = values[4];
    __pyx_v_A_xc = values[5];
    __pyx_v_A_beta = values[6];
    __pyx_v_alpha_m_P0 = values[7];
    __pyx_v_alpha_m_xc = values[8];
    __pyx_v_alpha_m_beta = values[9];
    __pyx_v_alpha_z_P0 = values[10];
    __pyx_v_alpha_z_xc = values[11];
    __pyx_v_alpha_z_beta = values[12];
    __pyx_v_mcut = values[13];
    __pyx_v_alphap_m_P0 = values[14];
    __pyx_v_alphap_m_xc = values[15];
    __pyx_v_alphap_m_beta = values[16];
    __pyx_v_alpha_c_P0 = values[17];
    __pyx_v_alpha_c_xc = values[18];
    __pyx_v_alpha_c_beta = values[19];
    __pyx_v_alpha = values[20];
    __pyx_v_gamma = values[21];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pressure_P_over_P_delta_at_x_M_z_b12_200c", 0, 3, 22, __pyx_nargs); __PYX_ERR(0, 4421, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pressure_P_over_P_delta_at_x_M_z_b12_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_426get_pressure_P_over_P_delta_at_x_M_z_b12_200c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_x_asked, __pyx_v_m_asked, __pyx_v_z_asked, __pyx_v_c_asked, __pyx_v_A_P0, __pyx_v_A_xc, __pyx_v_A_beta, __pyx_v_alpha_m_P0, __pyx_v_alpha_m_xc, __pyx_v_alpha_m_beta, __pyx_v_alpha_z_P0, __pyx_v_alpha_z_xc, __pyx_v_alpha_z_beta, __pyx_v_mcut, __pyx_v_alphap_m_P0, __pyx_v_alphap_m_xc, __pyx_v_alphap_m_beta, __pyx_v_alpha_c_P0, __pyx_v_alpha_c_xc, __pyx_v_alpha_c_beta, __pyx_v_alpha, __pyx_v_gamma);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_426get_pressure_P_over_P_delta_at_x_M_z_b12_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked, PyObject *__pyx_v_c_asked, PyObject *__pyx_v_A_P0, PyObject *__pyx_v_A_xc, PyObject *__pyx_v_A_beta, PyObject *__pyx_v_alpha_m_P0, PyObject *__pyx_v_alpha_m_xc, PyObject *__pyx_v_alpha_m_beta, PyObject *__pyx_v_alpha_z_P0, PyObject *__pyx_v_alpha_z_xc, PyObject *__pyx_v_alpha_z_beta, PyObject *__pyx_v_mcut, PyObject *__pyx_v_alphap_m_P0, PyObject *__pyx_v_alphap_m_xc, PyObject *__pyx_v_alphap_m_beta, PyObject *__pyx_v_alpha_c_P0, PyObject *__pyx_v_alpha_c_xc, PyObject *__pyx_v_alpha_c_beta, PyObject *__pyx_v_alpha, PyObject *__pyx_v_gamma) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  double __pyx_t_5;
  double __pyx_t_6;
  double __pyx_t_7;
  double __pyx_t_8;
  double __pyx_t_9;
  double __pyx_t_10;
  double __pyx_t_11;
  double __pyx_t_12;
  double __pyx_t_13;
  double __pyx_t_14;
  double __pyx_t_15;
  double __pyx_t_16;
  double __pyx_t_17;
  double __pyx_t_18;
  double __pyx_t_19;
  double __pyx_t_20;
  double __pyx_t_21;
  double __pyx_t_22;
  PyObject *__pyx_t_23 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pressure_P_over_P_delta_at_x_M_z_b12_200c", 1);

  /* "class-sz/python/classy.pyx":4444
 *                                                         alpha = 1.,
 *                                                         gamma = -0.3):
 *         return  get_pressure_P_over_P_delta_at_x_M_z_b12_200c(x_asked,             # <<<<<<<<<<<<<<
 *                                                               m_asked,
 *                                                               z_asked,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_x_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4444, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4445
 *                                                         gamma = -0.3):
 *         return  get_pressure_P_over_P_delta_at_x_M_z_b12_200c(x_asked,
 *                                                               m_asked,             # <<<<<<<<<<<<<<
 *                                                               z_asked,
 *                                                               c_asked,
 */
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4445, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4446
 *         return  get_pressure_P_over_P_delta_at_x_M_z_b12_200c(x_asked,
 *                                                               m_asked,
 *                                                               z_asked,             # <<<<<<<<<<<<<<
 *                                                               c_asked,
 *                                                               A_P0,
 */
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4446, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4447
 *                                                               m_asked,
 *                                                               z_asked,
 *                                                               c_asked,             # <<<<<<<<<<<<<<
 *                                                               A_P0,
 *                                                               A_xc,
 */
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_c_asked); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4447, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4448
 *                                                               z_asked,
 *                                                               c_asked,
 *                                                               A_P0,             # <<<<<<<<<<<<<<
 *                                                               A_xc,
 *                                                               A_beta,
 */
  __pyx_t_5 = __pyx_PyFloat_AsDouble(__pyx_v_A_P0); if (unlikely((__pyx_t_5 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4448, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4449
 *                                                               c_asked,
 *                                                               A_P0,
 *                                                               A_xc,             # <<<<<<<<<<<<<<
 *                                                               A_beta,
 *                                                               alpha_m_P0,
 */
  __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_v_A_xc); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4449, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4450
 *                                                               A_P0,
 *                                                               A_xc,
 *                                                               A_beta,             # <<<<<<<<<<<<<<
 *                                                               alpha_m_P0,
 *                                                               alpha_m_xc,
 */
  __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_v_A_beta); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4450, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4451
 *                                                               A_xc,
 *                                                               A_beta,
 *                                                               alpha_m_P0,             # <<<<<<<<<<<<<<
 *                                                               alpha_m_xc,
 *                                                               alpha_m_beta,
 */
  __pyx_t_8 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_m_P0); if (unlikely((__pyx_t_8 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4451, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4452
 *                                                               A_beta,
 *                                                               alpha_m_P0,
 *                                                               alpha_m_xc,             # <<<<<<<<<<<<<<
 *                                                               alpha_m_beta,
 *                                                               alpha_z_P0,
 */
  __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_m_xc); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4452, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4453
 *                                                               alpha_m_P0,
 *                                                               alpha_m_xc,
 *                                                               alpha_m_beta,             # <<<<<<<<<<<<<<
 *                                                               alpha_z_P0,
 *                                                               alpha_z_xc,
 */
  __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_m_beta); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4453, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4454
 *                                                               alpha_m_xc,
 *                                                               alpha_m_beta,
 *                                                               alpha_z_P0,             # <<<<<<<<<<<<<<
 *                                                               alpha_z_xc,
 *                                                               alpha_z_beta,
 */
  __pyx_t_11 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_z_P0); if (unlikely((__pyx_t_11 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4454, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4455
 *                                                               alpha_m_beta,
 *                                                               alpha_z_P0,
 *                                                               alpha_z_xc,             # <<<<<<<<<<<<<<
 *                                                               alpha_z_beta,
 *                                                               mcut,
 */
  __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_z_xc); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4455, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4456
 *                                                               alpha_z_P0,
 *                                                               alpha_z_xc,
 *                                                               alpha_z_beta,             # <<<<<<<<<<<<<<
 *                                                               mcut,
 *                                                               alphap_m_P0,
 */
  __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_z_beta); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4456, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4457
 *                                                               alpha_z_xc,
 *                                                               alpha_z_beta,
 *                                                               mcut,             # <<<<<<<<<<<<<<
 *                                                               alphap_m_P0,
 *                                                               alphap_m_xc,
 */
  __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_v_mcut); if (unlikely((__pyx_t_14 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4457, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4458
 *                                                               alpha_z_beta,
 *                                                               mcut,
 *                                                               alphap_m_P0,             # <<<<<<<<<<<<<<
 *                                                               alphap_m_xc,
 *                                                               alphap_m_beta,
 */
  __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_v_alphap_m_P0); if (unlikely((__pyx_t_15 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4458, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4459
 *                                                               mcut,
 *                                                               alphap_m_P0,
 *                                                               alphap_m_xc,             # <<<<<<<<<<<<<<
 *                                                               alphap_m_beta,
 *                                                               alpha_c_P0,
 */
  __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_v_alphap_m_xc); if (unlikely((__pyx_t_16 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4459, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4460
 *                                                               alphap_m_P0,
 *                                                               alphap_m_xc,
 *                                                               alphap_m_beta,             # <<<<<<<<<<<<<<
 *                                                               alpha_c_P0,
 *                                                               alpha_c_xc,
 */
  __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_v_alphap_m_beta); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4460, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4461
 *                                                               alphap_m_xc,
 *                                                               alphap_m_beta,
 *                                                               alpha_c_P0,             # <<<<<<<<<<<<<<
 *                                                               alpha_c_xc,
 *                                                               alpha_c_beta,
 */
  __pyx_t_18 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_c_P0); if (unlikely((__pyx_t_18 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4461, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4462
 *                                                               alphap_m_beta,
 *                                                               alpha_c_P0,
 *                                                               alpha_c_xc,             # <<<<<<<<<<<<<<
 *                                                               alpha_c_beta,
 *                                                               alpha,
 */
  __pyx_t_19 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_c_xc); if (unlikely((__pyx_t_19 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4462, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4463
 *                                                               alpha_c_P0,
 *                                                               alpha_c_xc,
 *                                                               alpha_c_beta,             # <<<<<<<<<<<<<<
 *                                                               alpha,
 *                                                               gamma,
 */
  __pyx_t_20 = __pyx_PyFloat_AsDouble(__pyx_v_alpha_c_beta); if (unlikely((__pyx_t_20 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4463, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4464
 *                                                               alpha_c_xc,
 *                                                               alpha_c_beta,
 *                                                               alpha,             # <<<<<<<<<<<<<<
 *                                                               gamma,
 *                                                               &self.ba,
 */
  __pyx_t_21 = __pyx_PyFloat_AsDouble(__pyx_v_alpha); if (unlikely((__pyx_t_21 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4464, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4465
 *                                                               alpha_c_beta,
 *                                                               alpha,
 *                                                               gamma,             # <<<<<<<<<<<<<<
 *                                                               &self.ba,
 *                                                               &self.tsz)
 */
  __pyx_t_22 = __pyx_PyFloat_AsDouble(__pyx_v_gamma); if (unlikely((__pyx_t_22 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4465, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4444
 *                                                         alpha = 1.,
 *                                                         gamma = -0.3):
 *         return  get_pressure_P_over_P_delta_at_x_M_z_b12_200c(x_asked,             # <<<<<<<<<<<<<<
 *                                                               m_asked,
 *                                                               z_asked,
 */
  __pyx_t_23 = PyFloat_FromDouble(get_pressure_P_over_P_delta_at_x_M_z_b12_200c(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8, __pyx_t_9, __pyx_t_10, __pyx_t_11, __pyx_t_12, __pyx_t_13, __pyx_t_14, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_t_18, __pyx_t_19, __pyx_t_20, __pyx_t_21, __pyx_t_22, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 4444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __pyx_r = __pyx_t_23;
  __pyx_t_23 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4421
 *                                                  &self.tsz)
 * 
 *     def get_pressure_P_over_P_delta_at_x_M_z_b12_200c(self,             # <<<<<<<<<<<<<<
 *                                                         x_asked,
 *                                                         m_asked,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_AddTraceback("classy_sz.Class.get_pressure_P_over_P_delta_at_x_M_z_b12_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4470
 * 
 * 
 *     def get_pressure_P_over_P_delta_at_x_gnfw_500c(self,             # <<<<<<<<<<<<<<
 *                                                      x_asked,
 *                                                      P0GNFW = 8.130,
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_429get_pressure_P_over_P_delta_at_x_gnfw_500c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_429get_pressure_P_over_P_delta_at_x_gnfw_500c = {"get_pressure_P_over_P_delta_at_x_gnfw_500c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_429get_pressure_P_over_P_delta_at_x_gnfw_500c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_429get_pressure_P_over_P_delta_at_x_gnfw_500c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_x_asked = 0;
  PyObject *__pyx_v_P0GNFW = 0;
  PyObject *__pyx_v_alphaGNFW = 0;
  PyObject *__pyx_v_betaGNFW = 0;
  PyObject *__pyx_v_gammaGNFW = 0;
  PyObject *__pyx_v_c500 = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pressure_P_over_P_delta_at_x_gnfw_500c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x_asked,&__pyx_n_s_P0GNFW,&__pyx_n_s_alphaGNFW,&__pyx_n_s_betaGNFW,&__pyx_n_s_gammaGNFW,&__pyx_n_s_c500,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_8_130));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_1_0620));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_5_4807));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_3292));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_1_156));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4470, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_P0GNFW);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4470, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alphaGNFW);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4470, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_betaGNFW);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4470, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_gammaGNFW);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4470, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_c500);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4470, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pressure_P_over_P_delta_at_x_gnfw_500c") < 0)) __PYX_ERR(0, 4470, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_x_asked = values[0];
    __pyx_v_P0GNFW = values[1];
    __pyx_v_alphaGNFW = values[2];
    __pyx_v_betaGNFW = values[3];
    __pyx_v_gammaGNFW = values[4];
    __pyx_v_c500 = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pressure_P_over_P_delta_at_x_gnfw_500c", 0, 1, 6, __pyx_nargs); __PYX_ERR(0, 4470, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pressure_P_over_P_delta_at_x_gnfw_500c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_428get_pressure_P_over_P_delta_at_x_gnfw_500c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_x_asked, __pyx_v_P0GNFW, __pyx_v_alphaGNFW, __pyx_v_betaGNFW, __pyx_v_gammaGNFW, __pyx_v_c500);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_428get_pressure_P_over_P_delta_at_x_gnfw_500c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x_asked, PyObject *__pyx_v_P0GNFW, PyObject *__pyx_v_alphaGNFW, PyObject *__pyx_v_betaGNFW, PyObject *__pyx_v_gammaGNFW, PyObject *__pyx_v_c500) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  double __pyx_t_5;
  double __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pressure_P_over_P_delta_at_x_gnfw_500c", 1);

  /* "class-sz/python/classy.pyx":4477
 *                                                      gammaGNFW = 0.3292,
 *                                                      c500 = 1.156):
 *         return  get_pressure_P_over_P_delta_at_x_gnfw_500c(x_asked,             # <<<<<<<<<<<<<<
 *                                                            P0GNFW,
 *                                                            alphaGNFW,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_x_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4477, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4478
 *                                                      c500 = 1.156):
 *         return  get_pressure_P_over_P_delta_at_x_gnfw_500c(x_asked,
 *                                                            P0GNFW,             # <<<<<<<<<<<<<<
 *                                                            alphaGNFW,
 *                                                            betaGNFW,
 */
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_P0GNFW); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4478, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4479
 *         return  get_pressure_P_over_P_delta_at_x_gnfw_500c(x_asked,
 *                                                            P0GNFW,
 *                                                            alphaGNFW,             # <<<<<<<<<<<<<<
 *                                                            betaGNFW,
 *                                                            gammaGNFW,
 */
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_alphaGNFW); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4479, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4480
 *                                                            P0GNFW,
 *                                                            alphaGNFW,
 *                                                            betaGNFW,             # <<<<<<<<<<<<<<
 *                                                            gammaGNFW,
 *                                                            c500,
 */
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_betaGNFW); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4480, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4481
 *                                                            alphaGNFW,
 *                                                            betaGNFW,
 *                                                            gammaGNFW,             # <<<<<<<<<<<<<<
 *                                                            c500,
 *                                                            &self.ba,
 */
  __pyx_t_5 = __pyx_PyFloat_AsDouble(__pyx_v_gammaGNFW); if (unlikely((__pyx_t_5 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4481, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4482
 *                                                            betaGNFW,
 *                                                            gammaGNFW,
 *                                                            c500,             # <<<<<<<<<<<<<<
 *                                                            &self.ba,
 *                                                            &self.tsz)
 */
  __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_v_c500); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4482, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4477
 *                                                      gammaGNFW = 0.3292,
 *                                                      c500 = 1.156):
 *         return  get_pressure_P_over_P_delta_at_x_gnfw_500c(x_asked,             # <<<<<<<<<<<<<<
 *                                                            P0GNFW,
 *                                                            alphaGNFW,
 */
  __pyx_t_7 = PyFloat_FromDouble(get_pressure_P_over_P_delta_at_x_gnfw_500c(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4470
 * 
 * 
 *     def get_pressure_P_over_P_delta_at_x_gnfw_500c(self,             # <<<<<<<<<<<<<<
 *                                                      x_asked,
 *                                                      P0GNFW = 8.130,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.get_pressure_P_over_P_delta_at_x_gnfw_500c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4485
 *                                                            &self.ba,
 *                                                            &self.tsz)
 *     def get_dA_z1z2(self,z1,z2):             # <<<<<<<<<<<<<<
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_431get_dA_z1z2(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_431get_dA_z1z2 = {"get_dA_z1z2", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_431get_dA_z1z2, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_431get_dA_z1z2(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z1 = 0;
  PyObject *__pyx_v_z2 = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dA_z1z2 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z1,&__pyx_n_s_z2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z1)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4485, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4485, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_dA_z1z2", 1, 2, 2, 1); __PYX_ERR(0, 4485, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dA_z1z2") < 0)) __PYX_ERR(0, 4485, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z1 = values[0];
    __pyx_v_z2 = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dA_z1z2", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4485, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dA_z1z2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_430get_dA_z1z2(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z1, __pyx_v_z2);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_430get_dA_z1z2(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z1, PyObject *__pyx_v_z2) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dA_z1z2", 1);

  /* "class-sz/python/classy.pyx":4486
 *                                                            &self.tsz)
 *     def get_dA_z1z2(self,z1,z2):
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))             # <<<<<<<<<<<<<<
 * 
 *     def get_dA(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyFloat_AddCObj(__pyx_float_1_, __pyx_v_z2, 1., 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyFloat_TrueDivideCObj(__pyx_float_1_, __pyx_t_1, 1., 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Negative(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_vectorize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_dA); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_z1};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyFloat_AddCObj(__pyx_float_1_, __pyx_v_z1, 1., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyNumber_Multiply(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_vectorize); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_dA); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_z2};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyFloat_AddCObj(__pyx_float_1_, __pyx_v_z2, 1., 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4485
 *                                                            &self.ba,
 *                                                            &self.tsz)
 *     def get_dA_z1z2(self,z1,z2):             # <<<<<<<<<<<<<<
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.get_dA_z1z2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4488
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 *     def get_dA(self,z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z) in Mpc/h
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_433get_dA(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_432get_dA, "\n        angular_distance(z) in Mpc/h\n\n\n        Parameters\n        ----------\n        z : float\n                Desired redshift\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_433get_dA = {"get_dA", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_433get_dA, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_432get_dA};
static PyObject *__pyx_pw_9classy_sz_5Class_433get_dA(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dA (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4488, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dA") < 0)) __PYX_ERR(0, 4488, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dA", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4488, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dA", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_432get_dA(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_432get_dA(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double __pyx_v_D_A;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dA", 1);

  /* "class-sz/python/classy.pyx":4502
 *         cdef double * pvecback
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":4504
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4504, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":4505
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4505, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 4505, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4504
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4507
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":4508
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         D_A = pvecback[self.ba.index_bg_ang_distance]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4508, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 4508, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4507
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4510
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         D_A = pvecback[self.ba.index_bg_ang_distance]             # <<<<<<<<<<<<<<
 * 
 *         free(pvecback)
 */
  __pyx_v_D_A = (__pyx_v_pvecback[__pyx_v_self->ba.index_bg_ang_distance]);

  /* "class-sz/python/classy.pyx":4512
 *         D_A = pvecback[self.ba.index_bg_ang_distance]
 * 
 *         free(pvecback)             # <<<<<<<<<<<<<<
 * 
 *         return D_A*self.ba.h
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":4514
 *         free(pvecback)
 * 
 *         return D_A*self.ba.h             # <<<<<<<<<<<<<<
 * 
 *     def get_rad_to_arcmin(self,theta_rad):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble((__pyx_v_D_A * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4488
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 *     def get_dA(self,z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z) in Mpc/h
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.get_dA", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4516
 *         return D_A*self.ba.h
 * 
 *     def get_rad_to_arcmin(self,theta_rad):             # <<<<<<<<<<<<<<
 *         return (60.*180.)/np.pi*theta_rad
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_435get_rad_to_arcmin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_435get_rad_to_arcmin = {"get_rad_to_arcmin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_435get_rad_to_arcmin, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_435get_rad_to_arcmin(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_theta_rad = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_rad_to_arcmin (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_theta_rad,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_theta_rad)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4516, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_rad_to_arcmin") < 0)) __PYX_ERR(0, 4516, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_theta_rad = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_rad_to_arcmin", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4516, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_rad_to_arcmin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_434get_rad_to_arcmin(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_theta_rad);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_434get_rad_to_arcmin(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_theta_rad) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_rad_to_arcmin", 1);

  /* "class-sz/python/classy.pyx":4517
 * 
 *     def get_rad_to_arcmin(self,theta_rad):
 *         return (60.*180.)/np.pi*theta_rad             # <<<<<<<<<<<<<<
 * 
 *     def get_truncated_nfw_profile_at_z_k_rd_cd_xout(self, double z, double k, double r_delta, double c_delta, double xout=1):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((60. * 180.)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_pi); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_v_theta_rad); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4516
 *         return D_A*self.ba.h
 * 
 *     def get_rad_to_arcmin(self,theta_rad):             # <<<<<<<<<<<<<<
 *         return (60.*180.)/np.pi*theta_rad
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_rad_to_arcmin", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4519
 *         return (60.*180.)/np.pi*theta_rad
 * 
 *     def get_truncated_nfw_profile_at_z_k_rd_cd_xout(self, double z, double k, double r_delta, double c_delta, double xout=1):             # <<<<<<<<<<<<<<
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_437get_truncated_nfw_profile_at_z_k_rd_cd_xout(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_437get_truncated_nfw_profile_at_z_k_rd_cd_xout = {"get_truncated_nfw_profile_at_z_k_rd_cd_xout", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_437get_truncated_nfw_profile_at_z_k_rd_cd_xout, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_437get_truncated_nfw_profile_at_z_k_rd_cd_xout(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  double __pyx_v_k;
  double __pyx_v_r_delta;
  double __pyx_v_c_delta;
  double __pyx_v_xout;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_truncated_nfw_profile_at_z_k_rd_cd_xout (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_k,&__pyx_n_s_r_delta,&__pyx_n_s_c_delta,&__pyx_n_s_xout,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_truncated_nfw_profile_at_z_k_rd_cd_xout", 0, 4, 5, 1); __PYX_ERR(0, 4519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r_delta)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_truncated_nfw_profile_at_z_k_rd_cd_xout", 0, 4, 5, 2); __PYX_ERR(0, 4519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_c_delta)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_truncated_nfw_profile_at_z_k_rd_cd_xout", 0, 4, 5, 3); __PYX_ERR(0, 4519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xout);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_truncated_nfw_profile_at_z_k_rd_cd_xout") < 0)) __PYX_ERR(0, 4519, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
    __pyx_v_r_delta = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_r_delta == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
    __pyx_v_c_delta = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_c_delta == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
    if (values[4]) {
      __pyx_v_xout = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_xout == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4519, __pyx_L3_error)
    } else {
      __pyx_v_xout = ((double)1.0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_truncated_nfw_profile_at_z_k_rd_cd_xout", 0, 4, 5, __pyx_nargs); __PYX_ERR(0, 4519, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_truncated_nfw_profile_at_z_k_rd_cd_xout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_436get_truncated_nfw_profile_at_z_k_rd_cd_xout(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_k, __pyx_v_r_delta, __pyx_v_c_delta, __pyx_v_xout);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_436get_truncated_nfw_profile_at_z_k_rd_cd_xout(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_k, double __pyx_v_r_delta, double __pyx_v_c_delta, double __pyx_v_xout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_truncated_nfw_profile_at_z_k_rd_cd_xout", 1);

  /* "class-sz/python/classy.pyx":4520
 * 
 *     def get_truncated_nfw_profile_at_z_k_rd_cd_xout(self, double z, double k, double r_delta, double c_delta, double xout=1):
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(evaluate_truncated_nfw_profile(__pyx_v_z, __pyx_v_k, __pyx_v_r_delta, __pyx_v_c_delta, __pyx_v_xout)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4519
 *         return (60.*180.)/np.pi*theta_rad
 * 
 *     def get_truncated_nfw_profile_at_z_k_rd_cd_xout(self, double z, double k, double r_delta, double c_delta, double xout=1):             # <<<<<<<<<<<<<<
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_truncated_nfw_profile_at_z_k_rd_cd_xout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4523
 * 
 * 
 *     def get_truncated_nfw_profile_at_z_k_m_xout(self, double z, double k, double m, double xout=1):             # <<<<<<<<<<<<<<
 *         delta_def = self.tsz.delta_def_matter_density
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_439get_truncated_nfw_profile_at_z_k_m_xout(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_439get_truncated_nfw_profile_at_z_k_m_xout = {"get_truncated_nfw_profile_at_z_k_m_xout", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_439get_truncated_nfw_profile_at_z_k_m_xout, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_439get_truncated_nfw_profile_at_z_k_m_xout(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  double __pyx_v_k;
  double __pyx_v_m;
  double __pyx_v_xout;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_truncated_nfw_profile_at_z_k_m_xout (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_k,&__pyx_n_s_m,&__pyx_n_s_xout,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_truncated_nfw_profile_at_z_k_m_xout", 0, 3, 4, 1); __PYX_ERR(0, 4523, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_truncated_nfw_profile_at_z_k_m_xout", 0, 3, 4, 2); __PYX_ERR(0, 4523, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xout);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_truncated_nfw_profile_at_z_k_m_xout") < 0)) __PYX_ERR(0, 4523, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
    __pyx_v_m = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_m == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
    if (values[3]) {
      __pyx_v_xout = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_xout == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4523, __pyx_L3_error)
    } else {
      __pyx_v_xout = ((double)1.0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_truncated_nfw_profile_at_z_k_m_xout", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4523, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_truncated_nfw_profile_at_z_k_m_xout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_438get_truncated_nfw_profile_at_z_k_m_xout(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_k, __pyx_v_m, __pyx_v_xout);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_438get_truncated_nfw_profile_at_z_k_m_xout(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_k, double __pyx_v_m, double __pyx_v_xout) {
  int __pyx_v_delta_def;
  PyObject *__pyx_v_delta = NULL;
  PyObject *__pyx_v_r_delta = NULL;
  PyObject *__pyx_v_c_delta = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  double __pyx_t_9;
  double __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_truncated_nfw_profile_at_z_k_m_xout", 1);

  /* "class-sz/python/classy.pyx":4524
 * 
 *     def get_truncated_nfw_profile_at_z_k_m_xout(self, double z, double k, double m, double xout=1):
 *         delta_def = self.tsz.delta_def_matter_density             # <<<<<<<<<<<<<<
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 *         r_delta = self.get_r_delta_of_m_delta_at_z(delta,m,z)
 */
  __pyx_t_1 = __pyx_v_self->tsz.delta_def_matter_density;
  __pyx_v_delta_def = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4525
 *     def get_truncated_nfw_profile_at_z_k_m_xout(self, double z, double k, double m, double xout=1):
 *         delta_def = self.tsz.delta_def_matter_density
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)             # <<<<<<<<<<<<<<
 *         r_delta = self.get_r_delta_of_m_delta_at_z(delta,m,z)
 *         c_delta = self.get_c_delta_at_m_and_z(m,z,delta_def)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_delta_from_delta_def_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_delta_def); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_delta = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4526
 *         delta_def = self.tsz.delta_def_matter_density
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 *         r_delta = self.get_r_delta_of_m_delta_at_z(delta,m,z)             # <<<<<<<<<<<<<<
 *         c_delta = self.get_c_delta_at_m_and_z(m,z,delta_def)
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_r_delta_of_m_delta_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_m); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_v_delta, __pyx_t_5, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4526, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_r_delta = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4527
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 *         r_delta = self.get_r_delta_of_m_delta_at_z(delta,m,z)
 *         c_delta = self.get_c_delta_at_m_and_z(m,z,delta_def)             # <<<<<<<<<<<<<<
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_c_delta_at_m_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_m); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_delta_def); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_t_4, __pyx_t_5, __pyx_t_6};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_c_delta = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4528
 *         r_delta = self.get_r_delta_of_m_delta_at_z(delta,m,z)
 *         c_delta = self.get_c_delta_at_m_and_z(m,z,delta_def)
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_v_r_delta); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4528, __pyx_L1_error)
  __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_c_delta); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4528, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(evaluate_truncated_nfw_profile(__pyx_v_z, __pyx_v_k, __pyx_t_9, __pyx_t_10, __pyx_v_xout)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4523
 * 
 * 
 *     def get_truncated_nfw_profile_at_z_k_m_xout(self, double z, double k, double m, double xout=1):             # <<<<<<<<<<<<<<
 *         delta_def = self.tsz.delta_def_matter_density
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.get_truncated_nfw_profile_at_z_k_m_xout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_delta);
  __Pyx_XDECREF(__pyx_v_r_delta);
  __Pyx_XDECREF(__pyx_v_c_delta);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4533
 * 
 *     # Define the vectorized method
 *     def get_uk_nfw(self, z_input, k_input, m_input, double xout=1):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the truncated NFW profile at given redshifts, wavenumbers, and masses.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_441get_uk_nfw(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_440get_uk_nfw, "\n        Vectorized computation of the truncated NFW profile at given redshifts, wavenumbers, and masses.\n\n        This method handles both scalar and array inputs for redshifts (z_input), wavenumbers (k_input), and masses (m_input).\n\n        Parameters:\n        z_input (float or np.ndarray): A scalar or 1D array of redshifts.\n        k_input (float or np.ndarray): A scalar or 1D array of wavenumbers in mpc/h.\n        m_input (float or np.ndarray): A scalar or 1D array of masses in msun/h.\n        xout (float): Optional; the xout parameter, setting the truncation radius at xout*r_delta, default is 1.\n\n        Returns:\n        np.ndarray: An array of profile values corresponding to the input redshifts, wavenumbers, and masses.\n\n        Raises:\n        TypeError: If the inputs are not floats or 1D arrays of floats.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_441get_uk_nfw = {"get_uk_nfw", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_441get_uk_nfw, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_440get_uk_nfw};
static PyObject *__pyx_pw_9classy_sz_5Class_441get_uk_nfw(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_input = 0;
  PyObject *__pyx_v_k_input = 0;
  PyObject *__pyx_v_m_input = 0;
  double __pyx_v_xout;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_uk_nfw (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_input,&__pyx_n_s_k_input,&__pyx_n_s_m_input,&__pyx_n_s_xout,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4533, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4533, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_uk_nfw", 0, 3, 4, 1); __PYX_ERR(0, 4533, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4533, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_uk_nfw", 0, 3, 4, 2); __PYX_ERR(0, 4533, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xout);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4533, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_uk_nfw") < 0)) __PYX_ERR(0, 4533, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z_input = values[0];
    __pyx_v_k_input = values[1];
    __pyx_v_m_input = values[2];
    if (values[3]) {
      __pyx_v_xout = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_xout == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4533, __pyx_L3_error)
    } else {
      __pyx_v_xout = ((double)1.0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_uk_nfw", 0, 3, 4, __pyx_nargs); __PYX_ERR(0, 4533, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_uk_nfw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_440get_uk_nfw(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_input, __pyx_v_k_input, __pyx_v_m_input, __pyx_v_xout);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4552
 *         """
 *         # Helper function to calculate the profile for a given set of inputs
 *         def compute_profile(double z, double k, double m, double xout):             # <<<<<<<<<<<<<<
 *             delta_def = self.tsz.delta_def_matter_density
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_10get_uk_nfw_1compute_profile(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_10get_uk_nfw_1compute_profile = {"compute_profile", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_10get_uk_nfw_1compute_profile, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_10get_uk_nfw_1compute_profile(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  double __pyx_v_k;
  double __pyx_v_m;
  double __pyx_v_xout;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("compute_profile (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_k,&__pyx_n_s_m,&__pyx_n_s_xout,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("compute_profile", 1, 4, 4, 1); __PYX_ERR(0, 4552, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("compute_profile", 1, 4, 4, 2); __PYX_ERR(0, 4552, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xout)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("compute_profile", 1, 4, 4, 3); __PYX_ERR(0, 4552, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "compute_profile") < 0)) __PYX_ERR(0, 4552, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
    __pyx_v_m = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_m == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
    __pyx_v_xout = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_xout == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4552, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("compute_profile", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 4552, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_uk_nfw.compute_profile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_10get_uk_nfw_compute_profile(__pyx_self, __pyx_v_z, __pyx_v_k, __pyx_v_m, __pyx_v_xout);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_10get_uk_nfw_compute_profile(PyObject *__pyx_self, double __pyx_v_z, double __pyx_v_k, double __pyx_v_m, double __pyx_v_xout) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *__pyx_cur_scope;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *__pyx_outer_scope;
  int __pyx_v_delta_def;
  PyObject *__pyx_v_delta = NULL;
  PyObject *__pyx_v_r_delta = NULL;
  PyObject *__pyx_v_c_delta = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  double __pyx_t_9;
  double __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("compute_profile", 1);
  __pyx_outer_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "class-sz/python/classy.pyx":4553
 *         # Helper function to calculate the profile for a given set of inputs
 *         def compute_profile(double z, double k, double m, double xout):
 *             delta_def = self.tsz.delta_def_matter_density             # <<<<<<<<<<<<<<
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 *             r_delta = self.get_r_delta_of_m_delta_at_z(delta, m, z)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4553, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self->tsz.delta_def_matter_density;
  __pyx_v_delta_def = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4554
 *         def compute_profile(double z, double k, double m, double xout):
 *             delta_def = self.tsz.delta_def_matter_density
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)             # <<<<<<<<<<<<<<
 *             r_delta = self.get_r_delta_of_m_delta_at_z(delta, m, z)
 *             c_delta = self.get_c_delta_at_m_and_z(m, z, delta_def)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4554, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_get_delta_from_delta_def_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_delta_def); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_4, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_delta = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4555
 *             delta_def = self.tsz.delta_def_matter_density
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 *             r_delta = self.get_r_delta_of_m_delta_at_z(delta, m, z)             # <<<<<<<<<<<<<<
 *             c_delta = self.get_c_delta_at_m_and_z(m, z, delta_def)
 *             return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4555, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_get_r_delta_of_m_delta_at_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_m); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_6, __pyx_v_delta, __pyx_t_5, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_r_delta = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4556
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 *             r_delta = self.get_r_delta_of_m_delta_at_z(delta, m, z)
 *             c_delta = self.get_c_delta_at_m_and_z(m, z, delta_def)             # <<<<<<<<<<<<<<
 *             return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 * 
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 4556, __pyx_L1_error) }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_get_c_delta_at_m_and_z); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_m); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_z); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_delta_def); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_8, __pyx_t_4, __pyx_t_5, __pyx_t_6};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_c_delta = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4557
 *             r_delta = self.get_r_delta_of_m_delta_at_z(delta, m, z)
 *             c_delta = self.get_c_delta_at_m_and_z(m, z, delta_def)
 *             return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)             # <<<<<<<<<<<<<<
 * 
 *         # Function to handle all combinations of inputs
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_v_r_delta); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4557, __pyx_L1_error)
  __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_c_delta); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4557, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(evaluate_truncated_nfw_profile(__pyx_v_z, __pyx_v_k, __pyx_t_9, __pyx_t_10, __pyx_v_xout)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4552
 *         """
 *         # Helper function to calculate the profile for a given set of inputs
 *         def compute_profile(double z, double k, double m, double xout):             # <<<<<<<<<<<<<<
 *             delta_def = self.tsz.delta_def_matter_density
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.get_uk_nfw.compute_profile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_delta);
  __Pyx_XDECREF(__pyx_v_r_delta);
  __Pyx_XDECREF(__pyx_v_c_delta);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4560
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(z_vals, k_vals, m_vals):             # <<<<<<<<<<<<<<
 *             z_len = len(z_vals)
 *             k_len = len(k_vals)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_10get_uk_nfw_3handle_combinations(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_10get_uk_nfw_3handle_combinations = {"handle_combinations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_10get_uk_nfw_3handle_combinations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_10get_uk_nfw_3handle_combinations(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_vals = 0;
  PyObject *__pyx_v_k_vals = 0;
  PyObject *__pyx_v_m_vals = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("handle_combinations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_vals,&__pyx_n_s_k_vals,&__pyx_n_s_m_vals,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_vals)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4560, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_vals)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4560, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("handle_combinations", 1, 3, 3, 1); __PYX_ERR(0, 4560, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_vals)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4560, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("handle_combinations", 1, 3, 3, 2); __PYX_ERR(0, 4560, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "handle_combinations") < 0)) __PYX_ERR(0, 4560, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_z_vals = values[0];
    __pyx_v_k_vals = values[1];
    __pyx_v_m_vals = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("handle_combinations", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4560, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_uk_nfw.handle_combinations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_10get_uk_nfw_2handle_combinations(__pyx_self, __pyx_v_z_vals, __pyx_v_k_vals, __pyx_v_m_vals);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_10get_uk_nfw_2handle_combinations(PyObject *__pyx_self, PyObject *__pyx_v_z_vals, PyObject *__pyx_v_k_vals, PyObject *__pyx_v_m_vals) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *__pyx_cur_scope;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *__pyx_outer_scope;
  Py_ssize_t __pyx_v_z_len;
  Py_ssize_t __pyx_v_k_len;
  Py_ssize_t __pyx_v_m_len;
  PyObject *__pyx_v_result = NULL;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_j;
  Py_ssize_t __pyx_v_k;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  double __pyx_t_15;
  double __pyx_t_16;
  double __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("handle_combinations", 1);
  __pyx_outer_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "class-sz/python/classy.pyx":4561
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(z_vals, k_vals, m_vals):
 *             z_len = len(z_vals)             # <<<<<<<<<<<<<<
 *             k_len = len(k_vals)
 *             m_len = len(m_vals)
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_z_vals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4561, __pyx_L1_error)
  __pyx_v_z_len = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4562
 *         def handle_combinations(z_vals, k_vals, m_vals):
 *             z_len = len(z_vals)
 *             k_len = len(k_vals)             # <<<<<<<<<<<<<<
 *             m_len = len(m_vals)
 *             result = np.empty((z_len, k_len, m_len), dtype=np.float64)
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_k_vals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4562, __pyx_L1_error)
  __pyx_v_k_len = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4563
 *             z_len = len(z_vals)
 *             k_len = len(k_vals)
 *             m_len = len(m_vals)             # <<<<<<<<<<<<<<
 *             result = np.empty((z_len, k_len, m_len), dtype=np.float64)
 *             for i in range(z_len):
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_m_vals); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4563, __pyx_L1_error)
  __pyx_v_m_len = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4564
 *             k_len = len(k_vals)
 *             m_len = len(m_vals)
 *             result = np.empty((z_len, k_len, m_len), dtype=np.float64)             # <<<<<<<<<<<<<<
 *             for i in range(z_len):
 *                 for j in range(k_len):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_z_len); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_k_len); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_m_len); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 4564, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(0, 4564, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5)) __PYX_ERR(0, 4564, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 4564, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_2) < 0) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_result = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4565
 *             m_len = len(m_vals)
 *             result = np.empty((z_len, k_len, m_len), dtype=np.float64)
 *             for i in range(z_len):             # <<<<<<<<<<<<<<
 *                 for j in range(k_len):
 *                     for k in range(m_len):
 */
  __pyx_t_1 = __pyx_v_z_len;
  __pyx_t_7 = __pyx_t_1;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "class-sz/python/classy.pyx":4566
 *             result = np.empty((z_len, k_len, m_len), dtype=np.float64)
 *             for i in range(z_len):
 *                 for j in range(k_len):             # <<<<<<<<<<<<<<
 *                     for k in range(m_len):
 *                         result[i, j, k] = compute_profile(z_vals[i], k_vals[j], m_vals[k], xout)
 */
    __pyx_t_9 = __pyx_v_k_len;
    __pyx_t_10 = __pyx_t_9;
    for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
      __pyx_v_j = __pyx_t_11;

      /* "class-sz/python/classy.pyx":4567
 *             for i in range(z_len):
 *                 for j in range(k_len):
 *                     for k in range(m_len):             # <<<<<<<<<<<<<<
 *                         result[i, j, k] = compute_profile(z_vals[i], k_vals[j], m_vals[k], xout)
 *             return result
 */
      __pyx_t_12 = __pyx_v_m_len;
      __pyx_t_13 = __pyx_t_12;
      for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
        __pyx_v_k = __pyx_t_14;

        /* "class-sz/python/classy.pyx":4568
 *                 for j in range(k_len):
 *                     for k in range(m_len):
 *                         result[i, j, k] = compute_profile(z_vals[i], k_vals[j], m_vals[k], xout)             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_z_vals, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_15 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_15 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_k_vals, __pyx_v_j, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_16 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_16 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_m_vals, __pyx_v_k, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_17 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_17 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_cur_scope->__pyx_v_compute_profile)) { __Pyx_RaiseClosureNameError("compute_profile"); __PYX_ERR(0, 4568, __pyx_L1_error) }
        __pyx_t_2 = __pyx_pf_9classy_sz_5Class_10get_uk_nfw_compute_profile(__pyx_cur_scope->__pyx_v_compute_profile, __pyx_t_15, __pyx_t_16, __pyx_t_17, __pyx_cur_scope->__pyx_v_xout); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_j); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_k); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_6);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6)) __PYX_ERR(0, 4568, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5)) __PYX_ERR(0, 4568, __pyx_L1_error);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3)) __PYX_ERR(0, 4568, __pyx_L1_error);
        __pyx_t_6 = 0;
        __pyx_t_5 = 0;
        __pyx_t_3 = 0;
        if (unlikely((PyObject_SetItem(__pyx_v_result, __pyx_t_4, __pyx_t_2) < 0))) __PYX_ERR(0, 4568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
  }

  /* "class-sz/python/classy.pyx":4569
 *                     for k in range(m_len):
 *                         result[i, j, k] = compute_profile(z_vals[i], k_vals[j], m_vals[k], xout)
 *             return result             # <<<<<<<<<<<<<<
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4560
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(z_vals, k_vals, m_vals):             # <<<<<<<<<<<<<<
 *             z_len = len(z_vals)
 *             k_len = len(k_vals)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.get_uk_nfw.handle_combinations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4533
 * 
 *     # Define the vectorized method
 *     def get_uk_nfw(self, z_input, k_input, m_input, double xout=1):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the truncated NFW profile at given redshifts, wavenumbers, and masses.
 */

static PyObject *__pyx_pf_9classy_sz_5Class_440get_uk_nfw(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_k_input, PyObject *__pyx_v_m_input, double __pyx_v_xout) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *__pyx_cur_scope;
  PyObject *__pyx_v_handle_combinations = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_uk_nfw", 0);
  __pyx_cur_scope = (struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *)__pyx_tp_new_9classy_sz___pyx_scope_struct_5_get_uk_nfw(__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 4533, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_xout = __pyx_v_xout;
  __Pyx_INCREF(__pyx_v_z_input);
  __Pyx_INCREF(__pyx_v_k_input);
  __Pyx_INCREF(__pyx_v_m_input);

  /* "class-sz/python/classy.pyx":4552
 *         """
 *         # Helper function to calculate the profile for a given set of inputs
 *         def compute_profile(double z, double k, double m, double xout):             # <<<<<<<<<<<<<<
 *             delta_def = self.tsz.delta_def_matter_density
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_10get_uk_nfw_1compute_profile, 0, __pyx_n_s_get_uk_nfw_locals_compute_profil, ((PyObject*)__pyx_cur_scope), __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__39)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_compute_profile = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4560
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(z_vals, k_vals, m_vals):             # <<<<<<<<<<<<<<
 *             z_len = len(z_vals)
 *             k_len = len(k_vals)
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_10get_uk_nfw_3handle_combinations, 0, __pyx_n_s_get_uk_nfw_locals_handle_combina, ((PyObject*)__pyx_cur_scope), __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__41)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_handle_combinations = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4572
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(k_input, (float, np.float64)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_z_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_z_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4573
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 *         if isinstance(k_input, (float, np.float64)):
 *             k_input = np.array([k_input], dtype=np.float64)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_z_input);
    __Pyx_GIVEREF(__pyx_v_z_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_z_input)) __PYX_ERR(0, 4573, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4573, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_z_input, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":4572
 * 
 *         # Handle the cases where inputs can be scalars or arrays
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(k_input, (float, np.float64)):
 */
  }

  /* "class-sz/python/classy.pyx":4574
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(k_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             k_input = np.array([k_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_k_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_k_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4575
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(k_input, (float, np.float64)):
 *             k_input = np.array([k_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 *         if isinstance(m_input, (float, np.float64)):
 *             m_input = np.array([m_input], dtype=np.float64)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_k_input);
    __Pyx_GIVEREF(__pyx_v_k_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_k_input)) __PYX_ERR(0, 4575, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4575, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_k_input, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":4574
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(k_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             k_input = np.array([k_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 */
  }

  /* "class-sz/python/classy.pyx":4576
 *         if isinstance(k_input, (float, np.float64)):
 *             k_input = np.array([k_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             m_input = np.array([m_input], dtype=np.float64)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_m_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_m_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L10_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4577
 *             k_input = np.array([k_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 *             m_input = np.array([m_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         # Ensure all inputs are 1D numpy arrays
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_m_input);
    __Pyx_GIVEREF(__pyx_v_m_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_m_input)) __PYX_ERR(0, 4577, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4577, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_m_input, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":4576
 *         if isinstance(k_input, (float, np.float64)):
 *             k_input = np.array([k_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             m_input = np.array([m_input], dtype=np.float64)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4580
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(k_input, np.ndarray) and k_input.ndim == 1 and k_input.dtype == np.float64 and
 *                 isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_z_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4580, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }

  /* "class-sz/python/classy.pyx":4581
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64 and
 *                 isinstance(k_input, np.ndarray) and k_input.ndim == 1 and k_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_k_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_k_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4581, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_k_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_float64); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4581, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4581, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }

  /* "class-sz/python/classy.pyx":4582
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64 and
 *                 isinstance(k_input, np.ndarray) and k_input.ndim == 1 and k_input.dtype == np.float64 and
 *                 isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")
 * 
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_m_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_5, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L13_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_5, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L13_bool_binop_done:;

  /* "class-sz/python/classy.pyx":4580
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(k_input, np.ndarray) and k_input.ndim == 1 and k_input.dtype == np.float64 and
 *                 isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 */
  __pyx_t_4 = (!__pyx_t_3);
  if (unlikely(__pyx_t_4)) {

    /* "class-sz/python/classy.pyx":4583
 *                 isinstance(k_input, np.ndarray) and k_input.ndim == 1 and k_input.dtype == np.float64 and
 *                 isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")             # <<<<<<<<<<<<<<
 * 
 *         # Compute the profile for all combinations of inputs
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 4583, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4580
 * 
 *         # Ensure all inputs are 1D numpy arrays
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64 and             # <<<<<<<<<<<<<<
 *                 isinstance(k_input, np.ndarray) and k_input.ndim == 1 and k_input.dtype == np.float64 and
 *                 isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 */
  }

  /* "class-sz/python/classy.pyx":4586
 * 
 *         # Compute the profile for all combinations of inputs
 *         return handle_combinations(z_input, k_input, m_input)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_pf_9classy_sz_5Class_10get_uk_nfw_2handle_combinations(__pyx_v_handle_combinations, __pyx_v_z_input, __pyx_v_k_input, __pyx_v_m_input); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4533
 * 
 *     # Define the vectorized method
 *     def get_uk_nfw(self, z_input, k_input, m_input, double xout=1):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the truncated NFW profile at given redshifts, wavenumbers, and masses.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("classy_sz.Class.get_uk_nfw", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handle_combinations);
  __Pyx_XDECREF(__pyx_v_z_input);
  __Pyx_XDECREF(__pyx_v_k_input);
  __Pyx_XDECREF(__pyx_v_m_input);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4592
 * 
 *     # Define the general method
 *     def get_uk(self, z_input, k_input, m_input, double xout=1, profile="nfw"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the profile at given redshifts, wavenumbers, and masses.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_443get_uk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_442get_uk, "\n        General computation of the profile at given redshifts, wavenumbers, and masses.\n\n        This method handles both scalar and array inputs for redshifts (z_input), wavenumbers (k_input), and masses (m_input).\n        It returns the corresponding profile based on the specified profile type.\n\n        Parameters:\n        z_input (float or np.ndarray): A scalar or 1D array of redshifts.\n        k_input (float or np.ndarray): A scalar or 1D array of wavenumbers in mpc/h.\n        m_input (float or np.ndarray): A scalar or 1D array of masses in msun/h.\n        xout (float): Optional; the xout parameter, setting the truncation radius at xout*r_delta, default is 1.\n        profile (str): Optional; the profile type, default is \"nfw\".\n\n        Returns:\n        np.ndarray: An array of profile values corresponding to the input redshifts, wavenumbers, and masses for the specified profile type.\n\n        Raises:\n        TypeError: If the inputs are not floats or 1D arrays of floats.\n        NotImplementedError: If the specified profile type is not implemented.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_443get_uk = {"get_uk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_443get_uk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_442get_uk};
static PyObject *__pyx_pw_9classy_sz_5Class_443get_uk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_input = 0;
  PyObject *__pyx_v_k_input = 0;
  PyObject *__pyx_v_m_input = 0;
  double __pyx_v_xout;
  PyObject *__pyx_v_profile = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_uk (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_input,&__pyx_n_s_k_input,&__pyx_n_s_m_input,&__pyx_n_s_xout,&__pyx_n_s_profile,0};
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_n_u_nfw));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4592, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4592, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_uk", 0, 3, 5, 1); __PYX_ERR(0, 4592, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4592, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_uk", 0, 3, 5, 2); __PYX_ERR(0, 4592, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xout);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4592, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_profile);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4592, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_uk") < 0)) __PYX_ERR(0, 4592, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z_input = values[0];
    __pyx_v_k_input = values[1];
    __pyx_v_m_input = values[2];
    if (values[3]) {
      __pyx_v_xout = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_xout == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4592, __pyx_L3_error)
    } else {
      __pyx_v_xout = ((double)1.0);
    }
    __pyx_v_profile = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_uk", 0, 3, 5, __pyx_nargs); __PYX_ERR(0, 4592, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_uk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_442get_uk(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_input, __pyx_v_k_input, __pyx_v_m_input, __pyx_v_xout, __pyx_v_profile);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_442get_uk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_k_input, PyObject *__pyx_v_m_input, double __pyx_v_xout, PyObject *__pyx_v_profile) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_uk", 1);

  /* "class-sz/python/classy.pyx":4613
 *         NotImplementedError: If the specified profile type is not implemented.
 *         """
 *         if profile == "nfw":             # <<<<<<<<<<<<<<
 *             return self.get_uk_nfw(z_input, k_input, m_input, xout)
 *         else:
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_profile, __pyx_n_u_nfw, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4613, __pyx_L1_error)
  if (likely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":4614
 *         """
 *         if profile == "nfw":
 *             return self.get_uk_nfw(z_input, k_input, m_input, xout)             # <<<<<<<<<<<<<<
 *         else:
 *             raise NotImplementedError(f"Profile '{profile}' is not implemented yet.")
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_uk_nfw); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyFloat_FromDouble(__pyx_v_xout); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_5, __pyx_v_z_input, __pyx_v_k_input, __pyx_v_m_input, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4614, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":4613
 *         NotImplementedError: If the specified profile type is not implemented.
 *         """
 *         if profile == "nfw":             # <<<<<<<<<<<<<<
 *             return self.get_uk_nfw(z_input, k_input, m_input, xout)
 *         else:
 */
  }

  /* "class-sz/python/classy.pyx":4616
 *             return self.get_uk_nfw(z_input, k_input, m_input, xout)
 *         else:
 *             raise NotImplementedError(f"Profile '{profile}' is not implemented yet.")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = 0;
    __pyx_t_8 = 127;
    __Pyx_INCREF(__pyx_kp_u_Profile);
    __pyx_t_7 += 9;
    __Pyx_GIVEREF(__pyx_kp_u_Profile);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_Profile);
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_profile, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u_is_not_implemented_yet);
    __pyx_t_7 += 25;
    __Pyx_GIVEREF(__pyx_kp_u_is_not_implemented_yet);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_is_not_implemented_yet);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_NotImplementedError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4616, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4616, __pyx_L1_error)
  }

  /* "class-sz/python/classy.pyx":4592
 * 
 *     # Define the general method
 *     def get_uk(self, z_input, k_input, m_input, double xout=1, profile="nfw"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the profile at given redshifts, wavenumbers, and masses.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_uk", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4619
 * 
 * 
 *     def get_arcmin_to_rad(self,theta_arcmin):             # <<<<<<<<<<<<<<
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_445get_arcmin_to_rad(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_445get_arcmin_to_rad = {"get_arcmin_to_rad", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_445get_arcmin_to_rad, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_445get_arcmin_to_rad(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_theta_arcmin = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_arcmin_to_rad (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_theta_arcmin,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_theta_arcmin)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4619, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_arcmin_to_rad") < 0)) __PYX_ERR(0, 4619, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_theta_arcmin = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_arcmin_to_rad", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4619, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_arcmin_to_rad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_444get_arcmin_to_rad(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_theta_arcmin);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_444get_arcmin_to_rad(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_theta_arcmin) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_arcmin_to_rad", 1);

  /* "class-sz/python/classy.pyx":4620
 * 
 *     def get_arcmin_to_rad(self,theta_arcmin):
 *         return np.pi/(60.*180.)*theta_arcmin             # <<<<<<<<<<<<<<
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_pi); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyFloat_FromDouble((60. * 180.)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Multiply(__pyx_t_3, __pyx_v_theta_arcmin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4619
 * 
 * 
 *     def get_arcmin_to_rad(self,theta_arcmin):             # <<<<<<<<<<<<<<
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_arcmin_to_rad", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4622
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_447get_gas_profile_at_x_M_z_nfw_200m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_447get_gas_profile_at_x_M_z_nfw_200m = {"get_gas_profile_at_x_M_z_nfw_200m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_447get_gas_profile_at_x_M_z_nfw_200m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_447get_gas_profile_at_x_M_z_nfw_200m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_r_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_nfw_200m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_r_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4622, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4622, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_nfw_200m", 1, 3, 3, 1); __PYX_ERR(0, 4622, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4622, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_nfw_200m", 1, 3, 3, 2); __PYX_ERR(0, 4622, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_gas_profile_at_x_M_z_nfw_200m") < 0)) __PYX_ERR(0, 4622, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_r_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_nfw_200m", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4622, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_nfw_200m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_446get_gas_profile_at_x_M_z_nfw_200m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_r_asked, __pyx_v_m_asked, __pyx_v_z_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_446get_gas_profile_at_x_M_z_nfw_200m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_nfw_200m", 1);

  /* "class-sz/python/classy.pyx":4623
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_gas_profile_at_x_M_z_bcm_200c(self, x_asked, m_asked,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_r_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4623, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4623, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4623, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_gas_profile_at_x_M_z_nfw_200m(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4622
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_nfw_200m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4625
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_bcm_200c(self, x_asked, m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_449get_gas_profile_at_x_M_z_bcm_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_449get_gas_profile_at_x_M_z_bcm_200c = {"get_gas_profile_at_x_M_z_bcm_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_449get_gas_profile_at_x_M_z_bcm_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_449get_gas_profile_at_x_M_z_bcm_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_x_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_bcm_200c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4625, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4625, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_bcm_200c", 1, 3, 3, 1); __PYX_ERR(0, 4625, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4625, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_bcm_200c", 1, 3, 3, 2); __PYX_ERR(0, 4625, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_gas_profile_at_x_M_z_bcm_200c") < 0)) __PYX_ERR(0, 4625, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_x_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_bcm_200c", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4625, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_bcm_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_448get_gas_profile_at_x_M_z_bcm_200c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_x_asked, __pyx_v_m_asked, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_448get_gas_profile_at_x_M_z_bcm_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_x_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_bcm_200c", 1);

  /* "class-sz/python/classy.pyx":4626
 * 
 *     def get_gas_profile_at_x_M_z_bcm_200c(self, x_asked, m_asked,z):
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_rvir_of_m200c_at_z(self,m_asked,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_x_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4626, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4626, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4626, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_gas_profile_at_x_M_z_bcm_200c(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4625
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_bcm_200c(self, x_asked, m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_bcm_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4628
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_rvir_of_m200c_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_451get_rvir_of_m200c_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_451get_rvir_of_m200c_at_z = {"get_rvir_of_m200c_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_451get_rvir_of_m200c_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_451get_rvir_of_m200c_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_rvir_of_m200c_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m_asked,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4628, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4628, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_rvir_of_m200c_at_z", 1, 2, 2, 1); __PYX_ERR(0, 4628, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_rvir_of_m200c_at_z") < 0)) __PYX_ERR(0, 4628, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m_asked = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_rvir_of_m200c_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4628, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_rvir_of_m200c_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_450get_rvir_of_m200c_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m_asked, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_450get_rvir_of_m200c_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_rvir_of_m200c_at_z", 1);

  /* "class-sz/python/classy.pyx":4629
 * 
 *     def get_rvir_of_m200c_at_z(self,m_asked,z):
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_Delta_c_of_Omega_m(self,Omega_m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4629, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4629, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_rvir_of_m200c_at_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4628
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_rvir_of_m200c_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_rvir_of_m200c_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4631
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_Delta_c_of_Omega_m(self,Omega_m):             # <<<<<<<<<<<<<<
 *         return Delta_c_of_Omega_m(Omega_m)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_453get_Delta_c_of_Omega_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_453get_Delta_c_of_Omega_m = {"get_Delta_c_of_Omega_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_453get_Delta_c_of_Omega_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_453get_Delta_c_of_Omega_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_Omega_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_Delta_c_of_Omega_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_Omega_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_Omega_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4631, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_Delta_c_of_Omega_m") < 0)) __PYX_ERR(0, 4631, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_Omega_m = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_Delta_c_of_Omega_m", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4631, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_Delta_c_of_Omega_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_452get_Delta_c_of_Omega_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_Omega_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_452get_Delta_c_of_Omega_m(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_Omega_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_Delta_c_of_Omega_m", 1);

  /* "class-sz/python/classy.pyx":4632
 * 
 *     def get_Delta_c_of_Omega_m(self,Omega_m):
 *         return Delta_c_of_Omega_m(Omega_m)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_Omega_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4632, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(Delta_c_of_Omega_m(__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4631
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_Delta_c_of_Omega_m(self,Omega_m):             # <<<<<<<<<<<<<<
 *         return Delta_c_of_Omega_m(Omega_m)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_Delta_c_of_Omega_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4635
 * 
 * 
 *     def get_cvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_455get_cvir_of_mvir_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_455get_cvir_of_mvir_at_z = {"get_cvir_of_mvir_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_455get_cvir_of_mvir_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_455get_cvir_of_mvir_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_cvir_of_mvir_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m_asked,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4635, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4635, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_cvir_of_mvir_at_z", 1, 2, 2, 1); __PYX_ERR(0, 4635, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_cvir_of_mvir_at_z") < 0)) __PYX_ERR(0, 4635, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m_asked = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_cvir_of_mvir_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4635, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_cvir_of_mvir_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_454get_cvir_of_mvir_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m_asked, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_454get_cvir_of_mvir_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_cvir_of_mvir_at_z", 1);

  /* "class-sz/python/classy.pyx":4636
 * 
 *     def get_cvir_of_mvir_at_z(self,m_asked,z):
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 *     def get_Omega_m_at_z(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4636, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4636, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(evaluate_cvir_of_mvir(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4635
 * 
 * 
 *     def get_cvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_cvir_of_mvir_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4638
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 *     def get_Omega_m_at_z(self,z):             # <<<<<<<<<<<<<<
 *         cdef double tau
 *         cdef int last_index #junk
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_457get_Omega_m_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_457get_Omega_m_at_z = {"get_Omega_m_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_457get_Omega_m_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_457get_Omega_m_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_Omega_m_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4638, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_Omega_m_at_z") < 0)) __PYX_ERR(0, 4638, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_Omega_m_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4638, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_Omega_m_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_456get_Omega_m_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_456get_Omega_m_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  double __pyx_v_tau;
  int __pyx_v_last_index;
  double *__pyx_v_pvecback;
  double __pyx_v_omega;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_Omega_m_at_z", 1);

  /* "class-sz/python/classy.pyx":4643
 *         cdef double * pvecback
 * 
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))             # <<<<<<<<<<<<<<
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 */
  __pyx_v_pvecback = ((double *)calloc(__pyx_v_self->ba.bg_size, (sizeof(double))));

  /* "class-sz/python/classy.pyx":4645
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4645, __pyx_L1_error)
  __pyx_t_2 = (background_tau_of_z((&__pyx_v_self->ba), __pyx_t_1, (&__pyx_v_tau)) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":4646
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 4646, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4645
 *         pvecback = <double*> calloc(self.ba.bg_size,sizeof(double))
 * 
 *         if background_tau_of_z(&self.ba,z,&tau)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4648
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_2 = (background_at_tau((&__pyx_v_self->ba), __pyx_v_tau, __pyx_v_self->ba.long_info, __pyx_v_self->ba.inter_normal, (&__pyx_v_last_index), __pyx_v_pvecback) == _FAILURE_);
  if (unlikely(__pyx_t_2)) {

    /* "class-sz/python/classy.pyx":4649
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         omega = pvecback[self.ba.index_bg_Omega_m]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4649, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4649, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4649, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 4649, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4648
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         if background_at_tau(&self.ba,tau,self.ba.long_info,self.ba.inter_normal,&last_index,pvecback)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4651
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         omega = pvecback[self.ba.index_bg_Omega_m]             # <<<<<<<<<<<<<<
 *         free(pvecback)
 *         return omega
 */
  __pyx_v_omega = (__pyx_v_pvecback[__pyx_v_self->ba.index_bg_Omega_m]);

  /* "class-sz/python/classy.pyx":4652
 * 
 *         omega = pvecback[self.ba.index_bg_Omega_m]
 *         free(pvecback)             # <<<<<<<<<<<<<<
 *         return omega
 * 
 */
  free(__pyx_v_pvecback);

  /* "class-sz/python/classy.pyx":4653
 *         omega = pvecback[self.ba.index_bg_Omega_m]
 *         free(pvecback)
 *         return omega             # <<<<<<<<<<<<<<
 * 
 *     def get_rvir_of_mvir_at_z(self,m_asked,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_omega); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4638
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 *     def get_Omega_m_at_z(self,z):             # <<<<<<<<<<<<<<
 *         cdef double tau
 *         cdef int last_index #junk
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.get_Omega_m_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4655
 *         return omega
 * 
 *     def get_rvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         omega = self.get_Omega_m_at_z(z)
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_459get_rvir_of_mvir_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_459get_rvir_of_mvir_at_z = {"get_rvir_of_mvir_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_459get_rvir_of_mvir_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_459get_rvir_of_mvir_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_rvir_of_mvir_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m_asked,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4655, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4655, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_rvir_of_mvir_at_z", 1, 2, 2, 1); __PYX_ERR(0, 4655, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_rvir_of_mvir_at_z") < 0)) __PYX_ERR(0, 4655, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m_asked = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_rvir_of_mvir_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4655, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_rvir_of_mvir_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_458get_rvir_of_mvir_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m_asked, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_458get_rvir_of_mvir_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z) {
  PyObject *__pyx_v_omega = NULL;
  PyObject *__pyx_v_Delta_c = NULL;
  PyObject *__pyx_v_rhoc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  double __pyx_t_5;
  double __pyx_t_6;
  double __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_rvir_of_mvir_at_z", 1);

  /* "class-sz/python/classy.pyx":4656
 * 
 *     def get_rvir_of_mvir_at_z(self,m_asked,z):
 *         omega = self.get_Omega_m_at_z(z)             # <<<<<<<<<<<<<<
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)
 *         rhoc =  self.get_rho_crit_at_z(z)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_Omega_m_at_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_omega = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4657
 *     def get_rvir_of_mvir_at_z(self,m_asked,z):
 *         omega = self.get_Omega_m_at_z(z)
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)             # <<<<<<<<<<<<<<
 *         rhoc =  self.get_rho_crit_at_z(z)
 *         return evaluate_rvir_of_mvir(m_asked,Delta_c,rhoc,&self.tsz);
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_Delta_c_of_Omega_m); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_omega};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_Delta_c = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4658
 *         omega = self.get_Omega_m_at_z(z)
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)
 *         rhoc =  self.get_rho_crit_at_z(z)             # <<<<<<<<<<<<<<
 *         return evaluate_rvir_of_mvir(m_asked,Delta_c,rhoc,&self.tsz);
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_rho_crit_at_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_rhoc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4659
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)
 *         rhoc =  self.get_rho_crit_at_z(z)
 *         return evaluate_rvir_of_mvir(m_asked,Delta_c,rhoc,&self.tsz);             # <<<<<<<<<<<<<<
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200c(self,r_asked,m_asked,z_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_5 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4659, __pyx_L1_error)
  __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_v_Delta_c); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4659, __pyx_L1_error)
  __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_v_rhoc); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4659, __pyx_L1_error)
  __pyx_t_1 = PyFloat_FromDouble(evaluate_rvir_of_mvir(__pyx_t_5, __pyx_t_6, __pyx_t_7, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4655
 *         return omega
 * 
 *     def get_rvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         omega = self.get_Omega_m_at_z(z)
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_rvir_of_mvir_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_omega);
  __Pyx_XDECREF(__pyx_v_Delta_c);
  __Pyx_XDECREF(__pyx_v_rhoc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4661
 *         return evaluate_rvir_of_mvir(m_asked,Delta_c,rhoc,&self.tsz);
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200c(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_461get_gas_profile_at_x_M_z_nfw_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_461get_gas_profile_at_x_M_z_nfw_200c = {"get_gas_profile_at_x_M_z_nfw_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_461get_gas_profile_at_x_M_z_nfw_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_461get_gas_profile_at_x_M_z_nfw_200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_r_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_nfw_200c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_r_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4661, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4661, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_nfw_200c", 1, 3, 3, 1); __PYX_ERR(0, 4661, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4661, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_nfw_200c", 1, 3, 3, 2); __PYX_ERR(0, 4661, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_gas_profile_at_x_M_z_nfw_200c") < 0)) __PYX_ERR(0, 4661, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_r_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_gas_profile_at_x_M_z_nfw_200c", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4661, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_nfw_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_460get_gas_profile_at_x_M_z_nfw_200c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_r_asked, __pyx_v_m_asked, __pyx_v_z_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_460get_gas_profile_at_x_M_z_nfw_200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_gas_profile_at_x_M_z_nfw_200c", 1);

  /* "class-sz/python/classy.pyx":4662
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200c(self,r_asked,m_asked,z_asked):
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_mass_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_r_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4662, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4662, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4662, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_gas_profile_at_x_M_z_nfw_200c(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4661
 *         return evaluate_rvir_of_mvir(m_asked,Delta_c,rhoc,&self.tsz);
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200c(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_gas_profile_at_x_M_z_nfw_200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4664
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_mass_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_463get_mass_profile_at_x_M_z_nfw_200m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_463get_mass_profile_at_x_M_z_nfw_200m = {"get_mass_profile_at_x_M_z_nfw_200m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_463get_mass_profile_at_x_M_z_nfw_200m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_463get_mass_profile_at_x_M_z_nfw_200m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_r_asked = 0;
  PyObject *__pyx_v_m_asked = 0;
  PyObject *__pyx_v_z_asked = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_mass_profile_at_x_M_z_nfw_200m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_r_asked,&__pyx_n_s_m_asked,&__pyx_n_s_z_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4664, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4664, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_mass_profile_at_x_M_z_nfw_200m", 1, 3, 3, 1); __PYX_ERR(0, 4664, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4664, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_mass_profile_at_x_M_z_nfw_200m", 1, 3, 3, 2); __PYX_ERR(0, 4664, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_mass_profile_at_x_M_z_nfw_200m") < 0)) __PYX_ERR(0, 4664, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_r_asked = values[0];
    __pyx_v_m_asked = values[1];
    __pyx_v_z_asked = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_mass_profile_at_x_M_z_nfw_200m", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4664, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_mass_profile_at_x_M_z_nfw_200m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_462get_mass_profile_at_x_M_z_nfw_200m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_r_asked, __pyx_v_m_asked, __pyx_v_z_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_462get_mass_profile_at_x_M_z_nfw_200m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_r_asked, PyObject *__pyx_v_m_asked, PyObject *__pyx_v_z_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_mass_profile_at_x_M_z_nfw_200m", 1);

  /* "class-sz/python/classy.pyx":4665
 * 
 *     def get_mass_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_planck_sigma_at_theta500(self, theta500):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_r_asked); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4665, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m_asked); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4665, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_z_asked); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4665, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_mass_profile_at_x_M_z_nfw_200m(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4664
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_mass_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_mass_profile_at_x_M_z_nfw_200m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4667
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_planck_sigma_at_theta500(self, theta500):             # <<<<<<<<<<<<<<
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_465get_planck_sigma_at_theta500(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_465get_planck_sigma_at_theta500 = {"get_planck_sigma_at_theta500", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_465get_planck_sigma_at_theta500, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_465get_planck_sigma_at_theta500(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_theta500 = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_planck_sigma_at_theta500 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_theta500,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_theta500)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4667, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_planck_sigma_at_theta500") < 0)) __PYX_ERR(0, 4667, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_theta500 = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_planck_sigma_at_theta500", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4667, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_planck_sigma_at_theta500", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_464get_planck_sigma_at_theta500(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_theta500);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_464get_planck_sigma_at_theta500(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_theta500) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_planck_sigma_at_theta500", 1);

  /* "class-sz/python/classy.pyx":4668
 * 
 *     def get_planck_sigma_at_theta500(self, theta500):
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_szcountsz_sigma_at_theta_in_patch(self, id,theta500):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_theta500); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4668, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_planck_sigma_at_theta500(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4667
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_planck_sigma_at_theta500(self, theta500):             # <<<<<<<<<<<<<<
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_planck_sigma_at_theta500", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4670
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 *     def get_szcountsz_sigma_at_theta_in_patch(self, id,theta500):             # <<<<<<<<<<<<<<
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_467get_szcountsz_sigma_at_theta_in_patch(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_467get_szcountsz_sigma_at_theta_in_patch = {"get_szcountsz_sigma_at_theta_in_patch", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_467get_szcountsz_sigma_at_theta_in_patch, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_467get_szcountsz_sigma_at_theta_in_patch(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_id = 0;
  PyObject *__pyx_v_theta500 = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_szcountsz_sigma_at_theta_in_patch (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_id,&__pyx_n_s_theta500,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_id)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4670, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_theta500)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4670, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_szcountsz_sigma_at_theta_in_patch", 1, 2, 2, 1); __PYX_ERR(0, 4670, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_szcountsz_sigma_at_theta_in_patch") < 0)) __PYX_ERR(0, 4670, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_id = values[0];
    __pyx_v_theta500 = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_szcountsz_sigma_at_theta_in_patch", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4670, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_szcountsz_sigma_at_theta_in_patch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_466get_szcountsz_sigma_at_theta_in_patch(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_id, __pyx_v_theta500);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_466get_szcountsz_sigma_at_theta_in_patch(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_id, PyObject *__pyx_v_theta500) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_szcountsz_sigma_at_theta_in_patch", 1);

  /* "class-sz/python/classy.pyx":4671
 * 
 *     def get_szcountsz_sigma_at_theta_in_patch(self, id,theta500):
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_second_order_bias_at_z_and_nu(self,z,nu):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_theta500); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4671, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_v_id); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4671, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_szcountsz_sigma_at_theta_in_patch(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4670
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 *     def get_szcountsz_sigma_at_theta_in_patch(self, id,theta500):             # <<<<<<<<<<<<<<
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_szcountsz_sigma_at_theta_in_patch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4673
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 *     def get_second_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_469get_second_order_bias_at_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_469get_second_order_bias_at_z_and_nu = {"get_second_order_bias_at_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_469get_second_order_bias_at_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_469get_second_order_bias_at_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_nu = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_second_order_bias_at_z_and_nu (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_nu,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4673, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4673, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_second_order_bias_at_z_and_nu", 1, 2, 2, 1); __PYX_ERR(0, 4673, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_second_order_bias_at_z_and_nu") < 0)) __PYX_ERR(0, 4673, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_nu = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_second_order_bias_at_z_and_nu", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4673, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_second_order_bias_at_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_468get_second_order_bias_at_z_and_nu(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_nu);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_468get_second_order_bias_at_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_second_order_bias_at_z_and_nu", 1);

  /* "class-sz/python/classy.pyx":4674
 * 
 *     def get_second_order_bias_at_z_and_nu(self,z,nu):
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 *     def get_first_order_bias_at_z_and_nu(self,z,nu):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4674, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_nu); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4674, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_second_order_bias_at_z_and_nu(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4673
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 *     def get_second_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_second_order_bias_at_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4676
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 *     def get_first_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_471get_first_order_bias_at_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_471get_first_order_bias_at_z_and_nu = {"get_first_order_bias_at_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_471get_first_order_bias_at_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_471get_first_order_bias_at_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_nu = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_first_order_bias_at_z_and_nu (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_nu,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4676, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4676, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_first_order_bias_at_z_and_nu", 1, 2, 2, 1); __PYX_ERR(0, 4676, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_first_order_bias_at_z_and_nu") < 0)) __PYX_ERR(0, 4676, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_nu = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_first_order_bias_at_z_and_nu", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4676, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_first_order_bias_at_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_470get_first_order_bias_at_z_and_nu(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_nu);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_470get_first_order_bias_at_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_first_order_bias_at_z_and_nu", 1);

  /* "class-sz/python/classy.pyx":4677
 * 
 *     def get_first_order_bias_at_z_and_nu(self,z,nu):
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_first_order_bias_at_z_and_m_unvectorized(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4677, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_nu); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4677, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_first_order_bias_at_z_and_nu(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4676
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 *     def get_first_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_first_order_bias_at_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4679
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_first_order_bias_at_z_and_m_unvectorized(self,z,m):             # <<<<<<<<<<<<<<
 *         nu = self.get_nu_at_z_and_m(z,m)
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_473get_first_order_bias_at_z_and_m_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_473get_first_order_bias_at_z_and_m_unvectorized = {"get_first_order_bias_at_z_and_m_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_473get_first_order_bias_at_z_and_m_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_473get_first_order_bias_at_z_and_m_unvectorized(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_first_order_bias_at_z_and_m_unvectorized (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4679, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4679, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_first_order_bias_at_z_and_m_unvectorized", 1, 2, 2, 1); __PYX_ERR(0, 4679, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_first_order_bias_at_z_and_m_unvectorized") < 0)) __PYX_ERR(0, 4679, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_first_order_bias_at_z_and_m_unvectorized", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4679, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_first_order_bias_at_z_and_m_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_472get_first_order_bias_at_z_and_m_unvectorized(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_472get_first_order_bias_at_z_and_m_unvectorized(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_v_nu = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  double __pyx_t_5;
  double __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_first_order_bias_at_z_and_m_unvectorized", 1);

  /* "class-sz/python/classy.pyx":4680
 * 
 *     def get_first_order_bias_at_z_and_m_unvectorized(self,z,m):
 *         nu = self.get_nu_at_z_and_m(z,m)             # <<<<<<<<<<<<<<
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_nu_at_z_and_m); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_z, __pyx_v_m};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4680, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_nu = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4681
 *     def get_first_order_bias_at_z_and_m_unvectorized(self,z,m):
 *         nu = self.get_nu_at_z_and_m(z,m)
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_5 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4681, __pyx_L1_error)
  __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_v_nu); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4681, __pyx_L1_error)
  __pyx_t_1 = PyFloat_FromDouble(get_first_order_bias_at_z_and_nu(__pyx_t_5, __pyx_t_6, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4679
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_first_order_bias_at_z_and_m_unvectorized(self,z,m):             # <<<<<<<<<<<<<<
 *         nu = self.get_nu_at_z_and_m(z,m)
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_first_order_bias_at_z_and_m_unvectorized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nu);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4685
 * 
 *    # Define the vectorized method
 *     def get_first_order_bias_at_z_and_m(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the first order bias at given redshifts and masses.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_475get_first_order_bias_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_474get_first_order_bias_at_z_and_m, "\n        Vectorized computation of the first order bias at given redshifts and masses.\n\n        This method handles both scalar and array inputs for redshifts (z_input) and masses (m_input).\n        It returns the first order bias for each pair of redshift and mass.\n\n        Parameters:\n        z_input (float or np.ndarray): A scalar or 1D array of redshifts.\n        m_input (float or np.ndarray): A scalar or 1D array of masses.\n\n        Returns:\n        np.ndarray: An array of first order bias values corresponding to the input redshifts and masses.\n\n        Raises:\n        TypeError: If the inputs are not floats or 1D arrays of floats.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_475get_first_order_bias_at_z_and_m = {"get_first_order_bias_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_475get_first_order_bias_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_474get_first_order_bias_at_z_and_m};
static PyObject *__pyx_pw_9classy_sz_5Class_475get_first_order_bias_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z_input = 0;
  PyObject *__pyx_v_m_input = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_first_order_bias_at_z_and_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_input,&__pyx_n_s_m_input,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4685, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m_input)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4685, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_first_order_bias_at_z_and_m", 1, 2, 2, 1); __PYX_ERR(0, 4685, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_first_order_bias_at_z_and_m") < 0)) __PYX_ERR(0, 4685, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z_input = values[0];
    __pyx_v_m_input = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_first_order_bias_at_z_and_m", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4685, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_first_order_bias_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_474get_first_order_bias_at_z_and_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_input, __pyx_v_m_input);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_474get_first_order_bias_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z_input, PyObject *__pyx_v_m_input) {
  PyObject *__pyx_v_z_broadcasted = NULL;
  PyObject *__pyx_v_m_broadcasted = NULL;
  PyObject *__pyx_v_z_flattened = NULL;
  PyObject *__pyx_v_m_flattened = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_first_order_bias_at_z_and_m", 0);
  __Pyx_INCREF(__pyx_v_z_input);
  __Pyx_INCREF(__pyx_v_m_input);

  /* "class-sz/python/classy.pyx":4703
 *         """
 *         # Convert scalar inputs to arrays
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_z_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_z_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4704
 *         # Convert scalar inputs to arrays
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 *         if isinstance(m_input, (float, np.float64)):
 *             m_input = np.array([m_input], dtype=np.float64)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_z_input);
    __Pyx_GIVEREF(__pyx_v_z_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_z_input)) __PYX_ERR(0, 4704, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4704, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_z_input, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":4703
 *         """
 *         # Convert scalar inputs to arrays
 *         if isinstance(z_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 */
  }

  /* "class-sz/python/classy.pyx":4705
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             m_input = np.array([m_input], dtype=np.float64)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_float64); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_4 = PyFloat_Check(__pyx_v_m_input); 
  if (!__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_m_input, __pyx_t_2); 
  __pyx_t_3 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":4706
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):
 *             m_input = np.array([m_input], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         # Ensure inputs are 1D arrays of type float64
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_m_input);
    __Pyx_GIVEREF(__pyx_v_m_input);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_m_input)) __PYX_ERR(0, 4706, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4706, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_m_input, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":4705
 *         if isinstance(z_input, (float, np.float64)):
 *             z_input = np.array([z_input], dtype=np.float64)
 *         if isinstance(m_input, (float, np.float64)):             # <<<<<<<<<<<<<<
 *             m_input = np.array([m_input], dtype=np.float64)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4709
 * 
 *         # Ensure inputs are 1D arrays of type float64
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 */
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_z_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_6, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_float64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_6, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4709, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __pyx_t_4;
  __pyx_L10_bool_binop_done:;
  __pyx_t_4 = (!__pyx_t_3);
  if (unlikely(__pyx_t_4)) {

    /* "class-sz/python/classy.pyx":4710
 *         # Ensure inputs are 1D arrays of type float64
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")             # <<<<<<<<<<<<<<
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4710, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4710, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4709
 * 
 *         # Ensure inputs are 1D arrays of type float64
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 */
  }

  /* "class-sz/python/classy.pyx":4711
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")
 * 
 */
  __pyx_t_3 = __Pyx_TypeCheck(__pyx_v_m_input, __pyx_ptype_5numpy_ndarray); 
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_input, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_input, __pyx_n_s_dtype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = __pyx_t_3;
  __pyx_L14_bool_binop_done:;
  __pyx_t_3 = (!__pyx_t_4);
  if (unlikely(__pyx_t_3)) {

    /* "class-sz/python/classy.pyx":4712
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")             # <<<<<<<<<<<<<<
 * 
 *         # Use broadcasting to handle different sizes
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 4712, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":4711
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):             # <<<<<<<<<<<<<<
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":4715
 * 
 *         # Use broadcasting to handle different sizes
 *         z_broadcasted, m_broadcasted = np.broadcast_arrays(z_input[:, np.newaxis], m_input)             # <<<<<<<<<<<<<<
 * 
 *         # Flatten the broadcasted arrays for iteration
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_broadcast_arrays); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_newaxis); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_slice__5);
  __Pyx_GIVEREF(__pyx_slice__5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_slice__5)) __PYX_ERR(0, 4715, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_7)) __PYX_ERR(0, 4715, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_z_input, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_7, __pyx_v_m_input};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
    PyObject* sequence = __pyx_t_5;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 4715, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_7);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    #endif
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L17_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_6); if (unlikely(!__pyx_t_7)) goto __pyx_L17_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_7);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_6), 2) < 0) __PYX_ERR(0, 4715, __pyx_L1_error)
    __pyx_t_9 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L18_unpacking_done;
    __pyx_L17_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 4715, __pyx_L1_error)
    __pyx_L18_unpacking_done:;
  }
  __pyx_v_z_broadcasted = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_m_broadcasted = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":4718
 * 
 *         # Flatten the broadcasted arrays for iteration
 *         z_flattened = z_broadcasted.flatten()             # <<<<<<<<<<<<<<
 *         m_flattened = m_broadcasted.flatten()
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_broadcasted, __pyx_n_s_flatten); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_z_flattened = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":4719
 *         # Flatten the broadcasted arrays for iteration
 *         z_flattened = z_broadcasted.flatten()
 *         m_flattened = m_broadcasted.flatten()             # <<<<<<<<<<<<<<
 * 
 *         # Initialize result array
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_m_broadcasted, __pyx_n_s_flatten); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_m_flattened = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":4722
 * 
 *         # Initialize result array
 *         result = np.empty(z_flattened.shape[0], dtype=np.float64)             # <<<<<<<<<<<<<<
 * 
 *         # Compute the first order bias for each pair
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_flattened, __pyx_n_s_shape); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2)) __PYX_ERR(0, 4722, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_float64); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_1) < 0) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4725
 * 
 *         # Compute the first order bias for each pair
 *         for i in range(z_flattened.shape[0]):             # <<<<<<<<<<<<<<
 *             result[i] = self.get_first_order_bias_at_z_and_m_unvectorized(z_flattened[i], m_flattened[i])
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_flattened, __pyx_n_s_shape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_10 = 0;
    __pyx_t_11 = NULL;
  } else {
    __pyx_t_10 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4725, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_11)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4725, __pyx_L1_error)
          #endif
          if (__pyx_t_10 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely((0 < 0))) __PYX_ERR(0, 4725, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4725, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4725, __pyx_L1_error)
          #endif
          if (__pyx_t_10 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely((0 < 0))) __PYX_ERR(0, 4725, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4725, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_11(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 4725, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":4726
 *         # Compute the first order bias for each pair
 *         for i in range(z_flattened.shape[0]):
 *             result[i] = self.get_first_order_bias_at_z_and_m_unvectorized(z_flattened[i], m_flattened[i])             # <<<<<<<<<<<<<<
 * 
 *         # Reshape the result to match the broadcasted shape
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_first_order_bias_at_z_and_m); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_z_flattened, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_m_flattened, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_12 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_12, __pyx_t_7, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_v_result, __pyx_v_i, __pyx_t_1) < 0))) __PYX_ERR(0, 4726, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":4725
 * 
 *         # Compute the first order bias for each pair
 *         for i in range(z_flattened.shape[0]):             # <<<<<<<<<<<<<<
 *             result[i] = self.get_first_order_bias_at_z_and_m_unvectorized(z_flattened[i], m_flattened[i])
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4729
 * 
 *         # Reshape the result to match the broadcasted shape
 *         result = result.reshape(z_broadcasted.shape)             # <<<<<<<<<<<<<<
 * 
 *         return result
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_reshape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_z_broadcasted, __pyx_n_s_shape); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4731
 *         result = result.reshape(z_broadcasted.shape)
 * 
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     # # Define the vectorized method
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4685
 * 
 *    # Define the vectorized method
 *     def get_first_order_bias_at_z_and_m(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the first order bias at given redshifts and masses.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("classy_sz.Class.get_first_order_bias_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_z_broadcasted);
  __Pyx_XDECREF(__pyx_v_m_broadcasted);
  __Pyx_XDECREF(__pyx_v_z_flattened);
  __Pyx_XDECREF(__pyx_v_m_flattened);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_z_input);
  __Pyx_XDECREF(__pyx_v_m_input);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4791
 *     #         raise TypeError("Inputs should be floats or 1D NumPy arrays of type float64, and when both are arrays, they should have the same length.")
 * 
 *     def get_cib_Snu_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_477get_cib_Snu_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_477get_cib_Snu_z_and_nu = {"get_cib_Snu_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_477get_cib_Snu_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_477get_cib_Snu_z_and_nu(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_nu = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_cib_Snu_z_and_nu (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_nu,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4791, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nu)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4791, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_cib_Snu_z_and_nu", 1, 2, 2, 1); __PYX_ERR(0, 4791, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_cib_Snu_z_and_nu") < 0)) __PYX_ERR(0, 4791, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_nu = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_cib_Snu_z_and_nu", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4791, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_cib_Snu_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_476get_cib_Snu_z_and_nu(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_nu);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_476get_cib_Snu_z_and_nu(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_nu) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_cib_Snu_z_and_nu", 1);

  /* "class-sz/python/classy.pyx":4792
 * 
 *     def get_cib_Snu_z_and_nu(self,z,nu):
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_sigma_at_z_and_m(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4792, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_nu); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4792, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_cib_Snu_z_and_nu(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4791
 *     #         raise TypeError("Inputs should be floats or 1D NumPy arrays of type float64, and when both are arrays, they should have the same length.")
 * 
 *     def get_cib_Snu_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_cib_Snu_z_and_nu", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4794
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_sigma_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_479get_sigma_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_479get_sigma_at_z_and_m = {"get_sigma_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_479get_sigma_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_479get_sigma_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sigma_at_z_and_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4794, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4794, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_sigma_at_z_and_m", 1, 2, 2, 1); __PYX_ERR(0, 4794, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_sigma_at_z_and_m") < 0)) __PYX_ERR(0, 4794, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sigma_at_z_and_m", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4794, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_sigma_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_478get_sigma_at_z_and_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_478get_sigma_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sigma_at_z_and_m", 1);

  /* "class-sz/python/classy.pyx":4795
 * 
 *     def get_sigma_at_z_and_m(self,z,m):
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 *     def get_dlnsigma_dlnR_at_z_and_m(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4795, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4795, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_sigma_at_z_and_m(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4794
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_sigma_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_sigma_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4797
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_dlnsigma_dlnR_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_481get_dlnsigma_dlnR_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_481get_dlnsigma_dlnR_at_z_and_m = {"get_dlnsigma_dlnR_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_481get_dlnsigma_dlnR_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_481get_dlnsigma_dlnR_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dlnsigma_dlnR_at_z_and_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4797, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4797, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_dlnsigma_dlnR_at_z_and_m", 1, 2, 2, 1); __PYX_ERR(0, 4797, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_dlnsigma_dlnR_at_z_and_m") < 0)) __PYX_ERR(0, 4797, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dlnsigma_dlnR_at_z_and_m", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4797, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_dlnsigma_dlnR_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_480get_dlnsigma_dlnR_at_z_and_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_480get_dlnsigma_dlnR_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dlnsigma_dlnR_at_z_and_m", 1);

  /* "class-sz/python/classy.pyx":4798
 * 
 *     def get_dlnsigma_dlnR_at_z_and_m(self,z,m):
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 *     def get_sigma8_at_z(self,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4798, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4798, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_dlnsigma_dlnR_at_z_and_m(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4797
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_dlnsigma_dlnR_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_dlnsigma_dlnR_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4800
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_483get_sigma8_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_483get_sigma8_at_z = {"get_sigma8_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_483get_sigma8_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_483get_sigma8_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sigma8_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4800, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_sigma8_at_z") < 0)) __PYX_ERR(0, 4800, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sigma8_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4800, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_sigma8_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_482get_sigma8_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_482get_sigma8_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sigma8_at_z", 1);

  /* "class-sz/python/classy.pyx":4801
 * 
 *     def get_sigma8_at_z(self,z):
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 *     def get_y_at_m_and_z(self,m,z):
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4801, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_sigma8_at_z(__pyx_t_1, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4800
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_sigma8_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4802
 *     def get_sigma8_at_z(self,z):
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_485get_y_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_485get_y_at_m_and_z = {"get_y_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_485get_y_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_485get_y_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_y_at_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4802, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4802, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_y_at_m_and_z", 1, 2, 2, 1); __PYX_ERR(0, 4802, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_y_at_m_and_z") < 0)) __PYX_ERR(0, 4802, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_y_at_m_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4802, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_y_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_484get_y_at_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_484get_y_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_y_at_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4803
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)             # <<<<<<<<<<<<<<
 * 
 *     def get_theta_at_m_and_z(self,m,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4803, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4803, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_y_at_m_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4802
 *     def get_sigma8_at_z(self,z):
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_y_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4805
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_theta_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_487get_theta_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_487get_theta_at_m_and_z = {"get_theta_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_487get_theta_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_487get_theta_at_m_and_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_theta_at_m_and_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4805, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4805, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_theta_at_m_and_z", 1, 2, 2, 1); __PYX_ERR(0, 4805, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_theta_at_m_and_z") < 0)) __PYX_ERR(0, 4805, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_theta_at_m_and_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4805, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_theta_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_486get_theta_at_m_and_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_486get_theta_at_m_and_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_theta_at_m_and_z", 1);

  /* "class-sz/python/classy.pyx":4806
 * 
 *     def get_theta_at_m_and_z(self,m,z):
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)             # <<<<<<<<<<<<<<
 * 
 *     def get_m200m_to_m500c_at_z_and_M(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4806, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4806, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_theta_at_m_and_z(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4805
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_theta_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_theta_at_m_and_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4808
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_m200m_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_489get_m200m_to_m500c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_489get_m200m_to_m500c_at_z_and_M = {"get_m200m_to_m500c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_489get_m200m_to_m500c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_489get_m200m_to_m500c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m200m_to_m500c_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4808, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4808, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m200m_to_m500c_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 4808, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m200m_to_m500c_at_z_and_M") < 0)) __PYX_ERR(0, 4808, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m200m_to_m500c_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4808, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m200m_to_m500c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_488get_m200m_to_m500c_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_488get_m200m_to_m500c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m200m_to_m500c_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":4809
 * 
 *     def get_m200m_to_m500c_at_z_and_M(self,z,m):
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_m200c_to_m500c_at_z_and_M(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4809, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4809, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m200m_to_m500c_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4808
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_m200m_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m200m_to_m500c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4811
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200c_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_491get_m200c_to_m500c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_491get_m200c_to_m500c_at_z_and_M = {"get_m200c_to_m500c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_491get_m200c_to_m500c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_491get_m200c_to_m500c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m200c_to_m500c_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4811, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4811, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m200c_to_m500c_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 4811, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m200c_to_m500c_at_z_and_M") < 0)) __PYX_ERR(0, 4811, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m200c_to_m500c_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4811, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m200c_to_m500c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_490get_m200c_to_m500c_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_490get_m200c_to_m500c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m200c_to_m500c_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":4812
 * 
 *     def get_m200c_to_m500c_at_z_and_M(self,z,m):
 *         return get_m200c_to_m500c_at_z_and_M(z,m,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4812, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4812, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m200c_to_m500c_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4811
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200c_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m200c_to_m500c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4815
 * 
 * 
 *     def get_m200c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_493get_m200c_to_m200m_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_493get_m200c_to_m200m_at_z_and_M = {"get_m200c_to_m200m_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_493get_m200c_to_m200m_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_493get_m200c_to_m200m_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m200c_to_m200m_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4815, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4815, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m200c_to_m200m_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 4815, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m200c_to_m200m_at_z_and_M") < 0)) __PYX_ERR(0, 4815, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m200c_to_m200m_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4815, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m200c_to_m200m_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_492get_m200c_to_m200m_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_492get_m200c_to_m200m_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m200c_to_m200m_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":4816
 * 
 *     def get_m200c_to_m200m_at_z_and_M(self,z,m):
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4816, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4816, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m200c_to_m200m_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4815
 * 
 * 
 *     def get_m200c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m200c_to_m200m_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4818
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_495get_m200m_to_m200c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_495get_m200m_to_m200c_at_z_and_M = {"get_m200m_to_m200c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_495get_m200m_to_m200c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_495get_m200m_to_m200c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m200m_to_m200c_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4818, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4818, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m200m_to_m200c_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 4818, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m200m_to_m200c_at_z_and_M") < 0)) __PYX_ERR(0, 4818, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m200m_to_m200c_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4818, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m200m_to_m200c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_494get_m200m_to_m200c_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_494get_m200m_to_m200c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m200m_to_m200c_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":4819
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z,m):
 *         return get_m200m_to_m200c_at_z_and_M(z,m,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4819, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4819, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m200m_to_m200c_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4818
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m200m_to_m200c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4823
 * 
 * 
 *     def get_m500c_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_497get_m500c_to_m200c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_497get_m500c_to_m200c_at_z_and_M = {"get_m500c_to_m200c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_497get_m500c_to_m200c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_497get_m500c_to_m200c_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m500c_to_m200c_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4823, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4823, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m500c_to_m200c_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 4823, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m500c_to_m200c_at_z_and_M") < 0)) __PYX_ERR(0, 4823, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m500c_to_m200c_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4823, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m500c_to_m200c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_496get_m500c_to_m200c_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_496get_m500c_to_m200c_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m500c_to_m200c_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":4824
 * 
 *     def get_m500c_to_m200c_at_z_and_M(self,z,m):
 *         return get_m500c_to_m200c_at_z_and_M(z,m,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4824, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4824, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m500c_to_m200c_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4823
 * 
 * 
 *     def get_m500c_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m500c_to_m200c_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4827
 * 
 * 
 *     def get_m500c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_499get_m500c_to_m200m_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_499get_m500c_to_m200m_at_z_and_M = {"get_m500c_to_m200m_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_499get_m500c_to_m200m_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_499get_m500c_to_m200m_at_z_and_M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_m500c_to_m200m_at_z_and_M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4827, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4827, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_m500c_to_m200m_at_z_and_M", 1, 2, 2, 1); __PYX_ERR(0, 4827, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_m500c_to_m200m_at_z_and_M") < 0)) __PYX_ERR(0, 4827, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_m500c_to_m200m_at_z_and_M", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4827, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_m500c_to_m200m_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_498get_m500c_to_m200m_at_z_and_M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_498get_m500c_to_m200m_at_z_and_M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_m500c_to_m200m_at_z_and_M", 1);

  /* "class-sz/python/classy.pyx":4828
 * 
 *     def get_m500c_to_m200m_at_z_and_M(self,z,m):
 *         return get_m500c_to_m200m_at_z_and_M(z,m,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4828, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4828, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_m500c_to_m200m_at_z_and_M(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4827
 * 
 * 
 *     def get_m500c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_m500c_to_m200m_at_z_and_M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4831
 * 
 * 
 *     def calcFRel(self,z, M500, obsFreqGHz = 148.0):             # <<<<<<<<<<<<<<
 *         """Calculates relativistic correction to SZ effect at specified frequency, given z, M500 in MSun.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_501calcFRel(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_500calcFRel, "Calculates relativistic correction to SZ effect at specified frequency, given z, M500 in MSun.\n\n        This assumes the Arnaud et al. (2005) M-T relation, and applies formulae of Itoh et al. (1998)\n\n        As for H13, we return fRel = 1 + delta_SZE (see also Marriage et al. 2011)\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_501calcFRel = {"calcFRel", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_501calcFRel, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_500calcFRel};
static PyObject *__pyx_pw_9classy_sz_5Class_501calcFRel(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_M500 = 0;
  PyObject *__pyx_v_obsFreqGHz = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("calcFRel (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_M500,&__pyx_n_s_obsFreqGHz,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_148_0));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4831, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M500)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4831, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("calcFRel", 0, 2, 3, 1); __PYX_ERR(0, 4831, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obsFreqGHz);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4831, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "calcFRel") < 0)) __PYX_ERR(0, 4831, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z = values[0];
    __pyx_v_M500 = values[1];
    __pyx_v_obsFreqGHz = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("calcFRel", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4831, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.calcFRel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_500calcFRel(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_M500, __pyx_v_obsFreqGHz);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_500calcFRel(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_M500, PyObject *__pyx_v_obsFreqGHz) {
  double __pyx_v_h;
  PyObject *__pyx_v_Ez = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_Eh = NULL;
  double __pyx_v_hplanck;
  double __pyx_v_kB;
  CYTHON_UNUSED double __pyx_v_sigmaT;
  double __pyx_v_me;
  double __pyx_v_e;
  double __pyx_v_c;
  PyObject *__pyx_v_TCMB = NULL;
  double __pyx_v_A;
  double __pyx_v_B;
  PyObject *__pyx_v_TkeV = NULL;
  PyObject *__pyx_v_TKelvin = NULL;
  PyObject *__pyx_v_thetae = NULL;
  PyObject *__pyx_v_X = NULL;
  PyObject *__pyx_v_Xtw = NULL;
  PyObject *__pyx_v_Stw = NULL;
  PyObject *__pyx_v_Y0 = NULL;
  PyObject *__pyx_v_Y1 = NULL;
  PyObject *__pyx_v_Y2 = NULL;
  PyObject *__pyx_v_Y3 = NULL;
  PyObject *__pyx_v_Y4 = NULL;
  PyObject *__pyx_v_deltaSZE = NULL;
  PyObject *__pyx_v_fRel = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("calcFRel", 0);
  __Pyx_INCREF(__pyx_v_M500);

  /* "class-sz/python/classy.pyx":4839
 * 
 *         """
 *         h = self.ba.h             # <<<<<<<<<<<<<<
 *         M500 = M500/h # in Msun
 *         Ez = Eh = self.Hubble(z)/self.Hubble(0)
 */
  __pyx_t_1 = __pyx_v_self->ba.h;
  __pyx_v_h = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4840
 *         """
 *         h = self.ba.h
 *         M500 = M500/h # in Msun             # <<<<<<<<<<<<<<
 *         Ez = Eh = self.Hubble(z)/self.Hubble(0)
 * 
 */
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_h); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_v_M500, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_M500, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4841
 *         h = self.ba.h
 *         M500 = M500/h # in Msun
 *         Ez = Eh = self.Hubble(z)/self.Hubble(0)             # <<<<<<<<<<<<<<
 * 
 *         # NOTE: we should define constants somewhere else...
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_z};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4841, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_int_0};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4841, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyNumber_Divide(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_Ez = __pyx_t_4;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_Eh = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4844
 * 
 *         # NOTE: we should define constants somewhere else...
 *         hplanck=6.63e-34             # <<<<<<<<<<<<<<
 *         kB=1.38e-23
 *         sigmaT=6.6524586e-29
 */
  __pyx_v_hplanck = 6.63e-34;

  /* "class-sz/python/classy.pyx":4845
 *         # NOTE: we should define constants somewhere else...
 *         hplanck=6.63e-34
 *         kB=1.38e-23             # <<<<<<<<<<<<<<
 *         sigmaT=6.6524586e-29
 *         me=9.11e-31
 */
  __pyx_v_kB = 1.38e-23;

  /* "class-sz/python/classy.pyx":4846
 *         hplanck=6.63e-34
 *         kB=1.38e-23
 *         sigmaT=6.6524586e-29             # <<<<<<<<<<<<<<
 *         me=9.11e-31
 *         e=1.6e-19
 */
  __pyx_v_sigmaT = 6.6524586e-29;

  /* "class-sz/python/classy.pyx":4847
 *         kB=1.38e-23
 *         sigmaT=6.6524586e-29
 *         me=9.11e-31             # <<<<<<<<<<<<<<
 *         e=1.6e-19
 *         c=3e8
 */
  __pyx_v_me = 9.11e-31;

  /* "class-sz/python/classy.pyx":4848
 *         sigmaT=6.6524586e-29
 *         me=9.11e-31
 *         e=1.6e-19             # <<<<<<<<<<<<<<
 *         c=3e8
 *         TCMB = self.T_cmb()
 */
  __pyx_v_e = 1.6e-19;

  /* "class-sz/python/classy.pyx":4849
 *         me=9.11e-31
 *         e=1.6e-19
 *         c=3e8             # <<<<<<<<<<<<<<
 *         TCMB = self.T_cmb()
 * 
 */
  __pyx_v_c = 3e8;

  /* "class-sz/python/classy.pyx":4850
 *         e=1.6e-19
 *         c=3e8
 *         TCMB = self.T_cmb()             # <<<<<<<<<<<<<<
 * 
 *         # Using Arnaud et al. (2005) M-T to get temperature
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_T_cmb); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_TCMB = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4853
 * 
 *         # Using Arnaud et al. (2005) M-T to get temperature
 *         A=3.84e14             # <<<<<<<<<<<<<<
 *         B=1.71
 *         #TkeV=5.*np.power(((cosmoModel.efunc(z)*M500)/A), 1/B)   # HMF/Astropy
 */
  __pyx_v_A = 3.84e14;

  /* "class-sz/python/classy.pyx":4854
 *         # Using Arnaud et al. (2005) M-T to get temperature
 *         A=3.84e14
 *         B=1.71             # <<<<<<<<<<<<<<
 *         #TkeV=5.*np.power(((cosmoModel.efunc(z)*M500)/A), 1/B)   # HMF/Astropy
 *         #TkeV=5.*np.power(((cosmoModel.Ez(z)*M500)/A), 1/B)   # Colossus
 */
  __pyx_v_B = 1.71;

  /* "class-sz/python/classy.pyx":4857
 *         #TkeV=5.*np.power(((cosmoModel.efunc(z)*M500)/A), 1/B)   # HMF/Astropy
 *         #TkeV=5.*np.power(((cosmoModel.Ez(z)*M500)/A), 1/B)   # Colossus
 *         TkeV=5.*np.power(((Ez*M500)/A), 1/B)             # <<<<<<<<<<<<<<
 *         TKelvin=TkeV*((1000*e)/kB)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_power); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Multiply(__pyx_v_Ez, __pyx_v_M500); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_A); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(__pyx_v_B == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 4857, __pyx_L1_error)
  }
  __pyx_t_6 = PyFloat_FromDouble((1.0 / __pyx_v_B)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_7, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Multiply(__pyx_float_5_, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_TkeV = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4858
 *         #TkeV=5.*np.power(((cosmoModel.Ez(z)*M500)/A), 1/B)   # Colossus
 *         TkeV=5.*np.power(((Ez*M500)/A), 1/B)
 *         TKelvin=TkeV*((1000*e)/kB)             # <<<<<<<<<<<<<<
 * 
 *         # Itoh et al. (1998) eqns. 2.25 - 2.30
 */
  __pyx_t_1 = (1000.0 * __pyx_v_e);
  if (unlikely(__pyx_v_kB == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "float division");
    __PYX_ERR(0, 4858, __pyx_L1_error)
  }
  __pyx_t_3 = PyFloat_FromDouble((__pyx_t_1 / __pyx_v_kB)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Multiply(__pyx_v_TkeV, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_TKelvin = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4861
 * 
 *         # Itoh et al. (1998) eqns. 2.25 - 2.30
 *         thetae=(kB*TKelvin)/(me*c**2)             # <<<<<<<<<<<<<<
 *         X=(hplanck*obsFreqGHz*1e9)/(kB*TCMB)
 *         Xtw=X*(np.cosh(X/2.)/np.sinh(X/2.))
 */
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_kB); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_4, __pyx_v_TKelvin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((__pyx_v_me * pow(__pyx_v_c, 2.0))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyNumber_Divide(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_thetae = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4862
 *         # Itoh et al. (1998) eqns. 2.25 - 2.30
 *         thetae=(kB*TKelvin)/(me*c**2)
 *         X=(hplanck*obsFreqGHz*1e9)/(kB*TCMB)             # <<<<<<<<<<<<<<
 *         Xtw=X*(np.cosh(X/2.)/np.sinh(X/2.))
 *         Stw=X/np.sinh(X/2.)
 */
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_hplanck); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_6, __pyx_v_obsFreqGHz); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_4, __pyx_float_1e9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_kB); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_4, __pyx_v_TCMB); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyNumber_Divide(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_X = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4863
 *         thetae=(kB*TKelvin)/(me*c**2)
 *         X=(hplanck*obsFreqGHz*1e9)/(kB*TCMB)
 *         Xtw=X*(np.cosh(X/2.)/np.sinh(X/2.))             # <<<<<<<<<<<<<<
 *         Stw=X/np.sinh(X/2.)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_cosh); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyFloat_TrueDivideObjC(__pyx_v_X, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_sinh); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyFloat_TrueDivideObjC(__pyx_v_X, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Multiply(__pyx_v_X, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4863, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_Xtw = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4864
 *         X=(hplanck*obsFreqGHz*1e9)/(kB*TCMB)
 *         Xtw=X*(np.cosh(X/2.)/np.sinh(X/2.))
 *         Stw=X/np.sinh(X/2.)             # <<<<<<<<<<<<<<
 * 
 *         Y0=-4+Xtw
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_sinh); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyFloat_TrueDivideObjC(__pyx_v_X, __pyx_float_2_, 2., 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyNumber_Divide(__pyx_v_X, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_Stw = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4866
 *         Stw=X/np.sinh(X/2.)
 * 
 *         Y0=-4+Xtw             # <<<<<<<<<<<<<<
 * 
 *         Y1=-10. + (47/2.)*Xtw - (42/5.)*Xtw**2 + (7/10.)*Xtw**3 + np.power(Stw, 2)*(-(21/5.) + (7/5.)*Xtw)
 */
  __pyx_t_4 = __Pyx_PyInt_AddCObj(__pyx_int_neg_4, __pyx_v_Xtw, -4L, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_Y0 = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4868
 *         Y0=-4+Xtw
 * 
 *         Y1=-10. + (47/2.)*Xtw - (42/5.)*Xtw**2 + (7/10.)*Xtw**3 + np.power(Stw, 2)*(-(21/5.) + (7/5.)*Xtw)             # <<<<<<<<<<<<<<
 * 
 *         Y2=-(15/2.) +  (1023/8.)*Xtw - (868/5.)*Xtw**2 + (329/5.)*Xtw**3 - (44/5.)*Xtw**4 + (11/30.)*Xtw**5 \
 */
  __pyx_t_4 = PyFloat_FromDouble((47.0 / 2.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_4, __pyx_v_Xtw); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyFloat_AddCObj(__pyx_float_neg_10_, __pyx_t_6, -10., 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((42.0 / 5.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Subtract(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((7.0 / 10.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_power); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_Stw, __pyx_int_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4868, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyFloat_FromDouble((-(21.0 / 5.))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyFloat_FromDouble((7.0 / 5.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_7, __pyx_v_Xtw); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_Y1 = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":4870
 *         Y1=-10. + (47/2.)*Xtw - (42/5.)*Xtw**2 + (7/10.)*Xtw**3 + np.power(Stw, 2)*(-(21/5.) + (7/5.)*Xtw)
 * 
 *         Y2=-(15/2.) +  (1023/8.)*Xtw - (868/5.)*Xtw**2 + (329/5.)*Xtw**3 - (44/5.)*Xtw**4 + (11/30.)*Xtw**5 \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 2)*(-(434/5.) + (658/5.)*Xtw - (242/5.)*Xtw**2 + (143/30.)*Xtw**3) \
 *             + np.power(Stw, 4)*(-(44/5.) + (187/60.)*Xtw)
 */
  __pyx_t_7 = PyFloat_FromDouble((-(15.0 / 2.))); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = PyFloat_FromDouble((1023.0 / 8.)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_2, __pyx_v_Xtw); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((868.0 / 5.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Subtract(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((329.0 / 5.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((44.0 / 5.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_4, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Subtract(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((11.0 / 30.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_5, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4871
 * 
 *         Y2=-(15/2.) +  (1023/8.)*Xtw - (868/5.)*Xtw**2 + (329/5.)*Xtw**3 - (44/5.)*Xtw**4 + (11/30.)*Xtw**5 \
 *             + np.power(Stw, 2)*(-(434/5.) + (658/5.)*Xtw - (242/5.)*Xtw**2 + (143/30.)*Xtw**3) \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 4)*(-(44/5.) + (187/60.)*Xtw)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_power); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_Stw, __pyx_int_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4871, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyFloat_FromDouble((-(434.0 / 5.))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyFloat_FromDouble((658.0 / 5.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_7, __pyx_v_Xtw); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((242.0 / 5.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Subtract(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((143.0 / 30.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4872
 *         Y2=-(15/2.) +  (1023/8.)*Xtw - (868/5.)*Xtw**2 + (329/5.)*Xtw**3 - (44/5.)*Xtw**4 + (11/30.)*Xtw**5 \
 *             + np.power(Stw, 2)*(-(434/5.) + (658/5.)*Xtw - (242/5.)*Xtw**2 + (143/30.)*Xtw**3) \
 *             + np.power(Stw, 4)*(-(44/5.) + (187/60.)*Xtw)             # <<<<<<<<<<<<<<
 * 
 *         Y3=(15/2.) + (2505/8.)*Xtw - (7098/5.)*Xtw**2 + (14253/10.)*Xtw**3 - (18594/35.)*Xtw**4 + (12059/140.)*Xtw**5 - (128/21.)*Xtw**6 + (16/105.)*Xtw**7 \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_power); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_Stw, __pyx_int_4};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4872, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = PyFloat_FromDouble((-(44.0 / 5.))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyFloat_FromDouble((187.0 / 60.)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_2, __pyx_v_Xtw); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_Y2 = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4874
 *             + np.power(Stw, 4)*(-(44/5.) + (187/60.)*Xtw)
 * 
 *         Y3=(15/2.) + (2505/8.)*Xtw - (7098/5.)*Xtw**2 + (14253/10.)*Xtw**3 - (18594/35.)*Xtw**4 + (12059/140.)*Xtw**5 - (128/21.)*Xtw**6 + (16/105.)*Xtw**7 \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 2)*(-(7098/10.) + (14253/5.)*Xtw - (102267/35.)*Xtw**2 + (156767/140.)*Xtw**3 - (1216/7.)*Xtw**4 + (64/7.)*Xtw**5) \
 *             + np.power(Stw, 4)*(-(18594/35.) + (205003/280.)*Xtw - (1920/7.)*Xtw**2 + (1024/35.)*Xtw**3) \
 */
  __pyx_t_2 = PyFloat_FromDouble((15.0 / 2.)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyFloat_FromDouble((2505.0 / 8.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_6, __pyx_v_Xtw); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyFloat_FromDouble((7098.0 / 5.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((14253.0 / 10.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyFloat_FromDouble((18594.0 / 35.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_4, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((12059.0 / 140.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_5, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyFloat_FromDouble((128.0 / 21.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_6, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((16.0 / 105.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_7, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4874, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":4875
 * 
 *         Y3=(15/2.) + (2505/8.)*Xtw - (7098/5.)*Xtw**2 + (14253/10.)*Xtw**3 - (18594/35.)*Xtw**4 + (12059/140.)*Xtw**5 - (128/21.)*Xtw**6 + (16/105.)*Xtw**7 \
 *             + np.power(Stw, 2)*(-(7098/10.) + (14253/5.)*Xtw - (102267/35.)*Xtw**2 + (156767/140.)*Xtw**3 - (1216/7.)*Xtw**4 + (64/7.)*Xtw**5) \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 4)*(-(18594/35.) + (205003/280.)*Xtw - (1920/7.)*Xtw**2 + (1024/35.)*Xtw**3) \
 *             + np.power(Stw, 6)*(-(544/21.) + (992/105.)*Xtw)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_power); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_Stw, __pyx_int_2};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyFloat_FromDouble((-(7098.0 / 10.))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyFloat_FromDouble((14253.0 / 5.)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_2, __pyx_v_Xtw); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((102267.0 / 35.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Subtract(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((156767.0 / 140.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((1216.0 / 7.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_4, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Subtract(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((64.0 / 7.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_5, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4876
 *         Y3=(15/2.) + (2505/8.)*Xtw - (7098/5.)*Xtw**2 + (14253/10.)*Xtw**3 - (18594/35.)*Xtw**4 + (12059/140.)*Xtw**5 - (128/21.)*Xtw**6 + (16/105.)*Xtw**7 \
 *             + np.power(Stw, 2)*(-(7098/10.) + (14253/5.)*Xtw - (102267/35.)*Xtw**2 + (156767/140.)*Xtw**3 - (1216/7.)*Xtw**4 + (64/7.)*Xtw**5) \
 *             + np.power(Stw, 4)*(-(18594/35.) + (205003/280.)*Xtw - (1920/7.)*Xtw**2 + (1024/35.)*Xtw**3) \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 6)*(-(544/21.) + (992/105.)*Xtw)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_power); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_Stw, __pyx_int_4};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = PyFloat_FromDouble((-(18594.0 / 35.))); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyFloat_FromDouble((205003.0 / 280.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_v_Xtw); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((1920.0 / 7.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Subtract(__pyx_t_6, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((1024.0 / 35.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_8, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4877
 *             + np.power(Stw, 2)*(-(7098/10.) + (14253/5.)*Xtw - (102267/35.)*Xtw**2 + (156767/140.)*Xtw**3 - (1216/7.)*Xtw**4 + (64/7.)*Xtw**5) \
 *             + np.power(Stw, 4)*(-(18594/35.) + (205003/280.)*Xtw - (1920/7.)*Xtw**2 + (1024/35.)*Xtw**3) \
 *             + np.power(Stw, 6)*(-(544/21.) + (992/105.)*Xtw)             # <<<<<<<<<<<<<<
 * 
 *         Y4=-(135/32.) + (30375/128.)*Xtw - (62391/10.)*Xtw**2 + (614727/40.)*Xtw**3 - (124389/10.)*Xtw**4 \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_power); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_Stw, __pyx_int_6};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4877, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = PyFloat_FromDouble((-(544.0 / 21.))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyFloat_FromDouble((992.0 / 105.)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_2, __pyx_v_Xtw); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4877, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_Y3 = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":4879
 *             + np.power(Stw, 6)*(-(544/21.) + (992/105.)*Xtw)
 * 
 *         Y4=-(135/32.) + (30375/128.)*Xtw - (62391/10.)*Xtw**2 + (614727/40.)*Xtw**3 - (124389/10.)*Xtw**4 \             # <<<<<<<<<<<<<<
 *             + (355703/80.)*Xtw**5 - (16568/21.)*Xtw**6 + (7516/105.)*Xtw**7 - (22/7.)*Xtw**8 + (11/210.)*Xtw**9 \
 *             + np.power(Stw, 2)*(-(62391/20.) + (614727/20.)*Xtw - (1368279/20.)*Xtw**2 + (4624139/80.)*Xtw**3 - (157396/7.)*Xtw**4 \
 */
  __pyx_t_2 = PyFloat_FromDouble((-(135.0 / 32.))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = PyFloat_FromDouble((30375.0 / 128.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_7, __pyx_v_Xtw); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((62391.0 / 10.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((614727.0 / 40.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((124389.0 / 10.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_4, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4879, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4880
 * 
 *         Y4=-(135/32.) + (30375/128.)*Xtw - (62391/10.)*Xtw**2 + (614727/40.)*Xtw**3 - (124389/10.)*Xtw**4 \
 *             + (355703/80.)*Xtw**5 - (16568/21.)*Xtw**6 + (7516/105.)*Xtw**7 - (22/7.)*Xtw**8 + (11/210.)*Xtw**9 \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 2)*(-(62391/20.) + (614727/20.)*Xtw - (1368279/20.)*Xtw**2 + (4624139/80.)*Xtw**3 - (157396/7.)*Xtw**4 \
 *             + (30064/7.)*Xtw**5 - (2717/7.)*Xtw**6 + (2761/210.)*Xtw**7) \
 */
  __pyx_t_3 = PyFloat_FromDouble((355703.0 / 80.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_5, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((16568.0 / 21.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_6, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((7516.0 / 105.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_7, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((22.0 / 7.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_8, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Subtract(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((11.0 / 210.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_9, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4881
 *         Y4=-(135/32.) + (30375/128.)*Xtw - (62391/10.)*Xtw**2 + (614727/40.)*Xtw**3 - (124389/10.)*Xtw**4 \
 *             + (355703/80.)*Xtw**5 - (16568/21.)*Xtw**6 + (7516/105.)*Xtw**7 - (22/7.)*Xtw**8 + (11/210.)*Xtw**9 \
 *             + np.power(Stw, 2)*(-(62391/20.) + (614727/20.)*Xtw - (1368279/20.)*Xtw**2 + (4624139/80.)*Xtw**3 - (157396/7.)*Xtw**4 \             # <<<<<<<<<<<<<<
 *             + (30064/7.)*Xtw**5 - (2717/7.)*Xtw**6 + (2761/210.)*Xtw**7) \
 *             + np.power(Stw, 4)*(-(124389/10.) + (6046951/160.)*Xtw - (248520/7.)*Xtw**2 + (481024/35.)*Xtw**3 - (15972/7.)*Xtw**4 + (18689/140.)*Xtw**5) \
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_power); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_Stw, __pyx_int_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyFloat_FromDouble((-(62391.0 / 20.))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyFloat_FromDouble((614727.0 / 20.)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_2, __pyx_v_Xtw); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((1368279.0 / 20.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Subtract(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((4624139.0 / 80.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((157396.0 / 7.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_4, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Subtract(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "class-sz/python/classy.pyx":4882
 *             + (355703/80.)*Xtw**5 - (16568/21.)*Xtw**6 + (7516/105.)*Xtw**7 - (22/7.)*Xtw**8 + (11/210.)*Xtw**9 \
 *             + np.power(Stw, 2)*(-(62391/20.) + (614727/20.)*Xtw - (1368279/20.)*Xtw**2 + (4624139/80.)*Xtw**3 - (157396/7.)*Xtw**4 \
 *             + (30064/7.)*Xtw**5 - (2717/7.)*Xtw**6 + (2761/210.)*Xtw**7) \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 4)*(-(124389/10.) + (6046951/160.)*Xtw - (248520/7.)*Xtw**2 + (481024/35.)*Xtw**3 - (15972/7.)*Xtw**4 + (18689/140.)*Xtw**5) \
 *             + np.power(Stw, 6)*(-(70414/21.) + (465992/105.)*Xtw - (11792/7.)*Xtw**2 + (19778/105.)*Xtw**3) \
 */
  __pyx_t_8 = PyFloat_FromDouble((30064.0 / 7.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_5, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyFloat_FromDouble((2717.0 / 7.)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_6, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Subtract(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((2761.0 / 210.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_7, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4881
 *         Y4=-(135/32.) + (30375/128.)*Xtw - (62391/10.)*Xtw**2 + (614727/40.)*Xtw**3 - (124389/10.)*Xtw**4 \
 *             + (355703/80.)*Xtw**5 - (16568/21.)*Xtw**6 + (7516/105.)*Xtw**7 - (22/7.)*Xtw**8 + (11/210.)*Xtw**9 \
 *             + np.power(Stw, 2)*(-(62391/20.) + (614727/20.)*Xtw - (1368279/20.)*Xtw**2 + (4624139/80.)*Xtw**3 - (157396/7.)*Xtw**4 \             # <<<<<<<<<<<<<<
 *             + (30064/7.)*Xtw**5 - (2717/7.)*Xtw**6 + (2761/210.)*Xtw**7) \
 *             + np.power(Stw, 4)*(-(124389/10.) + (6046951/160.)*Xtw - (248520/7.)*Xtw**2 + (481024/35.)*Xtw**3 - (15972/7.)*Xtw**4 + (18689/140.)*Xtw**5) \
 */
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":4883
 *             + np.power(Stw, 2)*(-(62391/20.) + (614727/20.)*Xtw - (1368279/20.)*Xtw**2 + (4624139/80.)*Xtw**3 - (157396/7.)*Xtw**4 \
 *             + (30064/7.)*Xtw**5 - (2717/7.)*Xtw**6 + (2761/210.)*Xtw**7) \
 *             + np.power(Stw, 4)*(-(124389/10.) + (6046951/160.)*Xtw - (248520/7.)*Xtw**2 + (481024/35.)*Xtw**3 - (15972/7.)*Xtw**4 + (18689/140.)*Xtw**5) \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 6)*(-(70414/21.) + (465992/105.)*Xtw - (11792/7.)*Xtw**2 + (19778/105.)*Xtw**3) \
 *             + np.power(Stw, 8)*(-(682/7.) + (7601/210.)*Xtw)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_power); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_Stw, __pyx_int_4};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyFloat_FromDouble((-(124389.0 / 10.))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyFloat_FromDouble((6046951.0 / 160.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_7, __pyx_v_Xtw); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((248520.0 / 7.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Subtract(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((481024.0 / 35.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((15972.0 / 7.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_4, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Subtract(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((18689.0 / 140.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_5, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4884
 *             + (30064/7.)*Xtw**5 - (2717/7.)*Xtw**6 + (2761/210.)*Xtw**7) \
 *             + np.power(Stw, 4)*(-(124389/10.) + (6046951/160.)*Xtw - (248520/7.)*Xtw**2 + (481024/35.)*Xtw**3 - (15972/7.)*Xtw**4 + (18689/140.)*Xtw**5) \
 *             + np.power(Stw, 6)*(-(70414/21.) + (465992/105.)*Xtw - (11792/7.)*Xtw**2 + (19778/105.)*Xtw**3) \             # <<<<<<<<<<<<<<
 *             + np.power(Stw, 8)*(-(682/7.) + (7601/210.)*Xtw)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_power); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_Stw, __pyx_int_6};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = PyFloat_FromDouble((-(70414.0 / 21.))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyFloat_FromDouble((465992.0 / 105.)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_2, __pyx_v_Xtw); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble((11792.0 / 7.)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = PyNumber_Multiply(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Subtract(__pyx_t_2, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyFloat_FromDouble((19778.0 / 105.)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = PyNumber_Power(__pyx_v_Xtw, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Multiply(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4885
 *             + np.power(Stw, 4)*(-(124389/10.) + (6046951/160.)*Xtw - (248520/7.)*Xtw**2 + (481024/35.)*Xtw**3 - (15972/7.)*Xtw**4 + (18689/140.)*Xtw**5) \
 *             + np.power(Stw, 6)*(-(70414/21.) + (465992/105.)*Xtw - (11792/7.)*Xtw**2 + (19778/105.)*Xtw**3) \
 *             + np.power(Stw, 8)*(-(682/7.) + (7601/210.)*Xtw)             # <<<<<<<<<<<<<<
 * 
 *         deltaSZE=((X**3)/(np.exp(X)-1)) * ((thetae*X*np.exp(X))/(np.exp(X)-1)) * (Y0 + Y1*thetae + Y2*thetae**2 + Y3*thetae**3 + Y4*thetae**4)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_power); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_Stw, __pyx_int_8};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyFloat_FromDouble((-(682.0 / 7.))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = PyFloat_FromDouble((7601.0 / 210.)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_7, __pyx_v_Xtw); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Multiply(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_Y4 = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":4887
 *             + np.power(Stw, 8)*(-(682/7.) + (7601/210.)*Xtw)
 * 
 *         deltaSZE=((X**3)/(np.exp(X)-1)) * ((thetae*X*np.exp(X))/(np.exp(X)-1)) * (Y0 + Y1*thetae + Y2*thetae**2 + Y3*thetae**3 + Y4*thetae**4)             # <<<<<<<<<<<<<<
 * 
 *         fRel=1+deltaSZE
 */
  __pyx_t_7 = PyNumber_Power(__pyx_v_X, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_exp); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_X};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_SubtractObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyNumber_Divide(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Multiply(__pyx_v_thetae, __pyx_v_X); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_exp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_X};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_X};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyInt_SubtractObjC(__pyx_t_7, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Multiply(__pyx_v_Y1, __pyx_v_thetae); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = PyNumber_Add(__pyx_v_Y0, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Power(__pyx_v_thetae, __pyx_int_2, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyNumber_Multiply(__pyx_v_Y2, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Power(__pyx_v_thetae, __pyx_int_3, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Multiply(__pyx_v_Y3, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Power(__pyx_v_thetae, __pyx_int_4, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyNumber_Multiply(__pyx_v_Y4, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_Multiply(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_deltaSZE = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":4889
 *         deltaSZE=((X**3)/(np.exp(X)-1)) * ((thetae*X*np.exp(X))/(np.exp(X)-1)) * (Y0 + Y1*thetae + Y2*thetae**2 + Y3*thetae**3 + Y4*thetae**4)
 * 
 *         fRel=1+deltaSZE             # <<<<<<<<<<<<<<
 * 
 *         return fRel
 */
  __pyx_t_7 = __Pyx_PyInt_AddCObj(__pyx_int_1, __pyx_v_deltaSZE, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_fRel = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":4891
 *         fRel=1+deltaSZE
 * 
 *         return fRel             # <<<<<<<<<<<<<<
 * 
 *     def get_radial_kernel_W_galaxy_lensing_at_z(self,double z):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_fRel);
  __pyx_r = __pyx_v_fRel;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4831
 * 
 * 
 *     def calcFRel(self,z, M500, obsFreqGHz = 148.0):             # <<<<<<<<<<<<<<
 *         """Calculates relativistic correction to SZ effect at specified frequency, given z, M500 in MSun.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("classy_sz.Class.calcFRel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_Ez);
  __Pyx_XDECREF(__pyx_v_Eh);
  __Pyx_XDECREF(__pyx_v_TCMB);
  __Pyx_XDECREF(__pyx_v_TkeV);
  __Pyx_XDECREF(__pyx_v_TKelvin);
  __Pyx_XDECREF(__pyx_v_thetae);
  __Pyx_XDECREF(__pyx_v_X);
  __Pyx_XDECREF(__pyx_v_Xtw);
  __Pyx_XDECREF(__pyx_v_Stw);
  __Pyx_XDECREF(__pyx_v_Y0);
  __Pyx_XDECREF(__pyx_v_Y1);
  __Pyx_XDECREF(__pyx_v_Y2);
  __Pyx_XDECREF(__pyx_v_Y3);
  __Pyx_XDECREF(__pyx_v_Y4);
  __Pyx_XDECREF(__pyx_v_deltaSZE);
  __Pyx_XDECREF(__pyx_v_fRel);
  __Pyx_XDECREF(__pyx_v_M500);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4893
 *         return fRel
 * 
 *     def get_radial_kernel_W_galaxy_lensing_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_503get_radial_kernel_W_galaxy_lensing_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_503get_radial_kernel_W_galaxy_lensing_at_z = {"get_radial_kernel_W_galaxy_lensing_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_503get_radial_kernel_W_galaxy_lensing_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_503get_radial_kernel_W_galaxy_lensing_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_radial_kernel_W_galaxy_lensing_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4893, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_radial_kernel_W_galaxy_lensing_at_z") < 0)) __PYX_ERR(0, 4893, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4893, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_radial_kernel_W_galaxy_lensing_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4893, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_radial_kernel_W_galaxy_lensing_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_502get_radial_kernel_W_galaxy_lensing_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_502get_radial_kernel_W_galaxy_lensing_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_radial_kernel_W_galaxy_lensing_at_z", 1);

  /* "class-sz/python/classy.pyx":4894
 * 
 *     def get_radial_kernel_W_galaxy_lensing_at_z(self,double z):
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_custom1_bias_at_z(self,double z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(radial_kernel_W_galaxy_lensing_at_z(__pyx_v_z, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4893
 *         return fRel
 * 
 *     def get_radial_kernel_W_galaxy_lensing_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_radial_kernel_W_galaxy_lensing_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4896
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 *     def get_custom1_bias_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_505get_custom1_bias_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_505get_custom1_bias_at_z = {"get_custom1_bias_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_505get_custom1_bias_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_505get_custom1_bias_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_custom1_bias_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4896, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_custom1_bias_at_z") < 0)) __PYX_ERR(0, 4896, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4896, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_custom1_bias_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4896, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_custom1_bias_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_504get_custom1_bias_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_504get_custom1_bias_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_custom1_bias_at_z", 1);

  /* "class-sz/python/classy.pyx":4897
 * 
 *     def get_custom1_bias_at_z(self,double z):
 *         return get_b_custom1_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_radial_kernel_W_custom1_at_z(self,double z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_b_custom1_at_z(__pyx_v_z, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4896
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 *     def get_custom1_bias_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_custom1_bias_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4899
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 *     def get_radial_kernel_W_custom1_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_507get_radial_kernel_W_custom1_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_507get_radial_kernel_W_custom1_at_z = {"get_radial_kernel_W_custom1_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_507get_radial_kernel_W_custom1_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_507get_radial_kernel_W_custom1_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_radial_kernel_W_custom1_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4899, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_radial_kernel_W_custom1_at_z") < 0)) __PYX_ERR(0, 4899, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4899, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_radial_kernel_W_custom1_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4899, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_radial_kernel_W_custom1_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_506get_radial_kernel_W_custom1_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_506get_radial_kernel_W_custom1_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_radial_kernel_W_custom1_at_z", 1);

  /* "class-sz/python/classy.pyx":4900
 * 
 *     def get_radial_kernel_W_custom1_at_z(self,double z):
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_custom1_profile_at_x_m_z(self,double x, double m, double z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_radial_kernel_W_custom1_at_z(__pyx_v_z, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4899
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 *     def get_radial_kernel_W_custom1_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_radial_kernel_W_custom1_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4902
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 *     def get_custom1_profile_at_x_m_z(self,double x, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_509get_custom1_profile_at_x_m_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_509get_custom1_profile_at_x_m_z = {"get_custom1_profile_at_x_m_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_509get_custom1_profile_at_x_m_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_509get_custom1_profile_at_x_m_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_x;
  double __pyx_v_m;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_custom1_profile_at_x_m_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x,&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4902, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4902, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_custom1_profile_at_x_m_z", 1, 3, 3, 1); __PYX_ERR(0, 4902, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4902, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_custom1_profile_at_x_m_z", 1, 3, 3, 2); __PYX_ERR(0, 4902, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_custom1_profile_at_x_m_z") < 0)) __PYX_ERR(0, 4902, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_x = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_x == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4902, __pyx_L3_error)
    __pyx_v_m = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_m == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4902, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4902, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_custom1_profile_at_x_m_z", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4902, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_custom1_profile_at_x_m_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_508get_custom1_profile_at_x_m_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_x, __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_508get_custom1_profile_at_x_m_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_x, double __pyx_v_m, double __pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_custom1_profile_at_x_m_z", 1);

  /* "class-sz/python/classy.pyx":4903
 * 
 *     def get_custom1_profile_at_x_m_z(self,double x, double m, double z):
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_custom1_profile_at_k_m_z(self,double k, double m, double z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_custom1_profile_at_x_m_z(__pyx_v_x, __pyx_v_m, __pyx_v_z, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4902
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 *     def get_custom1_profile_at_x_m_z(self,double x, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_custom1_profile_at_x_m_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4905
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 *     def get_custom1_profile_at_k_m_z(self,double k, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_511get_custom1_profile_at_k_m_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_511get_custom1_profile_at_k_m_z = {"get_custom1_profile_at_k_m_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_511get_custom1_profile_at_k_m_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_511get_custom1_profile_at_k_m_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k;
  double __pyx_v_m;
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_custom1_profile_at_k_m_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_m,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4905, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4905, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_custom1_profile_at_k_m_z", 1, 3, 3, 1); __PYX_ERR(0, 4905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4905, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_custom1_profile_at_k_m_z", 1, 3, 3, 2); __PYX_ERR(0, 4905, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_custom1_profile_at_k_m_z") < 0)) __PYX_ERR(0, 4905, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_k = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4905, __pyx_L3_error)
    __pyx_v_m = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_m == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4905, __pyx_L3_error)
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4905, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_custom1_profile_at_k_m_z", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4905, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_custom1_profile_at_k_m_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_510get_custom1_profile_at_k_m_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_m, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_510get_custom1_profile_at_k_m_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k, double __pyx_v_m, double __pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_custom1_profile_at_k_m_z", 1);

  /* "class-sz/python/classy.pyx":4906
 * 
 *     def get_custom1_profile_at_k_m_z(self,double k, double m, double z):
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_ng_bar_at_z(self,double z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_custom1_profile_at_k_m_z(__pyx_v_k, __pyx_v_m, __pyx_v_z, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4905
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 *     def get_custom1_profile_at_k_m_z(self,double k, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_custom1_profile_at_k_m_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4908
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 *     def get_ng_bar_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_513get_ng_bar_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_513get_ng_bar_at_z = {"get_ng_bar_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_513get_ng_bar_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_513get_ng_bar_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_ng_bar_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4908, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_ng_bar_at_z") < 0)) __PYX_ERR(0, 4908, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4908, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_ng_bar_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4908, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_ng_bar_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_512get_ng_bar_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_512get_ng_bar_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_ng_bar_at_z", 1);

  /* "class-sz/python/classy.pyx":4909
 * 
 *     def get_ng_bar_at_z(self,double z):
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_source_galaxy_number_counts(self,double z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(evaluate_mean_galaxy_number_density_at_z(__pyx_v_z, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4908
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 *     def get_ng_bar_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_ng_bar_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4911
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 *     def get_source_galaxy_number_counts(self,double z):             # <<<<<<<<<<<<<<
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_515get_source_galaxy_number_counts(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_515get_source_galaxy_number_counts = {"get_source_galaxy_number_counts", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_515get_source_galaxy_number_counts, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_515get_source_galaxy_number_counts(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_source_galaxy_number_counts (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4911, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_source_galaxy_number_counts") < 0)) __PYX_ERR(0, 4911, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4911, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_source_galaxy_number_counts", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4911, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_source_galaxy_number_counts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_514get_source_galaxy_number_counts(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_514get_source_galaxy_number_counts(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_source_galaxy_number_counts", 1);

  /* "class-sz/python/classy.pyx":4912
 * 
 *     def get_source_galaxy_number_counts(self,double z):
 *         return get_source_galaxy_number_counts(z, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_N_satellites(self,double z,double M_halo,double Nc_mean,double M_min,double alpha_s,double M1_prime):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_source_galaxy_number_counts(__pyx_v_z, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4911
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 *     def get_source_galaxy_number_counts(self,double z):             # <<<<<<<<<<<<<<
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_source_galaxy_number_counts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4914
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 *     def get_N_satellites(self,double z,double M_halo,double Nc_mean,double M_min,double alpha_s,double M1_prime):             # <<<<<<<<<<<<<<
 *         Ns = HOD_mean_number_of_satellite_galaxies(z,M_halo,Nc_mean,M_min,alpha_s,M1_prime,&self.tsz,&self.ba)
 *         return Ns
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_517get_N_satellites(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_517get_N_satellites = {"get_N_satellites", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_517get_N_satellites, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_517get_N_satellites(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  double __pyx_v_M_halo;
  double __pyx_v_Nc_mean;
  double __pyx_v_M_min;
  double __pyx_v_alpha_s;
  double __pyx_v_M1_prime;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_N_satellites (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_M_halo,&__pyx_n_s_Nc_mean,&__pyx_n_s_M_min,&__pyx_n_s_alpha_s,&__pyx_n_s_M1_prime,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M_halo)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_satellites", 1, 6, 6, 1); __PYX_ERR(0, 4914, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_Nc_mean)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_satellites", 1, 6, 6, 2); __PYX_ERR(0, 4914, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M_min)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_satellites", 1, 6, 6, 3); __PYX_ERR(0, 4914, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_alpha_s)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_satellites", 1, 6, 6, 4); __PYX_ERR(0, 4914, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M1_prime)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[5]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_satellites", 1, 6, 6, 5); __PYX_ERR(0, 4914, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_N_satellites") < 0)) __PYX_ERR(0, 4914, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 6)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
    __pyx_v_M_halo = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_M_halo == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
    __pyx_v_Nc_mean = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_Nc_mean == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
    __pyx_v_M_min = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_M_min == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
    __pyx_v_alpha_s = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_alpha_s == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
    __pyx_v_M1_prime = __pyx_PyFloat_AsDouble(values[5]); if (unlikely((__pyx_v_M1_prime == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4914, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_N_satellites", 1, 6, 6, __pyx_nargs); __PYX_ERR(0, 4914, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_N_satellites", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_516get_N_satellites(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_M_halo, __pyx_v_Nc_mean, __pyx_v_M_min, __pyx_v_alpha_s, __pyx_v_M1_prime);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_516get_N_satellites(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_M_halo, double __pyx_v_Nc_mean, double __pyx_v_M_min, double __pyx_v_alpha_s, double __pyx_v_M1_prime) {
  double __pyx_v_Ns;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_N_satellites", 1);

  /* "class-sz/python/classy.pyx":4915
 * 
 *     def get_N_satellites(self,double z,double M_halo,double Nc_mean,double M_min,double alpha_s,double M1_prime):
 *         Ns = HOD_mean_number_of_satellite_galaxies(z,M_halo,Nc_mean,M_min,alpha_s,M1_prime,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 *         return Ns
 * 
 */
  __pyx_v_Ns = HOD_mean_number_of_satellite_galaxies(__pyx_v_z, __pyx_v_M_halo, __pyx_v_Nc_mean, __pyx_v_M_min, __pyx_v_alpha_s, __pyx_v_M1_prime, (&__pyx_v_self->tsz), (&__pyx_v_self->ba));

  /* "class-sz/python/classy.pyx":4916
 *     def get_N_satellites(self,double z,double M_halo,double Nc_mean,double M_min,double alpha_s,double M1_prime):
 *         Ns = HOD_mean_number_of_satellite_galaxies(z,M_halo,Nc_mean,M_min,alpha_s,M1_prime,&self.tsz,&self.ba)
 *         return Ns             # <<<<<<<<<<<<<<
 * 
 *     def get_N_centrals(self,double z,double M_halo,double M_min,double sigma_log10M,double fc):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_Ns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4914
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 *     def get_N_satellites(self,double z,double M_halo,double Nc_mean,double M_min,double alpha_s,double M1_prime):             # <<<<<<<<<<<<<<
 *         Ns = HOD_mean_number_of_satellite_galaxies(z,M_halo,Nc_mean,M_min,alpha_s,M1_prime,&self.tsz,&self.ba)
 *         return Ns
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_N_satellites", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4918
 *         return Ns
 * 
 *     def get_N_centrals(self,double z,double M_halo,double M_min,double sigma_log10M,double fc):             # <<<<<<<<<<<<<<
 *         Nc = HOD_mean_number_of_central_galaxies(z,M_halo,M_min,sigma_log10M,fc,&self.tsz,&self.ba)
 *         return Nc
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_519get_N_centrals(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_519get_N_centrals = {"get_N_centrals", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_519get_N_centrals, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_519get_N_centrals(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  double __pyx_v_M_halo;
  double __pyx_v_M_min;
  double __pyx_v_sigma_log10M;
  double __pyx_v_fc;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_N_centrals (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_M_halo,&__pyx_n_s_M_min,&__pyx_n_s_sigma_log10M,&__pyx_n_s_fc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M_halo)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_centrals", 1, 5, 5, 1); __PYX_ERR(0, 4918, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_M_min)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_centrals", 1, 5, 5, 2); __PYX_ERR(0, 4918, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sigma_log10M)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_centrals", 1, 5, 5, 3); __PYX_ERR(0, 4918, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_N_centrals", 1, 5, 5, 4); __PYX_ERR(0, 4918, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_N_centrals") < 0)) __PYX_ERR(0, 4918, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
    __pyx_v_M_halo = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_M_halo == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
    __pyx_v_M_min = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_M_min == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
    __pyx_v_sigma_log10M = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_sigma_log10M == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
    __pyx_v_fc = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_fc == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4918, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_N_centrals", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 4918, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_N_centrals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_518get_N_centrals(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_M_halo, __pyx_v_M_min, __pyx_v_sigma_log10M, __pyx_v_fc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_518get_N_centrals(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, double __pyx_v_M_halo, double __pyx_v_M_min, double __pyx_v_sigma_log10M, double __pyx_v_fc) {
  double __pyx_v_Nc;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_N_centrals", 1);

  /* "class-sz/python/classy.pyx":4919
 * 
 *     def get_N_centrals(self,double z,double M_halo,double M_min,double sigma_log10M,double fc):
 *         Nc = HOD_mean_number_of_central_galaxies(z,M_halo,M_min,sigma_log10M,fc,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 *         return Nc
 * 
 */
  __pyx_v_Nc = HOD_mean_number_of_central_galaxies(__pyx_v_z, __pyx_v_M_halo, __pyx_v_M_min, __pyx_v_sigma_log10M, __pyx_v_fc, (&__pyx_v_self->tsz), (&__pyx_v_self->ba));

  /* "class-sz/python/classy.pyx":4920
 *     def get_N_centrals(self,double z,double M_halo,double M_min,double sigma_log10M,double fc):
 *         Nc = HOD_mean_number_of_central_galaxies(z,M_halo,M_min,sigma_log10M,fc,&self.tsz,&self.ba)
 *         return Nc             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_Nc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4918
 *         return Ns
 * 
 *     def get_N_centrals(self,double z,double M_halo,double M_min,double sigma_log10M,double fc):             # <<<<<<<<<<<<<<
 *         Nc = HOD_mean_number_of_central_galaxies(z,M_halo,M_min,sigma_log10M,fc,&self.tsz,&self.ba)
 *         return Nc
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_N_centrals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4923
 * 
 * 
 *     def get_unwise_m_min_cut_at_z(self,double z,int sample_id):             # <<<<<<<<<<<<<<
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_521get_unwise_m_min_cut_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_521get_unwise_m_min_cut_at_z = {"get_unwise_m_min_cut_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_521get_unwise_m_min_cut_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_521get_unwise_m_min_cut_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z;
  int __pyx_v_sample_id;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_unwise_m_min_cut_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_sample_id,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4923, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sample_id)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4923, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_unwise_m_min_cut_at_z", 1, 2, 2, 1); __PYX_ERR(0, 4923, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_unwise_m_min_cut_at_z") < 0)) __PYX_ERR(0, 4923, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4923, __pyx_L3_error)
    __pyx_v_sample_id = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_sample_id == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4923, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_unwise_m_min_cut_at_z", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 4923, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_unwise_m_min_cut_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_520get_unwise_m_min_cut_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_sample_id);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_520get_unwise_m_min_cut_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z, int __pyx_v_sample_id) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_unwise_m_min_cut_at_z", 1);

  /* "class-sz/python/classy.pyx":4924
 * 
 *     def get_unwise_m_min_cut_at_z(self,double z,int sample_id):
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_yc_at_m_and_z_H13(self,m,z,A,B):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(evaluate_unwise_m_min_cut(__pyx_v_z, __pyx_v_sample_id, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4923
 * 
 * 
 *     def get_unwise_m_min_cut_at_z(self,double z,int sample_id):             # <<<<<<<<<<<<<<
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_unwise_m_min_cut_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4926
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 *     def get_yc_at_m_and_z_H13(self,m,z,A,B):             # <<<<<<<<<<<<<<
 *         Eh = self.Hubble(z)/self.Hubble(0)
 *         f_rel = self.calcFRel(z, m)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_523get_yc_at_m_and_z_H13(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_523get_yc_at_m_and_z_H13 = {"get_yc_at_m_and_z_H13", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_523get_yc_at_m_and_z_H13, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_523get_yc_at_m_and_z_H13(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_A = 0;
  PyObject *__pyx_v_B = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_yc_at_m_and_z_H13 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_m,&__pyx_n_s_z,&__pyx_n_s_A,&__pyx_n_s_B,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4926, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4926, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_yc_at_m_and_z_H13", 1, 4, 4, 1); __PYX_ERR(0, 4926, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4926, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_yc_at_m_and_z_H13", 1, 4, 4, 2); __PYX_ERR(0, 4926, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_B)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4926, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_yc_at_m_and_z_H13", 1, 4, 4, 3); __PYX_ERR(0, 4926, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_yc_at_m_and_z_H13") < 0)) __PYX_ERR(0, 4926, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_m = values[0];
    __pyx_v_z = values[1];
    __pyx_v_A = values[2];
    __pyx_v_B = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_yc_at_m_and_z_H13", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 4926, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_yc_at_m_and_z_H13", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_522get_yc_at_m_and_z_H13(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_m, __pyx_v_z, __pyx_v_A, __pyx_v_B);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_522get_yc_at_m_and_z_H13(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_m, PyObject *__pyx_v_z, PyObject *__pyx_v_A, PyObject *__pyx_v_B) {
  PyObject *__pyx_v_Eh = NULL;
  PyObject *__pyx_v_f_rel = NULL;
  PyObject *__pyx_v_vec_theta = NULL;
  PyObject *__pyx_v_theta_500 = NULL;
  double __pyx_v_h;
  PyObject *__pyx_v_QF = NULL;
  PyObject *__pyx_v_get_Q_of_theta500 = NULL;
  PyObject *__pyx_v_yp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  double __pyx_t_6;
  double __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_yc_at_m_and_z_H13", 1);

  /* "class-sz/python/classy.pyx":4927
 * 
 *     def get_yc_at_m_and_z_H13(self,m,z,A,B):
 *         Eh = self.Hubble(z)/self.Hubble(0)             # <<<<<<<<<<<<<<
 *         f_rel = self.calcFRel(z, m)
 *         vec_theta = np.vectorize(self.get_theta_at_m_and_z)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4927, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_Hubble); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_int_0};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4927, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyNumber_Divide(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_Eh = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4928
 *     def get_yc_at_m_and_z_H13(self,m,z,A,B):
 *         Eh = self.Hubble(z)/self.Hubble(0)
 *         f_rel = self.calcFRel(z, m)             # <<<<<<<<<<<<<<
 *         vec_theta = np.vectorize(self.get_theta_at_m_and_z)
 *         theta_500 = vec_theta(m,z)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_calcFRel); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_z, __pyx_v_m};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_f_rel = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4929
 *         Eh = self.Hubble(z)/self.Hubble(0)
 *         f_rel = self.calcFRel(z, m)
 *         vec_theta = np.vectorize(self.get_theta_at_m_and_z)             # <<<<<<<<<<<<<<
 *         theta_500 = vec_theta(m,z)
 *         h = self.ba.h
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_vectorize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_theta_at_m_and_z); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_2};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4929, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_vec_theta = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4930
 *         f_rel = self.calcFRel(z, m)
 *         vec_theta = np.vectorize(self.get_theta_at_m_and_z)
 *         theta_500 = vec_theta(m,z)             # <<<<<<<<<<<<<<
 *         h = self.ba.h
 *         QF = np.loadtxt('/Users/boris/Work/CLASS-SZ/SO-SZ/class_sz/sz_auxiliary_files/so_3freqs_020621_theta500arcmin_Q.txt')
 */
  __Pyx_INCREF(__pyx_v_vec_theta);
  __pyx_t_1 = __pyx_v_vec_theta; __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_m, __pyx_v_z};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_theta_500 = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4931
 *         vec_theta = np.vectorize(self.get_theta_at_m_and_z)
 *         theta_500 = vec_theta(m,z)
 *         h = self.ba.h             # <<<<<<<<<<<<<<
 *         QF = np.loadtxt('/Users/boris/Work/CLASS-SZ/SO-SZ/class_sz/sz_auxiliary_files/so_3freqs_020621_theta500arcmin_Q.txt')
 *         get_Q_of_theta500 = interpolate.interp1d(QF[:,0],QF[:,1],fill_value='extrapolate')
 */
  __pyx_t_6 = __pyx_v_self->ba.h;
  __pyx_v_h = __pyx_t_6;

  /* "class-sz/python/classy.pyx":4932
 *         theta_500 = vec_theta(m,z)
 *         h = self.ba.h
 *         QF = np.loadtxt('/Users/boris/Work/CLASS-SZ/SO-SZ/class_sz/sz_auxiliary_files/so_3freqs_020621_theta500arcmin_Q.txt')             # <<<<<<<<<<<<<<
 *         get_Q_of_theta500 = interpolate.interp1d(QF[:,0],QF[:,1],fill_value='extrapolate')
 *         yp = A*pow(Eh,2.)*pow(m/(3.e14*h),1.+B)*f_rel*get_Q_of_theta500(theta_500)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_loadtxt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_kp_u_Users_boris_Work_CLASS_SZ_SO_SZ};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_QF = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4933
 *         h = self.ba.h
 *         QF = np.loadtxt('/Users/boris/Work/CLASS-SZ/SO-SZ/class_sz/sz_auxiliary_files/so_3freqs_020621_theta500arcmin_Q.txt')
 *         get_Q_of_theta500 = interpolate.interp1d(QF[:,0],QF[:,1],fill_value='extrapolate')             # <<<<<<<<<<<<<<
 *         yp = A*pow(Eh,2.)*pow(m/(3.e14*h),1.+B)*f_rel*get_Q_of_theta500(theta_500)
 *         return yp
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_interpolate); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_interp1d); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_QF, __pyx_tuple__42); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_QF, __pyx_tuple__43); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(0, 4933, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1)) __PYX_ERR(0, 4933, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_fill_value, __pyx_n_u_extrapolate) < 0) __PYX_ERR(0, 4933, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_get_Q_of_theta500 = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4934
 *         QF = np.loadtxt('/Users/boris/Work/CLASS-SZ/SO-SZ/class_sz/sz_auxiliary_files/so_3freqs_020621_theta500arcmin_Q.txt')
 *         get_Q_of_theta500 = interpolate.interp1d(QF[:,0],QF[:,1],fill_value='extrapolate')
 *         yp = A*pow(Eh,2.)*pow(m/(3.e14*h),1.+B)*f_rel*get_Q_of_theta500(theta_500)             # <<<<<<<<<<<<<<
 *         return yp
 * 
 */
  __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_v_Eh); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4934, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(pow(__pyx_t_6, 2.)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyNumber_Multiply(__pyx_v_A, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyFloat_FromDouble((3.e14 * __pyx_v_h)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyNumber_Divide(__pyx_v_m, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_t_5); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyFloat_AddCObj(__pyx_float_1_, __pyx_v_B, 1., 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_t_5); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyFloat_FromDouble(pow(__pyx_t_6, __pyx_t_7)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Multiply(__pyx_t_3, __pyx_v_f_rel); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_v_get_Q_of_theta500);
  __pyx_t_1 = __pyx_v_get_Q_of_theta500; __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_theta_500};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = PyNumber_Multiply(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_yp = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4935
 *         get_Q_of_theta500 = interpolate.interp1d(QF[:,0],QF[:,1],fill_value='extrapolate')
 *         yp = A*pow(Eh,2.)*pow(m/(3.e14*h),1.+B)*f_rel*get_Q_of_theta500(theta_500)
 *         return yp             # <<<<<<<<<<<<<<
 * 
 *     def _cumulativeNumberDensity(self, z):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_yp);
  __pyx_r = __pyx_v_yp;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4926
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 *     def get_yc_at_m_and_z_H13(self,m,z,A,B):             # <<<<<<<<<<<<<<
 *         Eh = self.Hubble(z)/self.Hubble(0)
 *         f_rel = self.calcFRel(z, m)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_yc_at_m_and_z_H13", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_Eh);
  __Pyx_XDECREF(__pyx_v_f_rel);
  __Pyx_XDECREF(__pyx_v_vec_theta);
  __Pyx_XDECREF(__pyx_v_theta_500);
  __Pyx_XDECREF(__pyx_v_QF);
  __Pyx_XDECREF(__pyx_v_get_Q_of_theta500);
  __Pyx_XDECREF(__pyx_v_yp);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4937
 *         return yp
 * 
 *     def _cumulativeNumberDensity(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Returns N > M (per cubic Mpc).
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_525_cumulativeNumberDensity(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_524_cumulativeNumberDensity, "\n        Returns N > M (per cubic Mpc).\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_525_cumulativeNumberDensity = {"_cumulativeNumberDensity", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_525_cumulativeNumberDensity, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_524_cumulativeNumberDensity};
static PyObject *__pyx_pw_9classy_sz_5Class_525_cumulativeNumberDensity(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_cumulativeNumberDensity (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4937, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_cumulativeNumberDensity") < 0)) __PYX_ERR(0, 4937, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_cumulativeNumberDensity", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4937, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class._cumulativeNumberDensity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_524_cumulativeNumberDensity(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_524_cumulativeNumberDensity(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  CYTHON_UNUSED double __pyx_v_h;
  PyObject *__pyx_v_mm = NULL;
  Py_ssize_t __pyx_v_imp;
  PyObject *__pyx_v_M = NULL;
  PyObject *__pyx_v_dndlnM = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_dndM = NULL;
  PyObject *__pyx_v_ngtm = NULL;
  PyObject *__pyx_v_MUpper = NULL;
  PyObject *__pyx_v_extrapolator = NULL;
  PyObject *__pyx_v_MF_extr = NULL;
  PyObject *__pyx_v_intUpper = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  unsigned int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_cumulativeNumberDensity", 1);

  /* "class-sz/python/classy.pyx":4943
 *         """
 * 
 *         h= self.ba.h             # <<<<<<<<<<<<<<
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *         for imp in range(len(mm)):
 */
  __pyx_t_1 = __pyx_v_self->ba.h;
  __pyx_v_h = __pyx_t_1;

  /* "class-sz/python/classy.pyx":4944
 * 
 *         h= self.ba.h
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)             # <<<<<<<<<<<<<<
 *         for imp in range(len(mm)):
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.n_m_dndlnM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 4944, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_double); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_mm = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4945
 *         h= self.ba.h
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *         for imp in range(len(mm)):             # <<<<<<<<<<<<<<
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 *         M= np.exp(mm)
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_mm); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4945, __pyx_L1_error)
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_imp = __pyx_t_9;

    /* "class-sz/python/classy.pyx":4946
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *         for imp in range(len(mm)):
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]             # <<<<<<<<<<<<<<
 *         M= np.exp(mm)
 *         dndlnM=np.vectorize(self.get_dndlnM_at_z_and_M)(z,M)
 */
    __pyx_t_6 = PyFloat_FromDouble((__pyx_v_self->tsz.array_m_dndlnM[__pyx_v_imp])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely((__Pyx_SetItemInt(__pyx_v_mm, __pyx_v_imp, __pyx_t_6, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1) < 0))) __PYX_ERR(0, 4946, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }

  /* "class-sz/python/classy.pyx":4947
 *         for imp in range(len(mm)):
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 *         M= np.exp(mm)             # <<<<<<<<<<<<<<
 *         dndlnM=np.vectorize(self.get_dndlnM_at_z_and_M)(z,M)
 *         dndM=dndlnM/M
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_exp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_mm};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_M = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4948
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 *         M= np.exp(mm)
 *         dndlnM=np.vectorize(self.get_dndlnM_at_z_and_M)(z,M)             # <<<<<<<<<<<<<<
 *         dndM=dndlnM/M
 *         ngtm=integrate.cumtrapz(dndlnM[::-1], np.log(M), initial = 0)[::-1]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_vectorize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_dndlnM_at_z_and_M); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_z, __pyx_v_M};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_dndlnM = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4949
 *         M= np.exp(mm)
 *         dndlnM=np.vectorize(self.get_dndlnM_at_z_and_M)(z,M)
 *         dndM=dndlnM/M             # <<<<<<<<<<<<<<
 *         ngtm=integrate.cumtrapz(dndlnM[::-1], np.log(M), initial = 0)[::-1]
 * 
 */
  __pyx_t_6 = __Pyx_PyNumber_Divide(__pyx_v_dndlnM, __pyx_v_M); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4949, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_dndM = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4950
 *         dndlnM=np.vectorize(self.get_dndlnM_at_z_and_M)(z,M)
 *         dndM=dndlnM/M
 *         ngtm=integrate.cumtrapz(dndlnM[::-1], np.log(M), initial = 0)[::-1]             # <<<<<<<<<<<<<<
 * 
 *         MUpper=np.arange(np.log(M[-1]), np.log(10**18), np.log(M[1])-np.log(M[0]))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_integrate); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_cumtrapz); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_dndlnM, __pyx_slice__44); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_log); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_M};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6)) __PYX_ERR(0, 4950, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3)) __PYX_ERR(0, 4950, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_initial, __pyx_int_0) < 0) __PYX_ERR(0, 4950, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_slice__44); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_ngtm = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4952
 *         ngtm=integrate.cumtrapz(dndlnM[::-1], np.log(M), initial = 0)[::-1]
 * 
 *         MUpper=np.arange(np.log(M[-1]), np.log(10**18), np.log(M[1])-np.log(M[0]))             # <<<<<<<<<<<<<<
 *         extrapolator=_spline(np.log(M), np.log(dndlnM), k=1)
 *         MF_extr=extrapolator(MUpper)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_arange); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_log); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_M, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_4};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4952, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_log); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_int_0xde0b6b3a7640000};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4952, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_log); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_M, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_4};
    __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4952, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_log); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_M, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_14 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_14, __pyx_t_4};
    __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4952, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __pyx_t_13 = PyNumber_Subtract(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_12, __pyx_t_6, __pyx_t_2, __pyx_t_13};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 3+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4952, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_MUpper = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4953
 * 
 *         MUpper=np.arange(np.log(M[-1]), np.log(10**18), np.log(M[1])-np.log(M[0]))
 *         extrapolator=_spline(np.log(M), np.log(dndlnM), k=1)             # <<<<<<<<<<<<<<
 *         MF_extr=extrapolator(MUpper)
 *         intUpper=integrate.simps(np.exp(MF_extr), dx=MUpper[2] - MUpper[1], even='first')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_spline); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_np); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_log); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_M};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4953, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_np); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_log); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_dndlnM};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5)) __PYX_ERR(0, 4953, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_k, __pyx_int_1) < 0) __PYX_ERR(0, 4953, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_extrapolator = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":4954
 *         MUpper=np.arange(np.log(M[-1]), np.log(10**18), np.log(M[1])-np.log(M[0]))
 *         extrapolator=_spline(np.log(M), np.log(dndlnM), k=1)
 *         MF_extr=extrapolator(MUpper)             # <<<<<<<<<<<<<<
 *         intUpper=integrate.simps(np.exp(MF_extr), dx=MUpper[2] - MUpper[1], even='first')
 *         ngtm=ngtm+intUpper
 */
  __Pyx_INCREF(__pyx_v_extrapolator);
  __pyx_t_2 = __pyx_v_extrapolator; __pyx_t_6 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_MUpper};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_MF_extr = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":4955
 *         extrapolator=_spline(np.log(M), np.log(dndlnM), k=1)
 *         MF_extr=extrapolator(MUpper)
 *         intUpper=integrate.simps(np.exp(MF_extr), dx=MUpper[2] - MUpper[1], even='first')             # <<<<<<<<<<<<<<
 *         ngtm=ngtm+intUpper
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_integrate); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_simps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_exp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_MF_extr};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5)) __PYX_ERR(0, 4955, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_MUpper, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_13 = __Pyx_GetItemInt(__pyx_v_MUpper, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_12 = PyNumber_Subtract(__pyx_t_6, __pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dx, __pyx_t_12) < 0) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_even, __pyx_n_u_first) < 0) __PYX_ERR(0, 4955, __pyx_L1_error)
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_intUpper = __pyx_t_12;
  __pyx_t_12 = 0;

  /* "class-sz/python/classy.pyx":4956
 *         MF_extr=extrapolator(MUpper)
 *         intUpper=integrate.simps(np.exp(MF_extr), dx=MUpper[2] - MUpper[1], even='first')
 *         ngtm=ngtm+intUpper             # <<<<<<<<<<<<<<
 * 
 *         return ngtm
 */
  __pyx_t_12 = PyNumber_Add(__pyx_v_ngtm, __pyx_v_intUpper); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 4956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF_SET(__pyx_v_ngtm, __pyx_t_12);
  __pyx_t_12 = 0;

  /* "class-sz/python/classy.pyx":4958
 *         ngtm=ngtm+intUpper
 * 
 *         return ngtm             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ngtm);
  __pyx_r = __pyx_v_ngtm;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4937
 *         return yp
 * 
 *     def _cumulativeNumberDensity(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Returns N > M (per cubic Mpc).
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("classy_sz.Class._cumulativeNumberDensity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mm);
  __Pyx_XDECREF(__pyx_v_M);
  __Pyx_XDECREF(__pyx_v_dndlnM);
  __Pyx_XDECREF(__pyx_v_dndM);
  __Pyx_XDECREF(__pyx_v_ngtm);
  __Pyx_XDECREF(__pyx_v_MUpper);
  __Pyx_XDECREF(__pyx_v_extrapolator);
  __Pyx_XDECREF(__pyx_v_MF_extr);
  __Pyx_XDECREF(__pyx_v_intUpper);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4961
 * 
 * 
 *     def getPLog10M(self, z):             # <<<<<<<<<<<<<<
 *         """Returns the log10(mass) probability distribution at the given z, for the logarithmic mass
 *         binning and mass definition set when the MockSurvey object was constructed.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_527getPLog10M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_526getPLog10M, "Returns the log10(mass) probability distribution at the given z, for the logarithmic mass\n        binning and mass definition set when the MockSurvey object was constructed.\n\n        Args:\n            z (:obj:`float`): Redshift at which to calculate P(log10(M)).\n\n        Returns:\n            Array corresponding to the log10(mass) probability distribution.\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_527getPLog10M = {"getPLog10M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_527getPLog10M, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_526getPLog10M};
static PyObject *__pyx_pw_9classy_sz_5Class_527getPLog10M(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPLog10M (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4961, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getPLog10M") < 0)) __PYX_ERR(0, 4961, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getPLog10M", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4961, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.getPLog10M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_526getPLog10M(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_526getPLog10M(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_v_numberDensity = NULL;
  PyObject *__pyx_v_mm = NULL;
  Py_ssize_t __pyx_v_imp;
  PyObject *__pyx_v_M = NULL;
  PyObject *__pyx_v_PLog10M = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPLog10M", 1);

  /* "class-sz/python/classy.pyx":4972
 * 
 *         """
 *         numberDensity=self._cumulativeNumberDensity(z)             # <<<<<<<<<<<<<<
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *         for imp in range(len(mm)):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cumulativeNumberDensity); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_z};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_numberDensity = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4973
 *         """
 *         numberDensity=self._cumulativeNumberDensity(z)
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)             # <<<<<<<<<<<<<<
 *         for imp in range(len(mm)):
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.n_m_dndlnM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(0, 4973, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_double); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_mm = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4974
 *         numberDensity=self._cumulativeNumberDensity(z)
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *         for imp in range(len(mm)):             # <<<<<<<<<<<<<<
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 *         M= np.exp(mm)
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_mm); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 4974, __pyx_L1_error)
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_imp = __pyx_t_9;

    /* "class-sz/python/classy.pyx":4975
 *         mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *         for imp in range(len(mm)):
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]             # <<<<<<<<<<<<<<
 *         M= np.exp(mm)
 *         PLog10M=numberDensity/np.trapz(numberDensity, M)
 */
    __pyx_t_6 = PyFloat_FromDouble((__pyx_v_self->tsz.array_m_dndlnM[__pyx_v_imp])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely((__Pyx_SetItemInt(__pyx_v_mm, __pyx_v_imp, __pyx_t_6, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1) < 0))) __PYX_ERR(0, 4975, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }

  /* "class-sz/python/classy.pyx":4976
 *         for imp in range(len(mm)):
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 *         M= np.exp(mm)             # <<<<<<<<<<<<<<
 *         PLog10M=numberDensity/np.trapz(numberDensity, M)
 *         return PLog10M
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_exp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_mm};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_M = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "class-sz/python/classy.pyx":4977
 *             mm[imp] = self.tsz.array_m_dndlnM[imp]
 *         M= np.exp(mm)
 *         PLog10M=numberDensity/np.trapz(numberDensity, M)             # <<<<<<<<<<<<<<
 *         return PLog10M
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_trapz); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_numberDensity, __pyx_v_M};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_v_numberDensity, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_PLog10M = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4978
 *         M= np.exp(mm)
 *         PLog10M=numberDensity/np.trapz(numberDensity, M)
 *         return PLog10M             # <<<<<<<<<<<<<<
 * 
 *     def getM500_from_y0_H13(self,y0,y0Err,A,B,sigma_int,z,applyMFDebiasCorrection = True):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_PLog10M);
  __pyx_r = __pyx_v_PLog10M;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4961
 * 
 * 
 *     def getPLog10M(self, z):             # <<<<<<<<<<<<<<
 *         """Returns the log10(mass) probability distribution at the given z, for the logarithmic mass
 *         binning and mass definition set when the MockSurvey object was constructed.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("classy_sz.Class.getPLog10M", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_numberDensity);
  __Pyx_XDECREF(__pyx_v_mm);
  __Pyx_XDECREF(__pyx_v_M);
  __Pyx_XDECREF(__pyx_v_PLog10M);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":4980
 *         return PLog10M
 * 
 *     def getM500_from_y0_H13(self,y0,y0Err,A,B,sigma_int,z,applyMFDebiasCorrection = True):             # <<<<<<<<<<<<<<
 *         # y0 is fixed_y_c*1e-4 in the catalogue
 *         # log_y0Err is fixed_err_y_c in the catalogue
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_529getM500_from_y0_H13(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_529getM500_from_y0_H13 = {"getM500_from_y0_H13", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_529getM500_from_y0_H13, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_529getM500_from_y0_H13(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_y0 = 0;
  PyObject *__pyx_v_y0Err = 0;
  PyObject *__pyx_v_A = 0;
  PyObject *__pyx_v_B = 0;
  PyObject *__pyx_v_sigma_int = 0;
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_applyMFDebiasCorrection = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getM500_from_y0_H13 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_y0,&__pyx_n_s_y0Err,&__pyx_n_s_A,&__pyx_n_s_B,&__pyx_n_s_sigma_int,&__pyx_n_s_z,&__pyx_n_s_applyMFDebiasCorrection,0};
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_y0)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4980, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_y0Err)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4980, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getM500_from_y0_H13", 0, 6, 7, 1); __PYX_ERR(0, 4980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_A)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4980, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getM500_from_y0_H13", 0, 6, 7, 2); __PYX_ERR(0, 4980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_B)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4980, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getM500_from_y0_H13", 0, 6, 7, 3); __PYX_ERR(0, 4980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sigma_int)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4980, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getM500_from_y0_H13", 0, 6, 7, 4); __PYX_ERR(0, 4980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[5]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4980, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("getM500_from_y0_H13", 0, 6, 7, 5); __PYX_ERR(0, 4980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_applyMFDebiasCorrection);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4980, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "getM500_from_y0_H13") < 0)) __PYX_ERR(0, 4980, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_y0 = values[0];
    __pyx_v_y0Err = values[1];
    __pyx_v_A = values[2];
    __pyx_v_B = values[3];
    __pyx_v_sigma_int = values[4];
    __pyx_v_z = values[5];
    __pyx_v_applyMFDebiasCorrection = values[6];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getM500_from_y0_H13", 0, 6, 7, __pyx_nargs); __PYX_ERR(0, 4980, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.getM500_from_y0_H13", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_528getM500_from_y0_H13(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_y0, __pyx_v_y0Err, __pyx_v_A, __pyx_v_B, __pyx_v_sigma_int, __pyx_v_z, __pyx_v_applyMFDebiasCorrection);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_528getM500_from_y0_H13(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_y0, PyObject *__pyx_v_y0Err, PyObject *__pyx_v_A, PyObject *__pyx_v_B, PyObject *__pyx_v_sigma_int, PyObject *__pyx_v_z, PyObject *__pyx_v_applyMFDebiasCorrection) {
  PyObject *__pyx_v_M500c_zk = NULL;
  PyObject *__pyx_v_log10M500c_zk = NULL;
  PyObject *__pyx_v_log_y0 = NULL;
  PyObject *__pyx_v_log_y0Err = NULL;
  double __pyx_v_h;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_v_log_y0pred = NULL;
  PyObject *__pyx_v_Py0GivenM = NULL;
  PyObject *__pyx_v_PLog10M_full = NULL;
  PyObject *__pyx_v_log10Ms = NULL;
  PyObject *__pyx_v_mm = NULL;
  Py_ssize_t __pyx_v_imp;
  PyObject *__pyx_v_PLog10M = NULL;
  double __pyx_v_Pz;
  PyObject *__pyx_v_P = NULL;
  PyObject *__pyx_v_PArr = NULL;
  CYTHON_UNUSED int __pyx_v_calcErrors;
  PyObject *__pyx_v_log10M = NULL;
  PyObject *__pyx_v_tckP = NULL;
  PyObject *__pyx_v_fineLog10M = NULL;
  PyObject *__pyx_v_fineP = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_clusterLogM500 = NULL;
  PyObject *__pyx_v_clusterM500 = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_minIndex = NULL;
  PyObject *__pyx_v_maxIndex = NULL;
  PyObject *__pyx_v_clusterM500MinusErr = NULL;
  PyObject *__pyx_v_clusterM500PlusErr = NULL;
  PyObject *__pyx_v_p = NULL;
  PyObject *__pyx_v_clusterLogM500Min = NULL;
  PyObject *__pyx_v_clusterLogM500Max = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  double __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getM500_from_y0_H13", 1);

  /* "class-sz/python/classy.pyx":4985
 *         # returns:
 *         # M500*1e14, M500_errPlus*1e14, M500_errMinus*1e14 in Msun
 *         M500c_zk = np.geomspace(1.00000000e+12,1e16,300)             # <<<<<<<<<<<<<<
 *         log10M500c_zk = np.log10(M500c_zk)
 *         #log10M500c_zk
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_geomspace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_M500c_zk = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4986
 *         # M500*1e14, M500_errPlus*1e14, M500_errMinus*1e14 in Msun
 *         M500c_zk = np.geomspace(1.00000000e+12,1e16,300)
 *         log10M500c_zk = np.log10(M500c_zk)             # <<<<<<<<<<<<<<
 *         #log10M500c_zk
 *         log_y0 = np.log(y0)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_log10); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4986, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_M500c_zk};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4986, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_log10M500c_zk = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4988
 *         log10M500c_zk = np.log10(M500c_zk)
 *         #log10M500c_zk
 *         log_y0 = np.log(y0)             # <<<<<<<<<<<<<<
 *         log_y0Err = y0Err/y0
 *         h = self.ba.h
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_log); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_y0};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4988, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_log_y0 = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4989
 *         #log10M500c_zk
 *         log_y0 = np.log(y0)
 *         log_y0Err = y0Err/y0             # <<<<<<<<<<<<<<
 *         h = self.ba.h
 *         m = (10**log10M500c_zk)*h
 */
  __pyx_t_1 = __Pyx_PyNumber_Divide(__pyx_v_y0Err, __pyx_v_y0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_log_y0Err = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":4990
 *         log_y0 = np.log(y0)
 *         log_y0Err = y0Err/y0
 *         h = self.ba.h             # <<<<<<<<<<<<<<
 *         m = (10**log10M500c_zk)*h
 *         log_y0pred = np.log(self.get_yc_at_m_and_z_H13(m,z,A,B)) # feeds in m500c in Msun/h
 */
  __pyx_t_5 = __pyx_v_self->ba.h;
  __pyx_v_h = __pyx_t_5;

  /* "class-sz/python/classy.pyx":4991
 *         log_y0Err = y0Err/y0
 *         h = self.ba.h
 *         m = (10**log10M500c_zk)*h             # <<<<<<<<<<<<<<
 *         log_y0pred = np.log(self.get_yc_at_m_and_z_H13(m,z,A,B)) # feeds in m500c in Msun/h
 *         Py0GivenM=np.exp(-np.power(log_y0-log_y0pred, 2)/(2*(np.power(log_y0Err, 2)+np.power(sigma_int, 2))))
 */
  __pyx_t_1 = PyNumber_Power(__pyx_int_10, __pyx_v_log10M500c_zk, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_h); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_m = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4992
 *         h = self.ba.h
 *         m = (10**log10M500c_zk)*h
 *         log_y0pred = np.log(self.get_yc_at_m_and_z_H13(m,z,A,B)) # feeds in m500c in Msun/h             # <<<<<<<<<<<<<<
 *         Py0GivenM=np.exp(-np.power(log_y0-log_y0pred, 2)/(2*(np.power(log_y0Err, 2)+np.power(sigma_int, 2))))
 *         Py0GivenM=Py0GivenM/np.trapz(Py0GivenM, log10M500c_zk)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_log); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_yc_at_m_and_z_H13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_m, __pyx_v_z, __pyx_v_A, __pyx_v_B};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_log_y0pred = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4993
 *         m = (10**log10M500c_zk)*h
 *         log_y0pred = np.log(self.get_yc_at_m_and_z_H13(m,z,A,B)) # feeds in m500c in Msun/h
 *         Py0GivenM=np.exp(-np.power(log_y0-log_y0pred, 2)/(2*(np.power(log_y0Err, 2)+np.power(sigma_int, 2))))             # <<<<<<<<<<<<<<
 *         Py0GivenM=Py0GivenM/np.trapz(Py0GivenM, log10M500c_zk)
 *         # Mass function de-bias
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_exp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_power); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Subtract(__pyx_v_log_y0, __pyx_v_log_y0pred); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_t_6, __pyx_int_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = PyNumber_Negative(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_power); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_log_y0Err, __pyx_int_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_power); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_sigma_int, __pyx_int_2};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = PyNumber_Add(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyInt_MultiplyCObj(__pyx_int_2, __pyx_t_9, 2, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyNumber_Divide(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_9};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_Py0GivenM = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":4994
 *         log_y0pred = np.log(self.get_yc_at_m_and_z_H13(m,z,A,B)) # feeds in m500c in Msun/h
 *         Py0GivenM=np.exp(-np.power(log_y0-log_y0pred, 2)/(2*(np.power(log_y0Err, 2)+np.power(sigma_int, 2))))
 *         Py0GivenM=Py0GivenM/np.trapz(Py0GivenM, log10M500c_zk)             # <<<<<<<<<<<<<<
 *         # Mass function de-bias
 *         if applyMFDebiasCorrection == True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_trapz); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_Py0GivenM, __pyx_v_log10M500c_zk};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4994, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = __Pyx_PyNumber_Divide(__pyx_v_Py0GivenM, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_Py0GivenM, __pyx_t_9);
  __pyx_t_9 = 0;

  /* "class-sz/python/classy.pyx":4996
 *         Py0GivenM=Py0GivenM/np.trapz(Py0GivenM, log10M500c_zk)
 *         # Mass function de-bias
 *         if applyMFDebiasCorrection == True:             # <<<<<<<<<<<<<<
 *             PLog10M_full=self.getPLog10M(z)
 *             log10Ms = log10M500c_zk
 */
  __pyx_t_9 = PyObject_RichCompare(__pyx_v_applyMFDebiasCorrection, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4996, __pyx_L1_error)
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 4996, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__pyx_t_10) {

    /* "class-sz/python/classy.pyx":4997
 *         # Mass function de-bias
 *         if applyMFDebiasCorrection == True:
 *             PLog10M_full=self.getPLog10M(z)             # <<<<<<<<<<<<<<
 *             log10Ms = log10M500c_zk
 *             mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getPLog10M); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_z};
      __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4997, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_PLog10M_full = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "class-sz/python/classy.pyx":4998
 *         if applyMFDebiasCorrection == True:
 *             PLog10M_full=self.getPLog10M(z)
 *             log10Ms = log10M500c_zk             # <<<<<<<<<<<<<<
 *             mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *             for imp in range(len(mm)):
 */
    __Pyx_INCREF(__pyx_v_log10M500c_zk);
    __pyx_v_log10Ms = __pyx_v_log10M500c_zk;

    /* "class-sz/python/classy.pyx":4999
 *             PLog10M_full=self.getPLog10M(z)
 *             log10Ms = log10M500c_zk
 *             mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)             # <<<<<<<<<<<<<<
 *             for imp in range(len(mm)):
 *                 mm[imp] = self.tsz.array_m_dndlnM[imp]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.n_m_dndlnM); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_9)) __PYX_ERR(0, 4999, __pyx_L1_error);
    __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_double); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_dtype, __pyx_t_7) < 0) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_mm = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":5000
 *             log10Ms = log10M500c_zk
 *             mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *             for imp in range(len(mm)):             # <<<<<<<<<<<<<<
 *                 mm[imp] = self.tsz.array_m_dndlnM[imp]
 *             PLog10M =  interpolate.interp1d(mm,PLog10M_full,fill_value='extrapolate')(np.log(10)*log10Ms)
 */
    __pyx_t_11 = PyObject_Length(__pyx_v_mm); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5000, __pyx_L1_error)
    __pyx_t_12 = __pyx_t_11;
    for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
      __pyx_v_imp = __pyx_t_13;

      /* "class-sz/python/classy.pyx":5001
 *             mm = np.zeros(self.tsz.n_m_dndlnM, dtype=np.double)
 *             for imp in range(len(mm)):
 *                 mm[imp] = self.tsz.array_m_dndlnM[imp]             # <<<<<<<<<<<<<<
 *             PLog10M =  interpolate.interp1d(mm,PLog10M_full,fill_value='extrapolate')(np.log(10)*log10Ms)
 *             PLog10M=PLog10M/np.trapz(PLog10M, np.log(10)*log10Ms)/np.log(10)
 */
      __pyx_t_7 = PyFloat_FromDouble((__pyx_v_self->tsz.array_m_dndlnM[__pyx_v_imp])); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5001, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (unlikely((__Pyx_SetItemInt(__pyx_v_mm, __pyx_v_imp, __pyx_t_7, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1) < 0))) __PYX_ERR(0, 5001, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }

    /* "class-sz/python/classy.pyx":5002
 *             for imp in range(len(mm)):
 *                 mm[imp] = self.tsz.array_m_dndlnM[imp]
 *             PLog10M =  interpolate.interp1d(mm,PLog10M_full,fill_value='extrapolate')(np.log(10)*log10Ms)             # <<<<<<<<<<<<<<
 *             PLog10M=PLog10M/np.trapz(PLog10M, np.log(10)*log10Ms)/np.log(10)
 *         else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_interpolate); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_interp1d); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v_mm);
    __Pyx_GIVEREF(__pyx_v_mm);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_mm)) __PYX_ERR(0, 5002, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_PLog10M_full);
    __Pyx_GIVEREF(__pyx_v_PLog10M_full);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_PLog10M_full)) __PYX_ERR(0, 5002, __pyx_L1_error);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_fill_value, __pyx_n_u_extrapolate) < 0) __PYX_ERR(0, 5002, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_log); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_int_10};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_Multiply(__pyx_t_3, __pyx_v_log10Ms); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_v_PLog10M = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":5003
 *                 mm[imp] = self.tsz.array_m_dndlnM[imp]
 *             PLog10M =  interpolate.interp1d(mm,PLog10M_full,fill_value='extrapolate')(np.log(10)*log10Ms)
 *             PLog10M=PLog10M/np.trapz(PLog10M, np.log(10)*log10Ms)/np.log(10)             # <<<<<<<<<<<<<<
 *         else:
 *             PLog10M=1.0
 */
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_trapz); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_log); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_int_10};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5003, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = PyNumber_Multiply(__pyx_t_8, __pyx_v_log10Ms); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_PLog10M, __pyx_t_9};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5003, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_v_PLog10M, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_log); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_int_10};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5003, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_t_8 = __Pyx_PyNumber_Divide(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5003, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_PLog10M, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "class-sz/python/classy.pyx":4996
 *         Py0GivenM=Py0GivenM/np.trapz(Py0GivenM, log10M500c_zk)
 *         # Mass function de-bias
 *         if applyMFDebiasCorrection == True:             # <<<<<<<<<<<<<<
 *             PLog10M_full=self.getPLog10M(z)
 *             log10Ms = log10M500c_zk
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":5005
 *             PLog10M=PLog10M/np.trapz(PLog10M, np.log(10)*log10Ms)/np.log(10)
 *         else:
 *             PLog10M=1.0             # <<<<<<<<<<<<<<
 *         Pz = 1.
 *         P=Py0GivenM*PLog10M*Pz
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_float_1_0);
    __pyx_v_PLog10M = __pyx_float_1_0;
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":5006
 *         else:
 *             PLog10M=1.0
 *         Pz = 1.             # <<<<<<<<<<<<<<
 *         P=Py0GivenM*PLog10M*Pz
 *         PArr = P
 */
  __pyx_v_Pz = 1.;

  /* "class-sz/python/classy.pyx":5007
 *             PLog10M=1.0
 *         Pz = 1.
 *         P=Py0GivenM*PLog10M*Pz             # <<<<<<<<<<<<<<
 *         PArr = P
 *         PArr=np.array(PArr)
 */
  __pyx_t_8 = PyNumber_Multiply(__pyx_v_Py0GivenM, __pyx_v_PLog10M); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyFloat_FromDouble(__pyx_v_Pz); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_P = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5008
 *         Pz = 1.
 *         P=Py0GivenM*PLog10M*Pz
 *         PArr = P             # <<<<<<<<<<<<<<
 *         PArr=np.array(PArr)
 *         P = PArr
 */
  __Pyx_INCREF(__pyx_v_P);
  __pyx_v_PArr = __pyx_v_P;

  /* "class-sz/python/classy.pyx":5009
 *         P=Py0GivenM*PLog10M*Pz
 *         PArr = P
 *         PArr=np.array(PArr)             # <<<<<<<<<<<<<<
 *         P = PArr
 *         P=P/np.trapz(P, log10M500c_zk)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_array); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_PArr};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5009, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_PArr, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5010
 *         PArr = P
 *         PArr=np.array(PArr)
 *         P = PArr             # <<<<<<<<<<<<<<
 *         P=P/np.trapz(P, log10M500c_zk)
 * 
 */
  __Pyx_INCREF(__pyx_v_PArr);
  __Pyx_DECREF_SET(__pyx_v_P, __pyx_v_PArr);

  /* "class-sz/python/classy.pyx":5011
 *         PArr=np.array(PArr)
 *         P = PArr
 *         P=P/np.trapz(P, log10M500c_zk)             # <<<<<<<<<<<<<<
 * 
 *         calcErrors = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_trapz); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_P, __pyx_v_log10M500c_zk};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = __Pyx_PyNumber_Divide(__pyx_v_P, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_P, __pyx_t_7);
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":5013
 *         P=P/np.trapz(P, log10M500c_zk)
 * 
 *         calcErrors = True             # <<<<<<<<<<<<<<
 *         log10M = log10M500c_zk
 *         # Find max likelihood and integrate to get error bars
 */
  __pyx_v_calcErrors = 1;

  /* "class-sz/python/classy.pyx":5014
 * 
 *         calcErrors = True
 *         log10M = log10M500c_zk             # <<<<<<<<<<<<<<
 *         # Find max likelihood and integrate to get error bars
 *         tckP=interpolate.splrep(log10M, P)
 */
  __Pyx_INCREF(__pyx_v_log10M500c_zk);
  __pyx_v_log10M = __pyx_v_log10M500c_zk;

  /* "class-sz/python/classy.pyx":5016
 *         log10M = log10M500c_zk
 *         # Find max likelihood and integrate to get error bars
 *         tckP=interpolate.splrep(log10M, P)             # <<<<<<<<<<<<<<
 *         fineLog10M=np.linspace(log10M.min(), log10M.max(), 10000)
 *         fineP=interpolate.splev(fineLog10M, tckP)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_interpolate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_splrep); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_log10M, __pyx_v_P};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_v_tckP = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":5017
 *         # Find max likelihood and integrate to get error bars
 *         tckP=interpolate.splrep(log10M, P)
 *         fineLog10M=np.linspace(log10M.min(), log10M.max(), 10000)             # <<<<<<<<<<<<<<
 *         fineP=interpolate.splev(fineLog10M, tckP)
 *         fineP=fineP/np.trapz(fineP, fineLog10M)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_linspace); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_log10M, __pyx_n_s_min); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_log10M, __pyx_n_s_max); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_t_8, __pyx_t_9, __pyx_int_10000};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_fineLog10M = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":5018
 *         tckP=interpolate.splrep(log10M, P)
 *         fineLog10M=np.linspace(log10M.min(), log10M.max(), 10000)
 *         fineP=interpolate.splev(fineLog10M, tckP)             # <<<<<<<<<<<<<<
 *         fineP=fineP/np.trapz(fineP, fineLog10M)
 *         index=np.argmax(fineP)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_interpolate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_splev); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_fineLog10M, __pyx_v_tckP};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_v_fineP = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":5019
 *         fineLog10M=np.linspace(log10M.min(), log10M.max(), 10000)
 *         fineP=interpolate.splev(fineLog10M, tckP)
 *         fineP=fineP/np.trapz(fineP, fineLog10M)             # <<<<<<<<<<<<<<
 *         index=np.argmax(fineP)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_trapz); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_v_fineP, __pyx_v_fineLog10M};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyNumber_Divide(__pyx_v_fineP, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_fineP, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5020
 *         fineP=interpolate.splev(fineLog10M, tckP)
 *         fineP=fineP/np.trapz(fineP, fineLog10M)
 *         index=np.argmax(fineP)             # <<<<<<<<<<<<<<
 * 
 *         clusterLogM500=fineLog10M[index]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_argmax); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5020, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_fineP};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_v_index = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5022
 *         index=np.argmax(fineP)
 * 
 *         clusterLogM500=fineLog10M[index]             # <<<<<<<<<<<<<<
 *         clusterM500=np.power(10, clusterLogM500)/1e14
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_fineLog10M, __pyx_v_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_clusterLogM500 = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5023
 * 
 *         clusterLogM500=fineLog10M[index]
 *         clusterM500=np.power(10, clusterLogM500)/1e14             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_power); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_int_10, __pyx_v_clusterLogM500};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5023, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_2, __pyx_float_1e14, 1e14, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_clusterM500 = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":5026
 * 
 * 
 *         for n in range(fineP.shape[0]):             # <<<<<<<<<<<<<<
 *             minIndex=index-n
 *             maxIndex=index+n
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_fineP, __pyx_n_s_shape); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_7, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
    __pyx_t_2 = __pyx_t_7; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_11 = 0;
    __pyx_t_14 = NULL;
  } else {
    __pyx_t_11 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5026, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  for (;;) {
    if (likely(!__pyx_t_14)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5026, __pyx_L1_error)
          #endif
          if (__pyx_t_11 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 5026, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5026, __pyx_L1_error)
          #endif
          if (__pyx_t_11 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 5026, __pyx_L1_error)
        #else
        __pyx_t_7 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5026, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_14(__pyx_t_2);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5026, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_n, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":5027
 * 
 *         for n in range(fineP.shape[0]):
 *             minIndex=index-n             # <<<<<<<<<<<<<<
 *             maxIndex=index+n
 *             if minIndex < 0 or maxIndex > fineP.shape[0]:
 */
    __pyx_t_7 = PyNumber_Subtract(__pyx_v_index, __pyx_v_n); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF_SET(__pyx_v_minIndex, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":5028
 *         for n in range(fineP.shape[0]):
 *             minIndex=index-n
 *             maxIndex=index+n             # <<<<<<<<<<<<<<
 *             if minIndex < 0 or maxIndex > fineP.shape[0]:
 *                 # This shouldn't happen; if it does, probably y0 is in the wrong units
 */
    __pyx_t_7 = PyNumber_Add(__pyx_v_index, __pyx_v_n); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5028, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF_SET(__pyx_v_maxIndex, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":5029
 *             minIndex=index-n
 *             maxIndex=index+n
 *             if minIndex < 0 or maxIndex > fineP.shape[0]:             # <<<<<<<<<<<<<<
 *                 # This shouldn't happen; if it does, probably y0 is in the wrong units
 *                 # Previously we threw an exception here, but we can't if using this for forced photometry
 */
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_minIndex, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5029, __pyx_L1_error)
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 5029, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (!__pyx_t_15) {
    } else {
      __pyx_t_10 = __pyx_t_15;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_fineP, __pyx_n_s_shape); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_GetItemInt(__pyx_t_7, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_maxIndex, __pyx_t_9, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5029, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 5029, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_10 = __pyx_t_15;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_10) {

      /* "class-sz/python/classy.pyx":5033
 *                 # Previously we threw an exception here, but we can't if using this for forced photometry
 *                 #print("WARNING: outside M500 range - check y0 units or for problem at cluster location in map (if not in forced photometry mode)")
 *                 clusterM500MinusErr=0.             # <<<<<<<<<<<<<<
 *                 clusterM500PlusErr=0.
 *                 break
 */
      __Pyx_INCREF(__pyx_float_0_);
      __pyx_v_clusterM500MinusErr = __pyx_float_0_;

      /* "class-sz/python/classy.pyx":5034
 *                 #print("WARNING: outside M500 range - check y0 units or for problem at cluster location in map (if not in forced photometry mode)")
 *                 clusterM500MinusErr=0.
 *                 clusterM500PlusErr=0.             # <<<<<<<<<<<<<<
 *                 break
 *             p=np.trapz(fineP[minIndex:maxIndex], fineLog10M[minIndex:maxIndex])
 */
      __Pyx_INCREF(__pyx_float_0_);
      __pyx_v_clusterM500PlusErr = __pyx_float_0_;

      /* "class-sz/python/classy.pyx":5035
 *                 clusterM500MinusErr=0.
 *                 clusterM500PlusErr=0.
 *                 break             # <<<<<<<<<<<<<<
 *             p=np.trapz(fineP[minIndex:maxIndex], fineLog10M[minIndex:maxIndex])
 *             if p >= 0.6827:
 */
      goto __pyx_L7_break;

      /* "class-sz/python/classy.pyx":5029
 *             minIndex=index-n
 *             maxIndex=index+n
 *             if minIndex < 0 or maxIndex > fineP.shape[0]:             # <<<<<<<<<<<<<<
 *                 # This shouldn't happen; if it does, probably y0 is in the wrong units
 *                 # Previously we threw an exception here, but we can't if using this for forced photometry
 */
    }

    /* "class-sz/python/classy.pyx":5036
 *                 clusterM500PlusErr=0.
 *                 break
 *             p=np.trapz(fineP[minIndex:maxIndex], fineLog10M[minIndex:maxIndex])             # <<<<<<<<<<<<<<
 *             if p >= 0.6827:
 *                 clusterLogM500Min=fineLog10M[minIndex]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_trapz); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_v_fineP, 0, 0, &__pyx_v_minIndex, &__pyx_v_maxIndex, NULL, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_fineLog10M, 0, 0, &__pyx_v_minIndex, &__pyx_v_maxIndex, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5036, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_t_9, __pyx_t_3};
      __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5036, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":5037
 *                 break
 *             p=np.trapz(fineP[minIndex:maxIndex], fineLog10M[minIndex:maxIndex])
 *             if p >= 0.6827:             # <<<<<<<<<<<<<<
 *                 clusterLogM500Min=fineLog10M[minIndex]
 *                 clusterLogM500Max=fineLog10M[maxIndex]
 */
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_p, __pyx_float_0_6827, Py_GE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5037, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 5037, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_10) {

      /* "class-sz/python/classy.pyx":5038
 *             p=np.trapz(fineP[minIndex:maxIndex], fineLog10M[minIndex:maxIndex])
 *             if p >= 0.6827:
 *                 clusterLogM500Min=fineLog10M[minIndex]             # <<<<<<<<<<<<<<
 *                 clusterLogM500Max=fineLog10M[maxIndex]
 *                 clusterM500MinusErr=(np.power(10, clusterLogM500)-np.power(10, clusterLogM500Min))/1e14
 */
      __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_fineLog10M, __pyx_v_minIndex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5038, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_clusterLogM500Min = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":5039
 *             if p >= 0.6827:
 *                 clusterLogM500Min=fineLog10M[minIndex]
 *                 clusterLogM500Max=fineLog10M[maxIndex]             # <<<<<<<<<<<<<<
 *                 clusterM500MinusErr=(np.power(10, clusterLogM500)-np.power(10, clusterLogM500Min))/1e14
 *                 clusterM500PlusErr=(np.power(10, clusterLogM500Max)-np.power(10, clusterLogM500))/1e14
 */
      __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_fineLog10M, __pyx_v_maxIndex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5039, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_clusterLogM500Max = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":5040
 *                 clusterLogM500Min=fineLog10M[minIndex]
 *                 clusterLogM500Max=fineLog10M[maxIndex]
 *                 clusterM500MinusErr=(np.power(10, clusterLogM500)-np.power(10, clusterLogM500Min))/1e14             # <<<<<<<<<<<<<<
 *                 clusterM500PlusErr=(np.power(10, clusterLogM500Max)-np.power(10, clusterLogM500))/1e14
 *                 break
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5040, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_power); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5040, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_int_10, __pyx_v_clusterLogM500};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5040, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5040, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_power); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5040, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_int_10, __pyx_v_clusterLogM500Min};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5040, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __pyx_t_9 = PyNumber_Subtract(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5040, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_9, __pyx_float_1e14, 1e14, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5040, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_clusterM500MinusErr = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":5041
 *                 clusterLogM500Max=fineLog10M[maxIndex]
 *                 clusterM500MinusErr=(np.power(10, clusterLogM500)-np.power(10, clusterLogM500Min))/1e14
 *                 clusterM500PlusErr=(np.power(10, clusterLogM500Max)-np.power(10, clusterLogM500))/1e14             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_power); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_int_10, __pyx_v_clusterLogM500Max};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5041, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_power); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_9, __pyx_int_10, __pyx_v_clusterLogM500};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5041, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_t_8 = PyNumber_Subtract(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyFloat_TrueDivideObjC(__pyx_t_8, __pyx_float_1e14, 1e14, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5041, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_clusterM500PlusErr = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "class-sz/python/classy.pyx":5042
 *                 clusterM500MinusErr=(np.power(10, clusterLogM500)-np.power(10, clusterLogM500Min))/1e14
 *                 clusterM500PlusErr=(np.power(10, clusterLogM500Max)-np.power(10, clusterLogM500))/1e14
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         return clusterM500*1e14, clusterM500MinusErr*1e14, clusterM500PlusErr*1e14
 */
      goto __pyx_L7_break;

      /* "class-sz/python/classy.pyx":5037
 *                 break
 *             p=np.trapz(fineP[minIndex:maxIndex], fineLog10M[minIndex:maxIndex])
 *             if p >= 0.6827:             # <<<<<<<<<<<<<<
 *                 clusterLogM500Min=fineLog10M[minIndex]
 *                 clusterLogM500Max=fineLog10M[maxIndex]
 */
    }

    /* "class-sz/python/classy.pyx":5026
 * 
 * 
 *         for n in range(fineP.shape[0]):             # <<<<<<<<<<<<<<
 *             minIndex=index-n
 *             maxIndex=index+n
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L12_for_end;
  __pyx_L7_break:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L12_for_end;
  __pyx_L12_for_end:;

  /* "class-sz/python/classy.pyx":5044
 *                 break
 * 
 *         return clusterM500*1e14, clusterM500MinusErr*1e14, clusterM500PlusErr*1e14             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyNumber_Multiply(__pyx_v_clusterM500, __pyx_float_1e14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(!__pyx_v_clusterM500MinusErr)) { __Pyx_RaiseUnboundLocalError("clusterM500MinusErr"); __PYX_ERR(0, 5044, __pyx_L1_error) }
  __pyx_t_7 = PyNumber_Multiply(__pyx_v_clusterM500MinusErr, __pyx_float_1e14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (unlikely(!__pyx_v_clusterM500PlusErr)) { __Pyx_RaiseUnboundLocalError("clusterM500PlusErr"); __PYX_ERR(0, 5044, __pyx_L1_error) }
  __pyx_t_8 = PyNumber_Multiply(__pyx_v_clusterM500PlusErr, __pyx_float_1e14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 5044, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7)) __PYX_ERR(0, 5044, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_8)) __PYX_ERR(0, 5044, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":4980
 *         return PLog10M
 * 
 *     def getM500_from_y0_H13(self,y0,y0Err,A,B,sigma_int,z,applyMFDebiasCorrection = True):             # <<<<<<<<<<<<<<
 *         # y0 is fixed_y_c*1e-4 in the catalogue
 *         # log_y0Err is fixed_err_y_c in the catalogue
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("classy_sz.Class.getM500_from_y0_H13", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_M500c_zk);
  __Pyx_XDECREF(__pyx_v_log10M500c_zk);
  __Pyx_XDECREF(__pyx_v_log_y0);
  __Pyx_XDECREF(__pyx_v_log_y0Err);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XDECREF(__pyx_v_log_y0pred);
  __Pyx_XDECREF(__pyx_v_Py0GivenM);
  __Pyx_XDECREF(__pyx_v_PLog10M_full);
  __Pyx_XDECREF(__pyx_v_log10Ms);
  __Pyx_XDECREF(__pyx_v_mm);
  __Pyx_XDECREF(__pyx_v_PLog10M);
  __Pyx_XDECREF(__pyx_v_P);
  __Pyx_XDECREF(__pyx_v_PArr);
  __Pyx_XDECREF(__pyx_v_log10M);
  __Pyx_XDECREF(__pyx_v_tckP);
  __Pyx_XDECREF(__pyx_v_fineLog10M);
  __Pyx_XDECREF(__pyx_v_fineP);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_clusterLogM500);
  __Pyx_XDECREF(__pyx_v_clusterM500);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_minIndex);
  __Pyx_XDECREF(__pyx_v_maxIndex);
  __Pyx_XDECREF(__pyx_v_clusterM500MinusErr);
  __Pyx_XDECREF(__pyx_v_clusterM500PlusErr);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_XDECREF(__pyx_v_clusterLogM500Min);
  __Pyx_XDECREF(__pyx_v_clusterLogM500Max);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5048
 * 
 * 
 *     def get_bispectrum_f2_kernel(self, double k1, double k2, double k3):             # <<<<<<<<<<<<<<
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_531get_bispectrum_f2_kernel(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_531get_bispectrum_f2_kernel = {"get_bispectrum_f2_kernel", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_531get_bispectrum_f2_kernel, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_531get_bispectrum_f2_kernel(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_k1;
  double __pyx_v_k2;
  double __pyx_v_k3;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_bispectrum_f2_kernel (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k1,&__pyx_n_s_k2,&__pyx_n_s_k3,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5048, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5048, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_bispectrum_f2_kernel", 1, 3, 3, 1); __PYX_ERR(0, 5048, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k3)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5048, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_bispectrum_f2_kernel", 1, 3, 3, 2); __PYX_ERR(0, 5048, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_bispectrum_f2_kernel") < 0)) __PYX_ERR(0, 5048, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_k1 = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_k1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5048, __pyx_L3_error)
    __pyx_v_k2 = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_k2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5048, __pyx_L3_error)
    __pyx_v_k3 = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_k3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5048, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_bispectrum_f2_kernel", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 5048, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_bispectrum_f2_kernel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_530get_bispectrum_f2_kernel(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k1, __pyx_v_k2, __pyx_v_k3);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_530get_bispectrum_f2_kernel(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_k1, double __pyx_v_k2, double __pyx_v_k3) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_bispectrum_f2_kernel", 1);

  /* "class-sz/python/classy.pyx":5049
 * 
 *     def get_bispectrum_f2_kernel(self, double k1, double k2, double k3):
 *         return bispectrum_f2_kernel(k1, k2, k3)             # <<<<<<<<<<<<<<
 * 
 *     def get_nu_at_z_and_m(self,z,m):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(bispectrum_f2_kernel(__pyx_v_k1, __pyx_v_k2, __pyx_v_k3)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5049, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5048
 * 
 * 
 *     def get_bispectrum_f2_kernel(self, double k1, double k2, double k3):             # <<<<<<<<<<<<<<
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_bispectrum_f2_kernel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5051
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 *     def get_nu_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         # (delc/sigma)**2
 *         return get_nu_at_z_and_m(z,m,&self.tsz,&self.ba)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_533get_nu_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_533get_nu_at_z_and_m = {"get_nu_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_533get_nu_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_533get_nu_at_z_and_m(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_nu_at_z_and_m (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5051, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5051, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_nu_at_z_and_m", 1, 2, 2, 1); __PYX_ERR(0, 5051, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_nu_at_z_and_m") < 0)) __PYX_ERR(0, 5051, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_nu_at_z_and_m", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5051, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_nu_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_532get_nu_at_z_and_m(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_532get_nu_at_z_and_m(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_nu_at_z_and_m", 1);

  /* "class-sz/python/classy.pyx":5053
 *     def get_nu_at_z_and_m(self,z,m):
 *         # (delc/sigma)**2
 *         return get_nu_at_z_and_m(z,m,&self.tsz,&self.ba)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5053, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5053, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_nu_at_z_and_m(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->ba))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5051
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 *     def get_nu_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         # (delc/sigma)**2
 *         return get_nu_at_z_and_m(z,m,&self.tsz,&self.ba)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_nu_at_z_and_m", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5056
 * 
 * 
 *     def get_matter_bispectrum_at_z_effective_approach_smoothed(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_535get_matter_bispectrum_at_z_effective_approach_smoothed(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_535get_matter_bispectrum_at_z_effective_approach_smoothed = {"get_matter_bispectrum_at_z_effective_approach_smoothed", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_535get_matter_bispectrum_at_z_effective_approach_smoothed, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_535get_matter_bispectrum_at_z_effective_approach_smoothed(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k2_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k3_in_h_over_Mpc = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_effective_approach_smoothed (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k1_in_h_over_Mpc,&__pyx_n_s_k2_in_h_over_Mpc,&__pyx_n_s_k3_in_h_over_Mpc,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5056, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k2_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5056, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_smoothed", 1, 4, 4, 1); __PYX_ERR(0, 5056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k3_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5056, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_smoothed", 1, 4, 4, 2); __PYX_ERR(0, 5056, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5056, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_smoothed", 1, 4, 4, 3); __PYX_ERR(0, 5056, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_matter_bispectrum_at_z_effective_approach_smoothed") < 0)) __PYX_ERR(0, 5056, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_k1_in_h_over_Mpc = values[0];
    __pyx_v_k2_in_h_over_Mpc = values[1];
    __pyx_v_k3_in_h_over_Mpc = values[2];
    __pyx_v_z = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_smoothed", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5056, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_effective_approach_smoothed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_534get_matter_bispectrum_at_z_effective_approach_smoothed(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k1_in_h_over_Mpc, __pyx_v_k2_in_h_over_Mpc, __pyx_v_k3_in_h_over_Mpc, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_534get_matter_bispectrum_at_z_effective_approach_smoothed(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_effective_approach_smoothed", 1);

  /* "class-sz/python/classy.pyx":5057
 * 
 *     def get_matter_bispectrum_at_z_effective_approach_smoothed(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)             # <<<<<<<<<<<<<<
 * 
 *     def get_ttg_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5057, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k2_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5057, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_k3_in_h_over_Mpc); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5057, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5057, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_matter_bispectrum_at_z_effective_approach_smoothed(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->tsz), (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->pm))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5057, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5056
 * 
 * 
 *     def get_matter_bispectrum_at_z_effective_approach_smoothed(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_effective_approach_smoothed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5059
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_537get_ttg_bispectrum_at_z_effective_approach(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_537get_ttg_bispectrum_at_z_effective_approach = {"get_ttg_bispectrum_at_z_effective_approach", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_537get_ttg_bispectrum_at_z_effective_approach, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_537get_ttg_bispectrum_at_z_effective_approach(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k2_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k3_in_h_over_Mpc = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_ttg_bispectrum_at_z_effective_approach (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k1_in_h_over_Mpc,&__pyx_n_s_k2_in_h_over_Mpc,&__pyx_n_s_k3_in_h_over_Mpc,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5059, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k2_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5059, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_effective_approach", 1, 4, 4, 1); __PYX_ERR(0, 5059, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k3_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5059, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_effective_approach", 1, 4, 4, 2); __PYX_ERR(0, 5059, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5059, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_effective_approach", 1, 4, 4, 3); __PYX_ERR(0, 5059, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_ttg_bispectrum_at_z_effective_approach") < 0)) __PYX_ERR(0, 5059, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_k1_in_h_over_Mpc = values[0];
    __pyx_v_k2_in_h_over_Mpc = values[1];
    __pyx_v_k3_in_h_over_Mpc = values[2];
    __pyx_v_z = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_effective_approach", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5059, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_ttg_bispectrum_at_z_effective_approach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_536get_ttg_bispectrum_at_z_effective_approach(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k1_in_h_over_Mpc, __pyx_v_k2_in_h_over_Mpc, __pyx_v_k3_in_h_over_Mpc, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_536get_ttg_bispectrum_at_z_effective_approach(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_ttg_bispectrum_at_z_effective_approach", 1);

  /* "class-sz/python/classy.pyx":5060
 * 
 *     def get_ttg_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)             # <<<<<<<<<<<<<<
 * 
 *     def get_ttg_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5060, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k2_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5060, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_k3_in_h_over_Mpc); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5060, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5060, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_ttg_bispectrum_at_z_effective_approach(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->tsz), (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->pm))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5059
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_ttg_bispectrum_at_z_effective_approach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5062
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_539get_ttg_bispectrum_at_z_tree_level_PT(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_539get_ttg_bispectrum_at_z_tree_level_PT = {"get_ttg_bispectrum_at_z_tree_level_PT", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_539get_ttg_bispectrum_at_z_tree_level_PT, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_539get_ttg_bispectrum_at_z_tree_level_PT(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k2_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k3_in_h_over_Mpc = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_ttg_bispectrum_at_z_tree_level_PT (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k1_in_h_over_Mpc,&__pyx_n_s_k2_in_h_over_Mpc,&__pyx_n_s_k3_in_h_over_Mpc,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5062, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k2_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5062, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_tree_level_PT", 1, 4, 4, 1); __PYX_ERR(0, 5062, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k3_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5062, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_tree_level_PT", 1, 4, 4, 2); __PYX_ERR(0, 5062, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5062, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_tree_level_PT", 1, 4, 4, 3); __PYX_ERR(0, 5062, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_ttg_bispectrum_at_z_tree_level_PT") < 0)) __PYX_ERR(0, 5062, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_k1_in_h_over_Mpc = values[0];
    __pyx_v_k2_in_h_over_Mpc = values[1];
    __pyx_v_k3_in_h_over_Mpc = values[2];
    __pyx_v_z = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_ttg_bispectrum_at_z_tree_level_PT", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5062, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_ttg_bispectrum_at_z_tree_level_PT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_538get_ttg_bispectrum_at_z_tree_level_PT(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k1_in_h_over_Mpc, __pyx_v_k2_in_h_over_Mpc, __pyx_v_k3_in_h_over_Mpc, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_538get_ttg_bispectrum_at_z_tree_level_PT(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_ttg_bispectrum_at_z_tree_level_PT", 1);

  /* "class-sz/python/classy.pyx":5063
 * 
 *     def get_ttg_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)             # <<<<<<<<<<<<<<
 * 
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5063, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k2_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5063, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_k3_in_h_over_Mpc); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5063, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5063, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_ttg_bispectrum_at_z_tree_level_PT(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->tsz), (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->pm))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5062
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_ttg_bispectrum_at_z_tree_level_PT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5065
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_541get_matter_bispectrum_at_z_effective_approach(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_541get_matter_bispectrum_at_z_effective_approach = {"get_matter_bispectrum_at_z_effective_approach", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_541get_matter_bispectrum_at_z_effective_approach, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_541get_matter_bispectrum_at_z_effective_approach(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k2_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k3_in_h_over_Mpc = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_effective_approach (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k1_in_h_over_Mpc,&__pyx_n_s_k2_in_h_over_Mpc,&__pyx_n_s_k3_in_h_over_Mpc,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5065, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k2_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5065, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach", 1, 4, 4, 1); __PYX_ERR(0, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k3_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5065, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach", 1, 4, 4, 2); __PYX_ERR(0, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5065, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach", 1, 4, 4, 3); __PYX_ERR(0, 5065, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_matter_bispectrum_at_z_effective_approach") < 0)) __PYX_ERR(0, 5065, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_k1_in_h_over_Mpc = values[0];
    __pyx_v_k2_in_h_over_Mpc = values[1];
    __pyx_v_k3_in_h_over_Mpc = values[2];
    __pyx_v_z = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5065, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_effective_approach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_540get_matter_bispectrum_at_z_effective_approach(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k1_in_h_over_Mpc, __pyx_v_k2_in_h_over_Mpc, __pyx_v_k3_in_h_over_Mpc, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_540get_matter_bispectrum_at_z_effective_approach(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_effective_approach", 1);

  /* "class-sz/python/classy.pyx":5066
 * 
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)             # <<<<<<<<<<<<<<
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5066, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k2_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5066, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_k3_in_h_over_Mpc); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5066, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5066, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_matter_bispectrum_at_z_effective_approach(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->tsz), (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->pm))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5065
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_effective_approach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5067
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_543get_matter_bispectrum_at_z_effective_approach_SC(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_543get_matter_bispectrum_at_z_effective_approach_SC = {"get_matter_bispectrum_at_z_effective_approach_SC", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_543get_matter_bispectrum_at_z_effective_approach_SC, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_543get_matter_bispectrum_at_z_effective_approach_SC(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k2_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k3_in_h_over_Mpc = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_effective_approach_SC (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k1_in_h_over_Mpc,&__pyx_n_s_k2_in_h_over_Mpc,&__pyx_n_s_k3_in_h_over_Mpc,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5067, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k2_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5067, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_SC", 1, 4, 4, 1); __PYX_ERR(0, 5067, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k3_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5067, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_SC", 1, 4, 4, 2); __PYX_ERR(0, 5067, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5067, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_SC", 1, 4, 4, 3); __PYX_ERR(0, 5067, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_matter_bispectrum_at_z_effective_approach_SC") < 0)) __PYX_ERR(0, 5067, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_k1_in_h_over_Mpc = values[0];
    __pyx_v_k2_in_h_over_Mpc = values[1];
    __pyx_v_k3_in_h_over_Mpc = values[2];
    __pyx_v_z = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_effective_approach_SC", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5067, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_effective_approach_SC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_542get_matter_bispectrum_at_z_effective_approach_SC(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k1_in_h_over_Mpc, __pyx_v_k2_in_h_over_Mpc, __pyx_v_k3_in_h_over_Mpc, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_542get_matter_bispectrum_at_z_effective_approach_SC(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_effective_approach_SC", 1);

  /* "class-sz/python/classy.pyx":5068
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)             # <<<<<<<<<<<<<<
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5068, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k2_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5068, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_k3_in_h_over_Mpc); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5068, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5068, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_matter_bispectrum_at_z_effective_approach_SC(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->tsz), (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->pm))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5067
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_effective_approach_SC", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5069
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_545get_matter_bispectrum_at_z_tree_level_PT(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_545get_matter_bispectrum_at_z_tree_level_PT = {"get_matter_bispectrum_at_z_tree_level_PT", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_545get_matter_bispectrum_at_z_tree_level_PT, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_545get_matter_bispectrum_at_z_tree_level_PT(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k2_in_h_over_Mpc = 0;
  PyObject *__pyx_v_k3_in_h_over_Mpc = 0;
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_tree_level_PT (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k1_in_h_over_Mpc,&__pyx_n_s_k2_in_h_over_Mpc,&__pyx_n_s_k3_in_h_over_Mpc,&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5069, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k2_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5069, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_tree_level_PT", 1, 4, 4, 1); __PYX_ERR(0, 5069, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k3_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5069, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_tree_level_PT", 1, 4, 4, 2); __PYX_ERR(0, 5069, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5069, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_tree_level_PT", 1, 4, 4, 3); __PYX_ERR(0, 5069, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_matter_bispectrum_at_z_tree_level_PT") < 0)) __PYX_ERR(0, 5069, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_k1_in_h_over_Mpc = values[0];
    __pyx_v_k2_in_h_over_Mpc = values[1];
    __pyx_v_k3_in_h_over_Mpc = values[2];
    __pyx_v_z = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_matter_bispectrum_at_z_tree_level_PT", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5069, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_tree_level_PT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_544get_matter_bispectrum_at_z_tree_level_PT(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k1_in_h_over_Mpc, __pyx_v_k2_in_h_over_Mpc, __pyx_v_k3_in_h_over_Mpc, __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_544get_matter_bispectrum_at_z_tree_level_PT(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_k1_in_h_over_Mpc, PyObject *__pyx_v_k2_in_h_over_Mpc, PyObject *__pyx_v_k3_in_h_over_Mpc, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_matter_bispectrum_at_z_tree_level_PT", 1);

  /* "class-sz/python/classy.pyx":5070
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)             # <<<<<<<<<<<<<<
 * 
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5070, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k2_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5070, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_k3_in_h_over_Mpc); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5070, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5070, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_matter_bispectrum_at_z_tree_level_PT(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->tsz), (&__pyx_v_self->ba), (&__pyx_v_self->nl), (&__pyx_v_self->pm))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5069
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_matter_bispectrum_at_z_tree_level_PT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5072
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_547get_nl_index_at_z_and_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_547get_nl_index_at_z_and_k = {"get_nl_index_at_z_and_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_547get_nl_index_at_z_and_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_547get_nl_index_at_z_and_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_nl_index_at_z_and_k (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_k1_in_h_over_Mpc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5072, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5072, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_nl_index_at_z_and_k", 1, 2, 2, 1); __PYX_ERR(0, 5072, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_nl_index_at_z_and_k") < 0)) __PYX_ERR(0, 5072, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_k1_in_h_over_Mpc = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_nl_index_at_z_and_k", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5072, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_nl_index_at_z_and_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_546get_nl_index_at_z_and_k(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_k1_in_h_over_Mpc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_546get_nl_index_at_z_and_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_k1_in_h_over_Mpc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_nl_index_at_z_and_k", 1);

  /* "class-sz/python/classy.pyx":5073
 * 
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)             # <<<<<<<<<<<<<<
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):
 *         return get_nl_index_at_z_and_k_no_wiggles(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5073, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5073, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_nl_index_at_z_and_k(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->nl))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5072
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_nl_index_at_z_and_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5074
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k_no_wiggles(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_549get_nl_index_at_z_and_k_no_wiggles(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_549get_nl_index_at_z_and_k_no_wiggles = {"get_nl_index_at_z_and_k_no_wiggles", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_549get_nl_index_at_z_and_k_no_wiggles, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_549get_nl_index_at_z_and_k_no_wiggles(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_k1_in_h_over_Mpc = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_nl_index_at_z_and_k_no_wiggles (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_k1_in_h_over_Mpc,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5074, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k1_in_h_over_Mpc)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5074, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_nl_index_at_z_and_k_no_wiggles", 1, 2, 2, 1); __PYX_ERR(0, 5074, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_nl_index_at_z_and_k_no_wiggles") < 0)) __PYX_ERR(0, 5074, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = values[0];
    __pyx_v_k1_in_h_over_Mpc = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_nl_index_at_z_and_k_no_wiggles", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5074, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_nl_index_at_z_and_k_no_wiggles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_548get_nl_index_at_z_and_k_no_wiggles(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_k1_in_h_over_Mpc);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_548get_nl_index_at_z_and_k_no_wiggles(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_k1_in_h_over_Mpc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_nl_index_at_z_and_k_no_wiggles", 1);

  /* "class-sz/python/classy.pyx":5075
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):
 *         return get_nl_index_at_z_and_k_no_wiggles(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5075, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_k1_in_h_over_Mpc); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5075, __pyx_L1_error)
  __pyx_t_3 = PyFloat_FromDouble(get_nl_index_at_z_and_k_no_wiggles(__pyx_t_1, __pyx_t_2, (&__pyx_v_self->tsz), (&__pyx_v_self->nl))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5074
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k_no_wiggles(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("classy_sz.Class.get_nl_index_at_z_and_k_no_wiggles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5079
 * 
 * 
 *     def get_vrms2_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_vrms2_at_z(z,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_551get_vrms2_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_551get_vrms2_at_z = {"get_vrms2_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_551get_vrms2_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_551get_vrms2_at_z(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_vrms2_at_z (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5079, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_vrms2_at_z") < 0)) __PYX_ERR(0, 5079, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_z = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_vrms2_at_z", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5079, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_vrms2_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_550get_vrms2_at_z(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_550get_vrms2_at_z(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_vrms2_at_z", 1);

  /* "class-sz/python/classy.pyx":5080
 * 
 *     def get_vrms2_at_z(self,z):
 *         return get_vrms2_at_z(z,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5080, __pyx_L1_error)
  __pyx_t_2 = PyFloat_FromDouble(get_vrms2_at_z(__pyx_t_1, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5079
 * 
 * 
 *     def get_vrms2_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_vrms2_at_z(z,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("classy_sz.Class.get_vrms2_at_z", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5083
 * 
 * 
 *     def get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(self,z,m,x):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_553get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_553get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c = {"get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_553get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_553get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_x = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,&__pyx_n_s_x,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5083, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5083, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", 1, 3, 3, 1); __PYX_ERR(0, 5083, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5083, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", 1, 3, 3, 2); __PYX_ERR(0, 5083, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c") < 0)) __PYX_ERR(0, 5083, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
    __pyx_v_x = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 5083, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_552get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m, __pyx_v_x);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_552get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", 1);

  /* "class-sz/python/classy.pyx":5084
 * 
 *     def get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(self,z,m,x):
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5084, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5084, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5084, __pyx_L1_error)
  __pyx_t_4 = PyFloat_FromDouble(get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(__pyx_t_1, __pyx_t_2, __pyx_t_3, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5083
 * 
 * 
 *     def get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(self,z,m,x):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("classy_sz.Class.get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5086
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 *     def get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_555get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_555get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c = {"get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_555get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_555get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_x = 0;
  PyObject *__pyx_v_d = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,&__pyx_n_s_x,&__pyx_n_s_d,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5086, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5086, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, 1); __PYX_ERR(0, 5086, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5086, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, 2); __PYX_ERR(0, 5086, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_d)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5086, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, 3); __PYX_ERR(0, 5086, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c") < 0)) __PYX_ERR(0, 5086, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
    __pyx_v_x = values[2];
    __pyx_v_d = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5086, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_554get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m, __pyx_v_x, __pyx_v_d);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_554get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_x, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", 1);

  /* "class-sz/python/classy.pyx":5087
 * 
 *     def get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_upp_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5087, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5087, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5087, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_d); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5087, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5087, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5086
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 *     def get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5089
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def get_upp_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_557get_upp_from_gnfw_pressure_at_x_z_and_m500c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_557get_upp_from_gnfw_pressure_at_x_z_and_m500c = {"get_upp_from_gnfw_pressure_at_x_z_and_m500c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_557get_upp_from_gnfw_pressure_at_x_z_and_m500c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_557get_upp_from_gnfw_pressure_at_x_z_and_m500c(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_m = 0;
  PyObject *__pyx_v_x = 0;
  PyObject *__pyx_v_d = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_upp_from_gnfw_pressure_at_x_z_and_m500c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_m,&__pyx_n_s_x,&__pyx_n_s_d,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5089, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5089, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_upp_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, 1); __PYX_ERR(0, 5089, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5089, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_upp_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, 2); __PYX_ERR(0, 5089, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_d)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5089, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_upp_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, 3); __PYX_ERR(0, 5089, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_upp_from_gnfw_pressure_at_x_z_and_m500c") < 0)) __PYX_ERR(0, 5089, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_z = values[0];
    __pyx_v_m = values[1];
    __pyx_v_x = values[2];
    __pyx_v_d = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_upp_from_gnfw_pressure_at_x_z_and_m500c", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 5089, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_upp_from_gnfw_pressure_at_x_z_and_m500c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_556get_upp_from_gnfw_pressure_at_x_z_and_m500c(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_m, __pyx_v_x, __pyx_v_d);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_556get_upp_from_gnfw_pressure_at_x_z_and_m500c(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_m, PyObject *__pyx_v_x, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  double __pyx_t_2;
  double __pyx_t_3;
  double __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_upp_from_gnfw_pressure_at_x_z_and_m500c", 1);

  /* "class-sz/python/classy.pyx":5090
 * 
 *     def get_upp_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def szunbinned_loglike(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_1 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5090, __pyx_L1_error)
  __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_m); if (unlikely((__pyx_t_2 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5090, __pyx_L1_error)
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_3 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5090, __pyx_L1_error)
  __pyx_t_4 = __pyx_PyFloat_AsDouble(__pyx_v_d); if (unlikely((__pyx_t_4 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5090, __pyx_L1_error)
  __pyx_t_5 = PyFloat_FromDouble(get_upp_from_gnfw_pressure_at_x_z_and_m500c(__pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_t_4, (&__pyx_v_self->ba), (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5089
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def get_upp_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("classy_sz.Class.get_upp_from_gnfw_pressure_at_x_z_and_m500c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5092
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def szunbinned_loglike(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_559szunbinned_loglike(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_559szunbinned_loglike = {"szunbinned_loglike", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_559szunbinned_loglike, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_559szunbinned_loglike(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("szunbinned_loglike (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("szunbinned_loglike", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "szunbinned_loglike", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_558szunbinned_loglike(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_558szunbinned_loglike(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("szunbinned_loglike", 1);

  /* "class-sz/python/classy.pyx":5093
 * 
 *     def szunbinned_loglike(self):
 *         return self.tsz.szunbinned_loglike             # <<<<<<<<<<<<<<
 *     def szcounts_ntot(self):
 *         return self.tsz.szcounts_ntot
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->tsz.szunbinned_loglike); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5092
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def szunbinned_loglike(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.szunbinned_loglike", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5094
 *     def szunbinned_loglike(self):
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_561szcounts_ntot(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_561szcounts_ntot = {"szcounts_ntot", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_561szcounts_ntot, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_561szcounts_ntot(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("szcounts_ntot (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("szcounts_ntot", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "szcounts_ntot", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_560szcounts_ntot(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_560szcounts_ntot(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("szcounts_ntot", 1);

  /* "class-sz/python/classy.pyx":5095
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):
 *         return self.tsz.szcounts_ntot             # <<<<<<<<<<<<<<
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):
 *         # # lndndzdq =  []
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->tsz.szcounts_ntot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5094
 *     def szunbinned_loglike(self):
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.szcounts_ntot", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5096
 *     def szcounts_ntot(self):
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):             # <<<<<<<<<<<<<<
 *         # # lndndzdq =  []
 *         # # print(self.tsz.szcat_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_563szcounts_ntot_rates_loglike(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_563szcounts_ntot_rates_loglike = {"szcounts_ntot_rates_loglike", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_563szcounts_ntot_rates_loglike, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_563szcounts_ntot_rates_loglike(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_nq;
  double __pyx_v_qmax;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("szcounts_ntot_rates_loglike (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_nq,&__pyx_n_s_qmax,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nq);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5096, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_qmax);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5096, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "szcounts_ntot_rates_loglike") < 0)) __PYX_ERR(0, 5096, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_nq = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_nq == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5096, __pyx_L3_error)
    } else {
      __pyx_v_nq = ((int)0x1F4);
    }
    if (values[1]) {
      __pyx_v_qmax = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_qmax == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5096, __pyx_L3_error)
    } else {
      __pyx_v_qmax = ((double)-1.0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("szcounts_ntot_rates_loglike", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 5096, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.szcounts_ntot_rates_loglike", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_562szcounts_ntot_rates_loglike(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_nq, __pyx_v_qmax);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_562szcounts_ntot_rates_loglike(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, int __pyx_v_nq, double __pyx_v_qmax) {
  double __pyx_v_zmin;
  double __pyx_v_zmax;
  int __pyx_v_nz;
  double __pyx_v_q_threshold;
  double __pyx_v_q_max;
  PyObject *__pyx_v_q_arr = NULL;
  PyObject *__pyx_v_z_arr = NULL;
  PyObject *__pyx_v_get_dndzdq = NULL;
  PyObject *__pyx_v_Nz = NULL;
  PyObject *__pyx_v_zp = NULL;
  PyObject *__pyx_v_Ntot = NULL;
  PyObject *__pyx_v_rates = NULL;
  int __pyx_v_index;
  PyObject *__pyx_v_loglike = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  double __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  unsigned int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("szcounts_ntot_rates_loglike", 1);

  /* "class-sz/python/classy.pyx":5100
 *         # # print(self.tsz.szcat_size)
 *         # # first we compute ntot
 *         zmin = self.tsz.szcounts_fft_z_min             # <<<<<<<<<<<<<<
 *         zmax = self.tsz.szcounts_fft_z_max
 *         nz = self.tsz.szcounts_fft_nz
 */
  __pyx_t_1 = __pyx_v_self->tsz.szcounts_fft_z_min;
  __pyx_v_zmin = __pyx_t_1;

  /* "class-sz/python/classy.pyx":5101
 *         # # first we compute ntot
 *         zmin = self.tsz.szcounts_fft_z_min
 *         zmax = self.tsz.szcounts_fft_z_max             # <<<<<<<<<<<<<<
 *         nz = self.tsz.szcounts_fft_nz
 *         q_threshold = self.tsz.sn_cutoff
 */
  __pyx_t_1 = __pyx_v_self->tsz.szcounts_fft_z_max;
  __pyx_v_zmax = __pyx_t_1;

  /* "class-sz/python/classy.pyx":5102
 *         zmin = self.tsz.szcounts_fft_z_min
 *         zmax = self.tsz.szcounts_fft_z_max
 *         nz = self.tsz.szcounts_fft_nz             # <<<<<<<<<<<<<<
 *         q_threshold = self.tsz.sn_cutoff
 *         if qmax == -1:
 */
  __pyx_t_2 = __pyx_v_self->tsz.szcounts_fft_nz;
  __pyx_v_nz = __pyx_t_2;

  /* "class-sz/python/classy.pyx":5103
 *         zmax = self.tsz.szcounts_fft_z_max
 *         nz = self.tsz.szcounts_fft_nz
 *         q_threshold = self.tsz.sn_cutoff             # <<<<<<<<<<<<<<
 *         if qmax == -1:
 *            q_max = self.tsz.szcounts_qmax_fft_padded
 */
  __pyx_t_1 = __pyx_v_self->tsz.sn_cutoff;
  __pyx_v_q_threshold = __pyx_t_1;

  /* "class-sz/python/classy.pyx":5104
 *         nz = self.tsz.szcounts_fft_nz
 *         q_threshold = self.tsz.sn_cutoff
 *         if qmax == -1:             # <<<<<<<<<<<<<<
 *            q_max = self.tsz.szcounts_qmax_fft_padded
 *         q_arr = np.geomspace(q_threshold, q_max,nq)
 */
  __pyx_t_3 = (__pyx_v_qmax == -1.0);
  if (__pyx_t_3) {

    /* "class-sz/python/classy.pyx":5105
 *         q_threshold = self.tsz.sn_cutoff
 *         if qmax == -1:
 *            q_max = self.tsz.szcounts_qmax_fft_padded             # <<<<<<<<<<<<<<
 *         q_arr = np.geomspace(q_threshold, q_max,nq)
 *         z_arr = np.linspace(zmin,zmax,nz)
 */
    __pyx_t_1 = __pyx_v_self->tsz.szcounts_qmax_fft_padded;
    __pyx_v_q_max = __pyx_t_1;

    /* "class-sz/python/classy.pyx":5104
 *         nz = self.tsz.szcounts_fft_nz
 *         q_threshold = self.tsz.sn_cutoff
 *         if qmax == -1:             # <<<<<<<<<<<<<<
 *            q_max = self.tsz.szcounts_qmax_fft_padded
 *         q_arr = np.geomspace(q_threshold, q_max,nq)
 */
  }

  /* "class-sz/python/classy.pyx":5106
 *         if qmax == -1:
 *            q_max = self.tsz.szcounts_qmax_fft_padded
 *         q_arr = np.geomspace(q_threshold, q_max,nq)             # <<<<<<<<<<<<<<
 *         z_arr = np.linspace(zmin,zmax,nz)
 *         get_dndzdq = np.vectorize(self.get_szcounts_dndzdq_at_z_q)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_geomspace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_q_threshold); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyFloat_FromDouble(__pyx_v_q_max); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_nq); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_9, __pyx_t_5, __pyx_t_7, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_10, 3+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_v_q_arr = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":5107
 *            q_max = self.tsz.szcounts_qmax_fft_padded
 *         q_arr = np.geomspace(q_threshold, q_max,nq)
 *         z_arr = np.linspace(zmin,zmax,nz)             # <<<<<<<<<<<<<<
 *         get_dndzdq = np.vectorize(self.get_szcounts_dndzdq_at_z_q)
 *         Nz = []
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_linspace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_zmin); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyFloat_FromDouble(__pyx_v_zmax); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_nz); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_9 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_9, __pyx_t_6, __pyx_t_7, __pyx_t_5};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 3+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_v_z_arr = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":5108
 *         q_arr = np.geomspace(q_threshold, q_max,nq)
 *         z_arr = np.linspace(zmin,zmax,nz)
 *         get_dndzdq = np.vectorize(self.get_szcounts_dndzdq_at_z_q)             # <<<<<<<<<<<<<<
 *         Nz = []
 *         for zp in z_arr:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_vectorize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_szcounts_dndzdq_at_z_q); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5108, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_get_dndzdq = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":5109
 *         z_arr = np.linspace(zmin,zmax,nz)
 *         get_dndzdq = np.vectorize(self.get_szcounts_dndzdq_at_z_q)
 *         Nz = []             # <<<<<<<<<<<<<<
 *         for zp in z_arr:
 *            Nz.append(np.trapz(get_dndzdq(zp,q_arr)*q_arr,x=np.log(q_arr)))
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_Nz = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":5110
 *         get_dndzdq = np.vectorize(self.get_szcounts_dndzdq_at_z_q)
 *         Nz = []
 *         for zp in z_arr:             # <<<<<<<<<<<<<<
 *            Nz.append(np.trapz(get_dndzdq(zp,q_arr)*q_arr,x=np.log(q_arr)))
 *         Nz = np.asarray(Nz)
 */
  if (likely(PyList_CheckExact(__pyx_v_z_arr)) || PyTuple_CheckExact(__pyx_v_z_arr)) {
    __pyx_t_4 = __pyx_v_z_arr; __Pyx_INCREF(__pyx_t_4);
    __pyx_t_11 = 0;
    __pyx_t_12 = NULL;
  } else {
    __pyx_t_11 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_z_arr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5110, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_12)) {
      if (likely(PyList_CheckExact(__pyx_t_4))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5110, __pyx_L1_error)
          #endif
          if (__pyx_t_11 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_11); __Pyx_INCREF(__pyx_t_5); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 5110, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5110, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5110, __pyx_L1_error)
          #endif
          if (__pyx_t_11 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_11); __Pyx_INCREF(__pyx_t_5); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 5110, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5110, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_12(__pyx_t_4);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5110, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_zp, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":5111
 *         Nz = []
 *         for zp in z_arr:
 *            Nz.append(np.trapz(get_dndzdq(zp,q_arr)*q_arr,x=np.log(q_arr)))             # <<<<<<<<<<<<<<
 *         Nz = np.asarray(Nz)
 *         Ntot = np.trapz(Nz,x=z_arr)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_trapz); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_v_get_dndzdq);
    __pyx_t_7 = __pyx_v_get_dndzdq; __pyx_t_6 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_zp, __pyx_v_q_arr};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_7 = PyNumber_Multiply(__pyx_t_5, __pyx_v_q_arr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_7);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(0, 5111, __pyx_L1_error);
    __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_log); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_13, function);
        __pyx_t_10 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_q_arr};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    }
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_x, __pyx_t_6) < 0) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_Nz, __pyx_t_6); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 5111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":5110
 *         get_dndzdq = np.vectorize(self.get_szcounts_dndzdq_at_z_q)
 *         Nz = []
 *         for zp in z_arr:             # <<<<<<<<<<<<<<
 *            Nz.append(np.trapz(get_dndzdq(zp,q_arr)*q_arr,x=np.log(q_arr)))
 *         Nz = np.asarray(Nz)
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":5112
 *         for zp in z_arr:
 *            Nz.append(np.trapz(get_dndzdq(zp,q_arr)*q_arr,x=np.log(q_arr)))
 *         Nz = np.asarray(Nz)             # <<<<<<<<<<<<<<
 *         Ntot = np.trapz(Nz,x=z_arr)
 *         # # compute rates
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_asarray); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_Nz};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_Nz, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":5113
 *            Nz.append(np.trapz(get_dndzdq(zp,q_arr)*q_arr,x=np.log(q_arr)))
 *         Nz = np.asarray(Nz)
 *         Ntot = np.trapz(Nz,x=z_arr)             # <<<<<<<<<<<<<<
 *         # # compute rates
 *         rates = []
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_trapz); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_Nz);
  __Pyx_GIVEREF(__pyx_v_Nz);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_Nz)) __PYX_ERR(0, 5113, __pyx_L1_error);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_x, __pyx_v_z_arr) < 0) __PYX_ERR(0, 5113, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_Ntot = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5115
 *         Ntot = np.trapz(Nz,x=z_arr)
 *         # # compute rates
 *         rates = []             # <<<<<<<<<<<<<<
 *         for index in range(self.tsz.szcat_size):
 *             if self.tsz.szcat_snr[index]>= q_threshold:
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_rates = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5116
 *         # # compute rates
 *         rates = []
 *         for index in range(self.tsz.szcat_size):             # <<<<<<<<<<<<<<
 *             if self.tsz.szcat_snr[index]>= q_threshold:
 *               rates.append(self.tsz.szrate[index])
 */
  __pyx_t_2 = __pyx_v_self->tsz.szcat_size;
  __pyx_t_15 = __pyx_t_2;
  for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
    __pyx_v_index = __pyx_t_16;

    /* "class-sz/python/classy.pyx":5117
 *         rates = []
 *         for index in range(self.tsz.szcat_size):
 *             if self.tsz.szcat_snr[index]>= q_threshold:             # <<<<<<<<<<<<<<
 *               rates.append(self.tsz.szrate[index])
 *         rates = np.asarray(rates)
 */
    __pyx_t_3 = ((__pyx_v_self->tsz.szcat_snr[__pyx_v_index]) >= __pyx_v_q_threshold);
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5118
 *         for index in range(self.tsz.szcat_size):
 *             if self.tsz.szcat_snr[index]>= q_threshold:
 *               rates.append(self.tsz.szrate[index])             # <<<<<<<<<<<<<<
 *         rates = np.asarray(rates)
 *         # # compute loglike
 */
      __pyx_t_5 = PyFloat_FromDouble((__pyx_v_self->tsz.szrate[__pyx_v_index])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5118, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = __Pyx_PyObject_Append(__pyx_v_rates, __pyx_t_5); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(0, 5118, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "class-sz/python/classy.pyx":5117
 *         rates = []
 *         for index in range(self.tsz.szcat_size):
 *             if self.tsz.szcat_snr[index]>= q_threshold:             # <<<<<<<<<<<<<<
 *               rates.append(self.tsz.szrate[index])
 *         rates = np.asarray(rates)
 */
    }
  }

  /* "class-sz/python/classy.pyx":5119
 *             if self.tsz.szcat_snr[index]>= q_threshold:
 *               rates.append(self.tsz.szrate[index])
 *         rates = np.asarray(rates)             # <<<<<<<<<<<<<<
 *         # # compute loglike
 *         loglike = - Ntot + np.sum(np.log(rates))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_rates};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_rates, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5121
 *         rates = np.asarray(rates)
 *         # # compute loglike
 *         loglike = - Ntot + np.sum(np.log(rates))             # <<<<<<<<<<<<<<
 *         return {'ntot':Ntot,'rates':rates,'loglike':loglike}
 *         # return Nz
 */
  __pyx_t_5 = PyNumber_Negative(__pyx_v_Ntot); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sum); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_log); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_rates};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __pyx_t_13 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = PyNumber_Add(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_loglike = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":5122
 *         # # compute loglike
 *         loglike = - Ntot + np.sum(np.log(rates))
 *         return {'ntot':Ntot,'rates':rates,'loglike':loglike}             # <<<<<<<<<<<<<<
 *         # return Nz
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_ntot, __pyx_v_Ntot) < 0) __PYX_ERR(0, 5122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_rates, __pyx_v_rates) < 0) __PYX_ERR(0, 5122, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_loglike, __pyx_v_loglike) < 0) __PYX_ERR(0, 5122, __pyx_L1_error)
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5096
 *     def szcounts_ntot(self):
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):             # <<<<<<<<<<<<<<
 *         # # lndndzdq =  []
 *         # # print(self.tsz.szcat_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("classy_sz.Class.szcounts_ntot_rates_loglike", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_q_arr);
  __Pyx_XDECREF(__pyx_v_z_arr);
  __Pyx_XDECREF(__pyx_v_get_dndzdq);
  __Pyx_XDECREF(__pyx_v_Nz);
  __Pyx_XDECREF(__pyx_v_zp);
  __Pyx_XDECREF(__pyx_v_Ntot);
  __Pyx_XDECREF(__pyx_v_rates);
  __Pyx_XDECREF(__pyx_v_loglike);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5125
 *         # return Nz
 * 
 *     def dndzdy_theoretical(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the dndzdy theoretical
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_565dndzdy_theoretical(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_564dndzdy_theoretical, "\n        (SZ) Return the dndzdy theoretical\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_565dndzdy_theoretical = {"dndzdy_theoretical", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_565dndzdy_theoretical, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_564dndzdy_theoretical};
static PyObject *__pyx_pw_9classy_sz_5Class_565dndzdy_theoretical(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dndzdy_theoretical (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("dndzdy_theoretical", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dndzdy_theoretical", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_564dndzdy_theoretical(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_564dndzdy_theoretical(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_v_dndzdy = NULL;
  PyObject *__pyx_v_z_center = NULL;
  PyObject *__pyx_v_z_edges = NULL;
  PyObject *__pyx_v_log10y_center = NULL;
  PyObject *__pyx_v_log10y_edges = NULL;
  int __pyx_v_index_y;
  int __pyx_v_index_z;
  PyObject *__pyx_v_dndzdy_index_z = NULL;
  PyObject *__pyx_v_szcat_z = NULL;
  PyObject *__pyx_v_szcat_snr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dndzdy_theoretical", 1);

  /* "class-sz/python/classy.pyx":5130
 *         """
 * 
 *         dndzdy =  []             # <<<<<<<<<<<<<<
 *         z_center =  []
 *         z_edges =  []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_dndzdy = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5131
 * 
 *         dndzdy =  []
 *         z_center =  []             # <<<<<<<<<<<<<<
 *         z_edges =  []
 *         log10y_center =  []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_z_center = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5132
 *         dndzdy =  []
 *         z_center =  []
 *         z_edges =  []             # <<<<<<<<<<<<<<
 *         log10y_center =  []
 *         log10y_edges =  []
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_z_edges = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5133
 *         z_center =  []
 *         z_edges =  []
 *         log10y_center =  []             # <<<<<<<<<<<<<<
 *         log10y_edges =  []
 *         cdef int index_y,index_z
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_log10y_center = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5134
 *         z_edges =  []
 *         log10y_center =  []
 *         log10y_edges =  []             # <<<<<<<<<<<<<<
 *         cdef int index_y,index_z
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_log10y_edges = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5137
 *         cdef int index_y,index_z
 * 
 *         for index_z in range(self.csz.Nbins_z):             # <<<<<<<<<<<<<<
 *             z_center.append(self.csz.z_center[index_z])
 *             z_edges.append(self.csz.z_center[index_z]-0.5*self.csz.dz)
 */
  __pyx_t_2 = __pyx_v_self->csz.Nbins_z;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index_z = __pyx_t_4;

    /* "class-sz/python/classy.pyx":5138
 * 
 *         for index_z in range(self.csz.Nbins_z):
 *             z_center.append(self.csz.z_center[index_z])             # <<<<<<<<<<<<<<
 *             z_edges.append(self.csz.z_center[index_z]-0.5*self.csz.dz)
 *             dndzdy_index_z = []
 */
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->csz.z_center[__pyx_v_index_z])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_z_center, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5138, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5139
 *         for index_z in range(self.csz.Nbins_z):
 *             z_center.append(self.csz.z_center[index_z])
 *             z_edges.append(self.csz.z_center[index_z]-0.5*self.csz.dz)             # <<<<<<<<<<<<<<
 *             dndzdy_index_z = []
 *             for index_y in range(self.csz.Nbins_y):
 */
    __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->csz.z_center[__pyx_v_index_z]) - (0.5 * __pyx_v_self->csz.dz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_z_edges, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5139, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5140
 *             z_center.append(self.csz.z_center[index_z])
 *             z_edges.append(self.csz.z_center[index_z]-0.5*self.csz.dz)
 *             dndzdy_index_z = []             # <<<<<<<<<<<<<<
 *             for index_y in range(self.csz.Nbins_y):
 *                 dndzdy_index_z.append(self.csz.dNdzdy_theoretical[index_z][index_y])
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_dndzdy_index_z, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5141
 *             z_edges.append(self.csz.z_center[index_z]-0.5*self.csz.dz)
 *             dndzdy_index_z = []
 *             for index_y in range(self.csz.Nbins_y):             # <<<<<<<<<<<<<<
 *                 dndzdy_index_z.append(self.csz.dNdzdy_theoretical[index_z][index_y])
 *             dndzdy.append(dndzdy_index_z)
 */
    __pyx_t_6 = __pyx_v_self->csz.Nbins_y;
    __pyx_t_7 = __pyx_t_6;
    for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
      __pyx_v_index_y = __pyx_t_8;

      /* "class-sz/python/classy.pyx":5142
 *             dndzdy_index_z = []
 *             for index_y in range(self.csz.Nbins_y):
 *                 dndzdy_index_z.append(self.csz.dNdzdy_theoretical[index_z][index_y])             # <<<<<<<<<<<<<<
 *             dndzdy.append(dndzdy_index_z)
 * 
 */
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->csz.dNdzdy_theoretical[__pyx_v_index_z])[__pyx_v_index_y])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5142, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_dndzdy_index_z, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5142, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "class-sz/python/classy.pyx":5143
 *             for index_y in range(self.csz.Nbins_y):
 *                 dndzdy_index_z.append(self.csz.dNdzdy_theoretical[index_z][index_y])
 *             dndzdy.append(dndzdy_index_z)             # <<<<<<<<<<<<<<
 * 
 *         z_edges.append(self.csz.z_center[self.csz.Nbins_z-1]+0.5*self.csz.dz)
 */
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_dndzdy, __pyx_v_dndzdy_index_z); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5143, __pyx_L1_error)
  }

  /* "class-sz/python/classy.pyx":5145
 *             dndzdy.append(dndzdy_index_z)
 * 
 *         z_edges.append(self.csz.z_center[self.csz.Nbins_z-1]+0.5*self.csz.dz)             # <<<<<<<<<<<<<<
 * 
 *         for index_y in range(self.csz.Nbins_y):
 */
  __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->csz.z_center[(__pyx_v_self->csz.Nbins_z - 1)]) + (0.5 * __pyx_v_self->csz.dz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_z_edges, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5147
 *         z_edges.append(self.csz.z_center[self.csz.Nbins_z-1]+0.5*self.csz.dz)
 * 
 *         for index_y in range(self.csz.Nbins_y):             # <<<<<<<<<<<<<<
 *             log10y_center.append(self.csz.logy[index_y])
 *             log10y_edges.append(self.csz.logy[index_y]-0.5*self.csz.dlogy)
 */
  __pyx_t_2 = __pyx_v_self->csz.Nbins_y;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index_y = __pyx_t_4;

    /* "class-sz/python/classy.pyx":5148
 * 
 *         for index_y in range(self.csz.Nbins_y):
 *             log10y_center.append(self.csz.logy[index_y])             # <<<<<<<<<<<<<<
 *             log10y_edges.append(self.csz.logy[index_y]-0.5*self.csz.dlogy)
 *         log10y_edges.append(self.csz.logy[self.csz.Nbins_y-1]+0.5*self.csz.dlogy)
 */
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->csz.logy[__pyx_v_index_y])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_log10y_center, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5148, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5149
 *         for index_y in range(self.csz.Nbins_y):
 *             log10y_center.append(self.csz.logy[index_y])
 *             log10y_edges.append(self.csz.logy[index_y]-0.5*self.csz.dlogy)             # <<<<<<<<<<<<<<
 *         log10y_edges.append(self.csz.logy[self.csz.Nbins_y-1]+0.5*self.csz.dlogy)
 * 
 */
    __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->csz.logy[__pyx_v_index_y]) - (0.5 * __pyx_v_self->csz.dlogy))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_log10y_edges, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5149, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":5150
 *             log10y_center.append(self.csz.logy[index_y])
 *             log10y_edges.append(self.csz.logy[index_y]-0.5*self.csz.dlogy)
 *         log10y_edges.append(self.csz.logy[self.csz.Nbins_y-1]+0.5*self.csz.dlogy)             # <<<<<<<<<<<<<<
 * 
 *         szcat_z = []
 */
  __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->csz.logy[(__pyx_v_self->csz.Nbins_y - 1)]) + (0.5 * __pyx_v_self->csz.dlogy))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_log10y_edges, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5152
 *         log10y_edges.append(self.csz.logy[self.csz.Nbins_y-1]+0.5*self.csz.dlogy)
 * 
 *         szcat_z = []             # <<<<<<<<<<<<<<
 *         szcat_snr = []
 *         for index_z in range(self.tsz.szcat_size):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_szcat_z = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5153
 * 
 *         szcat_z = []
 *         szcat_snr = []             # <<<<<<<<<<<<<<
 *         for index_z in range(self.tsz.szcat_size):
 *             szcat_z.append(self.tsz.szcat_z[index_z])
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_szcat_snr = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5154
 *         szcat_z = []
 *         szcat_snr = []
 *         for index_z in range(self.tsz.szcat_size):             # <<<<<<<<<<<<<<
 *             szcat_z.append(self.tsz.szcat_z[index_z])
 *             szcat_snr.append(self.tsz.szcat_snr[index_z])
 */
  __pyx_t_2 = __pyx_v_self->tsz.szcat_size;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_index_z = __pyx_t_4;

    /* "class-sz/python/classy.pyx":5155
 *         szcat_snr = []
 *         for index_z in range(self.tsz.szcat_size):
 *             szcat_z.append(self.tsz.szcat_z[index_z])             # <<<<<<<<<<<<<<
 *             szcat_snr.append(self.tsz.szcat_snr[index_z])
 * 
 */
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.szcat_z[__pyx_v_index_z])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_szcat_z, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5155, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5156
 *         for index_z in range(self.tsz.szcat_size):
 *             szcat_z.append(self.tsz.szcat_z[index_z])
 *             szcat_snr.append(self.tsz.szcat_snr[index_z])             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->tsz.szcat_snr[__pyx_v_index_z])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_szcat_snr, __pyx_t_1); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 5156, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "class-sz/python/classy.pyx":5159
 * 
 * 
 *         return {'dndzdy':dndzdy,             # <<<<<<<<<<<<<<
 *                 'z_center':z_center,
 *                 'z_edges':z_edges,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_dndzdy, __pyx_v_dndzdy) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5160
 * 
 *         return {'dndzdy':dndzdy,
 *                 'z_center':z_center,             # <<<<<<<<<<<<<<
 *                 'z_edges':z_edges,
 *                 'log10y_center':log10y_center,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_z_center, __pyx_v_z_center) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5161
 *         return {'dndzdy':dndzdy,
 *                 'z_center':z_center,
 *                 'z_edges':z_edges,             # <<<<<<<<<<<<<<
 *                 'log10y_center':log10y_center,
 *                 'log10y_edges':log10y_edges,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_z_edges, __pyx_v_z_edges) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5162
 *                 'z_center':z_center,
 *                 'z_edges':z_edges,
 *                 'log10y_center':log10y_center,             # <<<<<<<<<<<<<<
 *                 'log10y_edges':log10y_edges,
 *                 'szcat_z':szcat_z,
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_log10y_center, __pyx_v_log10y_center) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5163
 *                 'z_edges':z_edges,
 *                 'log10y_center':log10y_center,
 *                 'log10y_edges':log10y_edges,             # <<<<<<<<<<<<<<
 *                 'szcat_z':szcat_z,
 *                 'szcat_snr':szcat_snr}
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_log10y_edges, __pyx_v_log10y_edges) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5164
 *                 'log10y_center':log10y_center,
 *                 'log10y_edges':log10y_edges,
 *                 'szcat_z':szcat_z,             # <<<<<<<<<<<<<<
 *                 'szcat_snr':szcat_snr}
 * 
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_szcat_z, __pyx_v_szcat_z) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5165
 *                 'log10y_edges':log10y_edges,
 *                 'szcat_z':szcat_z,
 *                 'szcat_snr':szcat_snr}             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_szcat_snr, __pyx_v_szcat_snr) < 0) __PYX_ERR(0, 5159, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5125
 *         # return Nz
 * 
 *     def dndzdy_theoretical(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the dndzdy theoretical
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.dndzdy_theoretical", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dndzdy);
  __Pyx_XDECREF(__pyx_v_z_center);
  __Pyx_XDECREF(__pyx_v_z_edges);
  __Pyx_XDECREF(__pyx_v_log10y_center);
  __Pyx_XDECREF(__pyx_v_log10y_edges);
  __Pyx_XDECREF(__pyx_v_dndzdy_index_z);
  __Pyx_XDECREF(__pyx_v_szcat_z);
  __Pyx_XDECREF(__pyx_v_szcat_snr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5168
 * 
 * 
 *     def get_background(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return an array of the background quantities at all times.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_567get_background(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_566get_background, "\n        Return an array of the background quantities at all times.\n\n        Parameters\n        ----------\n\n        Returns\n        -------\n        background : dictionary containing background.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_567get_background = {"get_background", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_567get_background, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_566get_background};
static PyObject *__pyx_pw_9classy_sz_5Class_567get_background(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_background (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_background", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_background", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_566get_background(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_566get_background(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  char *__pyx_v_titles;
  double *__pyx_v_data;
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_v_number_of_titles = NULL;
  PyObject *__pyx_v_timesteps = NULL;
  PyObject *__pyx_v_background = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  size_t __pyx_t_8;
  int __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  Py_ssize_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_background", 1);

  /* "class-sz/python/classy.pyx":5181
 *         cdef char *titles
 *         cdef double* data
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))             # <<<<<<<<<<<<<<
 * 
 *         if background_output_titles(&self.ba, titles)==_FAILURE_:
 */
  __pyx_v_titles = ((char *)calloc(0x1F40, (sizeof(char))));

  /* "class-sz/python/classy.pyx":5183
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if background_output_titles(&self.ba, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_1 = (background_output_titles((&__pyx_v_self->ba), __pyx_v_titles) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5184
 * 
 *         if background_output_titles(&self.ba, titles)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         tmp = <bytes> titles
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 5184, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5183
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if background_output_titles(&self.ba, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5186
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         tmp = <bytes> titles             # <<<<<<<<<<<<<<
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 */
  __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_titles); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tmp = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5187
 * 
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())             # <<<<<<<<<<<<<<
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_decode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_tmp, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5188
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]             # <<<<<<<<<<<<<<
 *         number_of_titles = len(names)
 *         timesteps = self.ba.bt_size
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u__46};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_names = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5189
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)             # <<<<<<<<<<<<<<
 *         timesteps = self.ba.bt_size
 * 
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_names); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5189, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_number_of_titles = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5190
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 *         timesteps = self.ba.bt_size             # <<<<<<<<<<<<<<
 * 
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->ba.bt_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_timesteps = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5192
 *         timesteps = self.ba.bt_size
 * 
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)             # <<<<<<<<<<<<<<
 * 
 *         if background_output_data(&self.ba, number_of_titles, data)==_FAILURE_:
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t((sizeof(double))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_3, __pyx_v_timesteps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyInt_As_size_t(__pyx_t_3); if (unlikely((__pyx_t_8 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_data = ((double *)malloc(__pyx_t_8));

  /* "class-sz/python/classy.pyx":5194
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 * 
 *         if background_output_data(&self.ba, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_number_of_titles); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5194, __pyx_L1_error)
  __pyx_t_1 = (background_output_data((&__pyx_v_self->ba), __pyx_t_9, __pyx_v_data) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5195
 * 
 *         if background_output_data(&self.ba, number_of_titles, data)==_FAILURE_:
 *             raise CosmoSevereError(self.ba.error_message)             # <<<<<<<<<<<<<<
 * 
 *         background = {}
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->ba.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5195, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 5195, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5194
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 * 
 *         if background_output_data(&self.ba, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5197
 *             raise CosmoSevereError(self.ba.error_message)
 * 
 *         background = {}             # <<<<<<<<<<<<<<
 * 
 *         for i in range(number_of_titles):
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_background = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5199
 *         background = {}
 * 
 *         for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *             background[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = 0;
    __pyx_t_10 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5199, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_10)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5199, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 5199, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5199, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5199, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 5199, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5199, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_10(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5199, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":5200
 * 
 *         for i in range(number_of_titles):
 *             background[names[i]] = np.zeros(timesteps, dtype=np.double)             # <<<<<<<<<<<<<<
 *             for index in range(timesteps):
 *                 background[names[i]][index] = data[index*number_of_titles+i]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timesteps);
    __Pyx_GIVEREF(__pyx_v_timesteps);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timesteps)) __PYX_ERR(0, 5200, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_double); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely((PyDict_SetItem(__pyx_v_background, __pyx_t_5, __pyx_t_12) < 0))) __PYX_ERR(0, 5200, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "class-sz/python/classy.pyx":5201
 *         for i in range(number_of_titles):
 *             background[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                 background[names[i]][index] = data[index*number_of_titles+i]
 * 
 */
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_timesteps); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5201, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
      __pyx_t_5 = __pyx_t_12; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_13 = 0;
      __pyx_t_14 = NULL;
    } else {
      __pyx_t_13 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5201, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    for (;;) {
      if (likely(!__pyx_t_14)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5201, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_12 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 5201, __pyx_L1_error)
          #else
          __pyx_t_12 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5201, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5201, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 5201, __pyx_L1_error)
          #else
          __pyx_t_12 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5201, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          #endif
        }
      } else {
        __pyx_t_12 = __pyx_t_14(__pyx_t_5);
        if (unlikely(!__pyx_t_12)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5201, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_12);
      }
      __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "class-sz/python/classy.pyx":5202
 *             background[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 *                 background[names[i]][index] = data[index*number_of_titles+i]             # <<<<<<<<<<<<<<
 * 
 *         free(titles)
 */
      __pyx_t_12 = PyNumber_Multiply(__pyx_v_index, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_3 = PyNumber_Add(__pyx_t_12, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_15 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_15 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5202, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyFloat_FromDouble((__pyx_v_data[__pyx_t_15])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_background, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely((PyObject_SetItem(__pyx_t_4, __pyx_v_index, __pyx_t_3) < 0))) __PYX_ERR(0, 5202, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":5201
 *         for i in range(number_of_titles):
 *             background[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                 background[names[i]][index] = data[index*number_of_titles+i]
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":5199
 *         background = {}
 * 
 *         for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *             background[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5204
 *                 background[names[i]][index] = data[index*number_of_titles+i]
 * 
 *         free(titles)             # <<<<<<<<<<<<<<
 *         free(data)
 *         return background
 */
  free(__pyx_v_titles);

  /* "class-sz/python/classy.pyx":5205
 * 
 *         free(titles)
 *         free(data)             # <<<<<<<<<<<<<<
 *         return background
 * 
 */
  free(__pyx_v_data);

  /* "class-sz/python/classy.pyx":5206
 *         free(titles)
 *         free(data)
 *         return background             # <<<<<<<<<<<<<<
 * 
 *     def get_thermodynamics(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_background);
  __pyx_r = __pyx_v_background;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5168
 * 
 * 
 *     def get_background(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return an array of the background quantities at all times.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("classy_sz.Class.get_background", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XDECREF(__pyx_v_number_of_titles);
  __Pyx_XDECREF(__pyx_v_timesteps);
  __Pyx_XDECREF(__pyx_v_background);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5208
 *         return background
 * 
 *     def get_thermodynamics(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the thermodynamics quantities.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_569get_thermodynamics(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_568get_thermodynamics, "\n        Return the thermodynamics quantities.\n\n        Returns\n        -------\n        thermodynamics : dictionary containing thermodynamics.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_569get_thermodynamics = {"get_thermodynamics", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_569get_thermodynamics, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_568get_thermodynamics};
static PyObject *__pyx_pw_9classy_sz_5Class_569get_thermodynamics(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_thermodynamics (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_thermodynamics", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_thermodynamics", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_568get_thermodynamics(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_568get_thermodynamics(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  char *__pyx_v_titles;
  double *__pyx_v_data;
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_v_number_of_titles = NULL;
  PyObject *__pyx_v_timesteps = NULL;
  PyObject *__pyx_v_thermodynamics = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  size_t __pyx_t_8;
  int __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  Py_ssize_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_thermodynamics", 1);

  /* "class-sz/python/classy.pyx":5219
 *         cdef double* data
 * 
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))             # <<<<<<<<<<<<<<
 * 
 *         if thermodynamics_output_titles(&self.ba, &self.th, titles)==_FAILURE_:
 */
  __pyx_v_titles = ((char *)calloc(0x1F40, (sizeof(char))));

  /* "class-sz/python/classy.pyx":5221
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if thermodynamics_output_titles(&self.ba, &self.th, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  __pyx_t_1 = (thermodynamics_output_titles((&__pyx_v_self->ba), (&__pyx_v_self->th), __pyx_v_titles) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5222
 * 
 *         if thermodynamics_output_titles(&self.ba, &self.th, titles)==_FAILURE_:
 *             raise CosmoSevereError(self.th.error_message)             # <<<<<<<<<<<<<<
 * 
 *         tmp = <bytes> titles
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->th.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 5222, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5221
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if thermodynamics_output_titles(&self.ba, &self.th, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5224
 *             raise CosmoSevereError(self.th.error_message)
 * 
 *         tmp = <bytes> titles             # <<<<<<<<<<<<<<
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 */
  __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_titles); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tmp = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5225
 * 
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())             # <<<<<<<<<<<<<<
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_decode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_tmp, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5226
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]             # <<<<<<<<<<<<<<
 *         number_of_titles = len(names)
 *         timesteps = self.th.tt_size
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u__46};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_names = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5227
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)             # <<<<<<<<<<<<<<
 *         timesteps = self.th.tt_size
 * 
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_names); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5227, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_number_of_titles = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5228
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 *         timesteps = self.th.tt_size             # <<<<<<<<<<<<<<
 * 
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->th.tt_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_timesteps = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5230
 *         timesteps = self.th.tt_size
 * 
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)             # <<<<<<<<<<<<<<
 * 
 *         if thermodynamics_output_data(&self.ba, &self.th, number_of_titles, data)==_FAILURE_:
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t((sizeof(double))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_3, __pyx_v_timesteps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyInt_As_size_t(__pyx_t_3); if (unlikely((__pyx_t_8 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_data = ((double *)malloc(__pyx_t_8));

  /* "class-sz/python/classy.pyx":5232
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 * 
 *         if thermodynamics_output_data(&self.ba, &self.th, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_number_of_titles); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5232, __pyx_L1_error)
  __pyx_t_1 = (thermodynamics_output_data((&__pyx_v_self->ba), (&__pyx_v_self->th), __pyx_t_9, __pyx_v_data) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5233
 * 
 *         if thermodynamics_output_data(&self.ba, &self.th, number_of_titles, data)==_FAILURE_:
 *             raise CosmoSevereError(self.th.error_message)             # <<<<<<<<<<<<<<
 * 
 *         thermodynamics = {}
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->th.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 5233, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5232
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 * 
 *         if thermodynamics_output_data(&self.ba, &self.th, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.th.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5235
 *             raise CosmoSevereError(self.th.error_message)
 * 
 *         thermodynamics = {}             # <<<<<<<<<<<<<<
 * 
 *         for i in range(number_of_titles):
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_thermodynamics = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5237
 *         thermodynamics = {}
 * 
 *         for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *             thermodynamics[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = 0;
    __pyx_t_10 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5237, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_10)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5237, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 5237, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5237, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 5237, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5237, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_10(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5237, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":5238
 * 
 *         for i in range(number_of_titles):
 *             thermodynamics[names[i]] = np.zeros(timesteps, dtype=np.double)             # <<<<<<<<<<<<<<
 *             for index in range(timesteps):
 *                 thermodynamics[names[i]][index] = data[index*number_of_titles+i]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timesteps);
    __Pyx_GIVEREF(__pyx_v_timesteps);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timesteps)) __PYX_ERR(0, 5238, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_double); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely((PyDict_SetItem(__pyx_v_thermodynamics, __pyx_t_5, __pyx_t_12) < 0))) __PYX_ERR(0, 5238, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "class-sz/python/classy.pyx":5239
 *         for i in range(number_of_titles):
 *             thermodynamics[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                 thermodynamics[names[i]][index] = data[index*number_of_titles+i]
 * 
 */
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_timesteps); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
      __pyx_t_5 = __pyx_t_12; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_13 = 0;
      __pyx_t_14 = NULL;
    } else {
      __pyx_t_13 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5239, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    for (;;) {
      if (likely(!__pyx_t_14)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5239, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_12 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 5239, __pyx_L1_error)
          #else
          __pyx_t_12 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5239, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5239, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 5239, __pyx_L1_error)
          #else
          __pyx_t_12 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5239, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          #endif
        }
      } else {
        __pyx_t_12 = __pyx_t_14(__pyx_t_5);
        if (unlikely(!__pyx_t_12)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5239, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_12);
      }
      __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "class-sz/python/classy.pyx":5240
 *             thermodynamics[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 *                 thermodynamics[names[i]][index] = data[index*number_of_titles+i]             # <<<<<<<<<<<<<<
 * 
 *         free(titles)
 */
      __pyx_t_12 = PyNumber_Multiply(__pyx_v_index, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_3 = PyNumber_Add(__pyx_t_12, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_15 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_15 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5240, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyFloat_FromDouble((__pyx_v_data[__pyx_t_15])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_thermodynamics, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely((PyObject_SetItem(__pyx_t_4, __pyx_v_index, __pyx_t_3) < 0))) __PYX_ERR(0, 5240, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":5239
 *         for i in range(number_of_titles):
 *             thermodynamics[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                 thermodynamics[names[i]][index] = data[index*number_of_titles+i]
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":5237
 *         thermodynamics = {}
 * 
 *         for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *             thermodynamics[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5242
 *                 thermodynamics[names[i]][index] = data[index*number_of_titles+i]
 * 
 *         free(titles)             # <<<<<<<<<<<<<<
 *         free(data)
 *         return thermodynamics
 */
  free(__pyx_v_titles);

  /* "class-sz/python/classy.pyx":5243
 * 
 *         free(titles)
 *         free(data)             # <<<<<<<<<<<<<<
 *         return thermodynamics
 * 
 */
  free(__pyx_v_data);

  /* "class-sz/python/classy.pyx":5244
 *         free(titles)
 *         free(data)
 *         return thermodynamics             # <<<<<<<<<<<<<<
 * 
 *     def get_primordial(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_thermodynamics);
  __pyx_r = __pyx_v_thermodynamics;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5208
 *         return background
 * 
 *     def get_thermodynamics(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the thermodynamics quantities.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("classy_sz.Class.get_thermodynamics", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XDECREF(__pyx_v_number_of_titles);
  __Pyx_XDECREF(__pyx_v_timesteps);
  __Pyx_XDECREF(__pyx_v_thermodynamics);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5246
 *         return thermodynamics
 * 
 *     def get_primordial(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the primordial scalar and/or tensor spectrum depending on 'modes'.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_571get_primordial(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_570get_primordial, "\n        Return the primordial scalar and/or tensor spectrum depending on 'modes'.\n        'output' must be set to something, e.g. 'tCl'.\n\n        Returns\n        -------\n        primordial : dictionary containing k-vector and primordial scalar and tensor P(k).\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_571get_primordial = {"get_primordial", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_571get_primordial, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_570get_primordial};
static PyObject *__pyx_pw_9classy_sz_5Class_571get_primordial(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_primordial (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_primordial", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_primordial", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_570get_primordial(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_570get_primordial(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  char *__pyx_v_titles;
  double *__pyx_v_data;
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_v_number_of_titles = NULL;
  PyObject *__pyx_v_timesteps = NULL;
  PyObject *__pyx_v_primordial = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  unsigned int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  size_t __pyx_t_8;
  int __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  Py_ssize_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_primordial", 1);

  /* "class-sz/python/classy.pyx":5258
 *         cdef double* data
 * 
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))             # <<<<<<<<<<<<<<
 * 
 *         if primordial_output_titles(&self.pt, &self.pm, titles)==_FAILURE_:
 */
  __pyx_v_titles = ((char *)calloc(0x1F40, (sizeof(char))));

  /* "class-sz/python/classy.pyx":5260
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if primordial_output_titles(&self.pt, &self.pm, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pm.error_message)
 * 
 */
  __pyx_t_1 = (primordial_output_titles((&__pyx_v_self->pt), (&__pyx_v_self->pm), __pyx_v_titles) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5261
 * 
 *         if primordial_output_titles(&self.pt, &self.pm, titles)==_FAILURE_:
 *             raise CosmoSevereError(self.pm.error_message)             # <<<<<<<<<<<<<<
 * 
 *         tmp = <bytes> titles
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->pm.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5261, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 5261, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5260
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if primordial_output_titles(&self.pt, &self.pm, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pm.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5263
 *             raise CosmoSevereError(self.pm.error_message)
 * 
 *         tmp = <bytes> titles             # <<<<<<<<<<<<<<
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 */
  __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_titles); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tmp = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5264
 * 
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())             # <<<<<<<<<<<<<<
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_decode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_tmp, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5265
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]             # <<<<<<<<<<<<<<
 *         number_of_titles = len(names)
 *         timesteps = self.pm.lnk_size
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u__46};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_names = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5266
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)             # <<<<<<<<<<<<<<
 *         timesteps = self.pm.lnk_size
 * 
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_names); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5266, __pyx_L1_error)
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_number_of_titles = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5267
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 *         timesteps = self.pm.lnk_size             # <<<<<<<<<<<<<<
 * 
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->pm.lnk_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_timesteps = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5269
 *         timesteps = self.pm.lnk_size
 * 
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)             # <<<<<<<<<<<<<<
 * 
 *         if primordial_output_data(&self.pt, &self.pm, number_of_titles, data)==_FAILURE_:
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t((sizeof(double))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyNumber_Multiply(__pyx_t_3, __pyx_v_timesteps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_2, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyInt_As_size_t(__pyx_t_3); if (unlikely((__pyx_t_8 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_data = ((double *)malloc(__pyx_t_8));

  /* "class-sz/python/classy.pyx":5271
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 * 
 *         if primordial_output_data(&self.pt, &self.pm, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pm.error_message)
 * 
 */
  __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_number_of_titles); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5271, __pyx_L1_error)
  __pyx_t_1 = (primordial_output_data((&__pyx_v_self->pt), (&__pyx_v_self->pm), __pyx_t_9, __pyx_v_data) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5272
 * 
 *         if primordial_output_data(&self.pt, &self.pm, number_of_titles, data)==_FAILURE_:
 *             raise CosmoSevereError(self.pm.error_message)             # <<<<<<<<<<<<<<
 * 
 *         primordial = {}
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_self->pm.error_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 5272, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5271
 *         data = <double*>malloc(sizeof(double)*timesteps*number_of_titles)
 * 
 *         if primordial_output_data(&self.pt, &self.pm, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pm.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5274
 *             raise CosmoSevereError(self.pm.error_message)
 * 
 *         primordial = {}             # <<<<<<<<<<<<<<
 * 
 *         for i in range(number_of_titles):
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_primordial = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5276
 *         primordial = {}
 * 
 *         for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *             primordial[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = 0;
    __pyx_t_10 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5276, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_10)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5276, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 5276, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5276, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5276, __pyx_L1_error)
          #endif
          if (__pyx_t_7 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 5276, __pyx_L1_error)
        #else
        __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5276, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_10(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5276, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":5277
 * 
 *         for i in range(number_of_titles):
 *             primordial[names[i]] = np.zeros(timesteps, dtype=np.double)             # <<<<<<<<<<<<<<
 *             for index in range(timesteps):
 *                 primordial[names[i]][index] = data[index*number_of_titles+i]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timesteps);
    __Pyx_GIVEREF(__pyx_v_timesteps);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timesteps)) __PYX_ERR(0, 5277, __pyx_L1_error);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_double); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely((PyDict_SetItem(__pyx_v_primordial, __pyx_t_5, __pyx_t_12) < 0))) __PYX_ERR(0, 5277, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "class-sz/python/classy.pyx":5278
 *         for i in range(number_of_titles):
 *             primordial[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                 primordial[names[i]][index] = data[index*number_of_titles+i]
 * 
 */
    __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_timesteps); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (likely(PyList_CheckExact(__pyx_t_12)) || PyTuple_CheckExact(__pyx_t_12)) {
      __pyx_t_5 = __pyx_t_12; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_13 = 0;
      __pyx_t_14 = NULL;
    } else {
      __pyx_t_13 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5278, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    for (;;) {
      if (likely(!__pyx_t_14)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5278, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_12 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 5278, __pyx_L1_error)
          #else
          __pyx_t_12 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5278, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5278, __pyx_L1_error)
            #endif
            if (__pyx_t_13 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_12 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_13); __Pyx_INCREF(__pyx_t_12); __pyx_t_13++; if (unlikely((0 < 0))) __PYX_ERR(0, 5278, __pyx_L1_error)
          #else
          __pyx_t_12 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_13); __pyx_t_13++; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5278, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          #endif
        }
      } else {
        __pyx_t_12 = __pyx_t_14(__pyx_t_5);
        if (unlikely(!__pyx_t_12)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5278, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_12);
      }
      __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "class-sz/python/classy.pyx":5279
 *             primordial[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 *                 primordial[names[i]][index] = data[index*number_of_titles+i]             # <<<<<<<<<<<<<<
 * 
 *         free(titles)
 */
      __pyx_t_12 = PyNumber_Multiply(__pyx_v_index, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_3 = PyNumber_Add(__pyx_t_12, __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_15 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_15 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5279, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyFloat_FromDouble((__pyx_v_data[__pyx_t_15])); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_primordial, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely((PyObject_SetItem(__pyx_t_4, __pyx_v_index, __pyx_t_3) < 0))) __PYX_ERR(0, 5279, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":5278
 *         for i in range(number_of_titles):
 *             primordial[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                 primordial[names[i]][index] = data[index*number_of_titles+i]
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":5276
 *         primordial = {}
 * 
 *         for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *             primordial[names[i]] = np.zeros(timesteps, dtype=np.double)
 *             for index in range(timesteps):
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5281
 *                 primordial[names[i]][index] = data[index*number_of_titles+i]
 * 
 *         free(titles)             # <<<<<<<<<<<<<<
 *         free(data)
 *         return primordial
 */
  free(__pyx_v_titles);

  /* "class-sz/python/classy.pyx":5282
 * 
 *         free(titles)
 *         free(data)             # <<<<<<<<<<<<<<
 *         return primordial
 * 
 */
  free(__pyx_v_data);

  /* "class-sz/python/classy.pyx":5283
 *         free(titles)
 *         free(data)
 *         return primordial             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_primordial);
  __pyx_r = __pyx_v_primordial;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5246
 *         return thermodynamics
 * 
 *     def get_primordial(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the primordial scalar and/or tensor spectrum depending on 'modes'.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("classy_sz.Class.get_primordial", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XDECREF(__pyx_v_number_of_titles);
  __Pyx_XDECREF(__pyx_v_timesteps);
  __Pyx_XDECREF(__pyx_v_primordial);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5286
 * 
 * 
 *     @cython.returns(dict)             # <<<<<<<<<<<<<<
 *     @cython.initializedcheck(False)
 *     @cython.boundscheck(False)
 */

static PyObject *__pyx_pw_9classy_sz_5Class_573get_perturbations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9classy_sz_5Class_get_perturbations(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_perturbations = NULL;
  Py_ssize_t __pyx_v_j;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_number_of_titles;
  CYTHON_UNUSED Py_ssize_t __pyx_v_timesteps;
  PyObject *__pyx_v_names = 0;
  PyObject *__pyx_v_tmparray = 0;
  PyObject *__pyx_v_tmpdict = 0;
  __Pyx_memviewslice __pyx_v_data_mv = { 0, 0, { 0 }, { 0 }, { 0 } };
  double **__pyx_v_thedata;
  int *__pyx_v_thesizes;
  PyObject *__pyx_v_mode = NULL;
  PyObject *__pyx_v_thetitles = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  double **__pyx_t_9;
  int *__pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  double *__pyx_t_14;
  struct __pyx_array_obj *__pyx_t_15 = NULL;
  __Pyx_memviewslice __pyx_t_16 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_17;
  Py_ssize_t __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  __Pyx_memviewslice __pyx_t_20 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_21 = NULL;
  int __pyx_t_22;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_perturbations", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_perturbations); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5286, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_9classy_sz_5Class_573get_perturbations)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5286, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(PyDict_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_2))) __PYX_ERR(0, 5286, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "class-sz/python/classy.pyx":5309
 *         """
 * 
 *         perturbations = {}             # <<<<<<<<<<<<<<
 * 
 *         if self.pt.k_output_values_num<1:
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_perturbations = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5311
 *         perturbations = {}
 * 
 *         if self.pt.k_output_values_num<1:             # <<<<<<<<<<<<<<
 *             return perturbations
 * 
 */
  __pyx_t_6 = (__pyx_v_self->pt.k_output_values_num < 1);
  if (__pyx_t_6) {

    /* "class-sz/python/classy.pyx":5312
 * 
 *         if self.pt.k_output_values_num<1:
 *             return perturbations             # <<<<<<<<<<<<<<
 * 
 *         cdef:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_perturbations);
    __pyx_r = __pyx_v_perturbations;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":5311
 *         perturbations = {}
 * 
 *         if self.pt.k_output_values_num<1:             # <<<<<<<<<<<<<<
 *             return perturbations
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5328
 *         # Doing the exact same thing 3 times, for scalar, vector and tensor. Sorry
 *         # for copy-and-paste here, but I don't know what else to do.
 *         for mode in ['scalar','vector','tensor']:             # <<<<<<<<<<<<<<
 *             if mode=='scalar' and self.pt.has_scalars:
 *                 thetitles = <bytes> self.pt.scalar_titles
 */
  __pyx_t_1 = __pyx_tuple__48; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_7 = 0;
  for (;;) {
    if (__pyx_t_7 >= 3) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 5328, __pyx_L1_error)
    #else
    __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_mode, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":5329
 *         # for copy-and-paste here, but I don't know what else to do.
 *         for mode in ['scalar','vector','tensor']:
 *             if mode=='scalar' and self.pt.has_scalars:             # <<<<<<<<<<<<<<
 *                 thetitles = <bytes> self.pt.scalar_titles
 *                 thedata = self.pt.scalar_perturbations_data
 */
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_mode, __pyx_n_u_scalar, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 5329, __pyx_L1_error)
    if (__pyx_t_8) {
    } else {
      __pyx_t_6 = __pyx_t_8;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_self->pt.has_scalars != 0);
    __pyx_t_6 = __pyx_t_8;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_6) {

      /* "class-sz/python/classy.pyx":5330
 *         for mode in ['scalar','vector','tensor']:
 *             if mode=='scalar' and self.pt.has_scalars:
 *                 thetitles = <bytes> self.pt.scalar_titles             # <<<<<<<<<<<<<<
 *                 thedata = self.pt.scalar_perturbations_data
 *                 thesizes = self.pt.size_scalar_perturbation_data
 */
      __pyx_t_2 = __Pyx_PyObject_FromString(__pyx_v_self->pt.scalar_titles); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __pyx_t_2;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_thetitles, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":5331
 *             if mode=='scalar' and self.pt.has_scalars:
 *                 thetitles = <bytes> self.pt.scalar_titles
 *                 thedata = self.pt.scalar_perturbations_data             # <<<<<<<<<<<<<<
 *                 thesizes = self.pt.size_scalar_perturbation_data
 *             elif mode=='vector' and self.pt.has_vectors:
 */
      __pyx_t_9 = __pyx_v_self->pt.scalar_perturbations_data;
      __pyx_v_thedata = __pyx_t_9;

      /* "class-sz/python/classy.pyx":5332
 *                 thetitles = <bytes> self.pt.scalar_titles
 *                 thedata = self.pt.scalar_perturbations_data
 *                 thesizes = self.pt.size_scalar_perturbation_data             # <<<<<<<<<<<<<<
 *             elif mode=='vector' and self.pt.has_vectors:
 *                 thetitles = <bytes> self.pt.vector_titles
 */
      __pyx_t_10 = __pyx_v_self->pt.size_scalar_perturbation_data;
      __pyx_v_thesizes = __pyx_t_10;

      /* "class-sz/python/classy.pyx":5329
 *         # for copy-and-paste here, but I don't know what else to do.
 *         for mode in ['scalar','vector','tensor']:
 *             if mode=='scalar' and self.pt.has_scalars:             # <<<<<<<<<<<<<<
 *                 thetitles = <bytes> self.pt.scalar_titles
 *                 thedata = self.pt.scalar_perturbations_data
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5333
 *                 thedata = self.pt.scalar_perturbations_data
 *                 thesizes = self.pt.size_scalar_perturbation_data
 *             elif mode=='vector' and self.pt.has_vectors:             # <<<<<<<<<<<<<<
 *                 thetitles = <bytes> self.pt.vector_titles
 *                 thedata = self.pt.vector_perturbations_data
 */
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_mode, __pyx_n_u_vector, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 5333, __pyx_L1_error)
    if (__pyx_t_8) {
    } else {
      __pyx_t_6 = __pyx_t_8;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_self->pt.has_vectors != 0);
    __pyx_t_6 = __pyx_t_8;
    __pyx_L9_bool_binop_done:;
    if (__pyx_t_6) {

      /* "class-sz/python/classy.pyx":5334
 *                 thesizes = self.pt.size_scalar_perturbation_data
 *             elif mode=='vector' and self.pt.has_vectors:
 *                 thetitles = <bytes> self.pt.vector_titles             # <<<<<<<<<<<<<<
 *                 thedata = self.pt.vector_perturbations_data
 *                 thesizes = self.pt.size_vector_perturbation_data
 */
      __pyx_t_3 = __Pyx_PyObject_FromString(__pyx_v_self->pt.vector_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_thetitles, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "class-sz/python/classy.pyx":5335
 *             elif mode=='vector' and self.pt.has_vectors:
 *                 thetitles = <bytes> self.pt.vector_titles
 *                 thedata = self.pt.vector_perturbations_data             # <<<<<<<<<<<<<<
 *                 thesizes = self.pt.size_vector_perturbation_data
 *             elif mode=='tensor' and self.pt.has_tensors:
 */
      __pyx_t_9 = __pyx_v_self->pt.vector_perturbations_data;
      __pyx_v_thedata = __pyx_t_9;

      /* "class-sz/python/classy.pyx":5336
 *                 thetitles = <bytes> self.pt.vector_titles
 *                 thedata = self.pt.vector_perturbations_data
 *                 thesizes = self.pt.size_vector_perturbation_data             # <<<<<<<<<<<<<<
 *             elif mode=='tensor' and self.pt.has_tensors:
 *                 thetitles = <bytes> self.pt.tensor_titles
 */
      __pyx_t_10 = __pyx_v_self->pt.size_vector_perturbation_data;
      __pyx_v_thesizes = __pyx_t_10;

      /* "class-sz/python/classy.pyx":5333
 *                 thedata = self.pt.scalar_perturbations_data
 *                 thesizes = self.pt.size_scalar_perturbation_data
 *             elif mode=='vector' and self.pt.has_vectors:             # <<<<<<<<<<<<<<
 *                 thetitles = <bytes> self.pt.vector_titles
 *                 thedata = self.pt.vector_perturbations_data
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5337
 *                 thedata = self.pt.vector_perturbations_data
 *                 thesizes = self.pt.size_vector_perturbation_data
 *             elif mode=='tensor' and self.pt.has_tensors:             # <<<<<<<<<<<<<<
 *                 thetitles = <bytes> self.pt.tensor_titles
 *                 thedata = self.pt.tensor_perturbations_data
 */
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_mode, __pyx_n_u_tensor, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 5337, __pyx_L1_error)
    if (__pyx_t_8) {
    } else {
      __pyx_t_6 = __pyx_t_8;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_self->pt.has_tensors != 0);
    __pyx_t_6 = __pyx_t_8;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_6) {

      /* "class-sz/python/classy.pyx":5338
 *                 thesizes = self.pt.size_vector_perturbation_data
 *             elif mode=='tensor' and self.pt.has_tensors:
 *                 thetitles = <bytes> self.pt.tensor_titles             # <<<<<<<<<<<<<<
 *                 thedata = self.pt.tensor_perturbations_data
 *                 thesizes = self.pt.size_tensor_perturbation_data
 */
      __pyx_t_2 = __Pyx_PyObject_FromString(__pyx_v_self->pt.tensor_titles); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __pyx_t_2;
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_thetitles, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "class-sz/python/classy.pyx":5339
 *             elif mode=='tensor' and self.pt.has_tensors:
 *                 thetitles = <bytes> self.pt.tensor_titles
 *                 thedata = self.pt.tensor_perturbations_data             # <<<<<<<<<<<<<<
 *                 thesizes = self.pt.size_tensor_perturbation_data
 *             else:
 */
      __pyx_t_9 = __pyx_v_self->pt.tensor_perturbations_data;
      __pyx_v_thedata = __pyx_t_9;

      /* "class-sz/python/classy.pyx":5340
 *                 thetitles = <bytes> self.pt.tensor_titles
 *                 thedata = self.pt.tensor_perturbations_data
 *                 thesizes = self.pt.size_tensor_perturbation_data             # <<<<<<<<<<<<<<
 *             else:
 *                 continue
 */
      __pyx_t_10 = __pyx_v_self->pt.size_tensor_perturbation_data;
      __pyx_v_thesizes = __pyx_t_10;

      /* "class-sz/python/classy.pyx":5337
 *                 thedata = self.pt.vector_perturbations_data
 *                 thesizes = self.pt.size_vector_perturbation_data
 *             elif mode=='tensor' and self.pt.has_tensors:             # <<<<<<<<<<<<<<
 *                 thetitles = <bytes> self.pt.tensor_titles
 *                 thedata = self.pt.tensor_perturbations_data
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5342
 *                 thesizes = self.pt.size_tensor_perturbation_data
 *             else:
 *                 continue             # <<<<<<<<<<<<<<
 *             thetitles = str(thetitles.decode())
 *             names = thetitles.split("\t")[:-1]
 */
    /*else*/ {
      goto __pyx_L4_continue;
    }
    __pyx_L6:;

    /* "class-sz/python/classy.pyx":5343
 *             else:
 *                 continue
 *             thetitles = str(thetitles.decode())             # <<<<<<<<<<<<<<
 *             names = thetitles.split("\t")[:-1]
 *             number_of_titles = len(names)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_thetitles, __pyx_n_s_decode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5343, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5343, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5343, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_thetitles, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "class-sz/python/classy.pyx":5344
 *                 continue
 *             thetitles = str(thetitles.decode())
 *             names = thetitles.split("\t")[:-1]             # <<<<<<<<<<<<<<
 *             number_of_titles = len(names)
 *             tmparray = []
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_thetitles, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u__46};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5344, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!(likely(PyList_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_3))) __PYX_ERR(0, 5344, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_names, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":5345
 *             thetitles = str(thetitles.decode())
 *             names = thetitles.split("\t")[:-1]
 *             number_of_titles = len(names)             # <<<<<<<<<<<<<<
 *             tmparray = []
 *             if number_of_titles != 0:
 */
    if (unlikely(__pyx_v_names == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 5345, __pyx_L1_error)
    }
    __pyx_t_11 = __Pyx_PyList_GET_SIZE(__pyx_v_names); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5345, __pyx_L1_error)
    __pyx_v_number_of_titles = __pyx_t_11;

    /* "class-sz/python/classy.pyx":5346
 *             names = thetitles.split("\t")[:-1]
 *             number_of_titles = len(names)
 *             tmparray = []             # <<<<<<<<<<<<<<
 *             if number_of_titles != 0:
 *                 for j in range(self.pt.k_output_values_num):
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_tmparray, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":5347
 *             number_of_titles = len(names)
 *             tmparray = []
 *             if number_of_titles != 0:             # <<<<<<<<<<<<<<
 *                 for j in range(self.pt.k_output_values_num):
 *                     timesteps = thesizes[j]//number_of_titles
 */
    __pyx_t_6 = (__pyx_v_number_of_titles != 0);
    if (__pyx_t_6) {

      /* "class-sz/python/classy.pyx":5348
 *             tmparray = []
 *             if number_of_titles != 0:
 *                 for j in range(self.pt.k_output_values_num):             # <<<<<<<<<<<<<<
 *                     timesteps = thesizes[j]//number_of_titles
 *                     tmpdict={}
 */
      __pyx_t_12 = __pyx_v_self->pt.k_output_values_num;
      __pyx_t_13 = __pyx_t_12;
      for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_13; __pyx_t_11+=1) {
        __pyx_v_j = __pyx_t_11;

        /* "class-sz/python/classy.pyx":5349
 *             if number_of_titles != 0:
 *                 for j in range(self.pt.k_output_values_num):
 *                     timesteps = thesizes[j]//number_of_titles             # <<<<<<<<<<<<<<
 *                     tmpdict={}
 *                     data_mv = <double[:timesteps,:number_of_titles]> thedata[j]
 */
        __pyx_v_timesteps = ((__pyx_v_thesizes[__pyx_v_j]) / __pyx_v_number_of_titles);

        /* "class-sz/python/classy.pyx":5350
 *                 for j in range(self.pt.k_output_values_num):
 *                     timesteps = thesizes[j]//number_of_titles
 *                     tmpdict={}             # <<<<<<<<<<<<<<
 *                     data_mv = <double[:timesteps,:number_of_titles]> thedata[j]
 *                     for i in range(number_of_titles):
 */
        __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5350, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_tmpdict, ((PyObject*)__pyx_t_3));
        __pyx_t_3 = 0;

        /* "class-sz/python/classy.pyx":5351
 *                     timesteps = thesizes[j]//number_of_titles
 *                     tmpdict={}
 *                     data_mv = <double[:timesteps,:number_of_titles]> thedata[j]             # <<<<<<<<<<<<<<
 *                     for i in range(number_of_titles):
 *                         tmpdict[names[i]] = np.asarray(data_mv[:,i])
 */
        __pyx_t_14 = (__pyx_v_thedata[__pyx_v_j]);
        if (!__pyx_t_14) {
          PyErr_SetString(PyExc_ValueError,"Cannot create cython.array from NULL pointer");
          __PYX_ERR(0, 5351, __pyx_L1_error)
        }
        __pyx_t_2 = __pyx_format_from_typeinfo(&__Pyx_TypeInfo_double); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = Py_BuildValue((char*) "("  __PYX_BUILD_PY_SSIZE_T  __PYX_BUILD_PY_SSIZE_T  ")", ((Py_ssize_t)__pyx_v_timesteps), ((Py_ssize_t)__pyx_v_number_of_titles)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5351, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_15 = __pyx_array_new(__pyx_t_3, sizeof(double), PyBytes_AS_STRING(__pyx_t_2), (char *) "c", (char *) __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 5351, __pyx_L1_error)
        __Pyx_GOTREF((PyObject *)__pyx_t_15);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_16 = __Pyx_PyObject_to_MemoryviewSlice_d_dc_double(((PyObject *)__pyx_t_15), PyBUF_WRITABLE); if (unlikely(!__pyx_t_16.memview)) __PYX_ERR(0, 5351, __pyx_L1_error)
        __Pyx_DECREF((PyObject *)__pyx_t_15); __pyx_t_15 = 0;
        __PYX_XCLEAR_MEMVIEW(&__pyx_v_data_mv, 1);
        __pyx_v_data_mv = __pyx_t_16;
        __pyx_t_16.memview = NULL;
        __pyx_t_16.data = NULL;

        /* "class-sz/python/classy.pyx":5352
 *                     tmpdict={}
 *                     data_mv = <double[:timesteps,:number_of_titles]> thedata[j]
 *                     for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *                         tmpdict[names[i]] = np.asarray(data_mv[:,i])
 *                     tmparray.append(tmpdict)
 */
        __pyx_t_17 = __pyx_v_number_of_titles;
        __pyx_t_18 = __pyx_t_17;
        for (__pyx_t_19 = 0; __pyx_t_19 < __pyx_t_18; __pyx_t_19+=1) {
          __pyx_v_i = __pyx_t_19;

          /* "class-sz/python/classy.pyx":5353
 *                     data_mv = <double[:timesteps,:number_of_titles]> thedata[j]
 *                     for i in range(number_of_titles):
 *                         tmpdict[names[i]] = np.asarray(data_mv[:,i])             # <<<<<<<<<<<<<<
 *                     tmparray.append(tmpdict)
 *             perturbations[mode] = tmparray
 */
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5353, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5353, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_20.data = __pyx_v_data_mv.data;
          __pyx_t_20.memview = __pyx_v_data_mv.memview;
          __PYX_INC_MEMVIEW(&__pyx_t_20, 1);
          __pyx_t_20.shape[0] = __pyx_v_data_mv.shape[0];
__pyx_t_20.strides[0] = __pyx_v_data_mv.strides[0];
    __pyx_t_20.suboffsets[0] = -1;

{
    Py_ssize_t __pyx_tmp_idx = __pyx_v_i;
        Py_ssize_t __pyx_tmp_shape = __pyx_v_data_mv.shape[1];
    Py_ssize_t __pyx_tmp_stride = __pyx_v_data_mv.strides[1];
        if (__pyx_tmp_idx < 0)
            __pyx_tmp_idx += __pyx_tmp_shape;
        __pyx_t_20.data += __pyx_tmp_idx * __pyx_tmp_stride;
}

__pyx_t_3 = __pyx_memoryview_fromslice(__pyx_t_20, 1, (PyObject *(*)(char *)) __pyx_memview_get_double, (int (*)(char *, PyObject *)) __pyx_memview_set_double, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5353, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __PYX_XCLEAR_MEMVIEW(&__pyx_t_20, 1);
          __pyx_t_20.memview = NULL; __pyx_t_20.data = NULL;
          __pyx_t_21 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_21)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_21);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_21, __pyx_t_3};
            __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5353, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          if (unlikely(__pyx_v_names == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(0, 5353, __pyx_L1_error)
          }
          __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_names, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 5353, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely((PyDict_SetItem(__pyx_v_tmpdict, __pyx_t_4, __pyx_t_2) < 0))) __PYX_ERR(0, 5353, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }

        /* "class-sz/python/classy.pyx":5354
 *                     for i in range(number_of_titles):
 *                         tmpdict[names[i]] = np.asarray(data_mv[:,i])
 *                     tmparray.append(tmpdict)             # <<<<<<<<<<<<<<
 *             perturbations[mode] = tmparray
 * 
 */
        __pyx_t_22 = __Pyx_PyList_Append(__pyx_v_tmparray, __pyx_v_tmpdict); if (unlikely(__pyx_t_22 == ((int)-1))) __PYX_ERR(0, 5354, __pyx_L1_error)
      }

      /* "class-sz/python/classy.pyx":5347
 *             number_of_titles = len(names)
 *             tmparray = []
 *             if number_of_titles != 0:             # <<<<<<<<<<<<<<
 *                 for j in range(self.pt.k_output_values_num):
 *                     timesteps = thesizes[j]//number_of_titles
 */
    }

    /* "class-sz/python/classy.pyx":5355
 *                         tmpdict[names[i]] = np.asarray(data_mv[:,i])
 *                     tmparray.append(tmpdict)
 *             perturbations[mode] = tmparray             # <<<<<<<<<<<<<<
 * 
 *         return perturbations
 */
    if (unlikely((PyDict_SetItem(__pyx_v_perturbations, __pyx_v_mode, __pyx_v_tmparray) < 0))) __PYX_ERR(0, 5355, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5328
 *         # Doing the exact same thing 3 times, for scalar, vector and tensor. Sorry
 *         # for copy-and-paste here, but I don't know what else to do.
 *         for mode in ['scalar','vector','tensor']:             # <<<<<<<<<<<<<<
 *             if mode=='scalar' and self.pt.has_scalars:
 *                 thetitles = <bytes> self.pt.scalar_titles
 */
    __pyx_L4_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5357
 *             perturbations[mode] = tmparray
 * 
 *         return perturbations             # <<<<<<<<<<<<<<
 * 
 *     def get_transfer(self, z=0., output_format='class'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_perturbations);
  __pyx_r = __pyx_v_perturbations;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5286
 * 
 * 
 *     @cython.returns(dict)             # <<<<<<<<<<<<<<
 *     @cython.initializedcheck(False)
 *     @cython.boundscheck(False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF((PyObject *)__pyx_t_15);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_16, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_20, 1);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_AddTraceback("classy_sz.Class.get_perturbations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_perturbations);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XDECREF(__pyx_v_tmparray);
  __Pyx_XDECREF(__pyx_v_tmpdict);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_data_mv, 1);
  __Pyx_XDECREF(__pyx_v_mode);
  __Pyx_XDECREF(__pyx_v_thetitles);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_573get_perturbations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_572get_perturbations, "\n        Return scalar, vector and/or tensor perturbations as arrays for requested\n        k-values.\n\n        .. note::\n\n            you need to specify both 'k_output_values', and have some\n            perturbations computed, for instance by setting 'output' to 'tCl'.\n\n        Returns\n        -------\n        perturbations : dict of array of dicts\n                perturbations['scalar'] is an array of length 'k_output_values' of\n                dictionary containing scalar perturbations.\n                Similar for perturbations['vector'] and perturbations['tensor'].\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_573get_perturbations = {"get_perturbations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_573get_perturbations, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_572get_perturbations};
static PyObject *__pyx_pw_9classy_sz_5Class_573get_perturbations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_perturbations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_perturbations", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_perturbations", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_572get_perturbations(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_572get_perturbations(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_perturbations", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9classy_sz_5Class_get_perturbations(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_perturbations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5359
 *         return perturbations
 * 
 *     def get_transfer(self, z=0., output_format='class'):             # <<<<<<<<<<<<<<
 *         """
 *         Return the density and/or velocity transfer functions for all initial
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_575get_transfer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_574get_transfer, "\n        Return the density and/or velocity transfer functions for all initial\n        conditions today. You must include 'mTk' and/or 'vCTk' in the list of\n        'output'. The transfer functions can also be computed at higher redshift z\n        provided that 'z_pk' has been set and that 0<z<z_pk.\n\n        Parameters\n        ----------\n        z  : redshift (default = 0)\n        output_format  : ('class' or 'camb') Format transfer functions according to\n                         CLASS convention (default) or CAMB convention.\n\n        Returns\n        -------\n        tk : dictionary containing transfer functions.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_575get_transfer = {"get_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_575get_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_574get_transfer};
static PyObject *__pyx_pw_9classy_sz_5Class_575get_transfer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_z = 0;
  PyObject *__pyx_v_output_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_transfer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_output_format,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_float_0_));
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_n_u_class_2));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5359, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_output_format);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5359, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_transfer") < 0)) __PYX_ERR(0, 5359, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_z = values[0];
    __pyx_v_output_format = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_transfer", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 5359, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_574get_transfer(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_output_format);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_574get_transfer(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_z, PyObject *__pyx_v_output_format) {
  char *__pyx_v_titles;
  double *__pyx_v_data;
  char __pyx_v_ic_info[0x400];
  FileName __pyx_v_ic_suffix;
  enum file_format __pyx_v_outf;
  int __pyx_v_index_md;
  PyObject *__pyx_v_tmp = NULL;
  PyObject *__pyx_v_names = NULL;
  PyObject *__pyx_v_number_of_titles = NULL;
  PyObject *__pyx_v_timesteps = NULL;
  PyObject *__pyx_v_size_ic_data = NULL;
  PyObject *__pyx_v_ic_num = NULL;
  PyObject *__pyx_v_transfers = NULL;
  PyObject *__pyx_v_index_ic = NULL;
  PyObject *__pyx_v_ic_key = NULL;
  PyObject *__pyx_v_tmpdict = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  unsigned int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  size_t __pyx_t_10;
  double __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  PyObject *(*__pyx_t_15)(PyObject *);
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  Py_ssize_t __pyx_t_18;
  PyObject *(*__pyx_t_19)(PyObject *);
  Py_ssize_t __pyx_t_20;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_transfer", 1);

  /* "class-sz/python/classy.pyx":5382
 *         cdef file_format outf
 * 
 *         if (not self.pt.has_density_transfers) and (not self.pt.has_velocity_transfers):             # <<<<<<<<<<<<<<
 *             return {}
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->pt.has_density_transfers != 0));
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_self->pt.has_velocity_transfers != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":5383
 * 
 *         if (not self.pt.has_density_transfers) and (not self.pt.has_velocity_transfers):
 *             return {}             # <<<<<<<<<<<<<<
 * 
 *         if output_format == 'camb':
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "class-sz/python/classy.pyx":5382
 *         cdef file_format outf
 * 
 *         if (not self.pt.has_density_transfers) and (not self.pt.has_velocity_transfers):             # <<<<<<<<<<<<<<
 *             return {}
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5385
 *             return {}
 * 
 *         if output_format == 'camb':             # <<<<<<<<<<<<<<
 *             outf = camb_format
 *         else:
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_output_format, __pyx_n_u_camb, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 5385, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "class-sz/python/classy.pyx":5386
 * 
 *         if output_format == 'camb':
 *             outf = camb_format             # <<<<<<<<<<<<<<
 *         else:
 *             outf = class_format
 */
    __pyx_v_outf = camb_format;

    /* "class-sz/python/classy.pyx":5385
 *             return {}
 * 
 *         if output_format == 'camb':             # <<<<<<<<<<<<<<
 *             outf = camb_format
 *         else:
 */
    goto __pyx_L6;
  }

  /* "class-sz/python/classy.pyx":5388
 *             outf = camb_format
 *         else:
 *             outf = class_format             # <<<<<<<<<<<<<<
 * 
 *         index_md = self.pt.index_md_scalars;
 */
  /*else*/ {
    __pyx_v_outf = class_format;
  }
  __pyx_L6:;

  /* "class-sz/python/classy.pyx":5390
 *             outf = class_format
 * 
 *         index_md = self.pt.index_md_scalars;             # <<<<<<<<<<<<<<
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 */
  __pyx_t_4 = __pyx_v_self->pt.index_md_scalars;
  __pyx_v_index_md = __pyx_t_4;

  /* "class-sz/python/classy.pyx":5391
 * 
 *         index_md = self.pt.index_md_scalars;
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))             # <<<<<<<<<<<<<<
 * 
 *         if perturb_output_titles(&self.ba,&self.pt, outf, titles)==_FAILURE_:
 */
  __pyx_v_titles = ((char *)calloc(0x1F40, (sizeof(char))));

  /* "class-sz/python/classy.pyx":5393
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if perturb_output_titles(&self.ba,&self.pt, outf, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pt.error_message)
 * 
 */
  __pyx_t_1 = (perturb_output_titles((&__pyx_v_self->ba), (&__pyx_v_self->pt), __pyx_v_outf, __pyx_v_titles) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5394
 * 
 *         if perturb_output_titles(&self.ba,&self.pt, outf, titles)==_FAILURE_:
 *             raise CosmoSevereError(self.pt.error_message)             # <<<<<<<<<<<<<<
 * 
 *         tmp = <bytes> titles
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_self->pt.error_message); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 5394, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5393
 *         titles = <char*>calloc(_MAXTITLESTRINGLENGTH_,sizeof(char))
 * 
 *         if perturb_output_titles(&self.ba,&self.pt, outf, titles)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pt.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5396
 *             raise CosmoSevereError(self.pt.error_message)
 * 
 *         tmp = <bytes> titles             # <<<<<<<<<<<<<<
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 */
  __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_titles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_t_3;
  __Pyx_INCREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_tmp = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5397
 * 
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())             # <<<<<<<<<<<<<<
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_decode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_Unicode(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_tmp, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5398
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]             # <<<<<<<<<<<<<<
 *         number_of_titles = len(names)
 *         timesteps = self.pt.k_size[index_md]
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_tmp, __pyx_n_s_split); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u__46};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, -1L, NULL, NULL, &__pyx_slice__47, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_names = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5399
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)             # <<<<<<<<<<<<<<
 *         timesteps = self.pt.k_size[index_md]
 * 
 */
  __pyx_t_9 = PyObject_Length(__pyx_v_names); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 5399, __pyx_L1_error)
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_number_of_titles = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5400
 *         names = tmp.split("\t")[:-1]
 *         number_of_titles = len(names)
 *         timesteps = self.pt.k_size[index_md]             # <<<<<<<<<<<<<<
 * 
 *         size_ic_data = timesteps*number_of_titles;
 */
  __pyx_t_5 = __Pyx_PyInt_From_int((__pyx_v_self->pt.k_size[__pyx_v_index_md])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5400, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_timesteps = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5402
 *         timesteps = self.pt.k_size[index_md]
 * 
 *         size_ic_data = timesteps*number_of_titles;             # <<<<<<<<<<<<<<
 *         ic_num = self.pt.ic_size[index_md];
 * 
 */
  __pyx_t_5 = PyNumber_Multiply(__pyx_v_timesteps, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_size_ic_data = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5403
 * 
 *         size_ic_data = timesteps*number_of_titles;
 *         ic_num = self.pt.ic_size[index_md];             # <<<<<<<<<<<<<<
 * 
 *         data = <double*>malloc(sizeof(double)*size_ic_data*ic_num)
 */
  __pyx_t_5 = __Pyx_PyInt_From_int((__pyx_v_self->pt.ic_size[__pyx_v_index_md])); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_ic_num = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5405
 *         ic_num = self.pt.ic_size[index_md];
 * 
 *         data = <double*>malloc(sizeof(double)*size_ic_data*ic_num)             # <<<<<<<<<<<<<<
 * 
 *         if perturb_output_data(&self.ba, &self.pt, outf, <double> z, number_of_titles, data)==_FAILURE_:
 */
  __pyx_t_5 = __Pyx_PyInt_FromSize_t((sizeof(double))); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_5, __pyx_v_size_ic_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyNumber_Multiply(__pyx_t_3, __pyx_v_ic_num); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_10 = __Pyx_PyInt_As_size_t(__pyx_t_5); if (unlikely((__pyx_t_10 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_data = ((double *)malloc(__pyx_t_10));

  /* "class-sz/python/classy.pyx":5407
 *         data = <double*>malloc(sizeof(double)*size_ic_data*ic_num)
 * 
 *         if perturb_output_data(&self.ba, &self.pt, outf, <double> z, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pt.error_message)
 * 
 */
  __pyx_t_11 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_11 == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5407, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_number_of_titles); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5407, __pyx_L1_error)
  __pyx_t_1 = (perturb_output_data((&__pyx_v_self->ba), (&__pyx_v_self->pt), __pyx_v_outf, ((double)__pyx_t_11), __pyx_t_4, __pyx_v_data) == _FAILURE_);
  if (unlikely(__pyx_t_1)) {

    /* "class-sz/python/classy.pyx":5408
 * 
 *         if perturb_output_data(&self.ba, &self.pt, outf, <double> z, number_of_titles, data)==_FAILURE_:
 *             raise CosmoSevereError(self.pt.error_message)             # <<<<<<<<<<<<<<
 * 
 *         transfers = {}
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_self->pt.error_message); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5408, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 5408, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5407
 *         data = <double*>malloc(sizeof(double)*size_ic_data*ic_num)
 * 
 *         if perturb_output_data(&self.ba, &self.pt, outf, <double> z, number_of_titles, data)==_FAILURE_:             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(self.pt.error_message)
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5410
 *             raise CosmoSevereError(self.pt.error_message)
 * 
 *         transfers = {}             # <<<<<<<<<<<<<<
 * 
 *         for index_ic in range(ic_num):
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_transfers = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":5412
 *         transfers = {}
 * 
 *         for index_ic in range(ic_num):             # <<<<<<<<<<<<<<
 *             if perturb_output_firstline_and_ic_suffix(&self.pt, index_ic, ic_info, ic_suffix)==_FAILURE_:
 *                 raise CosmoSevereError(self.pt.error_message)
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_ic_num); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (likely(PyList_CheckExact(__pyx_t_5)) || PyTuple_CheckExact(__pyx_t_5)) {
    __pyx_t_3 = __pyx_t_5; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_9 = 0;
    __pyx_t_12 = NULL;
  } else {
    __pyx_t_9 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5412, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  for (;;) {
    if (likely(!__pyx_t_12)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5412, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_9); __Pyx_INCREF(__pyx_t_5); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 5412, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5412, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5412, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_9); __Pyx_INCREF(__pyx_t_5); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 5412, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5412, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_12(__pyx_t_3);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5412, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_index_ic, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":5413
 * 
 *         for index_ic in range(ic_num):
 *             if perturb_output_firstline_and_ic_suffix(&self.pt, index_ic, ic_info, ic_suffix)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.pt.error_message)
 *             ic_key = <bytes> ic_suffix
 */
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_index_ic); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5413, __pyx_L1_error)
    __pyx_t_1 = (perturb_output_firstline_and_ic_suffix((&__pyx_v_self->pt), __pyx_t_4, __pyx_v_ic_info, __pyx_v_ic_suffix) == _FAILURE_);
    if (unlikely(__pyx_t_1)) {

      /* "class-sz/python/classy.pyx":5414
 *         for index_ic in range(ic_num):
 *             if perturb_output_firstline_and_ic_suffix(&self.pt, index_ic, ic_info, ic_suffix)==_FAILURE_:
 *                 raise CosmoSevereError(self.pt.error_message)             # <<<<<<<<<<<<<<
 *             ic_key = <bytes> ic_suffix
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_self->pt.error_message); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_13 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_7};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 5414, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":5413
 * 
 *         for index_ic in range(ic_num):
 *             if perturb_output_firstline_and_ic_suffix(&self.pt, index_ic, ic_info, ic_suffix)==_FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.pt.error_message)
 *             ic_key = <bytes> ic_suffix
 */
    }

    /* "class-sz/python/classy.pyx":5415
 *             if perturb_output_firstline_and_ic_suffix(&self.pt, index_ic, ic_info, ic_suffix)==_FAILURE_:
 *                 raise CosmoSevereError(self.pt.error_message)
 *             ic_key = <bytes> ic_suffix             # <<<<<<<<<<<<<<
 * 
 *             tmpdict = {}
 */
    __pyx_t_5 = __Pyx_PyObject_FromString(__pyx_v_ic_suffix); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __pyx_t_5;
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_ic_key, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":5417
 *             ic_key = <bytes> ic_suffix
 * 
 *             tmpdict = {}             # <<<<<<<<<<<<<<
 *             for i in range(number_of_titles):
 *                 tmpdict[names[i]] = np.zeros(timesteps, dtype=np.double)
 */
    __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5417, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_tmpdict, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "class-sz/python/classy.pyx":5418
 * 
 *             tmpdict = {}
 *             for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *                 tmpdict[names[i]] = np.zeros(timesteps, dtype=np.double)
 *                 for index in range(timesteps):
 */
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (likely(PyList_CheckExact(__pyx_t_6)) || PyTuple_CheckExact(__pyx_t_6)) {
      __pyx_t_5 = __pyx_t_6; __Pyx_INCREF(__pyx_t_5);
      __pyx_t_14 = 0;
      __pyx_t_15 = NULL;
    } else {
      __pyx_t_14 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 5418, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    for (;;) {
      if (likely(!__pyx_t_15)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5418, __pyx_L1_error)
            #endif
            if (__pyx_t_14 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_14); __Pyx_INCREF(__pyx_t_6); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 5418, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5418, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5418, __pyx_L1_error)
            #endif
            if (__pyx_t_14 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_14); __Pyx_INCREF(__pyx_t_6); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(0, 5418, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5418, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_15(__pyx_t_5);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 5418, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "class-sz/python/classy.pyx":5419
 *             tmpdict = {}
 *             for i in range(number_of_titles):
 *                 tmpdict[names[i]] = np.zeros(timesteps, dtype=np.double)             # <<<<<<<<<<<<<<
 *                 for index in range(timesteps):
 *                     tmpdict[names[i]][index] = data[index_ic*size_ic_data+index*number_of_titles+i]
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_zeros); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_timesteps);
      __Pyx_GIVEREF(__pyx_v_timesteps);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_timesteps)) __PYX_ERR(0, 5419, __pyx_L1_error);
      __pyx_t_13 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_np); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_double); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_dtype, __pyx_t_17) < 0) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_6, __pyx_t_13); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      if (unlikely((PyDict_SetItem(__pyx_v_tmpdict, __pyx_t_13, __pyx_t_17) < 0))) __PYX_ERR(0, 5419, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

      /* "class-sz/python/classy.pyx":5420
 *             for i in range(number_of_titles):
 *                 tmpdict[names[i]] = np.zeros(timesteps, dtype=np.double)
 *                 for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                     tmpdict[names[i]][index] = data[index_ic*size_ic_data+index*number_of_titles+i]
 * 
 */
      __pyx_t_17 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_timesteps); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5420, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      if (likely(PyList_CheckExact(__pyx_t_17)) || PyTuple_CheckExact(__pyx_t_17)) {
        __pyx_t_13 = __pyx_t_17; __Pyx_INCREF(__pyx_t_13);
        __pyx_t_18 = 0;
        __pyx_t_19 = NULL;
      } else {
        __pyx_t_18 = -1; __pyx_t_13 = PyObject_GetIter(__pyx_t_17); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5420, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_19 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_13); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 5420, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      for (;;) {
        if (likely(!__pyx_t_19)) {
          if (likely(PyList_CheckExact(__pyx_t_13))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5420, __pyx_L1_error)
              #endif
              if (__pyx_t_18 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_17 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_18); __Pyx_INCREF(__pyx_t_17); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(0, 5420, __pyx_L1_error)
            #else
            __pyx_t_17 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5420, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_13);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5420, __pyx_L1_error)
              #endif
              if (__pyx_t_18 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_17 = PyTuple_GET_ITEM(__pyx_t_13, __pyx_t_18); __Pyx_INCREF(__pyx_t_17); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(0, 5420, __pyx_L1_error)
            #else
            __pyx_t_17 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5420, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            #endif
          }
        } else {
          __pyx_t_17 = __pyx_t_19(__pyx_t_13);
          if (unlikely(!__pyx_t_17)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 5420, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_17);
        }
        __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_17);
        __pyx_t_17 = 0;

        /* "class-sz/python/classy.pyx":5421
 *                 tmpdict[names[i]] = np.zeros(timesteps, dtype=np.double)
 *                 for index in range(timesteps):
 *                     tmpdict[names[i]][index] = data[index_ic*size_ic_data+index*number_of_titles+i]             # <<<<<<<<<<<<<<
 * 
 *             if ic_num==1:
 */
        __pyx_t_17 = PyNumber_Multiply(__pyx_v_index_ic, __pyx_v_size_ic_data); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __pyx_t_6 = PyNumber_Multiply(__pyx_v_index, __pyx_v_number_of_titles); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = PyNumber_Add(__pyx_t_17, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyNumber_Add(__pyx_t_7, __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_20 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_20 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyFloat_FromDouble((__pyx_v_data[__pyx_t_20])); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_names, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_17 = __Pyx_PyDict_GetItem(__pyx_v_tmpdict, __pyx_t_7); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely((PyObject_SetItem(__pyx_t_17, __pyx_v_index, __pyx_t_6) < 0))) __PYX_ERR(0, 5421, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "class-sz/python/classy.pyx":5420
 *             for i in range(number_of_titles):
 *                 tmpdict[names[i]] = np.zeros(timesteps, dtype=np.double)
 *                 for index in range(timesteps):             # <<<<<<<<<<<<<<
 *                     tmpdict[names[i]][index] = data[index_ic*size_ic_data+index*number_of_titles+i]
 * 
 */
      }
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5418
 * 
 *             tmpdict = {}
 *             for i in range(number_of_titles):             # <<<<<<<<<<<<<<
 *                 tmpdict[names[i]] = np.zeros(timesteps, dtype=np.double)
 *                 for index in range(timesteps):
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "class-sz/python/classy.pyx":5423
 *                     tmpdict[names[i]][index] = data[index_ic*size_ic_data+index*number_of_titles+i]
 * 
 *             if ic_num==1:             # <<<<<<<<<<<<<<
 *                 transfers = tmpdict
 *             else:
 */
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_ic_num, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 5423, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "class-sz/python/classy.pyx":5424
 * 
 *             if ic_num==1:
 *                 transfers = tmpdict             # <<<<<<<<<<<<<<
 *             else:
 *                 transfers[ic_key] = tmpdict
 */
      __Pyx_INCREF(__pyx_v_tmpdict);
      __Pyx_DECREF_SET(__pyx_v_transfers, __pyx_v_tmpdict);

      /* "class-sz/python/classy.pyx":5423
 *                     tmpdict[names[i]][index] = data[index_ic*size_ic_data+index*number_of_titles+i]
 * 
 *             if ic_num==1:             # <<<<<<<<<<<<<<
 *                 transfers = tmpdict
 *             else:
 */
      goto __pyx_L18;
    }

    /* "class-sz/python/classy.pyx":5426
 *                 transfers = tmpdict
 *             else:
 *                 transfers[ic_key] = tmpdict             # <<<<<<<<<<<<<<
 * 
 *         free(titles)
 */
    /*else*/ {
      if (unlikely((PyDict_SetItem(__pyx_v_transfers, __pyx_v_ic_key, __pyx_v_tmpdict) < 0))) __PYX_ERR(0, 5426, __pyx_L1_error)
    }
    __pyx_L18:;

    /* "class-sz/python/classy.pyx":5412
 *         transfers = {}
 * 
 *         for index_ic in range(ic_num):             # <<<<<<<<<<<<<<
 *             if perturb_output_firstline_and_ic_suffix(&self.pt, index_ic, ic_info, ic_suffix)==_FAILURE_:
 *                 raise CosmoSevereError(self.pt.error_message)
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5428
 *                 transfers[ic_key] = tmpdict
 * 
 *         free(titles)             # <<<<<<<<<<<<<<
 *         free(data)
 * 
 */
  free(__pyx_v_titles);

  /* "class-sz/python/classy.pyx":5429
 * 
 *         free(titles)
 *         free(data)             # <<<<<<<<<<<<<<
 * 
 *         return transfers
 */
  free(__pyx_v_data);

  /* "class-sz/python/classy.pyx":5431
 *         free(data)
 * 
 *         return transfers             # <<<<<<<<<<<<<<
 * 
 *     def get_current_derived_parameters(self, names):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_transfers);
  __pyx_r = __pyx_v_transfers;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5359
 *         return perturbations
 * 
 *     def get_transfer(self, z=0., output_format='class'):             # <<<<<<<<<<<<<<
 *         """
 *         Return the density and/or velocity transfer functions for all initial
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("classy_sz.Class.get_transfer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tmp);
  __Pyx_XDECREF(__pyx_v_names);
  __Pyx_XDECREF(__pyx_v_number_of_titles);
  __Pyx_XDECREF(__pyx_v_timesteps);
  __Pyx_XDECREF(__pyx_v_size_ic_data);
  __Pyx_XDECREF(__pyx_v_ic_num);
  __Pyx_XDECREF(__pyx_v_transfers);
  __Pyx_XDECREF(__pyx_v_index_ic);
  __Pyx_XDECREF(__pyx_v_ic_key);
  __Pyx_XDECREF(__pyx_v_tmpdict);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5433
 *         return transfers
 * 
 *     def get_current_derived_parameters(self, names):             # <<<<<<<<<<<<<<
 *         """
 *         get_current_derived_parameters(names)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_577get_current_derived_parameters(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_576get_current_derived_parameters, "\n        get_current_derived_parameters(names)\n\n        Return a dictionary containing an entry for all the names defined in the\n        input list.\n\n        Parameters\n        ----------\n        names : list\n                Derived parameters that can be asked from Monte Python, or\n                elsewhere.\n\n        Returns\n        -------\n        derived : dict\n\n        .. warning::\n\n            This method used to take as an argument directly the data class from\n            Monte Python. To maintain compatibility with this old feature, a\n            check is performed to verify that names is indeed a list. If not, it\n            returns a TypeError. The old version of this function, when asked\n            with the new argument, will raise an AttributeError.\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_577get_current_derived_parameters = {"get_current_derived_parameters", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_577get_current_derived_parameters, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_576get_current_derived_parameters};
static PyObject *__pyx_pw_9classy_sz_5Class_577get_current_derived_parameters(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_names = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_current_derived_parameters (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_names,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_names)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5433, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_current_derived_parameters") < 0)) __PYX_ERR(0, 5433, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_names = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_current_derived_parameters", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5433, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_current_derived_parameters", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_576get_current_derived_parameters(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_names);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_576get_current_derived_parameters(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_names) {
  PyObject *__pyx_v_derived = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_params_settings = NULL;
  PyObject *__pyx_v_lna = NULL;
  double __pyx_v_eps1;
  double __pyx_v_eps2;
  double __pyx_v_eps23;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  double __pyx_t_9;
  double __pyx_t_10;
  unsigned int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_current_derived_parameters", 1);

  /* "class-sz/python/classy.pyx":5459
 * 
 *         """
 *         if type(names) != type([]):             # <<<<<<<<<<<<<<
 *             raise TypeError("Deprecated")
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(((PyObject *)Py_TYPE(__pyx_v_names)), ((PyObject *)Py_TYPE(__pyx_t_1)), Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5459, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3)) {

    /* "class-sz/python/classy.pyx":5460
 *         """
 *         if type(names) != type([]):
 *             raise TypeError("Deprecated")             # <<<<<<<<<<<<<<
 * 
 *         derived = {}
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5460, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 5460, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5459
 * 
 *         """
 *         if type(names) != type([]):             # <<<<<<<<<<<<<<
 *             raise TypeError("Deprecated")
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5462
 *             raise TypeError("Deprecated")
 * 
 *         derived = {}             # <<<<<<<<<<<<<<
 *         for name in names:
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_derived = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5463
 * 
 *         derived = {}
 *         for name in names:             # <<<<<<<<<<<<<<
 * 
 *             if name == 'h':
 */
  if (likely(PyList_CheckExact(__pyx_v_names)) || PyTuple_CheckExact(__pyx_v_names)) {
    __pyx_t_2 = __pyx_v_names; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_names); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5463, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5463, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5463, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5463, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5463, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5463, __pyx_L1_error)
          #endif
          if (__pyx_t_4 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_1); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 5463, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5463, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5463, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5465
 *         for name in names:
 * 
 *             if name == 'h':             # <<<<<<<<<<<<<<
 *                 value = self.ba.h
 *             elif name == 'H0':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_h, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5465, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5466
 * 
 *             if name == 'h':
 *                 value = self.ba.h             # <<<<<<<<<<<<<<
 *             elif name == 'H0':
 *                 value = self.ba.h*100
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.h); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5465
 *         for name in names:
 * 
 *             if name == 'h':             # <<<<<<<<<<<<<<
 *                 value = self.ba.h
 *             elif name == 'H0':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5467
 *             if name == 'h':
 *                 value = self.ba.h
 *             elif name == 'H0':             # <<<<<<<<<<<<<<
 *                 value = self.ba.h*100
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_H0, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5467, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5468
 *                 value = self.ba.h
 *             elif name == 'H0':
 *                 value = self.ba.h*100             # <<<<<<<<<<<<<<
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':
 *                 value = self.ba.Omega0_lambda
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->ba.h * 100.0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5468, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5467
 *             if name == 'h':
 *                 value = self.ba.h
 *             elif name == 'H0':             # <<<<<<<<<<<<<<
 *                 value = self.ba.h*100
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5469
 *             elif name == 'H0':
 *                 value = self.ba.h*100
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_lambda
 *             elif name == 'Omega0_fld':
 */
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_Omega0_lambda, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 5469, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_3 = __pyx_t_6;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_Omega_Lambda, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 5469, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_6;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5470
 *                 value = self.ba.h*100
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':
 *                 value = self.ba.Omega0_lambda             # <<<<<<<<<<<<<<
 *             elif name == 'Omega0_fld':
 *                 value = self.ba.Omega0_fld
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_lambda); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5469
 *             elif name == 'H0':
 *                 value = self.ba.h*100
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_lambda
 *             elif name == 'Omega0_fld':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5471
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':
 *                 value = self.ba.Omega0_lambda
 *             elif name == 'Omega0_fld':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_fld
 *             elif name == 'age':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_Omega0_fld, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5471, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5472
 *                 value = self.ba.Omega0_lambda
 *             elif name == 'Omega0_fld':
 *                 value = self.ba.Omega0_fld             # <<<<<<<<<<<<<<
 *             elif name == 'age':
 *                 value = self.ba.age
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_fld); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5472, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5471
 *             elif name == 'Omega0_lambda' or name == 'Omega_Lambda':
 *                 value = self.ba.Omega0_lambda
 *             elif name == 'Omega0_fld':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_fld
 *             elif name == 'age':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5473
 *             elif name == 'Omega0_fld':
 *                 value = self.ba.Omega0_fld
 *             elif name == 'age':             # <<<<<<<<<<<<<<
 *                 value = self.ba.age
 *             elif name == 'conformal_age':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_age, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5473, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5474
 *                 value = self.ba.Omega0_fld
 *             elif name == 'age':
 *                 value = self.ba.age             # <<<<<<<<<<<<<<
 *             elif name == 'conformal_age':
 *                 value = self.ba.conformal_age
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.age); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5474, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5473
 *             elif name == 'Omega0_fld':
 *                 value = self.ba.Omega0_fld
 *             elif name == 'age':             # <<<<<<<<<<<<<<
 *                 value = self.ba.age
 *             elif name == 'conformal_age':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5475
 *             elif name == 'age':
 *                 value = self.ba.age
 *             elif name == 'conformal_age':             # <<<<<<<<<<<<<<
 *                 value = self.ba.conformal_age
 * 
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_conformal_age, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5475, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5476
 *                 value = self.ba.age
 *             elif name == 'conformal_age':
 *                 value = self.ba.conformal_age             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.conformal_age); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5475
 *             elif name == 'age':
 *                 value = self.ba.age
 *             elif name == 'conformal_age':             # <<<<<<<<<<<<<<
 *                 value = self.ba.conformal_age
 * 
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5479
 * 
 * 
 *             elif name == 'm_ncdm_in_eV':             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_m_ncdm_in_eV, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5479, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5482
 * 
 * 
 *                 if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *                     value =  self._pars['m_ncdm']
 */
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_skip_background_and_thermo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5482, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5484
 *                 if self._pars['skip_background_and_thermo']:
 * 
 *                     value =  self._pars['m_ncdm']             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
        __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_m_ncdm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "class-sz/python/classy.pyx":5482
 * 
 * 
 *                 if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *                     value =  self._pars['m_ncdm']
 */
        goto __pyx_L9;
      }

      /* "class-sz/python/classy.pyx":5488
 *                 else:
 * 
 *                     value = self.ba.m_ncdm_in_eV[0]             # <<<<<<<<<<<<<<
 * 
 *             elif name == 'm_ncdm_tot':
 */
      /*else*/ {
        __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->ba.m_ncdm_in_eV[0])); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5488, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;
      }
      __pyx_L9:;

      /* "class-sz/python/classy.pyx":5479
 * 
 * 
 *             elif name == 'm_ncdm_in_eV':             # <<<<<<<<<<<<<<
 * 
 * 
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5490
 *                     value = self.ba.m_ncdm_in_eV[0]
 * 
 *             elif name == 'm_ncdm_tot':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_ncdm_tot*self.ba.h*self.ba.h*93.14
 * 
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_m_ncdm_tot, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5490, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5491
 * 
 *             elif name == 'm_ncdm_tot':
 *                 value = self.ba.Omega0_ncdm_tot*self.ba.h*self.ba.h*93.14             # <<<<<<<<<<<<<<
 * 
 *             elif name == 'Neff':
 */
      __pyx_t_1 = PyFloat_FromDouble((((__pyx_v_self->ba.Omega0_ncdm_tot * __pyx_v_self->ba.h) * __pyx_v_self->ba.h) * 93.14)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5490
 *                     value = self.ba.m_ncdm_in_eV[0]
 * 
 *             elif name == 'm_ncdm_tot':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_ncdm_tot*self.ba.h*self.ba.h*93.14
 * 
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5493
 *                 value = self.ba.Omega0_ncdm_tot*self.ba.h*self.ba.h*93.14
 * 
 *             elif name == 'Neff':             # <<<<<<<<<<<<<<
 * 
 *                 value = self.ba.Neff
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_Neff, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5493, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5495
 *             elif name == 'Neff':
 * 
 *                 value = self.ba.Neff             # <<<<<<<<<<<<<<
 * 
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Neff); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5495, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5497
 *                 value = self.ba.Neff
 * 
 *                 if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *                   value = self.Neff_fast
 */
      __pyx_t_3 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5499
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 * 
 *                   value = self.Neff_fast             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
        __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->Neff_fast); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5499, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "class-sz/python/classy.pyx":5497
 *                 value = self.ba.Neff
 * 
 *                 if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *                   value = self.Neff_fast
 */
        goto __pyx_L10;
      }

      /* "class-sz/python/classy.pyx":5503
 *                 else:
 * 
 *                   value = self.ba.Neff             # <<<<<<<<<<<<<<
 * 
 *             elif name == 'Omega_m':
 */
      /*else*/ {
        __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Neff); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5503, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;
      }
      __pyx_L10:;

      /* "class-sz/python/classy.pyx":5493
 *                 value = self.ba.Omega0_ncdm_tot*self.ba.h*self.ba.h*93.14
 * 
 *             elif name == 'Neff':             # <<<<<<<<<<<<<<
 * 
 *                 value = self.ba.Neff
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5505
 *                   value = self.ba.Neff
 * 
 *             elif name == 'Omega_m':             # <<<<<<<<<<<<<<
 * 
 *                 if self._pars['skip_background_and_thermo']:
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_Omega_m, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5505, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5507
 *             elif name == 'Omega_m':
 * 
 *                 if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *                   params_settings = self._pars
 */
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_skip_background_and_thermo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5507, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5507, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5509
 *                 if self._pars['skip_background_and_thermo']:
 * 
 *                   params_settings = self._pars             # <<<<<<<<<<<<<<
 *                   value = (params_settings['omega_b']+params_settings['omega_cdm'])*(100./params_settings['H0'])**2.
 * 
 */
        __pyx_t_1 = __pyx_v_self->_pars;
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_params_settings, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "class-sz/python/classy.pyx":5510
 * 
 *                   params_settings = self._pars
 *                   value = (params_settings['omega_b']+params_settings['omega_cdm'])*(100./params_settings['H0'])**2.             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
        __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_params_settings, __pyx_n_u_omega_b); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_params_settings, __pyx_n_u_omega_cdm); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = PyNumber_Add(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_params_settings, __pyx_n_u_H0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_1 = __Pyx_PyFloat_TrueDivideCObj(__pyx_float_100_, __pyx_t_7, 100., 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyNumber_Power(__pyx_t_1, __pyx_float_2_, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyNumber_Multiply(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "class-sz/python/classy.pyx":5507
 *             elif name == 'Omega_m':
 * 
 *                 if self._pars['skip_background_and_thermo']:             # <<<<<<<<<<<<<<
 * 
 *                   params_settings = self._pars
 */
        goto __pyx_L11;
      }

      /* "class-sz/python/classy.pyx":5514
 *                 else:
 * 
 *                   value = self.ba.Omega0_m             # <<<<<<<<<<<<<<
 * 
 * 
 */
      /*else*/ {
        __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_m); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5514, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
        __pyx_t_1 = 0;
      }
      __pyx_L11:;

      /* "class-sz/python/classy.pyx":5505
 *                   value = self.ba.Neff
 * 
 *             elif name == 'Omega_m':             # <<<<<<<<<<<<<<
 * 
 *                 if self._pars['skip_background_and_thermo']:
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5517
 * 
 * 
 *             elif name == 'omega_mh2':             # <<<<<<<<<<<<<<
 * 
 *                 value = self.ba.Omega0_m*self.ba.h**2
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_omega_mh2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5517, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5519
 *             elif name == 'omega_mh2':
 * 
 *                 value = self.ba.Omega0_m*self.ba.h**2             # <<<<<<<<<<<<<<
 * 
 *             elif name == 'xi_idr':
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->ba.Omega0_m * pow(__pyx_v_self->ba.h, 2.0))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5519, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5517
 * 
 * 
 *             elif name == 'omega_mh2':             # <<<<<<<<<<<<<<
 * 
 *                 value = self.ba.Omega0_m*self.ba.h**2
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5521
 *                 value = self.ba.Omega0_m*self.ba.h**2
 * 
 *             elif name == 'xi_idr':             # <<<<<<<<<<<<<<
 *                 value = self.ba.T_idr/self.ba.T_cmb
 *             elif name == 'N_dg':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_xi_idr, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5521, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5522
 * 
 *             elif name == 'xi_idr':
 *                 value = self.ba.T_idr/self.ba.T_cmb             # <<<<<<<<<<<<<<
 *             elif name == 'N_dg':
 *                 value = self.ba.Omega0_idr/self.ba.Omega0_g*8./7.*pow(11./4.,4./3.)
 */
      if (unlikely(__pyx_v_self->ba.T_cmb == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5522, __pyx_L1_error)
      }
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->ba.T_idr / __pyx_v_self->ba.T_cmb)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5522, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5521
 *                 value = self.ba.Omega0_m*self.ba.h**2
 * 
 *             elif name == 'xi_idr':             # <<<<<<<<<<<<<<
 *                 value = self.ba.T_idr/self.ba.T_cmb
 *             elif name == 'N_dg':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5523
 *             elif name == 'xi_idr':
 *                 value = self.ba.T_idr/self.ba.T_cmb
 *             elif name == 'N_dg':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_idr/self.ba.Omega0_g*8./7.*pow(11./4.,4./3.)
 *             elif name == 'Gamma_0_nadm':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_N_dg, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5523, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5524
 *                 value = self.ba.T_idr/self.ba.T_cmb
 *             elif name == 'N_dg':
 *                 value = self.ba.Omega0_idr/self.ba.Omega0_g*8./7.*pow(11./4.,4./3.)             # <<<<<<<<<<<<<<
 *             elif name == 'Gamma_0_nadm':
 *                 value = self.th.a_idm_dr*(4./3.)*(self.ba.h*self.ba.h*self.ba.Omega0_idr)
 */
      if (unlikely(__pyx_v_self->ba.Omega0_g == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5524, __pyx_L1_error)
      }
      __pyx_t_1 = PyFloat_FromDouble(((((__pyx_v_self->ba.Omega0_idr / __pyx_v_self->ba.Omega0_g) * 8.) / 7.) * pow((11. / 4.), (4. / 3.)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5524, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5523
 *             elif name == 'xi_idr':
 *                 value = self.ba.T_idr/self.ba.T_cmb
 *             elif name == 'N_dg':             # <<<<<<<<<<<<<<
 *                 value = self.ba.Omega0_idr/self.ba.Omega0_g*8./7.*pow(11./4.,4./3.)
 *             elif name == 'Gamma_0_nadm':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5525
 *             elif name == 'N_dg':
 *                 value = self.ba.Omega0_idr/self.ba.Omega0_g*8./7.*pow(11./4.,4./3.)
 *             elif name == 'Gamma_0_nadm':             # <<<<<<<<<<<<<<
 *                 value = self.th.a_idm_dr*(4./3.)*(self.ba.h*self.ba.h*self.ba.Omega0_idr)
 *             elif name == 'a_dark':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_Gamma_0_nadm, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5525, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5526
 *                 value = self.ba.Omega0_idr/self.ba.Omega0_g*8./7.*pow(11./4.,4./3.)
 *             elif name == 'Gamma_0_nadm':
 *                 value = self.th.a_idm_dr*(4./3.)*(self.ba.h*self.ba.h*self.ba.Omega0_idr)             # <<<<<<<<<<<<<<
 *             elif name == 'a_dark':
 *                 value = self.th.a_idm_dr
 */
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->th.a_idm_dr * (4. / 3.)) * ((__pyx_v_self->ba.h * __pyx_v_self->ba.h) * __pyx_v_self->ba.Omega0_idr))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5526, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5525
 *             elif name == 'N_dg':
 *                 value = self.ba.Omega0_idr/self.ba.Omega0_g*8./7.*pow(11./4.,4./3.)
 *             elif name == 'Gamma_0_nadm':             # <<<<<<<<<<<<<<
 *                 value = self.th.a_idm_dr*(4./3.)*(self.ba.h*self.ba.h*self.ba.Omega0_idr)
 *             elif name == 'a_dark':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5527
 *             elif name == 'Gamma_0_nadm':
 *                 value = self.th.a_idm_dr*(4./3.)*(self.ba.h*self.ba.h*self.ba.Omega0_idr)
 *             elif name == 'a_dark':             # <<<<<<<<<<<<<<
 *                 value = self.th.a_idm_dr
 *             elif name == 'tau_reio':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_a_dark, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5527, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5528
 *                 value = self.th.a_idm_dr*(4./3.)*(self.ba.h*self.ba.h*self.ba.Omega0_idr)
 *             elif name == 'a_dark':
 *                 value = self.th.a_idm_dr             # <<<<<<<<<<<<<<
 *             elif name == 'tau_reio':
 *                 value = self.th.tau_reio
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.a_idm_dr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5527
 *             elif name == 'Gamma_0_nadm':
 *                 value = self.th.a_idm_dr*(4./3.)*(self.ba.h*self.ba.h*self.ba.Omega0_idr)
 *             elif name == 'a_dark':             # <<<<<<<<<<<<<<
 *                 value = self.th.a_idm_dr
 *             elif name == 'tau_reio':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5529
 *             elif name == 'a_dark':
 *                 value = self.th.a_idm_dr
 *             elif name == 'tau_reio':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_reio
 *             elif name == 'z_reio':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_tau_reio, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5529, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5530
 *                 value = self.th.a_idm_dr
 *             elif name == 'tau_reio':
 *                 value = self.th.tau_reio             # <<<<<<<<<<<<<<
 *             elif name == 'z_reio':
 *                 value = self.th.z_reio
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.tau_reio); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5529
 *             elif name == 'a_dark':
 *                 value = self.th.a_idm_dr
 *             elif name == 'tau_reio':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_reio
 *             elif name == 'z_reio':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5531
 *             elif name == 'tau_reio':
 *                 value = self.th.tau_reio
 *             elif name == 'z_reio':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_reio
 *             elif name == 'z_rec':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_z_reio, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5531, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5532
 *                 value = self.th.tau_reio
 *             elif name == 'z_reio':
 *                 value = self.th.z_reio             # <<<<<<<<<<<<<<
 *             elif name == 'z_rec':
 *                 value = self.th.z_rec
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.z_reio); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5531
 *             elif name == 'tau_reio':
 *                 value = self.th.tau_reio
 *             elif name == 'z_reio':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_reio
 *             elif name == 'z_rec':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5533
 *             elif name == 'z_reio':
 *                 value = self.th.z_reio
 *             elif name == 'z_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_rec
 *             elif name == 'tau_rec':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_z_rec, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5533, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5534
 *                 value = self.th.z_reio
 *             elif name == 'z_rec':
 *                 value = self.th.z_rec             # <<<<<<<<<<<<<<
 *             elif name == 'tau_rec':
 *                 value = self.th.tau_rec
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.z_rec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5533
 *             elif name == 'z_reio':
 *                 value = self.th.z_reio
 *             elif name == 'z_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_rec
 *             elif name == 'tau_rec':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5535
 *             elif name == 'z_rec':
 *                 value = self.th.z_rec
 *             elif name == 'tau_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_rec
 *             elif name == 'rs_rec':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_tau_rec, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5535, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5536
 *                 value = self.th.z_rec
 *             elif name == 'tau_rec':
 *                 value = self.th.tau_rec             # <<<<<<<<<<<<<<
 *             elif name == 'rs_rec':
 *                 value = self.th.rs_rec
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.tau_rec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5535
 *             elif name == 'z_rec':
 *                 value = self.th.z_rec
 *             elif name == 'tau_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_rec
 *             elif name == 'rs_rec':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5537
 *             elif name == 'tau_rec':
 *                 value = self.th.tau_rec
 *             elif name == 'rs_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_rec
 *             elif name == 'rs_rec_h':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_rs_rec, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5537, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5538
 *                 value = self.th.tau_rec
 *             elif name == 'rs_rec':
 *                 value = self.th.rs_rec             # <<<<<<<<<<<<<<
 *             elif name == 'rs_rec_h':
 *                 value = self.th.rs_rec*self.ba.h
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.rs_rec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5538, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5537
 *             elif name == 'tau_rec':
 *                 value = self.th.tau_rec
 *             elif name == 'rs_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_rec
 *             elif name == 'rs_rec_h':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5539
 *             elif name == 'rs_rec':
 *                 value = self.th.rs_rec
 *             elif name == 'rs_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_rec*self.ba.h
 *             elif name == 'ds_rec':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_rs_rec_h, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5539, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5540
 *                 value = self.th.rs_rec
 *             elif name == 'rs_rec_h':
 *                 value = self.th.rs_rec*self.ba.h             # <<<<<<<<<<<<<<
 *             elif name == 'ds_rec':
 *                 value = self.th.ds_rec
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->th.rs_rec * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5539
 *             elif name == 'rs_rec':
 *                 value = self.th.rs_rec
 *             elif name == 'rs_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_rec*self.ba.h
 *             elif name == 'ds_rec':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5541
 *             elif name == 'rs_rec_h':
 *                 value = self.th.rs_rec*self.ba.h
 *             elif name == 'ds_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_rec
 *             elif name == 'ds_rec_h':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ds_rec, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5541, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5542
 *                 value = self.th.rs_rec*self.ba.h
 *             elif name == 'ds_rec':
 *                 value = self.th.ds_rec             # <<<<<<<<<<<<<<
 *             elif name == 'ds_rec_h':
 *                 value = self.th.ds_rec*self.ba.h
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.ds_rec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5542, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5541
 *             elif name == 'rs_rec_h':
 *                 value = self.th.rs_rec*self.ba.h
 *             elif name == 'ds_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_rec
 *             elif name == 'ds_rec_h':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5543
 *             elif name == 'ds_rec':
 *                 value = self.th.ds_rec
 *             elif name == 'ds_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_rec*self.ba.h
 *             elif name == 'ra_rec':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ds_rec_h, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5543, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5544
 *                 value = self.th.ds_rec
 *             elif name == 'ds_rec_h':
 *                 value = self.th.ds_rec*self.ba.h             # <<<<<<<<<<<<<<
 *             elif name == 'ra_rec':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->th.ds_rec * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5544, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5543
 *             elif name == 'ds_rec':
 *                 value = self.th.ds_rec
 *             elif name == 'ds_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_rec*self.ba.h
 *             elif name == 'ra_rec':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5545
 *             elif name == 'ds_rec_h':
 *                 value = self.th.ds_rec*self.ba.h
 *             elif name == 'ra_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec*(1.+self.th.z_rec)
 *             elif name == 'ra_rec_h':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ra_rec, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5545, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5546
 *                 value = self.th.ds_rec*self.ba.h
 *             elif name == 'ra_rec':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)             # <<<<<<<<<<<<<<
 *             elif name == 'ra_rec_h':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)*self.ba.h
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->th.da_rec * (1. + __pyx_v_self->th.z_rec))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5546, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5545
 *             elif name == 'ds_rec_h':
 *                 value = self.th.ds_rec*self.ba.h
 *             elif name == 'ra_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec*(1.+self.th.z_rec)
 *             elif name == 'ra_rec_h':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5547
 *             elif name == 'ra_rec':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)
 *             elif name == 'ra_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec*(1.+self.th.z_rec)*self.ba.h
 *             elif name == 'da_rec':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ra_rec_h, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5547, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5548
 *                 value = self.th.da_rec*(1.+self.th.z_rec)
 *             elif name == 'ra_rec_h':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)*self.ba.h             # <<<<<<<<<<<<<<
 *             elif name == 'da_rec':
 *                 value = self.th.da_rec
 */
      __pyx_t_1 = PyFloat_FromDouble(((__pyx_v_self->th.da_rec * (1. + __pyx_v_self->th.z_rec)) * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5547
 *             elif name == 'ra_rec':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)
 *             elif name == 'ra_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec*(1.+self.th.z_rec)*self.ba.h
 *             elif name == 'da_rec':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5549
 *             elif name == 'ra_rec_h':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)*self.ba.h
 *             elif name == 'da_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec
 *             elif name == 'da_rec_h':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_da_rec, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5549, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5550
 *                 value = self.th.da_rec*(1.+self.th.z_rec)*self.ba.h
 *             elif name == 'da_rec':
 *                 value = self.th.da_rec             # <<<<<<<<<<<<<<
 *             elif name == 'da_rec_h':
 *                 value = self.th.da_rec*self.ba.h
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.da_rec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5550, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5549
 *             elif name == 'ra_rec_h':
 *                 value = self.th.da_rec*(1.+self.th.z_rec)*self.ba.h
 *             elif name == 'da_rec':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec
 *             elif name == 'da_rec_h':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5551
 *             elif name == 'da_rec':
 *                 value = self.th.da_rec
 *             elif name == 'da_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec*self.ba.h
 *             elif name == 'z_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_da_rec_h, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5551, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5552
 *                 value = self.th.da_rec
 *             elif name == 'da_rec_h':
 *                 value = self.th.da_rec*self.ba.h             # <<<<<<<<<<<<<<
 *             elif name == 'z_star':
 *                 value = self.th.z_star
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->th.da_rec * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5551
 *             elif name == 'da_rec':
 *                 value = self.th.da_rec
 *             elif name == 'da_rec_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_rec*self.ba.h
 *             elif name == 'z_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5553
 *             elif name == 'da_rec_h':
 *                 value = self.th.da_rec*self.ba.h
 *             elif name == 'z_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_star
 *             elif name == 'tau_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_z_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5553, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5554
 *                 value = self.th.da_rec*self.ba.h
 *             elif name == 'z_star':
 *                 value = self.th.z_star             # <<<<<<<<<<<<<<
 *             elif name == 'tau_star':
 *                 value = self.th.tau_star
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.z_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5553
 *             elif name == 'da_rec_h':
 *                 value = self.th.da_rec*self.ba.h
 *             elif name == 'z_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_star
 *             elif name == 'tau_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5555
 *             elif name == 'z_star':
 *                 value = self.th.z_star
 *             elif name == 'tau_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_star
 *             elif name == 'rs_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_tau_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5555, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5556
 *                 value = self.th.z_star
 *             elif name == 'tau_star':
 *                 value = self.th.tau_star             # <<<<<<<<<<<<<<
 *             elif name == 'rs_star':
 *                 value = self.th.rs_star
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.tau_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5555
 *             elif name == 'z_star':
 *                 value = self.th.z_star
 *             elif name == 'tau_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_star
 *             elif name == 'rs_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5557
 *             elif name == 'tau_star':
 *                 value = self.th.tau_star
 *             elif name == 'rs_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_star
 *             elif name == 'ds_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_rs_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5557, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5558
 *                 value = self.th.tau_star
 *             elif name == 'rs_star':
 *                 value = self.th.rs_star             # <<<<<<<<<<<<<<
 *             elif name == 'ds_star':
 *                 value = self.th.ds_star
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.rs_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5558, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5557
 *             elif name == 'tau_star':
 *                 value = self.th.tau_star
 *             elif name == 'rs_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_star
 *             elif name == 'ds_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5559
 *             elif name == 'rs_star':
 *                 value = self.th.rs_star
 *             elif name == 'ds_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_star
 *             elif name == 'ra_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ds_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5559, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5560
 *                 value = self.th.rs_star
 *             elif name == 'ds_star':
 *                 value = self.th.ds_star             # <<<<<<<<<<<<<<
 *             elif name == 'ra_star':
 *                 value = self.th.ra_star
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.ds_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5559
 *             elif name == 'rs_star':
 *                 value = self.th.rs_star
 *             elif name == 'ds_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_star
 *             elif name == 'ra_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5561
 *             elif name == 'ds_star':
 *                 value = self.th.ds_star
 *             elif name == 'ra_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.ra_star
 *             elif name == 'da_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ra_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5561, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5562
 *                 value = self.th.ds_star
 *             elif name == 'ra_star':
 *                 value = self.th.ra_star             # <<<<<<<<<<<<<<
 *             elif name == 'da_star':
 *                 value = self.th.da_star
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.ra_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5561
 *             elif name == 'ds_star':
 *                 value = self.th.ds_star
 *             elif name == 'ra_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.ra_star
 *             elif name == 'da_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5563
 *             elif name == 'ra_star':
 *                 value = self.th.ra_star
 *             elif name == 'da_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_star
 *             elif name == 'rd_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_da_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5563, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5564
 *                 value = self.th.ra_star
 *             elif name == 'da_star':
 *                 value = self.th.da_star             # <<<<<<<<<<<<<<
 *             elif name == 'rd_star':
 *                 value = self.th.rd_star
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.da_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5564, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5563
 *             elif name == 'ra_star':
 *                 value = self.th.ra_star
 *             elif name == 'da_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.da_star
 *             elif name == 'rd_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5565
 *             elif name == 'da_star':
 *                 value = self.th.da_star
 *             elif name == 'rd_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.rd_star
 *             elif name == 'z_d':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_rd_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5565, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5566
 *                 value = self.th.da_star
 *             elif name == 'rd_star':
 *                 value = self.th.rd_star             # <<<<<<<<<<<<<<
 *             elif name == 'z_d':
 *                 value = self.th.z_d
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.rd_star); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5566, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5565
 *             elif name == 'da_star':
 *                 value = self.th.da_star
 *             elif name == 'rd_star':             # <<<<<<<<<<<<<<
 *                 value = self.th.rd_star
 *             elif name == 'z_d':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5567
 *             elif name == 'rd_star':
 *                 value = self.th.rd_star
 *             elif name == 'z_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_d
 *             elif name == 'tau_d':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_z_d, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5567, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5568
 *                 value = self.th.rd_star
 *             elif name == 'z_d':
 *                 value = self.th.z_d             # <<<<<<<<<<<<<<
 *             elif name == 'tau_d':
 *                 value = self.th.tau_d
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.z_d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5567
 *             elif name == 'rd_star':
 *                 value = self.th.rd_star
 *             elif name == 'z_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.z_d
 *             elif name == 'tau_d':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5569
 *             elif name == 'z_d':
 *                 value = self.th.z_d
 *             elif name == 'tau_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_d
 *             elif name == 'ds_d':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_tau_d, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5569, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5570
 *                 value = self.th.z_d
 *             elif name == 'tau_d':
 *                 value = self.th.tau_d             # <<<<<<<<<<<<<<
 *             elif name == 'ds_d':
 *                 value = self.th.ds_d
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.tau_d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5569
 *             elif name == 'z_d':
 *                 value = self.th.z_d
 *             elif name == 'tau_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.tau_d
 *             elif name == 'ds_d':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5571
 *             elif name == 'tau_d':
 *                 value = self.th.tau_d
 *             elif name == 'ds_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_d
 *             elif name == 'ds_d_h':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ds_d, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5571, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5572
 *                 value = self.th.tau_d
 *             elif name == 'ds_d':
 *                 value = self.th.ds_d             # <<<<<<<<<<<<<<
 *             elif name == 'ds_d_h':
 *                 value = self.th.ds_d*self.ba.h
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.ds_d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5571
 *             elif name == 'tau_d':
 *                 value = self.th.tau_d
 *             elif name == 'ds_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_d
 *             elif name == 'ds_d_h':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5573
 *             elif name == 'ds_d':
 *                 value = self.th.ds_d
 *             elif name == 'ds_d_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_d*self.ba.h
 *             elif name == 'rs_d':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_ds_d_h, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5573, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5574
 *                 value = self.th.ds_d
 *             elif name == 'ds_d_h':
 *                 value = self.th.ds_d*self.ba.h             # <<<<<<<<<<<<<<
 *             elif name == 'rs_d':
 *                 value = self.th.rs_d
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->th.ds_d * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5574, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5573
 *             elif name == 'ds_d':
 *                 value = self.th.ds_d
 *             elif name == 'ds_d_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.ds_d*self.ba.h
 *             elif name == 'rs_d':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5575
 *             elif name == 'ds_d_h':
 *                 value = self.th.ds_d*self.ba.h
 *             elif name == 'rs_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_d
 *             elif name == 'rs_d_h':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_rs_d, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5575, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5576
 *                 value = self.th.ds_d*self.ba.h
 *             elif name == 'rs_d':
 *                 value = self.th.rs_d             # <<<<<<<<<<<<<<
 *             elif name == 'rs_d_h':
 *                 value = self.th.rs_d*self.ba.h
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.rs_d); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5575
 *             elif name == 'ds_d_h':
 *                 value = self.th.ds_d*self.ba.h
 *             elif name == 'rs_d':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_d
 *             elif name == 'rs_d_h':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5577
 *             elif name == 'rs_d':
 *                 value = self.th.rs_d
 *             elif name == 'rs_d_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_d*self.ba.h
 *             elif name == '100*theta_s':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_rs_d_h, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5577, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5578
 *                 value = self.th.rs_d
 *             elif name == 'rs_d_h':
 *                 value = self.th.rs_d*self.ba.h             # <<<<<<<<<<<<<<
 *             elif name == '100*theta_s':
 *                 value = 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 */
      __pyx_t_1 = PyFloat_FromDouble((__pyx_v_self->th.rs_d * __pyx_v_self->ba.h)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5578, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5577
 *             elif name == 'rs_d':
 *                 value = self.th.rs_d
 *             elif name == 'rs_d_h':             # <<<<<<<<<<<<<<
 *                 value = self.th.rs_d*self.ba.h
 *             elif name == '100*theta_s':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5579
 *             elif name == 'rs_d_h':
 *                 value = self.th.rs_d*self.ba.h
 *             elif name == '100*theta_s':             # <<<<<<<<<<<<<<
 *                 value = 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 *             elif name == '100*theta_star':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_kp_u_100_theta_s, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5579, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5580
 *                 value = self.th.rs_d*self.ba.h
 *             elif name == '100*theta_s':
 *                 value = 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)             # <<<<<<<<<<<<<<
 *             elif name == '100*theta_star':
 *                 value = 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 */
      __pyx_t_9 = (100. * __pyx_v_self->th.rs_rec);
      if (unlikely(__pyx_v_self->th.da_rec == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5580, __pyx_L1_error)
      }
      __pyx_t_10 = (__pyx_t_9 / __pyx_v_self->th.da_rec);
      __pyx_t_9 = (1. + __pyx_v_self->th.z_rec);
      if (unlikely(__pyx_t_9 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5580, __pyx_L1_error)
      }
      __pyx_t_1 = PyFloat_FromDouble((__pyx_t_10 / __pyx_t_9)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5579
 *             elif name == 'rs_d_h':
 *                 value = self.th.rs_d*self.ba.h
 *             elif name == '100*theta_s':             # <<<<<<<<<<<<<<
 *                 value = 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 *             elif name == '100*theta_star':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5581
 *             elif name == '100*theta_s':
 *                 value = 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 *             elif name == '100*theta_star':             # <<<<<<<<<<<<<<
 *                 value = 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 *             elif name == 'YHe':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_kp_u_100_theta_star, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5581, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5582
 *                 value = 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 *             elif name == '100*theta_star':
 *                 value = 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)             # <<<<<<<<<<<<<<
 *             elif name == 'YHe':
 *                 value = self.th.YHe
 */
      __pyx_t_9 = (100. * __pyx_v_self->th.rs_star);
      if (unlikely(__pyx_v_self->th.da_star == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5582, __pyx_L1_error)
      }
      __pyx_t_10 = (__pyx_t_9 / __pyx_v_self->th.da_star);
      __pyx_t_9 = (1. + __pyx_v_self->th.z_star);
      if (unlikely(__pyx_t_9 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5582, __pyx_L1_error)
      }
      __pyx_t_1 = PyFloat_FromDouble((__pyx_t_10 / __pyx_t_9)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5582, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5581
 *             elif name == '100*theta_s':
 *                 value = 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 *             elif name == '100*theta_star':             # <<<<<<<<<<<<<<
 *                 value = 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 *             elif name == 'YHe':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5583
 *             elif name == '100*theta_star':
 *                 value = 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 *             elif name == 'YHe':             # <<<<<<<<<<<<<<
 *                 value = self.th.YHe
 *             elif name == 'n_e':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_YHe, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5583, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5584
 *                 value = 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 *             elif name == 'YHe':
 *                 value = self.th.YHe             # <<<<<<<<<<<<<<
 *             elif name == 'n_e':
 *                 value = self.th.n_e
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.YHe); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5583
 *             elif name == '100*theta_star':
 *                 value = 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 *             elif name == 'YHe':             # <<<<<<<<<<<<<<
 *                 value = self.th.YHe
 *             elif name == 'n_e':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5585
 *             elif name == 'YHe':
 *                 value = self.th.YHe
 *             elif name == 'n_e':             # <<<<<<<<<<<<<<
 *                 value = self.th.n_e
 * 
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_n_e, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5585, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5586
 *                 value = self.th.YHe
 *             elif name == 'n_e':
 *                 value = self.th.n_e             # <<<<<<<<<<<<<<
 * 
 *             elif name == 'A_s':
 */
      __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->th.n_e); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5586, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "class-sz/python/classy.pyx":5585
 *             elif name == 'YHe':
 *                 value = self.th.YHe
 *             elif name == 'n_e':             # <<<<<<<<<<<<<<
 *                 value = self.th.n_e
 * 
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5588
 *                 value = self.th.n_e
 * 
 *             elif name == 'A_s':             # <<<<<<<<<<<<<<
 * 
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_A_s, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5588, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5590
 *             elif name == 'A_s':
 * 
 *                 if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *                     # print('self._pars:',self._pars)
 */
      __pyx_t_3 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5594
 *                     # print('self._pars:',self._pars)
 * 
 *                     if ('logA' in self._pars) or ('ln10^{10}A_s' in self._pars):             # <<<<<<<<<<<<<<
 * 
 *                         if 'ln10^{10}A_s' in self._pars:
 */
        __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_logA, __pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 5594, __pyx_L1_error)
        if (!__pyx_t_6) {
        } else {
          __pyx_t_3 = __pyx_t_6;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_ln10_10_A_s, __pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 5594, __pyx_L1_error)
        __pyx_t_3 = __pyx_t_6;
        __pyx_L14_bool_binop_done:;
        if (__pyx_t_3) {

          /* "class-sz/python/classy.pyx":5596
 *                     if ('logA' in self._pars) or ('ln10^{10}A_s' in self._pars):
 * 
 *                         if 'ln10^{10}A_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *                             lna = self._pars['ln10^{10}A_s']
 */
          __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_ln10_10_A_s, __pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5596, __pyx_L1_error)
          if (__pyx_t_3) {

            /* "class-sz/python/classy.pyx":5598
 *                         if 'ln10^{10}A_s' in self._pars:
 * 
 *                             lna = self._pars['ln10^{10}A_s']             # <<<<<<<<<<<<<<
 * 
 *                         else:
 */
            __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_kp_u_ln10_10_A_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5598, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_XDECREF_SET(__pyx_v_lna, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "class-sz/python/classy.pyx":5596
 *                     if ('logA' in self._pars) or ('ln10^{10}A_s' in self._pars):
 * 
 *                         if 'ln10^{10}A_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *                             lna = self._pars['ln10^{10}A_s']
 */
            goto __pyx_L16;
          }

          /* "class-sz/python/classy.pyx":5602
 *                         else:
 * 
 *                             lna = self._pars['logA']             # <<<<<<<<<<<<<<
 * 
 *                         value = 1e-10*np.exp(lna)
 */
          /*else*/ {
            __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_logA); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5602, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_XDECREF_SET(__pyx_v_lna, __pyx_t_1);
            __pyx_t_1 = 0;
          }
          __pyx_L16:;

          /* "class-sz/python/classy.pyx":5604
 *                             lna = self._pars['logA']
 * 
 *                         value = 1e-10*np.exp(lna)             # <<<<<<<<<<<<<<
 * 
 *                     else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_exp); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          __pyx_t_11 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_11 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_lna};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5604, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_t_8 = PyNumber_Multiply(__pyx_float_1eneg_10, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "class-sz/python/classy.pyx":5594
 *                     # print('self._pars:',self._pars)
 * 
 *                     if ('logA' in self._pars) or ('ln10^{10}A_s' in self._pars):             # <<<<<<<<<<<<<<
 * 
 *                         if 'ln10^{10}A_s' in self._pars:
 */
          goto __pyx_L13;
        }

        /* "class-sz/python/classy.pyx":5608
 *                     else:
 * 
 *                         value = self.A_s_fast             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
        /*else*/ {
          __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->A_s_fast); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5608, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
          __pyx_t_8 = 0;
        }
        __pyx_L13:;

        /* "class-sz/python/classy.pyx":5590
 *             elif name == 'A_s':
 * 
 *                 if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *                     # print('self._pars:',self._pars)
 */
        goto __pyx_L12;
      }

      /* "class-sz/python/classy.pyx":5612
 *                 else:
 * 
 *                   value = self.pm.A_s             # <<<<<<<<<<<<<<
 * 
 *             elif name == 'ln10^{10}A_s' or name == 'logA':
 */
      /*else*/ {
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.A_s); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5612, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;
      }
      __pyx_L12:;

      /* "class-sz/python/classy.pyx":5588
 *                 value = self.th.n_e
 * 
 *             elif name == 'A_s':             # <<<<<<<<<<<<<<
 * 
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5614
 *                   value = self.pm.A_s
 * 
 *             elif name == 'ln10^{10}A_s' or name == 'logA':             # <<<<<<<<<<<<<<
 * 
 *                 if 'ln10^{10}A_s' in self._pars:
 */
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_kp_u_ln10_10_A_s, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 5614, __pyx_L1_error)
    if (!__pyx_t_6) {
    } else {
      __pyx_t_3 = __pyx_t_6;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_logA, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 5614, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_6;
    __pyx_L17_bool_binop_done:;
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5616
 *             elif name == 'ln10^{10}A_s' or name == 'logA':
 * 
 *                 if 'ln10^{10}A_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *                     value = self._pars['ln10^{10}A_s']
 */
      __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u_ln10_10_A_s, __pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5616, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5618
 *                 if 'ln10^{10}A_s' in self._pars:
 * 
 *                     value = self._pars['ln10^{10}A_s']             # <<<<<<<<<<<<<<
 * 
 *                 elif 'logA' in self._pars:
 */
        __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_kp_u_ln10_10_A_s); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5618, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "class-sz/python/classy.pyx":5616
 *             elif name == 'ln10^{10}A_s' or name == 'logA':
 * 
 *                 if 'ln10^{10}A_s' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *                     value = self._pars['ln10^{10}A_s']
 */
        goto __pyx_L19;
      }

      /* "class-sz/python/classy.pyx":5620
 *                     value = self._pars['ln10^{10}A_s']
 * 
 *                 elif 'logA' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *                     value = self._pars['logA']
 */
      __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_logA, __pyx_v_self->_pars, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5620, __pyx_L1_error)
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5622
 *                 elif 'logA' in self._pars:
 * 
 *                     value = self._pars['logA']             # <<<<<<<<<<<<<<
 * 
 *                 elif self.tsz.use_class_sz_fast_mode == 1:
 */
        __pyx_t_8 = __Pyx_PyObject_Dict_GetItem(__pyx_v_self->_pars, __pyx_n_u_logA); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5622, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "class-sz/python/classy.pyx":5620
 *                     value = self._pars['ln10^{10}A_s']
 * 
 *                 elif 'logA' in self._pars:             # <<<<<<<<<<<<<<
 * 
 *                     value = self._pars['logA']
 */
        goto __pyx_L19;
      }

      /* "class-sz/python/classy.pyx":5624
 *                     value = self._pars['logA']
 * 
 *                 elif self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *                     value = self.logA_fast
 */
      __pyx_t_3 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5626
 *                 elif self.tsz.use_class_sz_fast_mode == 1:
 * 
 *                     value = self.logA_fast             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->logA_fast); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5626, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "class-sz/python/classy.pyx":5624
 *                     value = self._pars['logA']
 * 
 *                 elif self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 * 
 *                     value = self.logA_fast
 */
        goto __pyx_L19;
      }

      /* "class-sz/python/classy.pyx":5630
 *                 else:
 * 
 *                     value = log(1.e10*self.pm.A_s)             # <<<<<<<<<<<<<<
 * 
 * 
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_log); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5630, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = PyFloat_FromDouble((1.e10 * __pyx_v_self->pm.A_s)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5630, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_12 = NULL;
        __pyx_t_11 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_11 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_7};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5630, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;
      }
      __pyx_L19:;

      /* "class-sz/python/classy.pyx":5614
 *                   value = self.pm.A_s
 * 
 *             elif name == 'ln10^{10}A_s' or name == 'logA':             # <<<<<<<<<<<<<<
 * 
 *                 if 'ln10^{10}A_s' in self._pars:
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5633
 * 
 * 
 *             elif name == 'n_s':             # <<<<<<<<<<<<<<
 *                 value = self.pm.n_s
 *             elif name == 'alpha_s':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_n_s, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5633, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5634
 * 
 *             elif name == 'n_s':
 *                 value = self.pm.n_s             # <<<<<<<<<<<<<<
 *             elif name == 'alpha_s':
 *                 value = self.pm.alpha_s
 */
      __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.n_s); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5634, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5633
 * 
 * 
 *             elif name == 'n_s':             # <<<<<<<<<<<<<<
 *                 value = self.pm.n_s
 *             elif name == 'alpha_s':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5635
 *             elif name == 'n_s':
 *                 value = self.pm.n_s
 *             elif name == 'alpha_s':             # <<<<<<<<<<<<<<
 *                 value = self.pm.alpha_s
 *             elif name == 'beta_s':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_alpha_s, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5635, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5636
 *                 value = self.pm.n_s
 *             elif name == 'alpha_s':
 *                 value = self.pm.alpha_s             # <<<<<<<<<<<<<<
 *             elif name == 'beta_s':
 *                 value = self.pm.beta_s
 */
      __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.alpha_s); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5636, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5635
 *             elif name == 'n_s':
 *                 value = self.pm.n_s
 *             elif name == 'alpha_s':             # <<<<<<<<<<<<<<
 *                 value = self.pm.alpha_s
 *             elif name == 'beta_s':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5637
 *             elif name == 'alpha_s':
 *                 value = self.pm.alpha_s
 *             elif name == 'beta_s':             # <<<<<<<<<<<<<<
 *                 value = self.pm.beta_s
 *             elif name == 'r':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_beta_s, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5637, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5638
 *                 value = self.pm.alpha_s
 *             elif name == 'beta_s':
 *                 value = self.pm.beta_s             # <<<<<<<<<<<<<<
 *             elif name == 'r':
 *                 # This is at the pivot scale
 */
      __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.beta_s); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5637
 *             elif name == 'alpha_s':
 *                 value = self.pm.alpha_s
 *             elif name == 'beta_s':             # <<<<<<<<<<<<<<
 *                 value = self.pm.beta_s
 *             elif name == 'r':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5639
 *             elif name == 'beta_s':
 *                 value = self.pm.beta_s
 *             elif name == 'r':             # <<<<<<<<<<<<<<
 *                 # This is at the pivot scale
 *                 value = self.pm.r
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_r, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5639, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5641
 *             elif name == 'r':
 *                 # This is at the pivot scale
 *                 value = self.pm.r             # <<<<<<<<<<<<<<
 *             elif name == 'r_0002':
 *                 # at k_pivot = 0.002/Mpc
 */
      __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.r); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5639
 *             elif name == 'beta_s':
 *                 value = self.pm.beta_s
 *             elif name == 'r':             # <<<<<<<<<<<<<<
 *                 # This is at the pivot scale
 *                 value = self.pm.r
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5642
 *                 # This is at the pivot scale
 *                 value = self.pm.r
 *             elif name == 'r_0002':             # <<<<<<<<<<<<<<
 *                 # at k_pivot = 0.002/Mpc
 *                 value = self.pm.r*(0.002/self.pm.k_pivot)**(
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_r_0002, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5642, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5644
 *             elif name == 'r_0002':
 *                 # at k_pivot = 0.002/Mpc
 *                 value = self.pm.r*(0.002/self.pm.k_pivot)**(             # <<<<<<<<<<<<<<
 *                     self.pm.n_t-self.pm.n_s-1+0.5*self.pm.alpha_s*log(
 *                         0.002/self.pm.k_pivot))
 */
      __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.r); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (unlikely(__pyx_v_self->pm.k_pivot == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5644, __pyx_L1_error)
      }
      __pyx_t_1 = PyFloat_FromDouble((0.002 / __pyx_v_self->pm.k_pivot)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "class-sz/python/classy.pyx":5645
 *                 # at k_pivot = 0.002/Mpc
 *                 value = self.pm.r*(0.002/self.pm.k_pivot)**(
 *                     self.pm.n_t-self.pm.n_s-1+0.5*self.pm.alpha_s*log(             # <<<<<<<<<<<<<<
 *                         0.002/self.pm.k_pivot))
 *             elif name == 'n_t':
 */
      __pyx_t_7 = PyFloat_FromDouble(((__pyx_v_self->pm.n_t - __pyx_v_self->pm.n_s) - 1.0)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_12 = PyFloat_FromDouble((0.5 * __pyx_v_self->pm.alpha_s)); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 5645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_log); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);

      /* "class-sz/python/classy.pyx":5646
 *                 value = self.pm.r*(0.002/self.pm.k_pivot)**(
 *                     self.pm.n_t-self.pm.n_s-1+0.5*self.pm.alpha_s*log(
 *                         0.002/self.pm.k_pivot))             # <<<<<<<<<<<<<<
 *             elif name == 'n_t':
 *                 value = self.pm.n_t
 */
      if (unlikely(__pyx_v_self->pm.k_pivot == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5646, __pyx_L1_error)
      }
      __pyx_t_15 = PyFloat_FromDouble((0.002 / __pyx_v_self->pm.k_pivot)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 5646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_16 = NULL;
      __pyx_t_11 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_16)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_11 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_15};
        __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5645, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }

      /* "class-sz/python/classy.pyx":5645
 *                 # at k_pivot = 0.002/Mpc
 *                 value = self.pm.r*(0.002/self.pm.k_pivot)**(
 *                     self.pm.n_t-self.pm.n_s-1+0.5*self.pm.alpha_s*log(             # <<<<<<<<<<<<<<
 *                         0.002/self.pm.k_pivot))
 *             elif name == 'n_t':
 */
      __pyx_t_14 = PyNumber_Multiply(__pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = PyNumber_Add(__pyx_t_7, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "class-sz/python/classy.pyx":5644
 *             elif name == 'r_0002':
 *                 # at k_pivot = 0.002/Mpc
 *                 value = self.pm.r*(0.002/self.pm.k_pivot)**(             # <<<<<<<<<<<<<<
 *                     self.pm.n_t-self.pm.n_s-1+0.5*self.pm.alpha_s*log(
 *                         0.002/self.pm.k_pivot))
 */
      __pyx_t_14 = PyNumber_Power(__pyx_t_1, __pyx_t_13, Py_None); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = PyNumber_Multiply(__pyx_t_8, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5644, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5642
 *                 # This is at the pivot scale
 *                 value = self.pm.r
 *             elif name == 'r_0002':             # <<<<<<<<<<<<<<
 *                 # at k_pivot = 0.002/Mpc
 *                 value = self.pm.r*(0.002/self.pm.k_pivot)**(
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5647
 *                     self.pm.n_t-self.pm.n_s-1+0.5*self.pm.alpha_s*log(
 *                         0.002/self.pm.k_pivot))
 *             elif name == 'n_t':             # <<<<<<<<<<<<<<
 *                 value = self.pm.n_t
 *             elif name == 'alpha_t':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_n_t, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5647, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5648
 *                         0.002/self.pm.k_pivot))
 *             elif name == 'n_t':
 *                 value = self.pm.n_t             # <<<<<<<<<<<<<<
 *             elif name == 'alpha_t':
 *                 value = self.pm.alpha_t
 */
      __pyx_t_13 = PyFloat_FromDouble(__pyx_v_self->pm.n_t); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5648, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5647
 *                     self.pm.n_t-self.pm.n_s-1+0.5*self.pm.alpha_s*log(
 *                         0.002/self.pm.k_pivot))
 *             elif name == 'n_t':             # <<<<<<<<<<<<<<
 *                 value = self.pm.n_t
 *             elif name == 'alpha_t':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5649
 *             elif name == 'n_t':
 *                 value = self.pm.n_t
 *             elif name == 'alpha_t':             # <<<<<<<<<<<<<<
 *                 value = self.pm.alpha_t
 *             elif name == 'V_0':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_alpha_t, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5649, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5650
 *                 value = self.pm.n_t
 *             elif name == 'alpha_t':
 *                 value = self.pm.alpha_t             # <<<<<<<<<<<<<<
 *             elif name == 'V_0':
 *                 value = self.pm.V0
 */
      __pyx_t_13 = PyFloat_FromDouble(__pyx_v_self->pm.alpha_t); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5649
 *             elif name == 'n_t':
 *                 value = self.pm.n_t
 *             elif name == 'alpha_t':             # <<<<<<<<<<<<<<
 *                 value = self.pm.alpha_t
 *             elif name == 'V_0':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5651
 *             elif name == 'alpha_t':
 *                 value = self.pm.alpha_t
 *             elif name == 'V_0':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V0
 *             elif name == 'V_1':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_V_0, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5651, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5652
 *                 value = self.pm.alpha_t
 *             elif name == 'V_0':
 *                 value = self.pm.V0             # <<<<<<<<<<<<<<
 *             elif name == 'V_1':
 *                 value = self.pm.V1
 */
      __pyx_t_13 = PyFloat_FromDouble(__pyx_v_self->pm.V0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5652, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5651
 *             elif name == 'alpha_t':
 *                 value = self.pm.alpha_t
 *             elif name == 'V_0':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V0
 *             elif name == 'V_1':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5653
 *             elif name == 'V_0':
 *                 value = self.pm.V0
 *             elif name == 'V_1':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V1
 *             elif name == 'V_2':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_V_1, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5653, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5654
 *                 value = self.pm.V0
 *             elif name == 'V_1':
 *                 value = self.pm.V1             # <<<<<<<<<<<<<<
 *             elif name == 'V_2':
 *                 value = self.pm.V2
 */
      __pyx_t_13 = PyFloat_FromDouble(__pyx_v_self->pm.V1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5653
 *             elif name == 'V_0':
 *                 value = self.pm.V0
 *             elif name == 'V_1':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V1
 *             elif name == 'V_2':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5655
 *             elif name == 'V_1':
 *                 value = self.pm.V1
 *             elif name == 'V_2':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V2
 *             elif name == 'V_3':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_V_2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5655, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5656
 *                 value = self.pm.V1
 *             elif name == 'V_2':
 *                 value = self.pm.V2             # <<<<<<<<<<<<<<
 *             elif name == 'V_3':
 *                 value = self.pm.V3
 */
      __pyx_t_13 = PyFloat_FromDouble(__pyx_v_self->pm.V2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5655
 *             elif name == 'V_1':
 *                 value = self.pm.V1
 *             elif name == 'V_2':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V2
 *             elif name == 'V_3':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5657
 *             elif name == 'V_2':
 *                 value = self.pm.V2
 *             elif name == 'V_3':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V3
 *             elif name == 'V_4':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_V_3, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5657, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5658
 *                 value = self.pm.V2
 *             elif name == 'V_3':
 *                 value = self.pm.V3             # <<<<<<<<<<<<<<
 *             elif name == 'V_4':
 *                 value = self.pm.V4
 */
      __pyx_t_13 = PyFloat_FromDouble(__pyx_v_self->pm.V3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5657
 *             elif name == 'V_2':
 *                 value = self.pm.V2
 *             elif name == 'V_3':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V3
 *             elif name == 'V_4':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5659
 *             elif name == 'V_3':
 *                 value = self.pm.V3
 *             elif name == 'V_4':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V4
 *             elif name == 'epsilon_V':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_V_4, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5659, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5660
 *                 value = self.pm.V3
 *             elif name == 'V_4':
 *                 value = self.pm.V4             # <<<<<<<<<<<<<<
 *             elif name == 'epsilon_V':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 */
      __pyx_t_13 = PyFloat_FromDouble(__pyx_v_self->pm.V4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5660, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5659
 *             elif name == 'V_3':
 *                 value = self.pm.V3
 *             elif name == 'V_4':             # <<<<<<<<<<<<<<
 *                 value = self.pm.V4
 *             elif name == 'epsilon_V':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5661
 *             elif name == 'V_4':
 *                 value = self.pm.V4
 *             elif name == 'epsilon_V':             # <<<<<<<<<<<<<<
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_epsilon_V, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5661, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5662
 *                 value = self.pm.V4
 *             elif name == 'epsilon_V':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))             # <<<<<<<<<<<<<<
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 value = eps1*((1.-eps1/3.+eps2/6.)/(1.-eps1/3.))**2
 */
      __pyx_v_eps1 = (__pyx_v_self->pm.r * ((1. / 16.) - ((0.7296 / 16.) * (((__pyx_v_self->pm.r / 8.) + __pyx_v_self->pm.n_s) - 1.))));

      /* "class-sz/python/classy.pyx":5663
 *             elif name == 'epsilon_V':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)             # <<<<<<<<<<<<<<
 *                 value = eps1*((1.-eps1/3.+eps2/6.)/(1.-eps1/3.))**2
 *             elif name == 'eta_V':
 */
      __pyx_v_eps2 = (((((-__pyx_v_self->pm.n_s) + 1.) - (0.7296 * __pyx_v_self->pm.alpha_s)) - (__pyx_v_self->pm.r * ((1. / 8.) + (((1. / 8.) * (__pyx_v_self->pm.n_s - 1.)) * (-0.7296 - 1.5))))) - (pow((__pyx_v_self->pm.r / 8.), 2.0) * (-0.7296 - 1.)));

      /* "class-sz/python/classy.pyx":5664
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 value = eps1*((1.-eps1/3.+eps2/6.)/(1.-eps1/3.))**2             # <<<<<<<<<<<<<<
 *             elif name == 'eta_V':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 */
      __pyx_t_9 = ((1. - (__pyx_v_eps1 / 3.)) + (__pyx_v_eps2 / 6.));
      __pyx_t_10 = (1. - (__pyx_v_eps1 / 3.));
      if (unlikely(__pyx_t_10 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5664, __pyx_L1_error)
      }
      __pyx_t_13 = PyFloat_FromDouble((__pyx_v_eps1 * pow((__pyx_t_9 / __pyx_t_10), 2.0))); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5664, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5661
 *             elif name == 'V_4':
 *                 value = self.pm.V4
 *             elif name == 'epsilon_V':             # <<<<<<<<<<<<<<
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5665
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 value = eps1*((1.-eps1/3.+eps2/6.)/(1.-eps1/3.))**2
 *             elif name == 'eta_V':             # <<<<<<<<<<<<<<
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_eta_V, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5665, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5666
 *                 value = eps1*((1.-eps1/3.+eps2/6.)/(1.-eps1/3.))**2
 *             elif name == 'eta_V':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))             # <<<<<<<<<<<<<<
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 */
      __pyx_v_eps1 = (__pyx_v_self->pm.r * ((1. / 16.) - ((0.7296 / 16.) * (((__pyx_v_self->pm.r / 8.) + __pyx_v_self->pm.n_s) - 1.))));

      /* "class-sz/python/classy.pyx":5667
 *             elif name == 'eta_V':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)             # <<<<<<<<<<<<<<
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = (2.*eps1-eps2/2.-2./3.*eps1**2+5./6.*eps1*eps2-eps2**2/12.-eps23/6.)/(1.-eps1/3.)
 */
      __pyx_v_eps2 = (((((-__pyx_v_self->pm.n_s) + 1.) - (0.7296 * __pyx_v_self->pm.alpha_s)) - (__pyx_v_self->pm.r * ((1. / 8.) + (((1. / 8.) * (__pyx_v_self->pm.n_s - 1.)) * (-0.7296 - 1.5))))) - (pow((__pyx_v_self->pm.r / 8.), 2.0) * (-0.7296 - 1.)));

      /* "class-sz/python/classy.pyx":5668
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)             # <<<<<<<<<<<<<<
 *                 value = (2.*eps1-eps2/2.-2./3.*eps1**2+5./6.*eps1*eps2-eps2**2/12.-eps23/6.)/(1.-eps1/3.)
 *             elif name == 'ksi_V^2':
 */
      __pyx_v_eps23 = ((1. / 8.) * (((pow(__pyx_v_self->pm.r, 2.0) / 8.) + ((__pyx_v_self->pm.n_s - 1.) * __pyx_v_self->pm.r)) - (8. * __pyx_v_self->pm.alpha_s)));

      /* "class-sz/python/classy.pyx":5669
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = (2.*eps1-eps2/2.-2./3.*eps1**2+5./6.*eps1*eps2-eps2**2/12.-eps23/6.)/(1.-eps1/3.)             # <<<<<<<<<<<<<<
 *             elif name == 'ksi_V^2':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 */
      __pyx_t_10 = ((((((2. * __pyx_v_eps1) - (__pyx_v_eps2 / 2.)) - ((2. / 3.) * pow(__pyx_v_eps1, 2.0))) + (((5. / 6.) * __pyx_v_eps1) * __pyx_v_eps2)) - (pow(__pyx_v_eps2, 2.0) / 12.)) - (__pyx_v_eps23 / 6.));
      __pyx_t_9 = (1. - (__pyx_v_eps1 / 3.));
      if (unlikely(__pyx_t_9 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5669, __pyx_L1_error)
      }
      __pyx_t_13 = PyFloat_FromDouble((__pyx_t_10 / __pyx_t_9)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5669, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5665
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 value = eps1*((1.-eps1/3.+eps2/6.)/(1.-eps1/3.))**2
 *             elif name == 'eta_V':             # <<<<<<<<<<<<<<
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5670
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = (2.*eps1-eps2/2.-2./3.*eps1**2+5./6.*eps1*eps2-eps2**2/12.-eps23/6.)/(1.-eps1/3.)
 *             elif name == 'ksi_V^2':             # <<<<<<<<<<<<<<
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_kp_u_ksi_V_2, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5670, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5671
 *                 value = (2.*eps1-eps2/2.-2./3.*eps1**2+5./6.*eps1*eps2-eps2**2/12.-eps23/6.)/(1.-eps1/3.)
 *             elif name == 'ksi_V^2':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))             # <<<<<<<<<<<<<<
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 */
      __pyx_v_eps1 = (__pyx_v_self->pm.r * ((1. / 16.) - ((0.7296 / 16.) * (((__pyx_v_self->pm.r / 8.) + __pyx_v_self->pm.n_s) - 1.))));

      /* "class-sz/python/classy.pyx":5672
 *             elif name == 'ksi_V^2':
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)             # <<<<<<<<<<<<<<
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = 2.*(1.-eps1/3.+eps2/6.)*(2.*eps1**2-3./2.*eps1*eps2+eps23/4.)/(1.-eps1/3.)**2
 */
      __pyx_v_eps2 = (((((-__pyx_v_self->pm.n_s) + 1.) - (0.7296 * __pyx_v_self->pm.alpha_s)) - (__pyx_v_self->pm.r * ((1. / 8.) + (((1. / 8.) * (__pyx_v_self->pm.n_s - 1.)) * (-0.7296 - 1.5))))) - (pow((__pyx_v_self->pm.r / 8.), 2.0) * (-0.7296 - 1.)));

      /* "class-sz/python/classy.pyx":5673
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)             # <<<<<<<<<<<<<<
 *                 value = 2.*(1.-eps1/3.+eps2/6.)*(2.*eps1**2-3./2.*eps1*eps2+eps23/4.)/(1.-eps1/3.)**2
 *             elif name == 'exp_m_2_tau_As':
 */
      __pyx_v_eps23 = ((1. / 8.) * (((pow(__pyx_v_self->pm.r, 2.0) / 8.) + ((__pyx_v_self->pm.n_s - 1.) * __pyx_v_self->pm.r)) - (8. * __pyx_v_self->pm.alpha_s)));

      /* "class-sz/python/classy.pyx":5674
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = 2.*(1.-eps1/3.+eps2/6.)*(2.*eps1**2-3./2.*eps1*eps2+eps23/4.)/(1.-eps1/3.)**2             # <<<<<<<<<<<<<<
 *             elif name == 'exp_m_2_tau_As':
 *                 value = exp(-2.*self.th.tau_reio)*self.pm.A_s
 */
      __pyx_t_9 = ((2. * ((1. - (__pyx_v_eps1 / 3.)) + (__pyx_v_eps2 / 6.))) * (((2. * pow(__pyx_v_eps1, 2.0)) - (((3. / 2.) * __pyx_v_eps1) * __pyx_v_eps2)) + (__pyx_v_eps23 / 4.)));
      __pyx_t_10 = pow((1. - (__pyx_v_eps1 / 3.)), 2.0);
      if (unlikely(__pyx_t_10 == 0)) {
        PyErr_SetString(PyExc_ZeroDivisionError, "float division");
        __PYX_ERR(0, 5674, __pyx_L1_error)
      }
      __pyx_t_13 = PyFloat_FromDouble((__pyx_t_9 / __pyx_t_10)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5674, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_13);
      __pyx_t_13 = 0;

      /* "class-sz/python/classy.pyx":5670
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = (2.*eps1-eps2/2.-2./3.*eps1**2+5./6.*eps1*eps2-eps2**2/12.-eps23/6.)/(1.-eps1/3.)
 *             elif name == 'ksi_V^2':             # <<<<<<<<<<<<<<
 *                 eps1 = self.pm.r*(1./16.-0.7296/16.*(self.pm.r/8.+self.pm.n_s-1.))
 *                 eps2 = -self.pm.n_s+1.-0.7296*self.pm.alpha_s-self.pm.r*(1./8.+1./8.*(self.pm.n_s-1.)*(-0.7296-1.5))-(self.pm.r/8.)**2*(-0.7296-1.)
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5675
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = 2.*(1.-eps1/3.+eps2/6.)*(2.*eps1**2-3./2.*eps1*eps2+eps23/4.)/(1.-eps1/3.)**2
 *             elif name == 'exp_m_2_tau_As':             # <<<<<<<<<<<<<<
 *                 value = exp(-2.*self.th.tau_reio)*self.pm.A_s
 *             elif name == 'phi_min':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_exp_m_2_tau_As, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5675, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5676
 *                 value = 2.*(1.-eps1/3.+eps2/6.)*(2.*eps1**2-3./2.*eps1*eps2+eps23/4.)/(1.-eps1/3.)**2
 *             elif name == 'exp_m_2_tau_As':
 *                 value = exp(-2.*self.th.tau_reio)*self.pm.A_s             # <<<<<<<<<<<<<<
 *             elif name == 'phi_min':
 *                 value = self.pm.phi_min
 */
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_exp); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5676, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_8 = PyFloat_FromDouble((-2. * __pyx_v_self->th.tau_reio)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5676, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = NULL;
      __pyx_t_11 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_11 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_8};
        __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5676, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __pyx_t_14 = PyFloat_FromDouble(__pyx_v_self->pm.A_s); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5676, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_8 = PyNumber_Multiply(__pyx_t_13, __pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5676, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5675
 *                 eps23 = 1./8.*(self.pm.r**2/8.+(self.pm.n_s-1.)*self.pm.r-8.*self.pm.alpha_s)
 *                 value = 2.*(1.-eps1/3.+eps2/6.)*(2.*eps1**2-3./2.*eps1*eps2+eps23/4.)/(1.-eps1/3.)**2
 *             elif name == 'exp_m_2_tau_As':             # <<<<<<<<<<<<<<
 *                 value = exp(-2.*self.th.tau_reio)*self.pm.A_s
 *             elif name == 'phi_min':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5677
 *             elif name == 'exp_m_2_tau_As':
 *                 value = exp(-2.*self.th.tau_reio)*self.pm.A_s
 *             elif name == 'phi_min':             # <<<<<<<<<<<<<<
 *                 value = self.pm.phi_min
 *             elif name == 'phi_max':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_phi_min, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5677, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5678
 *                 value = exp(-2.*self.th.tau_reio)*self.pm.A_s
 *             elif name == 'phi_min':
 *                 value = self.pm.phi_min             # <<<<<<<<<<<<<<
 *             elif name == 'phi_max':
 *                 value = self.pm.phi_max
 */
      __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.phi_min); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5678, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5677
 *             elif name == 'exp_m_2_tau_As':
 *                 value = exp(-2.*self.th.tau_reio)*self.pm.A_s
 *             elif name == 'phi_min':             # <<<<<<<<<<<<<<
 *                 value = self.pm.phi_min
 *             elif name == 'phi_max':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5679
 *             elif name == 'phi_min':
 *                 value = self.pm.phi_min
 *             elif name == 'phi_max':             # <<<<<<<<<<<<<<
 *                 value = self.pm.phi_max
 *             elif name == 'sigma8':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_phi_max, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5679, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5680
 *                 value = self.pm.phi_min
 *             elif name == 'phi_max':
 *                 value = self.pm.phi_max             # <<<<<<<<<<<<<<
 *             elif name == 'sigma8':
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 */
      __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->pm.phi_max); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5680, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5679
 *             elif name == 'phi_min':
 *                 value = self.pm.phi_min
 *             elif name == 'phi_max':             # <<<<<<<<<<<<<<
 *                 value = self.pm.phi_max
 *             elif name == 'sigma8':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5681
 *             elif name == 'phi_max':
 *                 value = self.pm.phi_max
 *             elif name == 'sigma8':             # <<<<<<<<<<<<<<
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 *                   value = self.sigma8_fast
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_sigma8, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5681, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5682
 *                 value = self.pm.phi_max
 *             elif name == 'sigma8':
 *                 if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *                   value = self.sigma8_fast
 *                 else:
 */
      __pyx_t_3 = (__pyx_v_self->tsz.use_class_sz_fast_mode == 1);
      if (__pyx_t_3) {

        /* "class-sz/python/classy.pyx":5683
 *             elif name == 'sigma8':
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 *                   value = self.sigma8_fast             # <<<<<<<<<<<<<<
 *                 else:
 *                   value = self.nl.sigma8[self.nl.index_pk_m]
 */
        __pyx_t_8 = PyFloat_FromDouble(__pyx_v_self->sigma8_fast); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5683, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "class-sz/python/classy.pyx":5682
 *                 value = self.pm.phi_max
 *             elif name == 'sigma8':
 *                 if self.tsz.use_class_sz_fast_mode == 1:             # <<<<<<<<<<<<<<
 *                   value = self.sigma8_fast
 *                 else:
 */
        goto __pyx_L20;
      }

      /* "class-sz/python/classy.pyx":5685
 *                   value = self.sigma8_fast
 *                 else:
 *                   value = self.nl.sigma8[self.nl.index_pk_m]             # <<<<<<<<<<<<<<
 *             elif name == 'sigma8_cb':
 *                 value = self.nl.sigma8[self.nl.index_pk_cb]
 */
      /*else*/ {
        __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->nl.sigma8[__pyx_v_self->nl.index_pk_m])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5685, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;
      }
      __pyx_L20:;

      /* "class-sz/python/classy.pyx":5681
 *             elif name == 'phi_max':
 *                 value = self.pm.phi_max
 *             elif name == 'sigma8':             # <<<<<<<<<<<<<<
 *                 if self.tsz.use_class_sz_fast_mode == 1:
 *                   value = self.sigma8_fast
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5686
 *                 else:
 *                   value = self.nl.sigma8[self.nl.index_pk_m]
 *             elif name == 'sigma8_cb':             # <<<<<<<<<<<<<<
 *                 value = self.nl.sigma8[self.nl.index_pk_cb]
 *             elif name == 'k_eq':
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_sigma8_cb, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5686, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "class-sz/python/classy.pyx":5687
 *                   value = self.nl.sigma8[self.nl.index_pk_m]
 *             elif name == 'sigma8_cb':
 *                 value = self.nl.sigma8[self.nl.index_pk_cb]             # <<<<<<<<<<<<<<
 *             elif name == 'k_eq':
 *                 value = self.ba.a_eq*self.ba.H_eq
 */
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->nl.sigma8[__pyx_v_self->nl.index_pk_cb])); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5686
 *                 else:
 *                   value = self.nl.sigma8[self.nl.index_pk_m]
 *             elif name == 'sigma8_cb':             # <<<<<<<<<<<<<<
 *                 value = self.nl.sigma8[self.nl.index_pk_cb]
 *             elif name == 'k_eq':
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5688
 *             elif name == 'sigma8_cb':
 *                 value = self.nl.sigma8[self.nl.index_pk_cb]
 *             elif name == 'k_eq':             # <<<<<<<<<<<<<<
 *                 value = self.ba.a_eq*self.ba.H_eq
 * 
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_k_eq, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 5688, __pyx_L1_error)
    if (likely(__pyx_t_3)) {

      /* "class-sz/python/classy.pyx":5689
 *                 value = self.nl.sigma8[self.nl.index_pk_cb]
 *             elif name == 'k_eq':
 *                 value = self.ba.a_eq*self.ba.H_eq             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
      __pyx_t_8 = PyFloat_FromDouble((__pyx_v_self->ba.a_eq * __pyx_v_self->ba.H_eq)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5689, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "class-sz/python/classy.pyx":5688
 *             elif name == 'sigma8_cb':
 *                 value = self.nl.sigma8[self.nl.index_pk_cb]
 *             elif name == 'k_eq':             # <<<<<<<<<<<<<<
 *                 value = self.ba.a_eq*self.ba.H_eq
 * 
 */
      goto __pyx_L6;
    }

    /* "class-sz/python/classy.pyx":5692
 * 
 *             else:
 *                 raise CosmoSevereError("%s was not recognized as a derived parameter" % name)             # <<<<<<<<<<<<<<
 *             derived[name] = value
 *         return derived
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 5692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_13 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_s_was_not_recognized_as_a_deriv, __pyx_v_name); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 5692, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_1 = NULL;
      __pyx_t_11 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_11 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_13};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 5692, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(0, 5692, __pyx_L1_error)
    }
    __pyx_L6:;

    /* "class-sz/python/classy.pyx":5693
 *             else:
 *                 raise CosmoSevereError("%s was not recognized as a derived parameter" % name)
 *             derived[name] = value             # <<<<<<<<<<<<<<
 *         return derived
 * 
 */
    if (unlikely((PyDict_SetItem(__pyx_v_derived, __pyx_v_name, __pyx_v_value) < 0))) __PYX_ERR(0, 5693, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5463
 * 
 *         derived = {}
 *         for name in names:             # <<<<<<<<<<<<<<
 * 
 *             if name == 'h':
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5694
 *                 raise CosmoSevereError("%s was not recognized as a derived parameter" % name)
 *             derived[name] = value
 *         return derived             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_scale(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_derived);
  __pyx_r = __pyx_v_derived;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5433
 *         return transfers
 * 
 *     def get_current_derived_parameters(self, names):             # <<<<<<<<<<<<<<
 *         """
 *         get_current_derived_parameters(names)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("classy_sz.Class.get_current_derived_parameters", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_derived);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_params_settings);
  __Pyx_XDECREF(__pyx_v_lna);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5696
 *         return derived
 * 
 *     def nonlinear_scale(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_scale(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_579nonlinear_scale(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_578nonlinear_scale, "\n        nonlinear_scale(z, z_size)\n\n        Return the nonlinear scale for all the redshift specified in z, of size\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_579nonlinear_scale = {"nonlinear_scale", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_579nonlinear_scale, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_578nonlinear_scale};
static PyObject *__pyx_pw_9classy_sz_5Class_579nonlinear_scale(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_scale (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5696, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5696, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_scale", 1, 2, 2, 1); __PYX_ERR(0, 5696, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_scale") < 0)) __PYX_ERR(0, 5696, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5696, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_scale", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5696, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_scale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5696, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_578nonlinear_scale(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_578nonlinear_scale(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  int __pyx_v_index_z;
  PyArrayObject *__pyx_v_k_nl = 0;
  PyArrayObject *__pyx_v_k_nl_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k_nl;
  __Pyx_Buffer __pyx_pybuffer_k_nl;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k_nl_cb;
  __Pyx_Buffer __pyx_pybuffer_k_nl_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_scale", 1);
  __pyx_pybuffer_k_nl.pybuffer.buf = NULL;
  __pyx_pybuffer_k_nl.refcount = 0;
  __pyx_pybuffernd_k_nl.data = NULL;
  __pyx_pybuffernd_k_nl.rcbuffer = &__pyx_pybuffer_k_nl;
  __pyx_pybuffer_k_nl_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_k_nl_cb.refcount = 0;
  __pyx_pybuffernd_k_nl_cb.data = NULL;
  __pyx_pybuffernd_k_nl_cb.rcbuffer = &__pyx_pybuffer_k_nl_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5696, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5711
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl_cb = np.zeros(z_size,'float64')
 *         #cdef double *k_nl
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5711, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k_nl.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_k_nl = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5711, __pyx_L1_error)
    } else {__pyx_pybuffernd_k_nl.diminfo[0].strides = __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k_nl.diminfo[0].shape = __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_k_nl = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5712
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         #cdef double *k_nl
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5712, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_k_nl_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5712, __pyx_L1_error)
    } else {__pyx_pybuffernd_k_nl_cb.diminfo[0].strides = __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k_nl_cb.diminfo[0].shape = __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_k_nl_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5715
 *         #cdef double *k_nl
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 *         for index_z in range(z_size):             # <<<<<<<<<<<<<<
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)
 */
  __pyx_t_8 = __pyx_v_z_size;
  __pyx_t_9 = __pyx_t_8;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
    __pyx_v_index_z = __pyx_t_10;

    /* "class-sz/python/classy.pyx":5716
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 *         for index_z in range(z_size):
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 */
    __pyx_t_11 = __pyx_v_index_z;
    __pyx_t_12 = -1;
    if (__pyx_t_11 < 0) {
      __pyx_t_11 += __pyx_pybuffernd_z.diminfo[0].shape;
      if (unlikely(__pyx_t_11 < 0)) __pyx_t_12 = 0;
    } else if (unlikely(__pyx_t_11 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_12 = 0;
    if (unlikely(__pyx_t_12 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_12);
      __PYX_ERR(0, 5716, __pyx_L1_error)
    }
    __pyx_t_13 = __pyx_v_index_z;
    __pyx_t_12 = -1;
    if (__pyx_t_13 < 0) {
      __pyx_t_13 += __pyx_pybuffernd_k_nl.diminfo[0].shape;
      if (unlikely(__pyx_t_13 < 0)) __pyx_t_12 = 0;
    } else if (unlikely(__pyx_t_13 >= __pyx_pybuffernd_k_nl.diminfo[0].shape)) __pyx_t_12 = 0;
    if (unlikely(__pyx_t_12 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_12);
      __PYX_ERR(0, 5716, __pyx_L1_error)
    }
    __pyx_t_14 = __pyx_v_index_z;
    __pyx_t_12 = -1;
    if (__pyx_t_14 < 0) {
      __pyx_t_14 += __pyx_pybuffernd_k_nl_cb.diminfo[0].shape;
      if (unlikely(__pyx_t_14 < 0)) __pyx_t_12 = 0;
    } else if (unlikely(__pyx_t_14 >= __pyx_pybuffernd_k_nl_cb.diminfo[0].shape)) __pyx_t_12 = 0;
    if (unlikely(__pyx_t_12 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_12);
      __PYX_ERR(0, 5716, __pyx_L1_error)
    }
    __pyx_t_15 = (nonlinear_k_nl_at_z((&__pyx_v_self->ba), (&__pyx_v_self->nl), (*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_11, __pyx_pybuffernd_z.diminfo[0].strides)), (&(*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_k_nl.diminfo[0].strides))), (&(*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.buf, __pyx_t_14, __pyx_pybuffernd_k_nl_cb.diminfo[0].strides)))) == _FAILURE_);
    if (unlikely(__pyx_t_15)) {

      /* "class-sz/python/classy.pyx":5717
 *         for index_z in range(z_size):
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return k_nl
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5717, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5717, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5717, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 5717, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":5716
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 *         for index_z in range(z_size):
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 */
    }
  }

  /* "class-sz/python/classy.pyx":5719
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 *         return k_nl             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_scale_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_k_nl);
  __pyx_r = ((PyObject *)__pyx_v_k_nl);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5696
 *         return derived
 * 
 *     def nonlinear_scale(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_scale(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_scale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_k_nl);
  __Pyx_XDECREF((PyObject *)__pyx_v_k_nl_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5721
 *         return k_nl
 * 
 *     def nonlinear_scale_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_581nonlinear_scale_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_580nonlinear_scale_cb, "\n\nmake        nonlinear_scale_cb(z, z_size)\n\n        Return the nonlinear scale for all the redshift specified in z, of size\n\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_581nonlinear_scale_cb = {"nonlinear_scale_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_581nonlinear_scale_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_580nonlinear_scale_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_581nonlinear_scale_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_scale_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5721, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5721, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_scale_cb", 1, 2, 2, 1); __PYX_ERR(0, 5721, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_scale_cb") < 0)) __PYX_ERR(0, 5721, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5721, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_scale_cb", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5721, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_scale_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5721, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_580nonlinear_scale_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_580nonlinear_scale_cb(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  int __pyx_v_index_z;
  PyArrayObject *__pyx_v_k_nl = 0;
  PyArrayObject *__pyx_v_k_nl_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k_nl;
  __Pyx_Buffer __pyx_pybuffer_k_nl;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k_nl_cb;
  __Pyx_Buffer __pyx_pybuffer_k_nl_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_scale_cb", 1);
  __pyx_pybuffer_k_nl.pybuffer.buf = NULL;
  __pyx_pybuffer_k_nl.refcount = 0;
  __pyx_pybuffernd_k_nl.data = NULL;
  __pyx_pybuffernd_k_nl.rcbuffer = &__pyx_pybuffer_k_nl;
  __pyx_pybuffer_k_nl_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_k_nl_cb.refcount = 0;
  __pyx_pybuffernd_k_nl_cb.data = NULL;
  __pyx_pybuffernd_k_nl_cb.rcbuffer = &__pyx_pybuffer_k_nl_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5721, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5738
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl_cb = np.zeros(z_size,'float64')
 *         #cdef double *k_nl
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5738, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5738, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k_nl.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_k_nl = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5738, __pyx_L1_error)
    } else {__pyx_pybuffernd_k_nl.diminfo[0].strides = __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k_nl.diminfo[0].shape = __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_k_nl = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5739
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] k_nl_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         #cdef double *k_nl
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5739, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_k_nl_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5739, __pyx_L1_error)
    } else {__pyx_pybuffernd_k_nl_cb.diminfo[0].strides = __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k_nl_cb.diminfo[0].shape = __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_k_nl_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5742
 *         #cdef double *k_nl
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 *         if (self.ba.Omega0_ncdm_tot == 0.):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(
 *                 "No massive neutrinos. You must use pk, rather than pk_cb."
 */
  __pyx_t_8 = (__pyx_v_self->ba.Omega0_ncdm_tot == 0.);
  if (unlikely(__pyx_t_8)) {

    /* "class-sz/python/classy.pyx":5743
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 *         if (self.ba.Omega0_ncdm_tot == 0.):
 *             raise CosmoSevereError(             # <<<<<<<<<<<<<<
 *                 "No massive neutrinos. You must use pk, rather than pk_cb."
 *                 )
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_No_massive_neutrinos_You_must_us};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5743, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 5743, __pyx_L1_error)

    /* "class-sz/python/classy.pyx":5742
 *         #cdef double *k_nl
 *         #k_nl = <double*> calloc(z_size,sizeof(double))
 *         if (self.ba.Omega0_ncdm_tot == 0.):             # <<<<<<<<<<<<<<
 *             raise CosmoSevereError(
 *                 "No massive neutrinos. You must use pk, rather than pk_cb."
 */
  }

  /* "class-sz/python/classy.pyx":5746
 *                 "No massive neutrinos. You must use pk, rather than pk_cb."
 *                 )
 *         for index_z in range(z_size):             # <<<<<<<<<<<<<<
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)
 */
  __pyx_t_9 = __pyx_v_z_size;
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_index_z = __pyx_t_11;

    /* "class-sz/python/classy.pyx":5747
 *                 )
 *         for index_z in range(z_size):
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 */
    __pyx_t_12 = __pyx_v_index_z;
    __pyx_t_13 = -1;
    if (__pyx_t_12 < 0) {
      __pyx_t_12 += __pyx_pybuffernd_z.diminfo[0].shape;
      if (unlikely(__pyx_t_12 < 0)) __pyx_t_13 = 0;
    } else if (unlikely(__pyx_t_12 >= __pyx_pybuffernd_z.diminfo[0].shape)) __pyx_t_13 = 0;
    if (unlikely(__pyx_t_13 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_13);
      __PYX_ERR(0, 5747, __pyx_L1_error)
    }
    __pyx_t_14 = __pyx_v_index_z;
    __pyx_t_13 = -1;
    if (__pyx_t_14 < 0) {
      __pyx_t_14 += __pyx_pybuffernd_k_nl.diminfo[0].shape;
      if (unlikely(__pyx_t_14 < 0)) __pyx_t_13 = 0;
    } else if (unlikely(__pyx_t_14 >= __pyx_pybuffernd_k_nl.diminfo[0].shape)) __pyx_t_13 = 0;
    if (unlikely(__pyx_t_13 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_13);
      __PYX_ERR(0, 5747, __pyx_L1_error)
    }
    __pyx_t_15 = __pyx_v_index_z;
    __pyx_t_13 = -1;
    if (__pyx_t_15 < 0) {
      __pyx_t_15 += __pyx_pybuffernd_k_nl_cb.diminfo[0].shape;
      if (unlikely(__pyx_t_15 < 0)) __pyx_t_13 = 0;
    } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_k_nl_cb.diminfo[0].shape)) __pyx_t_13 = 0;
    if (unlikely(__pyx_t_13 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_13);
      __PYX_ERR(0, 5747, __pyx_L1_error)
    }
    __pyx_t_8 = (nonlinear_k_nl_at_z((&__pyx_v_self->ba), (&__pyx_v_self->nl), (*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_z.rcbuffer->pybuffer.buf, __pyx_t_12, __pyx_pybuffernd_z.diminfo[0].strides)), (&(*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k_nl.rcbuffer->pybuffer.buf, __pyx_t_14, __pyx_pybuffernd_k_nl.diminfo[0].strides))), (&(*__Pyx_BufPtrStrided1d(__pyx_t_9classy_sz_DTYPE_t *, __pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer.buf, __pyx_t_15, __pyx_pybuffernd_k_nl_cb.diminfo[0].strides)))) == _FAILURE_);
    if (unlikely(__pyx_t_8)) {

      /* "class-sz/python/classy.pyx":5748
 *         for index_z in range(z_size):
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:
 *                 raise CosmoSevereError(self.nl.error_message)             # <<<<<<<<<<<<<<
 * 
 *         return k_nl_cb
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_CosmoSevereError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_self->nl.error_message); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5748, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 5748, __pyx_L1_error)

      /* "class-sz/python/classy.pyx":5747
 *                 )
 *         for index_z in range(z_size):
 *             if nonlinear_k_nl_at_z(&self.ba,&self.nl,z[index_z],&k_nl[index_z],&k_nl_cb[index_z]) == _FAILURE_:             # <<<<<<<<<<<<<<
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 */
    }
  }

  /* "class-sz/python/classy.pyx":5750
 *                 raise CosmoSevereError(self.nl.error_message)
 * 
 *         return k_nl_cb             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigma8(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_k_nl_cb);
  __pyx_r = ((PyObject *)__pyx_v_k_nl_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5721
 *         return k_nl
 * 
 *     def nonlinear_scale_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_scale_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k_nl_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_k_nl);
  __Pyx_XDECREF((PyObject *)__pyx_v_k_nl_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5752
 *         return k_nl_cb
 * 
 *     def nonlinear_hmcode_sigma8(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_583nonlinear_hmcode_sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_582nonlinear_hmcode_sigma8, "\n        nonlinear_hmcode_sigma8(z, z_size)\n\n        Return sigma_8 for all the redshift specified in z, of size\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_583nonlinear_hmcode_sigma8 = {"nonlinear_hmcode_sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_583nonlinear_hmcode_sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_582nonlinear_hmcode_sigma8};
static PyObject *__pyx_pw_9classy_sz_5Class_583nonlinear_hmcode_sigma8(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigma8 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5752, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5752, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigma8", 1, 2, 2, 1); __PYX_ERR(0, 5752, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigma8") < 0)) __PYX_ERR(0, 5752, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5752, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigma8", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5752, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigma8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5752, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_582nonlinear_hmcode_sigma8(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_582nonlinear_hmcode_sigma8(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  PyArrayObject *__pyx_v_sigma_8 = 0;
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_8_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_8;
  __Pyx_Buffer __pyx_pybuffer_sigma_8;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_8_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_8_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigma8", 1);
  __pyx_pybuffer_sigma_8.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_8.refcount = 0;
  __pyx_pybuffernd_sigma_8.data = NULL;
  __pyx_pybuffernd_sigma_8.rcbuffer = &__pyx_pybuffer_sigma_8;
  __pyx_pybuffer_sigma_8_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_8_cb.refcount = 0;
  __pyx_pybuffernd_sigma_8_cb.data = NULL;
  __pyx_pybuffernd_sigma_8_cb.rcbuffer = &__pyx_pybuffer_sigma_8_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5752, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5761
 *         cdef int index_z
 * 
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8 = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5761, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_8.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_8 = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_8.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5761, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_8.diminfo[0].strides = __pyx_pybuffernd_sigma_8.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_8.diminfo[0].shape = __pyx_pybuffernd_sigma_8.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_8 = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5762
 * 
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8 = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5762, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5762, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_8_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5762, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_8_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_8_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_8_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5768
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_8             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigma8_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_8);
  __pyx_r = ((PyObject *)__pyx_v_sigma_8);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5752
 *         return k_nl_cb
 * 
 *     def nonlinear_hmcode_sigma8(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigma8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_8);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_8_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5770
 *         return sigma_8
 * 
 *     def nonlinear_hmcode_sigma8_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_585nonlinear_hmcode_sigma8_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_584nonlinear_hmcode_sigma8_cb, "\n        nonlinear_hmcode_sigma8(z, z_size)\n\n        Return sigma_8 for all the redshift specified in z, of size\n\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_585nonlinear_hmcode_sigma8_cb = {"nonlinear_hmcode_sigma8_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_585nonlinear_hmcode_sigma8_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_584nonlinear_hmcode_sigma8_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_585nonlinear_hmcode_sigma8_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigma8_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5770, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5770, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigma8_cb", 1, 2, 2, 1); __PYX_ERR(0, 5770, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigma8_cb") < 0)) __PYX_ERR(0, 5770, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5770, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigma8_cb", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5770, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigma8_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5770, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_584nonlinear_hmcode_sigma8_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_584nonlinear_hmcode_sigma8_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_8 = 0;
  PyArrayObject *__pyx_v_sigma_8_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_8;
  __Pyx_Buffer __pyx_pybuffer_sigma_8;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_8_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_8_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigma8_cb", 1);
  __pyx_pybuffer_sigma_8.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_8.refcount = 0;
  __pyx_pybuffernd_sigma_8.data = NULL;
  __pyx_pybuffernd_sigma_8.rcbuffer = &__pyx_pybuffer_sigma_8;
  __pyx_pybuffer_sigma_8_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_8_cb.refcount = 0;
  __pyx_pybuffernd_sigma_8_cb.data = NULL;
  __pyx_pybuffernd_sigma_8_cb.rcbuffer = &__pyx_pybuffer_sigma_8_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5770, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5779
 *         cdef int index_z
 * 
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8 = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5779, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_8.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_8 = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_8.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5779, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_8.diminfo[0].strides = __pyx_pybuffernd_sigma_8.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_8.diminfo[0].shape = __pyx_pybuffernd_sigma_8.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_8 = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5780
 * 
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8 = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_8_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5780, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_8_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5780, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_8_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_8_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_8_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5786
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_8_cb             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigmadisp(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_8_cb);
  __pyx_r = ((PyObject *)__pyx_v_sigma_8_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5770
 *         return sigma_8
 * 
 *     def nonlinear_hmcode_sigma8_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigma8_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_8_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_8);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_8_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5788
 *         return sigma_8_cb
 * 
 *     def nonlinear_hmcode_sigmadisp(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_587nonlinear_hmcode_sigmadisp(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_586nonlinear_hmcode_sigmadisp, "\n        nonlinear_hmcode_sigmadisp(z, z_size)\n\n        Return sigma_disp for all the redshift specified in z, of size\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_587nonlinear_hmcode_sigmadisp = {"nonlinear_hmcode_sigmadisp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_587nonlinear_hmcode_sigmadisp, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_586nonlinear_hmcode_sigmadisp};
static PyObject *__pyx_pw_9classy_sz_5Class_587nonlinear_hmcode_sigmadisp(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5788, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5788, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp", 1, 2, 2, 1); __PYX_ERR(0, 5788, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigmadisp") < 0)) __PYX_ERR(0, 5788, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5788, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5788, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5788, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_586nonlinear_hmcode_sigmadisp(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_586nonlinear_hmcode_sigmadisp(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  PyArrayObject *__pyx_v_sigma_disp = 0;
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_disp_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp", 1);
  __pyx_pybuffer_sigma_disp.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp.refcount = 0;
  __pyx_pybuffernd_sigma_disp.data = NULL;
  __pyx_pybuffernd_sigma_disp.rcbuffer = &__pyx_pybuffer_sigma_disp;
  __pyx_pybuffer_sigma_disp_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp_cb.refcount = 0;
  __pyx_pybuffernd_sigma_disp_cb.data = NULL;
  __pyx_pybuffernd_sigma_disp_cb.rcbuffer = &__pyx_pybuffer_sigma_disp_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5788, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5803
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5803, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5803, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5803, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp.diminfo[0].strides = __pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp.diminfo[0].shape = __pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_disp = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5804
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5804, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5804, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_disp_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5810
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_disp             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigmadisp_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_disp);
  __pyx_r = ((PyObject *)__pyx_v_sigma_disp);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5788
 *         return sigma_8_cb
 * 
 *     def nonlinear_hmcode_sigmadisp(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5812
 *         return sigma_disp
 * 
 *     def nonlinear_hmcode_sigmadisp_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_589nonlinear_hmcode_sigmadisp_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_588nonlinear_hmcode_sigmadisp_cb, "\n        nonlinear_hmcode_sigmadisp(z, z_size)\n\n        Return sigma_disp for all the redshift specified in z, of size\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_589nonlinear_hmcode_sigmadisp_cb = {"nonlinear_hmcode_sigmadisp_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_589nonlinear_hmcode_sigmadisp_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_588nonlinear_hmcode_sigmadisp_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_589nonlinear_hmcode_sigmadisp_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5812, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5812, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp_cb", 1, 2, 2, 1); __PYX_ERR(0, 5812, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigmadisp_cb") < 0)) __PYX_ERR(0, 5812, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5812, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp_cb", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5812, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5812, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_588nonlinear_hmcode_sigmadisp_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_588nonlinear_hmcode_sigmadisp_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_disp = 0;
  PyArrayObject *__pyx_v_sigma_disp_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp_cb", 1);
  __pyx_pybuffer_sigma_disp.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp.refcount = 0;
  __pyx_pybuffernd_sigma_disp.data = NULL;
  __pyx_pybuffernd_sigma_disp.rcbuffer = &__pyx_pybuffer_sigma_disp;
  __pyx_pybuffer_sigma_disp_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp_cb.refcount = 0;
  __pyx_pybuffernd_sigma_disp_cb.data = NULL;
  __pyx_pybuffernd_sigma_disp_cb.rcbuffer = &__pyx_pybuffer_sigma_disp_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5812, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5827
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5827, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5827, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp.diminfo[0].strides = __pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp.diminfo[0].shape = __pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_disp = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5828
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5828, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5828, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_disp_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5834
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_disp_cb             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigmadisp100(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_disp_cb);
  __pyx_r = ((PyObject *)__pyx_v_sigma_disp_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5812
 *         return sigma_disp
 * 
 *     def nonlinear_hmcode_sigmadisp_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5836
 *         return sigma_disp_cb
 * 
 *     def nonlinear_hmcode_sigmadisp100(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_591nonlinear_hmcode_sigmadisp100(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_590nonlinear_hmcode_sigmadisp100, "\n        nonlinear_hmcode_sigmadisp100(z, z_size)\n\n        Return sigma_disp_100 for all the redshift specified in z, of size\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_591nonlinear_hmcode_sigmadisp100 = {"nonlinear_hmcode_sigmadisp100", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_591nonlinear_hmcode_sigmadisp100, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_590nonlinear_hmcode_sigmadisp100};
static PyObject *__pyx_pw_9classy_sz_5Class_591nonlinear_hmcode_sigmadisp100(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp100 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5836, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5836, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp100", 1, 2, 2, 1); __PYX_ERR(0, 5836, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigmadisp100") < 0)) __PYX_ERR(0, 5836, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5836, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp100", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5836, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp100", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5836, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_590nonlinear_hmcode_sigmadisp100(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_590nonlinear_hmcode_sigmadisp100(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  PyArrayObject *__pyx_v_sigma_disp_100 = 0;
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_disp_100_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp_100;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp_100;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp_100_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp_100_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp100", 1);
  __pyx_pybuffer_sigma_disp_100.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp_100.refcount = 0;
  __pyx_pybuffernd_sigma_disp_100.data = NULL;
  __pyx_pybuffernd_sigma_disp_100.rcbuffer = &__pyx_pybuffer_sigma_disp_100;
  __pyx_pybuffer_sigma_disp_100_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp_100_cb.refcount = 0;
  __pyx_pybuffernd_sigma_disp_100_cb.data = NULL;
  __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer = &__pyx_pybuffer_sigma_disp_100_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5836, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5851
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100 = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5851, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp_100 = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5851, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp_100.diminfo[0].strides = __pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp_100.diminfo[0].shape = __pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_disp_100 = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5852
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100 = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5852, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp_100_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5852, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp_100_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp_100_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_disp_100_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5858
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_disp_100             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigmadisp100_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_disp_100);
  __pyx_r = ((PyObject *)__pyx_v_sigma_disp_100);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5836
 *         return sigma_disp_cb
 * 
 *     def nonlinear_hmcode_sigmadisp100(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp100", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp_100);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp_100_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5860
 *         return sigma_disp_100
 * 
 *     def nonlinear_hmcode_sigmadisp100_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_593nonlinear_hmcode_sigmadisp100_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_592nonlinear_hmcode_sigmadisp100_cb, "\n        nonlinear_hmcode_sigmadisp100(z, z_size)\n\n        Return sigma_disp_100 for all the redshift specified in z, of size\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_593nonlinear_hmcode_sigmadisp100_cb = {"nonlinear_hmcode_sigmadisp100_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_593nonlinear_hmcode_sigmadisp100_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_592nonlinear_hmcode_sigmadisp100_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_593nonlinear_hmcode_sigmadisp100_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp100_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5860, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5860, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp100_cb", 1, 2, 2, 1); __PYX_ERR(0, 5860, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigmadisp100_cb") < 0)) __PYX_ERR(0, 5860, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5860, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmadisp100_cb", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5860, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp100_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5860, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_592nonlinear_hmcode_sigmadisp100_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_592nonlinear_hmcode_sigmadisp100_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_disp_100 = 0;
  PyArrayObject *__pyx_v_sigma_disp_100_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp_100;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp_100;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_disp_100_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_disp_100_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmadisp100_cb", 1);
  __pyx_pybuffer_sigma_disp_100.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp_100.refcount = 0;
  __pyx_pybuffernd_sigma_disp_100.data = NULL;
  __pyx_pybuffernd_sigma_disp_100.rcbuffer = &__pyx_pybuffer_sigma_disp_100;
  __pyx_pybuffer_sigma_disp_100_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_disp_100_cb.refcount = 0;
  __pyx_pybuffernd_sigma_disp_100_cb.data = NULL;
  __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer = &__pyx_pybuffer_sigma_disp_100_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5860, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5875
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100 = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5875, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5875, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp_100 = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5875, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp_100.diminfo[0].strides = __pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp_100.diminfo[0].shape = __pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_disp_100 = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5876
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100 = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_disp_100_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5876, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_disp_100_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5876, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_disp_100_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_disp_100_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_disp_100_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5882
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_disp_100_cb             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigmaprime(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_disp_100_cb);
  __pyx_r = ((PyObject *)__pyx_v_sigma_disp_100_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5860
 *         return sigma_disp_100
 * 
 *     def nonlinear_hmcode_sigmadisp100_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmadisp100_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_disp_100_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp_100);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_disp_100_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5884
 *         return sigma_disp_100_cb
 * 
 *     def nonlinear_hmcode_sigmaprime(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_595nonlinear_hmcode_sigmaprime(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_594nonlinear_hmcode_sigmaprime, "\n        nonlinear_hmcode_sigmaprime(z, z_size)\n\n        Return sigma_disp for all the redshift specified in z, of size\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_595nonlinear_hmcode_sigmaprime = {"nonlinear_hmcode_sigmaprime", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_595nonlinear_hmcode_sigmaprime, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_594nonlinear_hmcode_sigmaprime};
static PyObject *__pyx_pw_9classy_sz_5Class_595nonlinear_hmcode_sigmaprime(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmaprime (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5884, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5884, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmaprime", 1, 2, 2, 1); __PYX_ERR(0, 5884, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigmaprime") < 0)) __PYX_ERR(0, 5884, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5884, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmaprime", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5884, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmaprime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5884, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_594nonlinear_hmcode_sigmaprime(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_594nonlinear_hmcode_sigmaprime(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  PyArrayObject *__pyx_v_sigma_prime = 0;
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_prime_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_prime;
  __Pyx_Buffer __pyx_pybuffer_sigma_prime;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_prime_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_prime_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmaprime", 1);
  __pyx_pybuffer_sigma_prime.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_prime.refcount = 0;
  __pyx_pybuffernd_sigma_prime.data = NULL;
  __pyx_pybuffernd_sigma_prime.rcbuffer = &__pyx_pybuffer_sigma_prime;
  __pyx_pybuffer_sigma_prime_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_prime_cb.refcount = 0;
  __pyx_pybuffernd_sigma_prime_cb.data = NULL;
  __pyx_pybuffernd_sigma_prime_cb.rcbuffer = &__pyx_pybuffer_sigma_prime_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5884, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5899
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5899, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_prime = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5899, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_prime.diminfo[0].strides = __pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_prime.diminfo[0].shape = __pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_prime = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5900
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5900, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_prime_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5900, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_prime_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_prime_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_prime_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5906
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_prime             # <<<<<<<<<<<<<<
 * 
 *     def nonlinear_hmcode_sigmaprime_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_prime);
  __pyx_r = ((PyObject *)__pyx_v_sigma_prime);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5884
 *         return sigma_disp_100_cb
 * 
 *     def nonlinear_hmcode_sigmaprime(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmaprime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_prime);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_prime_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5908
 *         return sigma_prime
 * 
 *     def nonlinear_hmcode_sigmaprime_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_597nonlinear_hmcode_sigmaprime_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_596nonlinear_hmcode_sigmaprime_cb, "\n        nonlinear_hmcode_sigmaprime(z, z_size)\n\n        Return sigma_disp for all the redshift specified in z, of size\n        z_size\n\n        Parameters\n        ----------\n        z : numpy array\n                Array of requested redshifts\n        z_size : int\n                Size of the redshift array\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_597nonlinear_hmcode_sigmaprime_cb = {"nonlinear_hmcode_sigmaprime_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_597nonlinear_hmcode_sigmaprime_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_596nonlinear_hmcode_sigmaprime_cb};
static PyObject *__pyx_pw_9classy_sz_5Class_597nonlinear_hmcode_sigmaprime_cb(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_z_size;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmaprime_cb (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z,&__pyx_n_s_z_size,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5908, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5908, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmaprime_cb", 1, 2, 2, 1); __PYX_ERR(0, 5908, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "nonlinear_hmcode_sigmaprime_cb") < 0)) __PYX_ERR(0, 5908, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z = ((PyArrayObject *)values[0]);
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5908, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("nonlinear_hmcode_sigmaprime_cb", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5908, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmaprime_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5908, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_596nonlinear_hmcode_sigmaprime_cb(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z, __pyx_v_z_size);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_596nonlinear_hmcode_sigmaprime_cb(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyArrayObject *__pyx_v_z, int __pyx_v_z_size) {
  CYTHON_UNUSED PyArrayObject *__pyx_v_sigma_prime = 0;
  PyArrayObject *__pyx_v_sigma_prime_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_prime;
  __Pyx_Buffer __pyx_pybuffer_sigma_prime;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_sigma_prime_cb;
  __Pyx_Buffer __pyx_pybuffer_sigma_prime_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("nonlinear_hmcode_sigmaprime_cb", 1);
  __pyx_pybuffer_sigma_prime.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_prime.refcount = 0;
  __pyx_pybuffernd_sigma_prime.data = NULL;
  __pyx_pybuffernd_sigma_prime.rcbuffer = &__pyx_pybuffer_sigma_prime;
  __pyx_pybuffer_sigma_prime_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_sigma_prime_cb.refcount = 0;
  __pyx_pybuffernd_sigma_prime_cb.data = NULL;
  __pyx_pybuffernd_sigma_prime_cb.rcbuffer = &__pyx_pybuffer_sigma_prime_cb;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5908, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5923
 *         """
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime_cb = np.zeros(z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5923, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_prime = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5923, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_prime.diminfo[0].strides = __pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_prime.diminfo[0].shape = __pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_sigma_prime = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5924
 *         cdef int index_z
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime = np.zeros(z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] sigma_prime_cb = np.zeros(z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 * #        for index_z in range(z_size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_z_size); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5924, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_sigma_prime_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5924, __pyx_L1_error)
    } else {__pyx_pybuffernd_sigma_prime_cb.diminfo[0].strides = __pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_sigma_prime_cb.diminfo[0].shape = __pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_sigma_prime_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5930
 * #                raise CosmoSevereError(self.nl.error_message)
 * 
 *         return sigma_prime_cb             # <<<<<<<<<<<<<<
 * 
 *     def __call__(self, ctx):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_sigma_prime_cb);
  __pyx_r = ((PyObject *)__pyx_v_sigma_prime_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5908
 *         return sigma_prime
 * 
 *     def nonlinear_hmcode_sigmaprime_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.nonlinear_hmcode_sigmaprime_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_sigma_prime_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_prime);
  __Pyx_XDECREF((PyObject *)__pyx_v_sigma_prime_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5932
 *         return sigma_prime_cb
 * 
 *     def __call__(self, ctx):             # <<<<<<<<<<<<<<
 *         """
 *         Function to interface with CosmoHammer
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_599__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_598__call__, "\n        Function to interface with CosmoHammer\n\n        Parameters\n        ----------\n        ctx : context\n                Contains several dictionaries storing data and cosmological\n                information\n\n        ");
#if CYTHON_UPDATE_DESCRIPTOR_DOC
struct wrapperbase __pyx_wrapperbase_9classy_sz_5Class_598__call__;
#endif
static PyObject *__pyx_pw_9classy_sz_5Class_599__call__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_ctx = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__call__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ctx,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ctx)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5932, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__call__") < 0)) __PYX_ERR(0, 5932, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_ctx = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__call__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5932, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_598__call__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_ctx);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_598__call__(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyObject *__pyx_v_ctx) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_elem = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__call__", 1);

  /* "class-sz/python/classy.pyx":5943
 * 
 *         """
 *         data = ctx.get('data')  # recover data from the context             # <<<<<<<<<<<<<<
 * 
 *         # If the module has already been called once, clean-up
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_data};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_data = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5946
 * 
 *         # If the module has already been called once, clean-up
 *         if self.state:             # <<<<<<<<<<<<<<
 *             self.struct_cleanup()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_state); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 5946, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "class-sz/python/classy.pyx":5947
 *         # If the module has already been called once, clean-up
 *         if self.state:
 *             self.struct_cleanup()             # <<<<<<<<<<<<<<
 * 
 *         # Set the module to the current values
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_struct_cleanup); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5947, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5946
 * 
 *         # If the module has already been called once, clean-up
 *         if self.state:             # <<<<<<<<<<<<<<
 *             self.struct_cleanup()
 * 
 */
  }

  /* "class-sz/python/classy.pyx":5950
 * 
 *         # Set the module to the current values
 *         self.set(data.cosmo_arguments)             # <<<<<<<<<<<<<<
 *         self.compute(["lensing"])
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_cosmo_arguments); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5951
 *         # Set the module to the current values
 *         self.set(data.cosmo_arguments)
 *         self.compute(["lensing"])             # <<<<<<<<<<<<<<
 * 
 *         # Compute the derived paramter value and store them
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_compute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_lensing);
  __Pyx_GIVEREF(__pyx_n_u_lensing);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_lensing)) __PYX_ERR(0, 5951, __pyx_L1_error);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5951, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5954
 * 
 *         # Compute the derived paramter value and store them
 *         params = ctx.getData()             # <<<<<<<<<<<<<<
 *         self.get_current_derived_parameters(
 *             data.get_mcmc_parameters(['derived']))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_n_s_getData); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5954, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_params = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5955
 *         # Compute the derived paramter value and store them
 *         params = ctx.getData()
 *         self.get_current_derived_parameters(             # <<<<<<<<<<<<<<
 *             data.get_mcmc_parameters(['derived']))
 *         for elem in data.get_mcmc_parameters(['derived']):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_current_derived_parameters); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "class-sz/python/classy.pyx":5956
 *         params = ctx.getData()
 *         self.get_current_derived_parameters(
 *             data.get_mcmc_parameters(['derived']))             # <<<<<<<<<<<<<<
 *         for elem in data.get_mcmc_parameters(['derived']):
 *             data.mcmc_parameters[elem]['current'] /= \
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_get_mcmc_parameters); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_derived);
  __Pyx_GIVEREF(__pyx_n_u_derived);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_derived)) __PYX_ERR(0, 5956, __pyx_L1_error);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5957
 *         self.get_current_derived_parameters(
 *             data.get_mcmc_parameters(['derived']))
 *         for elem in data.get_mcmc_parameters(['derived']):             # <<<<<<<<<<<<<<
 *             data.mcmc_parameters[elem]['current'] /= \
 *                 data.mcmc_parameters[elem]['scale']
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_get_mcmc_parameters); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_derived);
  __Pyx_GIVEREF(__pyx_n_u_derived);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_derived)) __PYX_ERR(0, 5957, __pyx_L1_error);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_2 = __pyx_t_1; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_9 = 0;
    __pyx_t_10 = NULL;
  } else {
    __pyx_t_9 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5957, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 5957, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_10)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5957, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_1); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 5957, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5957, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 5957, __pyx_L1_error)
          #endif
          if (__pyx_t_9 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_9); __Pyx_INCREF(__pyx_t_1); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 5957, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5957, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_10(__pyx_t_2);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 5957, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_elem, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "class-sz/python/classy.pyx":5958
 *             data.get_mcmc_parameters(['derived']))
 *         for elem in data.get_mcmc_parameters(['derived']):
 *             data.mcmc_parameters[elem]['current'] /= \             # <<<<<<<<<<<<<<
 *                 data.mcmc_parameters[elem]['scale']
 *             params[elem] = data.mcmc_parameters[elem]['current']
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_mcmc_parameters); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_elem); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_INCREF(__pyx_n_u_current);
    __pyx_t_11 = __pyx_n_u_current;
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "class-sz/python/classy.pyx":5959
 *         for elem in data.get_mcmc_parameters(['derived']):
 *             data.mcmc_parameters[elem]['current'] /= \
 *                 data.mcmc_parameters[elem]['scale']             # <<<<<<<<<<<<<<
 *             params[elem] = data.mcmc_parameters[elem]['current']
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_mcmc_parameters); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_6, __pyx_v_elem); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_t_7, __pyx_n_u_scale); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 5959, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "class-sz/python/classy.pyx":5958
 *             data.get_mcmc_parameters(['derived']))
 *         for elem in data.get_mcmc_parameters(['derived']):
 *             data.mcmc_parameters[elem]['current'] /= \             # <<<<<<<<<<<<<<
 *                 data.mcmc_parameters[elem]['scale']
 *             params[elem] = data.mcmc_parameters[elem]['current']
 */
    __pyx_t_7 = __Pyx_PyNumber_InPlaceDivide(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_t_11, __pyx_t_7) < 0))) __PYX_ERR(0, 5958, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":5960
 *             data.mcmc_parameters[elem]['current'] /= \
 *                 data.mcmc_parameters[elem]['scale']
 *             params[elem] = data.mcmc_parameters[elem]['current']             # <<<<<<<<<<<<<<
 * 
 *         ctx.add('boundary', True)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_data, __pyx_n_s_mcmc_parameters); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_elem); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 5960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_7, __pyx_n_u_current); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely((PyObject_SetItem(__pyx_v_params, __pyx_v_elem, __pyx_t_3) < 0))) __PYX_ERR(0, 5960, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "class-sz/python/classy.pyx":5957
 *         self.get_current_derived_parameters(
 *             data.get_mcmc_parameters(['derived']))
 *         for elem in data.get_mcmc_parameters(['derived']):             # <<<<<<<<<<<<<<
 *             data.mcmc_parameters[elem]['current'] /= \
 *                 data.mcmc_parameters[elem]['scale']
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "class-sz/python/classy.pyx":5962
 *             params[elem] = data.mcmc_parameters[elem]['current']
 * 
 *         ctx.add('boundary', True)             # <<<<<<<<<<<<<<
 *         # Store itself into the context, to be accessed by the likelihoods
 *         ctx.add('cosmo', self)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5964
 *         ctx.add('boundary', True)
 *         # Store itself into the context, to be accessed by the likelihoods
 *         ctx.add('cosmo', self)             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ctx, __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_n_u_cosmo, ((PyObject *)__pyx_v_self)};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "class-sz/python/classy.pyx":5932
 *         return sigma_prime_cb
 * 
 *     def __call__(self, ctx):             # <<<<<<<<<<<<<<
 *         """
 *         Function to interface with CosmoHammer
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("classy_sz.Class.__call__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_elem);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5966
 *         ctx.add('cosmo', self)
 * 
 *     def get_pk_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_601get_pk_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_600get_pk_array, " Fast function to get the power spectrum on a k and z array ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_601get_pk_array = {"get_pk_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_601get_pk_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_600get_pk_array};
static PyObject *__pyx_pw_9classy_sz_5Class_601get_pk_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_k = 0;
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_k_size;
  int __pyx_v_z_size;
  PyObject *__pyx_v_nonlinear = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,&__pyx_n_s_k_size,&__pyx_n_s_z_size,&__pyx_n_s_nonlinear,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5966, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5966, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_array", 1, 5, 5, 1); __PYX_ERR(0, 5966, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5966, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_array", 1, 5, 5, 2); __PYX_ERR(0, 5966, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5966, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_array", 1, 5, 5, 3); __PYX_ERR(0, 5966, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nonlinear)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5966, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_array", 1, 5, 5, 4); __PYX_ERR(0, 5966, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_array") < 0)) __PYX_ERR(0, 5966, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_k = ((PyArrayObject *)values[0]);
    __pyx_v_z = ((PyArrayObject *)values[1]);
    __pyx_v_k_size = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5966, __pyx_L3_error)
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5966, __pyx_L3_error)
    __pyx_v_nonlinear = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_array", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 5966, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_k), __pyx_ptype_5numpy_ndarray, 1, "k", 0))) __PYX_ERR(0, 5966, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5966, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_600get_pk_array(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z, __pyx_v_k_size, __pyx_v_z_size, __pyx_v_nonlinear);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_600get_pk_array(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, PyObject *__pyx_v_nonlinear) {
  PyArrayObject *__pyx_v_pk = 0;
  PyArrayObject *__pyx_v_pk_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k;
  __Pyx_Buffer __pyx_pybuffer_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk;
  __Pyx_Buffer __pyx_pybuffer_pk;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk_cb;
  __Pyx_Buffer __pyx_pybuffer_pk_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_array", 1);
  __pyx_pybuffer_pk.pybuffer.buf = NULL;
  __pyx_pybuffer_pk.refcount = 0;
  __pyx_pybuffernd_pk.data = NULL;
  __pyx_pybuffernd_pk.rcbuffer = &__pyx_pybuffer_pk;
  __pyx_pybuffer_pk_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_pk_cb.refcount = 0;
  __pyx_pybuffernd_pk_cb.data = NULL;
  __pyx_pybuffernd_pk_cb.rcbuffer = &__pyx_pybuffer_pk_cb;
  __pyx_pybuffer_k.pybuffer.buf = NULL;
  __pyx_pybuffer_k.refcount = 0;
  __pyx_pybuffernd_k.data = NULL;
  __pyx_pybuffernd_k.rcbuffer = &__pyx_pybuffer_k;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k.rcbuffer->pybuffer, (PyObject*)__pyx_v_k, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5966, __pyx_L1_error)
  }
  __pyx_pybuffernd_k.diminfo[0].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k.diminfo[0].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5966, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5968
 *     def get_pk_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int((__pyx_v_k_size * __pyx_v_z_size)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5968, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_pk = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5968, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk.diminfo[0].strides = __pyx_pybuffernd_pk.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk.diminfo[0].shape = __pyx_pybuffernd_pk.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_pk = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5969
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 *         if nonlinear == 0:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int((__pyx_v_k_size * __pyx_v_z_size)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5969, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_pk_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5969, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk_cb.diminfo[0].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk_cb.diminfo[0].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_pk_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5971
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')
 * 
 *         if nonlinear == 0:             # <<<<<<<<<<<<<<
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_linear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)
 * 
 */
  __pyx_t_8 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_nonlinear, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 5971, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "class-sz/python/classy.pyx":5972
 * 
 *         if nonlinear == 0:
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_linear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    (void)(nonlinear_pks_at_kvec_and_zvec((&__pyx_v_self->ba), (&__pyx_v_self->nl), pk_linear, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_k))), __pyx_v_k_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_z))), __pyx_v_z_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk))), ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk_cb)))));

    /* "class-sz/python/classy.pyx":5971
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')
 * 
 *         if nonlinear == 0:             # <<<<<<<<<<<<<<
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_linear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)
 * 
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":5975
 * 
 *         else:
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_nonlinear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)             # <<<<<<<<<<<<<<
 * 
 *         return pk
 */
  /*else*/ {
    (void)(nonlinear_pks_at_kvec_and_zvec((&__pyx_v_self->ba), (&__pyx_v_self->nl), pk_nonlinear, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_k))), __pyx_v_k_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_z))), __pyx_v_z_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk))), ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk_cb)))));
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":5977
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_nonlinear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)
 * 
 *         return pk             # <<<<<<<<<<<<<<
 * 
 *     def get_pk_cb_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_pk);
  __pyx_r = ((PyObject *)__pyx_v_pk);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5966
 *         ctx.add('cosmo', self)
 * 
 *     def get_pk_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.get_pk_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pk);
  __Pyx_XDECREF((PyObject *)__pyx_v_pk_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5979
 *         return pk
 * 
 *     def get_pk_cb_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_603get_pk_cb_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_602get_pk_cb_array, " Fast function to get the power spectrum on a k and z array ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_603get_pk_cb_array = {"get_pk_cb_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_603get_pk_cb_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_602get_pk_cb_array};
static PyObject *__pyx_pw_9classy_sz_5Class_603get_pk_cb_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_k = 0;
  PyArrayObject *__pyx_v_z = 0;
  int __pyx_v_k_size;
  int __pyx_v_z_size;
  PyObject *__pyx_v_nonlinear = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pk_cb_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_k,&__pyx_n_s_z,&__pyx_n_s_k_size,&__pyx_n_s_z_size,&__pyx_n_s_nonlinear,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5979, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5979, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_array", 1, 5, 5, 1); __PYX_ERR(0, 5979, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5979, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_array", 1, 5, 5, 2); __PYX_ERR(0, 5979, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_size)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5979, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_array", 1, 5, 5, 3); __PYX_ERR(0, 5979, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_nonlinear)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5979, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_pk_cb_array", 1, 5, 5, 4); __PYX_ERR(0, 5979, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_pk_cb_array") < 0)) __PYX_ERR(0, 5979, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_k = ((PyArrayObject *)values[0]);
    __pyx_v_z = ((PyArrayObject *)values[1]);
    __pyx_v_k_size = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_k_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5979, __pyx_L3_error)
    __pyx_v_z_size = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_z_size == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5979, __pyx_L3_error)
    __pyx_v_nonlinear = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_pk_cb_array", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 5979, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_pk_cb_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_k), __pyx_ptype_5numpy_ndarray, 1, "k", 0))) __PYX_ERR(0, 5979, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_z), __pyx_ptype_5numpy_ndarray, 1, "z", 0))) __PYX_ERR(0, 5979, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_602get_pk_cb_array(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_k, __pyx_v_z, __pyx_v_k_size, __pyx_v_z_size, __pyx_v_nonlinear);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_602get_pk_cb_array(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_z, int __pyx_v_k_size, int __pyx_v_z_size, PyObject *__pyx_v_nonlinear) {
  PyArrayObject *__pyx_v_pk = 0;
  PyArrayObject *__pyx_v_pk_cb = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k;
  __Pyx_Buffer __pyx_pybuffer_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk;
  __Pyx_Buffer __pyx_pybuffer_pk;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk_cb;
  __Pyx_Buffer __pyx_pybuffer_pk_cb;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_z;
  __Pyx_Buffer __pyx_pybuffer_z;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyArrayObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_pk_cb_array", 1);
  __pyx_pybuffer_pk.pybuffer.buf = NULL;
  __pyx_pybuffer_pk.refcount = 0;
  __pyx_pybuffernd_pk.data = NULL;
  __pyx_pybuffernd_pk.rcbuffer = &__pyx_pybuffer_pk;
  __pyx_pybuffer_pk_cb.pybuffer.buf = NULL;
  __pyx_pybuffer_pk_cb.refcount = 0;
  __pyx_pybuffernd_pk_cb.data = NULL;
  __pyx_pybuffernd_pk_cb.rcbuffer = &__pyx_pybuffer_pk_cb;
  __pyx_pybuffer_k.pybuffer.buf = NULL;
  __pyx_pybuffer_k.refcount = 0;
  __pyx_pybuffernd_k.data = NULL;
  __pyx_pybuffernd_k.rcbuffer = &__pyx_pybuffer_k;
  __pyx_pybuffer_z.pybuffer.buf = NULL;
  __pyx_pybuffer_z.refcount = 0;
  __pyx_pybuffernd_z.data = NULL;
  __pyx_pybuffernd_z.rcbuffer = &__pyx_pybuffer_z;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k.rcbuffer->pybuffer, (PyObject*)__pyx_v_k, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5979, __pyx_L1_error)
  }
  __pyx_pybuffernd_k.diminfo[0].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k.diminfo[0].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_z.rcbuffer->pybuffer, (PyObject*)__pyx_v_z, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5979, __pyx_L1_error)
  }
  __pyx_pybuffernd_z.diminfo[0].strides = __pyx_pybuffernd_z.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_z.diminfo[0].shape = __pyx_pybuffernd_z.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5981
 *     def get_pk_cb_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int((__pyx_v_k_size * __pyx_v_z_size)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5981, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5981, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_pk = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5981, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk.diminfo[0].strides = __pyx_pybuffernd_pk.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk.diminfo[0].shape = __pyx_pybuffernd_pk.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_pk = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5982
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')             # <<<<<<<<<<<<<<
 * 
 *         if nonlinear == 0:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 5982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int((__pyx_v_k_size * __pyx_v_z_size)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 5982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_3, __pyx_n_u_float64};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 5982, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_1);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_pk_cb = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(0, 5982, __pyx_L1_error)
    } else {__pyx_pybuffernd_pk_cb.diminfo[0].strides = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk_cb.diminfo[0].shape = __pyx_pybuffernd_pk_cb.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_pk_cb = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "class-sz/python/classy.pyx":5984
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')
 * 
 *         if nonlinear == 0:             # <<<<<<<<<<<<<<
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_linear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)
 * 
 */
  __pyx_t_8 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_nonlinear, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 5984, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "class-sz/python/classy.pyx":5985
 * 
 *         if nonlinear == 0:
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_linear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    (void)(nonlinear_pks_at_kvec_and_zvec((&__pyx_v_self->ba), (&__pyx_v_self->nl), pk_linear, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_k))), __pyx_v_k_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_z))), __pyx_v_z_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk))), ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk_cb)))));

    /* "class-sz/python/classy.pyx":5984
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk_cb = np.zeros(k_size*z_size,'float64')
 * 
 *         if nonlinear == 0:             # <<<<<<<<<<<<<<
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_linear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)
 * 
 */
    goto __pyx_L3;
  }

  /* "class-sz/python/classy.pyx":5988
 * 
 *         else:
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_nonlinear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)             # <<<<<<<<<<<<<<
 * 
 *         return pk_cb
 */
  /*else*/ {
    (void)(nonlinear_pks_at_kvec_and_zvec((&__pyx_v_self->ba), (&__pyx_v_self->nl), pk_nonlinear, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_k))), __pyx_v_k_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_z))), __pyx_v_z_size, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk))), ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk_cb)))));
  }
  __pyx_L3:;

  /* "class-sz/python/classy.pyx":5990
 *             nonlinear_pks_at_kvec_and_zvec(&self.ba, &self.nl, pk_nonlinear, <double*> k.data, k_size, <double*> z.data, z_size, <double*> pk.data, <double*> pk_cb.data)
 * 
 *         return pk_cb             # <<<<<<<<<<<<<<
 * 
 *     def get_fftlog_ComputeXiLMsloz(self, int l, int m, int N, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] pk, np.ndarray[DTYPE_t,ndim=1] r, np.ndarray[DTYPE_t,ndim=1] xi):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_pk_cb);
  __pyx_r = ((PyObject *)__pyx_v_pk_cb);
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5979
 *         return pk
 * 
 *     def get_pk_cb_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.get_pk_cb_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk_cb.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_z.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_pk);
  __Pyx_XDECREF((PyObject *)__pyx_v_pk_cb);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5992
 *         return pk_cb
 * 
 *     def get_fftlog_ComputeXiLMsloz(self, int l, int m, int N, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] pk, np.ndarray[DTYPE_t,ndim=1] r, np.ndarray[DTYPE_t,ndim=1] xi):             # <<<<<<<<<<<<<<
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_605get_fftlog_ComputeXiLMsloz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_605get_fftlog_ComputeXiLMsloz = {"get_fftlog_ComputeXiLMsloz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_605get_fftlog_ComputeXiLMsloz, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_605get_fftlog_ComputeXiLMsloz(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_l;
  int __pyx_v_m;
  int __pyx_v_N;
  PyArrayObject *__pyx_v_k = 0;
  PyArrayObject *__pyx_v_pk = 0;
  PyArrayObject *__pyx_v_r = 0;
  PyArrayObject *__pyx_v_xi = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_fftlog_ComputeXiLMsloz (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_l,&__pyx_n_s_m,&__pyx_n_s_N,&__pyx_n_s_k,&__pyx_n_s_pk,&__pyx_n_s_r,&__pyx_n_s_xi,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_l)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_m)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_fftlog_ComputeXiLMsloz", 1, 7, 7, 1); __PYX_ERR(0, 5992, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_N)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_fftlog_ComputeXiLMsloz", 1, 7, 7, 2); __PYX_ERR(0, 5992, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_fftlog_ComputeXiLMsloz", 1, 7, 7, 3); __PYX_ERR(0, 5992, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pk)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_fftlog_ComputeXiLMsloz", 1, 7, 7, 4); __PYX_ERR(0, 5992, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_r)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[5]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_fftlog_ComputeXiLMsloz", 1, 7, 7, 5); __PYX_ERR(0, 5992, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_xi)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[6]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_fftlog_ComputeXiLMsloz", 1, 7, 7, 6); __PYX_ERR(0, 5992, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_fftlog_ComputeXiLMsloz") < 0)) __PYX_ERR(0, 5992, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 7)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
      values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
      values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
    }
    __pyx_v_l = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_l == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
    __pyx_v_m = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_m == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
    __pyx_v_N = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_N == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 5992, __pyx_L3_error)
    __pyx_v_k = ((PyArrayObject *)values[3]);
    __pyx_v_pk = ((PyArrayObject *)values[4]);
    __pyx_v_r = ((PyArrayObject *)values[5]);
    __pyx_v_xi = ((PyArrayObject *)values[6]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_fftlog_ComputeXiLMsloz", 1, 7, 7, __pyx_nargs); __PYX_ERR(0, 5992, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_fftlog_ComputeXiLMsloz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_k), __pyx_ptype_5numpy_ndarray, 1, "k", 0))) __PYX_ERR(0, 5992, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pk), __pyx_ptype_5numpy_ndarray, 1, "pk", 0))) __PYX_ERR(0, 5992, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_r), __pyx_ptype_5numpy_ndarray, 1, "r", 0))) __PYX_ERR(0, 5992, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_xi), __pyx_ptype_5numpy_ndarray, 1, "xi", 0))) __PYX_ERR(0, 5992, __pyx_L1_error)
  __pyx_r = __pyx_pf_9classy_sz_5Class_604get_fftlog_ComputeXiLMsloz(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_l, __pyx_v_m, __pyx_v_N, __pyx_v_k, __pyx_v_pk, __pyx_v_r, __pyx_v_xi);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_604get_fftlog_ComputeXiLMsloz(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, int __pyx_v_l, int __pyx_v_m, int __pyx_v_N, PyArrayObject *__pyx_v_k, PyArrayObject *__pyx_v_pk, PyArrayObject *__pyx_v_r, PyArrayObject *__pyx_v_xi) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_k;
  __Pyx_Buffer __pyx_pybuffer_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_pk;
  __Pyx_Buffer __pyx_pybuffer_pk;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_r;
  __Pyx_Buffer __pyx_pybuffer_r;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_xi;
  __Pyx_Buffer __pyx_pybuffer_xi;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_fftlog_ComputeXiLMsloz", 1);
  __pyx_pybuffer_k.pybuffer.buf = NULL;
  __pyx_pybuffer_k.refcount = 0;
  __pyx_pybuffernd_k.data = NULL;
  __pyx_pybuffernd_k.rcbuffer = &__pyx_pybuffer_k;
  __pyx_pybuffer_pk.pybuffer.buf = NULL;
  __pyx_pybuffer_pk.refcount = 0;
  __pyx_pybuffernd_pk.data = NULL;
  __pyx_pybuffernd_pk.rcbuffer = &__pyx_pybuffer_pk;
  __pyx_pybuffer_r.pybuffer.buf = NULL;
  __pyx_pybuffer_r.refcount = 0;
  __pyx_pybuffernd_r.data = NULL;
  __pyx_pybuffernd_r.rcbuffer = &__pyx_pybuffer_r;
  __pyx_pybuffer_xi.pybuffer.buf = NULL;
  __pyx_pybuffer_xi.refcount = 0;
  __pyx_pybuffernd_xi.data = NULL;
  __pyx_pybuffernd_xi.rcbuffer = &__pyx_pybuffer_xi;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_k.rcbuffer->pybuffer, (PyObject*)__pyx_v_k, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5992, __pyx_L1_error)
  }
  __pyx_pybuffernd_k.diminfo[0].strides = __pyx_pybuffernd_k.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_k.diminfo[0].shape = __pyx_pybuffernd_k.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_pk.rcbuffer->pybuffer, (PyObject*)__pyx_v_pk, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5992, __pyx_L1_error)
  }
  __pyx_pybuffernd_pk.diminfo[0].strides = __pyx_pybuffernd_pk.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_pk.diminfo[0].shape = __pyx_pybuffernd_pk.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_r.rcbuffer->pybuffer, (PyObject*)__pyx_v_r, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5992, __pyx_L1_error)
  }
  __pyx_pybuffernd_r.diminfo[0].strides = __pyx_pybuffernd_r.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_r.diminfo[0].shape = __pyx_pybuffernd_r.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xi.rcbuffer->pybuffer, (PyObject*)__pyx_v_xi, &__Pyx_TypeInfo_nn___pyx_t_9classy_sz_DTYPE_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 5992, __pyx_L1_error)
  }
  __pyx_pybuffernd_xi.diminfo[0].strides = __pyx_pybuffernd_xi.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_xi.diminfo[0].shape = __pyx_pybuffernd_xi.rcbuffer->pybuffer.shape[0];

  /* "class-sz/python/classy.pyx":5993
 * 
 *     def get_fftlog_ComputeXiLMsloz(self, int l, int m, int N, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] pk, np.ndarray[DTYPE_t,ndim=1] r, np.ndarray[DTYPE_t,ndim=1] xi):
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_n5k_z_of_chi(self, double chi):
 */
  fftlog_ComputeXiLMsloz(__pyx_v_l, __pyx_v_m, __pyx_v_N, ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_k))), ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_pk))), ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_r))), ((double *)__pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_xi))), (&__pyx_v_self->tsz));

  /* "class-sz/python/classy.pyx":5992
 *         return pk_cb
 * 
 *     def get_fftlog_ComputeXiLMsloz(self, int l, int m, int N, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] pk, np.ndarray[DTYPE_t,ndim=1] r, np.ndarray[DTYPE_t,ndim=1] xi):             # <<<<<<<<<<<<<<
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_r.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xi.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("classy_sz.Class.get_fftlog_ComputeXiLMsloz", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_k.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_pk.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_r.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xi.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5995
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 *     def get_n5k_z_of_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_607get_n5k_z_of_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_607get_n5k_z_of_chi = {"get_n5k_z_of_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_607get_n5k_z_of_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_607get_n5k_z_of_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_chi;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_n5k_z_of_chi (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_chi,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5995, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_n5k_z_of_chi") < 0)) __PYX_ERR(0, 5995, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_chi = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_chi == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5995, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_n5k_z_of_chi", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 5995, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_n5k_z_of_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_606get_n5k_z_of_chi(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_chi);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_606get_n5k_z_of_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_chi) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_n5k_z_of_chi", 1);

  /* "class-sz/python/classy.pyx":5996
 * 
 *     def get_n5k_z_of_chi(self, double chi):
 *         return get_n5k_z_of_chi(chi, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_n5k_pk_at_z_and_k(self, double z_asked, double k_asked):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_n5k_z_of_chi(__pyx_v_chi, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5995
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 *     def get_n5k_z_of_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_n5k_z_of_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":5998
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 *     def get_n5k_pk_at_z_and_k(self, double z_asked, double k_asked):             # <<<<<<<<<<<<<<
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_609get_n5k_pk_at_z_and_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_609get_n5k_pk_at_z_and_k = {"get_n5k_pk_at_z_and_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_609get_n5k_pk_at_z_and_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_609get_n5k_pk_at_z_and_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_z_asked;
  double __pyx_v_k_asked;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_n5k_pk_at_z_and_k (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_z_asked,&__pyx_n_s_k_asked,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_z_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5998, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_k_asked)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 5998, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_n5k_pk_at_z_and_k", 1, 2, 2, 1); __PYX_ERR(0, 5998, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_n5k_pk_at_z_and_k") < 0)) __PYX_ERR(0, 5998, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_z_asked = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_z_asked == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5998, __pyx_L3_error)
    __pyx_v_k_asked = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_k_asked == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 5998, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_n5k_pk_at_z_and_k", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 5998, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_n5k_pk_at_z_and_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_608get_n5k_pk_at_z_and_k(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_z_asked, __pyx_v_k_asked);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_608get_n5k_pk_at_z_and_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_z_asked, double __pyx_v_k_asked) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_n5k_pk_at_z_and_k", 1);

  /* "class-sz/python/classy.pyx":5999
 * 
 *     def get_n5k_pk_at_z_and_k(self, double z_asked, double k_asked):
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def get_n5k_cl_K1_at_chi(self, double chi):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_n5k_pk_at_z_and_k(__pyx_v_z_asked, __pyx_v_k_asked, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 5999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":5998
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 *     def get_n5k_pk_at_z_and_k(self, double z_asked, double k_asked):             # <<<<<<<<<<<<<<
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_n5k_pk_at_z_and_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":6001
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 *     def get_n5k_cl_K1_at_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_611get_n5k_cl_K1_at_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_611get_n5k_cl_K1_at_chi = {"get_n5k_cl_K1_at_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_611get_n5k_cl_K1_at_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_611get_n5k_cl_K1_at_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  double __pyx_v_chi;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_n5k_cl_K1_at_chi (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_chi,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_chi)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 6001, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_n5k_cl_K1_at_chi") < 0)) __PYX_ERR(0, 6001, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_chi = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_chi == (double)-1) && PyErr_Occurred())) __PYX_ERR(0, 6001, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_n5k_cl_K1_at_chi", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 6001, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.get_n5k_cl_K1_at_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_610get_n5k_cl_K1_at_chi(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v_chi);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_610get_n5k_cl_K1_at_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self, double __pyx_v_chi) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_n5k_cl_K1_at_chi", 1);

  /* "class-sz/python/classy.pyx":6002
 * 
 *     def get_n5k_cl_K1_at_chi(self, double chi):
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)             # <<<<<<<<<<<<<<
 * 
 *     def load_n5k_cl_K1(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(get_n5k_cl_K1_at_chi(__pyx_v_chi, (&__pyx_v_self->tsz))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":6001
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 *     def get_n5k_cl_K1_at_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.get_n5k_cl_K1_at_chi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":6004
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 *     def load_n5k_cl_K1(self):             # <<<<<<<<<<<<<<
 *         load_n5k_cl_K1(&self.tsz)
 *         return 1
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_613load_n5k_cl_K1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_613load_n5k_cl_K1 = {"load_n5k_cl_K1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_613load_n5k_cl_K1, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_613load_n5k_cl_K1(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_n5k_cl_K1 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("load_n5k_cl_K1", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "load_n5k_cl_K1", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_612load_n5k_cl_K1(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_612load_n5k_cl_K1(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_n5k_cl_K1", 1);

  /* "class-sz/python/classy.pyx":6005
 * 
 *     def load_n5k_cl_K1(self):
 *         load_n5k_cl_K1(&self.tsz)             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
  (void)(load_n5k_cl_K1((&__pyx_v_self->tsz)));

  /* "class-sz/python/classy.pyx":6006
 *     def load_n5k_cl_K1(self):
 *         load_n5k_cl_K1(&self.tsz)
 *         return 1             # <<<<<<<<<<<<<<
 * 
 *     def load_n5k_pk_zk(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_int_1);
  __pyx_r = __pyx_int_1;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":6004
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 *     def load_n5k_cl_K1(self):             # <<<<<<<<<<<<<<
 *         load_n5k_cl_K1(&self.tsz)
 *         return 1
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":6008
 *         return 1
 * 
 *     def load_n5k_pk_zk(self):             # <<<<<<<<<<<<<<
 *         load_n5k_pk_zk(&self.tsz)
 *         return 1
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_615load_n5k_pk_zk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_615load_n5k_pk_zk = {"load_n5k_pk_zk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_615load_n5k_pk_zk, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_615load_n5k_pk_zk(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_n5k_pk_zk (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("load_n5k_pk_zk", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "load_n5k_pk_zk", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_614load_n5k_pk_zk(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_614load_n5k_pk_zk(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_n5k_pk_zk", 1);

  /* "class-sz/python/classy.pyx":6009
 * 
 *     def load_n5k_pk_zk(self):
 *         load_n5k_pk_zk(&self.tsz)             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
  (void)(load_n5k_pk_zk((&__pyx_v_self->tsz)));

  /* "class-sz/python/classy.pyx":6010
 *     def load_n5k_pk_zk(self):
 *         load_n5k_pk_zk(&self.tsz)
 *         return 1             # <<<<<<<<<<<<<<
 * 
 *     def load_n5k_z_of_chi(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_int_1);
  __pyx_r = __pyx_int_1;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":6008
 *         return 1
 * 
 *     def load_n5k_pk_zk(self):             # <<<<<<<<<<<<<<
 *         load_n5k_pk_zk(&self.tsz)
 *         return 1
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":6012
 *         return 1
 * 
 *     def load_n5k_z_of_chi(self):             # <<<<<<<<<<<<<<
 *         load_n5k_z_of_chi(&self.tsz)
 *         return 1
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_617load_n5k_z_of_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_617load_n5k_z_of_chi = {"load_n5k_z_of_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_617load_n5k_z_of_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_617load_n5k_z_of_chi(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_n5k_z_of_chi (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("load_n5k_z_of_chi", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "load_n5k_z_of_chi", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_616load_n5k_z_of_chi(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_616load_n5k_z_of_chi(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_n5k_z_of_chi", 1);

  /* "class-sz/python/classy.pyx":6013
 * 
 *     def load_n5k_z_of_chi(self):
 *         load_n5k_z_of_chi(&self.tsz)             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
  (void)(load_n5k_z_of_chi((&__pyx_v_self->tsz)));

  /* "class-sz/python/classy.pyx":6014
 *     def load_n5k_z_of_chi(self):
 *         load_n5k_z_of_chi(&self.tsz)
 *         return 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_int_1);
  __pyx_r = __pyx_int_1;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":6012
 *         return 1
 * 
 *     def load_n5k_z_of_chi(self):             # <<<<<<<<<<<<<<
 *         load_n5k_z_of_chi(&self.tsz)
 *         return 1
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":6017
 * 
 * 
 *     def Omega0_k(self):             # <<<<<<<<<<<<<<
 *         """ Curvature contribution """
 *         return self.ba.Omega0_k
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_619Omega0_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_618Omega0_k, " Curvature contribution ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_619Omega0_k = {"Omega0_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_619Omega0_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_618Omega0_k};
static PyObject *__pyx_pw_9classy_sz_5Class_619Omega0_k(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega0_k (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega0_k", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega0_k", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_618Omega0_k(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_618Omega0_k(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega0_k", 1);

  /* "class-sz/python/classy.pyx":6019
 *     def Omega0_k(self):
 *         """ Curvature contribution """
 *         return self.ba.Omega0_k             # <<<<<<<<<<<<<<
 * 
 *     def Omega0_cdm(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_k); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":6017
 * 
 * 
 *     def Omega0_k(self):             # <<<<<<<<<<<<<<
 *         """ Curvature contribution """
 *         return self.ba.Omega0_k
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega0_k", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":6021
 *         return self.ba.Omega0_k
 * 
 *     def Omega0_cdm(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the cold dark matter density parameter at present time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_621Omega0_cdm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_620Omega0_cdm, "\n        Return the cold dark matter density parameter at present time.\n\n        Returns:\n            float: The current value of the Omega0_cdm parameter from the background structure.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_621Omega0_cdm = {"Omega0_cdm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_621Omega0_cdm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_620Omega0_cdm};
static PyObject *__pyx_pw_9classy_sz_5Class_621Omega0_cdm(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega0_cdm (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega0_cdm", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega0_cdm", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_620Omega0_cdm(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_620Omega0_cdm(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega0_cdm", 1);

  /* "class-sz/python/classy.pyx":6028
 *             float: The current value of the Omega0_cdm parameter from the background structure.
 *         """
 *         return self.ba.Omega0_cdm             # <<<<<<<<<<<<<<
 * 
 *     def Omega0_b(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_cdm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":6021
 *         return self.ba.Omega0_k
 * 
 *     def Omega0_cdm(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the cold dark matter density parameter at present time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega0_cdm", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "class-sz/python/classy.pyx":6030
 *         return self.ba.Omega0_cdm
 * 
 *     def Omega0_b(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the baryon density parameter at present time.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_623Omega0_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9classy_sz_5Class_622Omega0_b, "\n        Return the baryon density parameter at present time.\n\n        Returns:\n            float: The current value of the Omega0_b parameter from the background structure.\n        ");
static PyMethodDef __pyx_mdef_9classy_sz_5Class_623Omega0_b = {"Omega0_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_623Omega0_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_622Omega0_b};
static PyObject *__pyx_pw_9classy_sz_5Class_623Omega0_b(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("Omega0_b (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("Omega0_b", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "Omega0_b", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_622Omega0_b(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_622Omega0_b(struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("Omega0_b", 1);

  /* "class-sz/python/classy.pyx":6037
 *             float: The current value of the Omega0_b parameter from the background structure.
 *         """
 *         return self.ba.Omega0_b             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->ba.Omega0_b); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "class-sz/python/classy.pyx":6030
 *         return self.ba.Omega0_cdm
 * 
 *     def Omega0_b(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the baryon density parameter at present time.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("classy_sz.Class.Omega0_b", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_625__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_625__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_625__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_625__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_9classy_sz_5Class_624__reduce_cython__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_624__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("classy_sz.Class.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_9classy_sz_5Class_627__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9classy_sz_5Class_627__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_627__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9classy_sz_5Class_627__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("classy_sz.Class.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9classy_sz_5Class_626__setstate_cython__(((struct __pyx_obj_9classy_sz_Class *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9classy_sz_5Class_626__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9classy_sz_Class *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("classy_sz.Class.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_9classy_sz_Class __pyx_vtable_9classy_sz_Class;

static PyObject *__pyx_tp_new_9classy_sz_Class(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9classy_sz_Class *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_9classy_sz_Class *)o);
  p->__pyx_vtab = __pyx_vtabptr_9classy_sz_Class;
  p->_pars = Py_None; Py_INCREF(Py_None);
  p->ncp = Py_None; Py_INCREF(Py_None);
  p->logger = Py_None; Py_INCREF(Py_None);
  p->class_szfast = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9classy_sz_5Class_3__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9classy_sz_Class(PyObject *o) {
  struct __pyx_obj_9classy_sz_Class *p = (struct __pyx_obj_9classy_sz_Class *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9classy_sz_Class) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9classy_sz_5Class_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->_pars);
  Py_CLEAR(p->ncp);
  Py_CLEAR(p->logger);
  Py_CLEAR(p->class_szfast);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_9classy_sz_Class(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9classy_sz_Class *p = (struct __pyx_obj_9classy_sz_Class *)o;
  if (p->_pars) {
    e = (*v)(p->_pars, a); if (e) return e;
  }
  if (p->ncp) {
    e = (*v)(p->ncp, a); if (e) return e;
  }
  if (p->logger) {
    e = (*v)(p->logger, a); if (e) return e;
  }
  if (p->class_szfast) {
    e = (*v)(p->class_szfast, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9classy_sz_Class(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9classy_sz_Class *p = (struct __pyx_obj_9classy_sz_Class *)o;
  tmp = ((PyObject*)p->_pars);
  p->_pars = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->ncp);
  p->ncp = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->logger);
  p->logger = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->class_szfast);
  p->class_szfast = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9classy_sz_5Class_pars(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9classy_sz_5Class_4pars_1__get__(o);
}

static PyObject *__pyx_getprop_9classy_sz_5Class_state(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9classy_sz_5Class_5state_1__get__(o);
}

static PyObject *__pyx_getprop_9classy_sz_5Class_Omega_nu(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9classy_sz_5Class_8Omega_nu_1__get__(o);
}

static PyObject *__pyx_getprop_9classy_sz_5Class_nonlinear_method(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9classy_sz_5Class_16nonlinear_method_1__get__(o);
}

static PyObject *__pyx_getprop_9classy_sz_5Class_PATH_TO_CLASS_SZ_DATA(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9classy_sz_5Class_21PATH_TO_CLASS_SZ_DATA_1__get__(o);
}

static PyMethodDef __pyx_methods_9classy_sz_Class[] = {
  {"set_default", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_1set_default, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9classy_sz_5Class_7set, METH_VARARGS|METH_KEYWORDS, 0},
  {"empty", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_9empty, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_fillparfile", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_11_fillparfile, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"struct_cleanup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_13struct_cleanup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_check_task_dependency", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_15_check_task_dependency, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_14_check_task_dependency},
  {"_pars_check", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_17_pars_check, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"compute", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_19compute, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_18compute},
  {"calculate_pkl_fftlog_alphas", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_21calculate_pkl_fftlog_alphas, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pkl_reconstructed_from_fftlog", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_23get_pkl_reconstructed_from_fftlog, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"compute_class_szfast", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_25compute_class_szfast, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"compute_class_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_27compute_class_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"raw_cl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_29raw_cl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_28raw_cl},
  {"lensed_cl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_31lensed_cl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_30lensed_cl},
  {"density_cl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_33density_cl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_32density_cl},
  {"z_of_r", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_35z_of_r, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_34z_of_r},
  {"luminosity_distance", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_37luminosity_distance, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_36luminosity_distance},
  {"get_pkl_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_39get_pkl_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pknl_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_41get_pknl_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"pk_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_43pk_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_42pk_unvectorized},
  {"pk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_45pk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_44pk},
  {"pk_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_47pk_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_46pk_cb},
  {"pk_lin_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_49pk_lin_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_48pk_lin_unvectorized},
  {"pk_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_51pk_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_50pk_lin},
  {"pk_nonlin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_53pk_nonlin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_52pk_nonlin},
  {"pk_cb_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_55pk_cb_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_54pk_cb_lin},
  {"get_pk_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_57get_pk_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_56get_pk_cb},
  {"get_pk_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_59get_pk_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_58get_pk_lin},
  {"get_pk_cb_lin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_61get_pk_cb_lin, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_60get_pk_cb_lin},
  {"get_pk_and_k_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_63get_pk_and_k_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_62get_pk_and_k_and_z},
  {"sigma", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_65sigma, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_64sigma},
  {"sigma_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_67sigma_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_66sigma_cb},
  {"pk_tilt", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_69pk_tilt, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_68pk_tilt},
  {"nonlinear_hmcode_window_nfw", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_71nonlinear_hmcode_window_nfw, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_70nonlinear_hmcode_window_nfw},
  {"effective_f_sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_73effective_f_sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_72effective_f_sigma8},
  {"age", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_75age, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"h", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_77h, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"n_s", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_79n_s, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"tau_reio", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_81tau_reio, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"Omega_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_83Omega_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"Omega_r", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_85Omega_r, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"theta_s_100", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_87theta_s_100, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"theta_star_100", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_89theta_star_100, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"Omega_Lambda", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_91Omega_Lambda, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"Omega_g", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_93Omega_g, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"Omega_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_95Omega_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"omega_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_97omega_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"omega_cdm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_99omega_cdm, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"Neff", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_101Neff, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"k_eq", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_103k_eq, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_105sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_sigma8_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_107get_sigma8_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_effective_f_sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_109get_effective_f_sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_fstar_of_m_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_111get_fstar_of_m_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"sigma8_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_113sigma8_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"rs_drag", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_115rs_drag, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"z_reio", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_117z_reio, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_119get_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_118get_chi},
  {"angular_distance", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_121angular_distance, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_120angular_distance},
  {"get_radial_kernel_W_galaxy_ngal_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_123get_radial_kernel_W_galaxy_ngal_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_122get_radial_kernel_W_galaxy_ngal_at_z},
  {"scale_independent_growth_factor", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_125scale_independent_growth_factor, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_124scale_independent_growth_factor},
  {"scale_independent_growth_factor_f", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_127scale_independent_growth_factor_f, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_126scale_independent_growth_factor_f},
  {"z_of_tau", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_129z_of_tau, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_128z_of_tau},
  {"get_Ez", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_131get_Ez, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_130get_Ez},
  {"Hubble", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_133Hubble, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_132Hubble},
  {"get_H", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_135get_H, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_134get_H},
  {"Om_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_137Om_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_136Om_m},
  {"ionization_fraction", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_139ionization_fraction, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_138ionization_fraction},
  {"baryon_temperature", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_141baryon_temperature, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_140baryon_temperature},
  {"T_cmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_143T_cmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_142T_cmb},
  {"Omega0_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_145Omega0_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_144Omega0_m},
  {"cl_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_147cl_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_146cl_sz},
  {"dl_isw_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_149dl_isw_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_148dl_isw_sz},
  {"cl_sz_at_nu_in_GHz_in_microK2", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_151cl_sz_at_nu_in_GHz_in_microK2, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_volume_dVdzdOmega_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_153get_volume_dVdzdOmega_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_z_of_chi_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_155get_z_of_chi_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_z_of_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_157get_z_of_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_comoving_volume", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_159get_comoving_volume, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_158get_comoving_volume},
  {"get_IA_of_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_161get_IA_of_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_f_of_sigma_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_163get_f_of_sigma_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_delta_mean_from_delta_crit_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_165get_delta_mean_from_delta_crit_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_galaxy_number_counts", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_167get_galaxy_number_counts, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_cov_N_N", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_169get_cov_N_N, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_168get_cov_N_N},
  {"cl_kg_kg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_171cl_kg_kg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_170cl_kg_kg},
  {"cl_kg_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_173cl_kg_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_172cl_kg_k},
  {"cl_yg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_175cl_yg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_174cl_yg},
  {"cl_IA_g", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_177cl_IA_g, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_176cl_IA_g},
  {"cl_kg_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_179cl_kg_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_178cl_kg_m},
  {"cl_ykg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_181cl_ykg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_180cl_ykg},
  {"cl_kSZ_kSZ_g", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_183cl_kSZ_kSZ_g, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_182cl_kSZ_kSZ_g},
  {"cl_kSZ_kSZ_kg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_185cl_kSZ_kSZ_kg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_184cl_kSZ_kSZ_kg},
  {"cl_kSZ_kSZ_kcmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_187cl_kSZ_kSZ_kcmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_186cl_kSZ_kSZ_kcmb},
  {"cl_gal_gal_kcmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_189cl_gal_gal_kcmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_188cl_gal_gal_kcmb},
  {"cl_te_y_y", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_191cl_te_y_y, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_190cl_te_y_y},
  {"cl_ym", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_193cl_ym, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_192cl_ym},
  {"cl_y_kcmb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_195cl_y_kcmb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_194cl_y_kcmb},
  {"cl_t2t2f", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_197cl_t2t2f, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"cl_gg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_199cl_gg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_198cl_gg},
  {"cl_ksz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_201cl_ksz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_200cl_ksz},
  {"cl_ggamma", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_203cl_ggamma, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_202cl_ggamma},
  {"gamma_ggamma", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_205gamma_ggamma, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_204gamma_ggamma},
  {"cl_ee", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_207cl_ee, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_206cl_ee},
  {"cl_eg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_209cl_eg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_208cl_eg},
  {"cl_kg", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_211cl_kg, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_210cl_kg},
  {"pk_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_213pk_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_212pk_at_z_hm},
  {"bk_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_215bk_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_214bk_at_z_hm},
  {"bk_ttg_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_217bk_ttg_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_216bk_ttg_at_z_hm},
  {"b_yyy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_219b_yyy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_218b_yyy},
  {"b_tty", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_221b_tty, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_220b_tty},
  {"pk_gg_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_223pk_gg_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_222pk_gg_at_z_hm},
  {"pk_b_at_z_2h", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_225pk_b_at_z_2h, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_224pk_b_at_z_2h},
  {"pk_bb_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_227pk_bb_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_226pk_bb_at_z_hm},
  {"pk_em_at_z_hm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_229pk_em_at_z_hm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_228pk_em_at_z_hm},
  {"cl_kk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_231cl_kk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_230cl_kk},
  {"cl_c1c1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_233cl_c1c1, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_232cl_c1c1},
  {"cl_c1_lens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_235cl_c1_lens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_234cl_c1_lens},
  {"cl_c1_tSZ", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_237cl_c1_tSZ, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_236cl_c1_tSZ},
  {"cl_c1_gal", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_239cl_c1_gal, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_238cl_c1_gal},
  {"cl_c1_gallens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_241cl_c1_gallens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_240cl_c1_gallens},
  {"cib_monopole", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_243cib_monopole, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_242cib_monopole},
  {"cib_shotnoise", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_245cib_shotnoise, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_244cib_shotnoise},
  {"cl_cib_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_247cl_cib_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_246cl_cib_cib},
  {"cl_galn_galn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_249cl_galn_galn, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_248cl_galn_galn},
  {"cl_galn_lens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_251cl_galn_lens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_250cl_galn_lens},
  {"cl_galn_gallens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_253cl_galn_gallens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_252cl_galn_gallens},
  {"cl_galn_tsz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_255cl_galn_tsz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_254cl_galn_tsz},
  {"cl_galn_IA", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_257cl_galn_IA, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_256cl_galn_IA},
  {"cl_lensmagn_gallens", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_259cl_lensmagn_gallens, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_258cl_lensmagn_gallens},
  {"cl_lensmagn_tsz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_261cl_lensmagn_tsz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_260cl_lensmagn_tsz},
  {"cl_kg_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_263cl_kg_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_262cl_kg_cib},
  {"cl_custom1_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_265cl_custom1_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_264cl_custom1_cib},
  {"cl_tSZ_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_267cl_tSZ_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_266cl_tSZ_cib},
  {"cl_gal_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_269cl_gal_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_268cl_gal_cib},
  {"cl_lens_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_271cl_lens_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_270cl_lens_cib},
  {"cl_km", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_273cl_km, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_272cl_km},
  {"cl_mm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_275cl_mm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_274cl_mm},
  {"cl_gm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_277cl_gm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_276cl_gm},
  {"get_scale_dependent_bias_at_z_and_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_279get_scale_dependent_bias_at_z_and_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_szcounts_dndzdq_at_z_q", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_281get_szcounts_dndzdq_at_z_q, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_params_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_283get_params_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_282get_params_sz},
  {"tllprime_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_285tllprime_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_284tllprime_sz},
  {"A_rs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_287A_rs, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_286A_rs},
  {"B_sz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_289B_sz, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_288B_sz},
  {"Rho_crit_0", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_291Rho_crit_0, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_290Rho_crit_0},
  {"rho0_crit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_293rho0_crit, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_292rho0_crit},
  {"rho0_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_295rho0_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_294rho0_cb},
  {"rho0_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_297rho0_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_296rho0_m},
  {"chi_star", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_299chi_star, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_298chi_star},
  {"delta_def_custom1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_301delta_def_custom1, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_300delta_def_custom1},
  {"effective_galaxy_bias", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_303effective_galaxy_bias, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_302effective_galaxy_bias},
  {"x_out_custom1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_305x_out_custom1, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_304x_out_custom1},
  {"M1SZ", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_307M1SZ, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_306M1SZ},
  {"ystar", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_309ystar, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_308ystar},
  {"alpha", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_311alpha, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_310alpha},
  {"sigmaM", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_313sigmaM, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_312sigmaM},
  {"sigma8_Pcb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_315sigma8_Pcb, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"A_cib", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_317A_cib, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_316A_cib},
  {"A_sn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_319A_sn, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_318A_sn},
  {"A_ir", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_321A_ir, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_320A_ir},
  {"A_cn", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_323A_cn, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_322A_cn},
  {"get_te_of_m500c_at_z_arnaud", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_325get_te_of_m500c_at_z_arnaud, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_lensing_noise_at_ell", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_327get_lensing_noise_at_ell, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_te_of_m500c_at_z_lee", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_329get_te_of_m500c_at_z_lee, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_f_tinker10_at_nu_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_331get_f_tinker10_at_nu_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_f_tinker08_at_nu_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_333get_f_tinker08_at_nu_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_T10_alpha_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_335get_T10_alpha_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dndlnM_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_337get_dndlnM_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dndlnm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_339get_dndlnm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_338get_dndlnm},
  {"get_dcib0dz_at_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_341get_dcib0dz_at_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dydz_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_343get_dydz_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_mean_y", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_345get_mean_y, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_mean_galaxy_bias_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_347get_mean_galaxy_bias_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_gnu_tsz_of_nu_in_ghz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_349get_gnu_tsz_of_nu_in_ghz, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_hmf_counter_term_nmin_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_351get_hmf_counter_term_nmin_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_hmf_counter_term_b1min_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_353get_hmf_counter_term_b1min_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_hmf_counter_term_b2min_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_355get_hmf_counter_term_b2min_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_gas_density_profile_at_k_M_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_357get_gas_density_profile_at_k_M_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_rho_2h_at_r_and_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_359get_rho_2h_at_r_and_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_P_delta_at_m_and_z_b12", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_361get_P_delta_at_m_and_z_b12, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_gas_pressure_2h_at_r_and_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_363get_gas_pressure_2h_at_r_and_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dkappacmbdz_at_l_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_365get_dkappacmbdz_at_l_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dydzdlnm_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_367get_dydzdlnm_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_c_delta_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_369get_c_delta_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_delta_from_delta_def_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_371get_delta_from_delta_def_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_r_delta_of_m_delta_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_373get_r_delta_of_m_delta_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m200m_to_m200c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_375get_m200m_to_m200c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_normalization_gas_density_profile", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_377get_normalization_gas_density_profile, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m_to_xout_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_379get_m_to_xout_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_c200m_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_381get_c200m_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_c200c_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_383get_c200c_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_c500c_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_385get_c500c_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_c200m_at_m_and_z_D08", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_387get_c200m_at_m_and_z_D08, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_c200c_at_m_and_z_D08", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_389get_c200c_at_m_and_z_D08, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_c200c_at_m_and_z_B13", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_391get_c200c_at_m_and_z_B13, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_f_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_393get_f_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_f_free", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_395get_f_free, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_mu_e", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_397get_mu_e, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_Omega_m_0", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_399get_Omega_m_0, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_Omega_r_0", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_401get_Omega_r_0, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m_nfw", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_403get_m_nfw, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_rho_crit_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_405get_rho_crit_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pkl_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_407get_pkl_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_406get_pkl_unvectorized},
  {"get_pknl_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_409get_pknl_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_408get_pknl_unvectorized},
  {"get_pkl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_411get_pkl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_410get_pkl},
  {"get_pknl", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_413get_pknl, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_412get_pknl},
  {"get_pk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_415get_pk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_414get_pk},
  {"get_pk_nonlin_at_k_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_417get_pk_nonlin_at_k_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pk_lin_at_k_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_419get_pk_lin_at_k_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pk_nonlin_at_k_and_z_fast", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_421get_pk_nonlin_at_k_and_z_fast, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pk_lin_at_k_and_z_fast", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_423get_pk_lin_at_k_and_z_fast, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_gas_profile_at_x_M_z_b16_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_425get_gas_profile_at_x_M_z_b16_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pressure_P_over_P_delta_at_x_M_z_b12_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_427get_pressure_P_over_P_delta_at_x_M_z_b12_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_pressure_P_over_P_delta_at_x_gnfw_500c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_429get_pressure_P_over_P_delta_at_x_gnfw_500c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dA_z1z2", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_431get_dA_z1z2, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dA", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_433get_dA, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_432get_dA},
  {"get_rad_to_arcmin", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_435get_rad_to_arcmin, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_truncated_nfw_profile_at_z_k_rd_cd_xout", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_437get_truncated_nfw_profile_at_z_k_rd_cd_xout, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_truncated_nfw_profile_at_z_k_m_xout", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_439get_truncated_nfw_profile_at_z_k_m_xout, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_uk_nfw", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_441get_uk_nfw, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_440get_uk_nfw},
  {"get_uk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_443get_uk, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_442get_uk},
  {"get_arcmin_to_rad", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_445get_arcmin_to_rad, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_gas_profile_at_x_M_z_nfw_200m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_447get_gas_profile_at_x_M_z_nfw_200m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_gas_profile_at_x_M_z_bcm_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_449get_gas_profile_at_x_M_z_bcm_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_rvir_of_m200c_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_451get_rvir_of_m200c_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_Delta_c_of_Omega_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_453get_Delta_c_of_Omega_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_cvir_of_mvir_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_455get_cvir_of_mvir_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_Omega_m_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_457get_Omega_m_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_rvir_of_mvir_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_459get_rvir_of_mvir_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_gas_profile_at_x_M_z_nfw_200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_461get_gas_profile_at_x_M_z_nfw_200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_mass_profile_at_x_M_z_nfw_200m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_463get_mass_profile_at_x_M_z_nfw_200m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_planck_sigma_at_theta500", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_465get_planck_sigma_at_theta500, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_szcountsz_sigma_at_theta_in_patch", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_467get_szcountsz_sigma_at_theta_in_patch, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_second_order_bias_at_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_469get_second_order_bias_at_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_first_order_bias_at_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_471get_first_order_bias_at_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_first_order_bias_at_z_and_m_unvectorized", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_473get_first_order_bias_at_z_and_m_unvectorized, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_first_order_bias_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_475get_first_order_bias_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_474get_first_order_bias_at_z_and_m},
  {"get_cib_Snu_z_and_nu", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_477get_cib_Snu_z_and_nu, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_sigma_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_479get_sigma_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dlnsigma_dlnR_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_481get_dlnsigma_dlnR_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_sigma8_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_483get_sigma8_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_y_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_485get_y_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_theta_at_m_and_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_487get_theta_at_m_and_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m200m_to_m500c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_489get_m200m_to_m500c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m200c_to_m500c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_491get_m200c_to_m500c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m200c_to_m200m_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_493get_m200c_to_m200m_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m200m_to_m200c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_495get_m200m_to_m200c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m500c_to_m200c_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_497get_m500c_to_m200c_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_m500c_to_m200m_at_z_and_M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_499get_m500c_to_m200m_at_z_and_M, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"calcFRel", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_501calcFRel, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_500calcFRel},
  {"get_radial_kernel_W_galaxy_lensing_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_503get_radial_kernel_W_galaxy_lensing_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_custom1_bias_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_505get_custom1_bias_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_radial_kernel_W_custom1_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_507get_radial_kernel_W_custom1_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_custom1_profile_at_x_m_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_509get_custom1_profile_at_x_m_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_custom1_profile_at_k_m_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_511get_custom1_profile_at_k_m_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_ng_bar_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_513get_ng_bar_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_source_galaxy_number_counts", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_515get_source_galaxy_number_counts, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_N_satellites", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_517get_N_satellites, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_N_centrals", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_519get_N_centrals, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_unwise_m_min_cut_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_521get_unwise_m_min_cut_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_yc_at_m_and_z_H13", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_523get_yc_at_m_and_z_H13, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_cumulativeNumberDensity", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_525_cumulativeNumberDensity, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_524_cumulativeNumberDensity},
  {"getPLog10M", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_527getPLog10M, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_526getPLog10M},
  {"getM500_from_y0_H13", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_529getM500_from_y0_H13, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_bispectrum_f2_kernel", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_531get_bispectrum_f2_kernel, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_nu_at_z_and_m", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_533get_nu_at_z_and_m, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_matter_bispectrum_at_z_effective_approach_smoothed", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_535get_matter_bispectrum_at_z_effective_approach_smoothed, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_ttg_bispectrum_at_z_effective_approach", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_537get_ttg_bispectrum_at_z_effective_approach, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_ttg_bispectrum_at_z_tree_level_PT", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_539get_ttg_bispectrum_at_z_tree_level_PT, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_matter_bispectrum_at_z_effective_approach", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_541get_matter_bispectrum_at_z_effective_approach, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_matter_bispectrum_at_z_effective_approach_SC", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_543get_matter_bispectrum_at_z_effective_approach_SC, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_matter_bispectrum_at_z_tree_level_PT", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_545get_matter_bispectrum_at_z_tree_level_PT, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_nl_index_at_z_and_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_547get_nl_index_at_z_and_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_nl_index_at_z_and_k_no_wiggles", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_549get_nl_index_at_z_and_k_no_wiggles, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_vrms2_at_z", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_551get_vrms2_at_z, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_553get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_555get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_upp_from_gnfw_pressure_at_x_z_and_m500c", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_557get_upp_from_gnfw_pressure_at_x_z_and_m500c, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"szunbinned_loglike", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_559szunbinned_loglike, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"szcounts_ntot", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_561szcounts_ntot, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"szcounts_ntot_rates_loglike", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_563szcounts_ntot_rates_loglike, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"dndzdy_theoretical", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_565dndzdy_theoretical, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_564dndzdy_theoretical},
  {"get_background", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_567get_background, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_566get_background},
  {"get_thermodynamics", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_569get_thermodynamics, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_568get_thermodynamics},
  {"get_primordial", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_571get_primordial, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_570get_primordial},
  {"get_transfer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_575get_transfer, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_574get_transfer},
  {"get_current_derived_parameters", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_577get_current_derived_parameters, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_576get_current_derived_parameters},
  {"nonlinear_scale", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_579nonlinear_scale, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_578nonlinear_scale},
  {"nonlinear_scale_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_581nonlinear_scale_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_580nonlinear_scale_cb},
  {"nonlinear_hmcode_sigma8", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_583nonlinear_hmcode_sigma8, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_582nonlinear_hmcode_sigma8},
  {"nonlinear_hmcode_sigma8_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_585nonlinear_hmcode_sigma8_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_584nonlinear_hmcode_sigma8_cb},
  {"nonlinear_hmcode_sigmadisp", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_587nonlinear_hmcode_sigmadisp, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_586nonlinear_hmcode_sigmadisp},
  {"nonlinear_hmcode_sigmadisp_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_589nonlinear_hmcode_sigmadisp_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_588nonlinear_hmcode_sigmadisp_cb},
  {"nonlinear_hmcode_sigmadisp100", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_591nonlinear_hmcode_sigmadisp100, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_590nonlinear_hmcode_sigmadisp100},
  {"nonlinear_hmcode_sigmadisp100_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_593nonlinear_hmcode_sigmadisp100_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_592nonlinear_hmcode_sigmadisp100_cb},
  {"nonlinear_hmcode_sigmaprime", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_595nonlinear_hmcode_sigmaprime, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_594nonlinear_hmcode_sigmaprime},
  {"nonlinear_hmcode_sigmaprime_cb", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_597nonlinear_hmcode_sigmaprime_cb, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_596nonlinear_hmcode_sigmaprime_cb},
  {"get_pk_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_601get_pk_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_600get_pk_array},
  {"get_pk_cb_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_603get_pk_cb_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_602get_pk_cb_array},
  {"get_fftlog_ComputeXiLMsloz", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_605get_fftlog_ComputeXiLMsloz, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_n5k_z_of_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_607get_n5k_z_of_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_n5k_pk_at_z_and_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_609get_n5k_pk_at_z_and_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_n5k_cl_K1_at_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_611get_n5k_cl_K1_at_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"load_n5k_cl_K1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_613load_n5k_cl_K1, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"load_n5k_pk_zk", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_615load_n5k_pk_zk, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"load_n5k_z_of_chi", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_617load_n5k_z_of_chi, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"Omega0_k", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_619Omega0_k, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_618Omega0_k},
  {"Omega0_cdm", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_621Omega0_cdm, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_620Omega0_cdm},
  {"Omega0_b", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_623Omega0_b, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9classy_sz_5Class_622Omega0_b},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_625__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9classy_sz_5Class_627__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9classy_sz_Class[] = {
  {(char *)"pars", __pyx_getprop_9classy_sz_5Class_pars, 0, (char *)0, 0},
  {(char *)"state", __pyx_getprop_9classy_sz_5Class_state, 0, (char *)0, 0},
  {(char *)"Omega_nu", __pyx_getprop_9classy_sz_5Class_Omega_nu, 0, (char *)0, 0},
  {(char *)"nonlinear_method", __pyx_getprop_9classy_sz_5Class_nonlinear_method, 0, (char *)0, 0},
  {(char *)"PATH_TO_CLASS_SZ_DATA", __pyx_getprop_9classy_sz_5Class_PATH_TO_CLASS_SZ_DATA, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9classy_sz_Class_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9classy_sz_Class},
  {Py_tp_call, (void *)__pyx_pw_9classy_sz_5Class_599__call__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Class wrapping, creates the glue between C and python\n\n    The actual Class wrapping, the only class we will call from MontePython\n    (indeed the only one we will import, with the command:\n    from classy_sz import Class\n\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9classy_sz_Class},
  {Py_tp_clear, (void *)__pyx_tp_clear_9classy_sz_Class},
  {Py_tp_methods, (void *)__pyx_methods_9classy_sz_Class},
  {Py_tp_getset, (void *)__pyx_getsets_9classy_sz_Class},
  {Py_tp_new, (void *)__pyx_tp_new_9classy_sz_Class},
  {0, 0},
};
static PyType_Spec __pyx_type_9classy_sz_Class_spec = {
  "classy_sz.Class",
  sizeof(struct __pyx_obj_9classy_sz_Class),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9classy_sz_Class_slots,
};
#else

static PyTypeObject __pyx_type_9classy_sz_Class = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""Class", /*tp_name*/
  sizeof(struct __pyx_obj_9classy_sz_Class), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9classy_sz_Class, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  __pyx_pw_9classy_sz_5Class_599__call__, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Class wrapping, creates the glue between C and python\n\n    The actual Class wrapping, the only class we will call from MontePython\n    (indeed the only one we will import, with the command:\n    from classy_sz import Class\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_9classy_sz_Class, /*tp_traverse*/
  __pyx_tp_clear_9classy_sz_Class, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9classy_sz_Class, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9classy_sz_Class, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9classy_sz_Class, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

#if CYTHON_USE_FREELISTS
static struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings *__pyx_freelist_9classy_sz___pyx_scope_struct__suppress_warnings[8];
static int __pyx_freecount_9classy_sz___pyx_scope_struct__suppress_warnings = 0;
#endif

static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct__suppress_warnings(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_freecount_9classy_sz___pyx_scope_struct__suppress_warnings > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings)))) {
    o = (PyObject*)__pyx_freelist_9classy_sz___pyx_scope_struct__suppress_warnings[--__pyx_freecount_9classy_sz___pyx_scope_struct__suppress_warnings];
    memset(o, 0, sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings));
    (void) PyObject_INIT(o, t);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_9classy_sz___pyx_scope_struct__suppress_warnings(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9classy_sz___pyx_scope_struct__suppress_warnings) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_FREELISTS
  if (((int)(__pyx_freecount_9classy_sz___pyx_scope_struct__suppress_warnings < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings)))) {
    __pyx_freelist_9classy_sz___pyx_scope_struct__suppress_warnings[__pyx_freecount_9classy_sz___pyx_scope_struct__suppress_warnings++] = ((struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9classy_sz___pyx_scope_struct__suppress_warnings},
  {Py_tp_new, (void *)__pyx_tp_new_9classy_sz___pyx_scope_struct__suppress_warnings},
  {0, 0},
};
static PyType_Spec __pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings_spec = {
  "classy_sz.__pyx_scope_struct__suppress_warnings",
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings_slots,
};
#else

static PyTypeObject __pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""__pyx_scope_struct__suppress_warnings", /*tp_name*/
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct__suppress_warnings), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9classy_sz___pyx_scope_struct__suppress_warnings, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9classy_sz___pyx_scope_struct__suppress_warnings, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

#if CYTHON_USE_FREELISTS
static struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *__pyx_freelist_9classy_sz___pyx_scope_struct_1_compute_class_szfast[8];
static int __pyx_freecount_9classy_sz___pyx_scope_struct_1_compute_class_szfast = 0;
#endif

static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_1_compute_class_szfast(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_1_compute_class_szfast > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast)))) {
    o = (PyObject*)__pyx_freelist_9classy_sz___pyx_scope_struct_1_compute_class_szfast[--__pyx_freecount_9classy_sz___pyx_scope_struct_1_compute_class_szfast];
    memset(o, 0, sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_1_compute_class_szfast(PyObject *o) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_1_compute_class_szfast) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_1_compute_class_szfast < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast)))) {
    __pyx_freelist_9classy_sz___pyx_scope_struct_1_compute_class_szfast[__pyx_freecount_9classy_sz___pyx_scope_struct_1_compute_class_szfast++] = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_9classy_sz___pyx_scope_struct_1_compute_class_szfast(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9classy_sz___pyx_scope_struct_1_compute_class_szfast(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9classy_sz_Class *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9classy_sz___pyx_scope_struct_1_compute_class_szfast},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9classy_sz___pyx_scope_struct_1_compute_class_szfast},
  {Py_tp_clear, (void *)__pyx_tp_clear_9classy_sz___pyx_scope_struct_1_compute_class_szfast},
  {Py_tp_new, (void *)__pyx_tp_new_9classy_sz___pyx_scope_struct_1_compute_class_szfast},
  {0, 0},
};
static PyType_Spec __pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast_spec = {
  "classy_sz.__pyx_scope_struct_1_compute_class_szfast",
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast_slots,
};
#else

static PyTypeObject __pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""__pyx_scope_struct_1_compute_class_szfast", /*tp_name*/
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_1_compute_class_szfast), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_1_compute_class_szfast, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9classy_sz___pyx_scope_struct_1_compute_class_szfast, /*tp_traverse*/
  __pyx_tp_clear_9classy_sz___pyx_scope_struct_1_compute_class_szfast, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9classy_sz___pyx_scope_struct_1_compute_class_szfast, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

#if CYTHON_USE_FREELISTS
static struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *__pyx_freelist_9classy_sz___pyx_scope_struct_2_genexpr[8];
static int __pyx_freecount_9classy_sz___pyx_scope_struct_2_genexpr = 0;
#endif

static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_2_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_2_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr)))) {
    o = (PyObject*)__pyx_freelist_9classy_sz___pyx_scope_struct_2_genexpr[--__pyx_freecount_9classy_sz___pyx_scope_struct_2_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_2_genexpr(PyObject *o) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_2_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_key);
  #if CYTHON_USE_FREELISTS
  if (((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_2_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr)))) {
    __pyx_freelist_9classy_sz___pyx_scope_struct_2_genexpr[__pyx_freecount_9classy_sz___pyx_scope_struct_2_genexpr++] = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_9classy_sz___pyx_scope_struct_2_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9classy_sz___pyx_scope_struct_2_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9classy_sz___pyx_scope_struct_2_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9classy_sz___pyx_scope_struct_2_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_9classy_sz___pyx_scope_struct_2_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_9classy_sz___pyx_scope_struct_2_genexpr_spec = {
  "classy_sz.__pyx_scope_struct_2_genexpr",
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_9classy_sz___pyx_scope_struct_2_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_9classy_sz___pyx_scope_struct_2_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""__pyx_scope_struct_2_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_2_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_2_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9classy_sz___pyx_scope_struct_2_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9classy_sz___pyx_scope_struct_2_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

#if CYTHON_USE_FREELISTS
static struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *__pyx_freelist_9classy_sz___pyx_scope_struct_3_get_pkl[8];
static int __pyx_freecount_9classy_sz___pyx_scope_struct_3_get_pkl = 0;
#endif

static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_3_get_pkl(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_3_get_pkl > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl)))) {
    o = (PyObject*)__pyx_freelist_9classy_sz___pyx_scope_struct_3_get_pkl[--__pyx_freecount_9classy_sz___pyx_scope_struct_3_get_pkl];
    memset(o, 0, sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_3_get_pkl(PyObject *o) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_3_get_pkl) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_compute_pkl);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_3_get_pkl < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl)))) {
    __pyx_freelist_9classy_sz___pyx_scope_struct_3_get_pkl[__pyx_freecount_9classy_sz___pyx_scope_struct_3_get_pkl++] = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_9classy_sz___pyx_scope_struct_3_get_pkl(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *)o;
  if (p->__pyx_v_compute_pkl) {
    e = (*v)(p->__pyx_v_compute_pkl, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9classy_sz___pyx_scope_struct_3_get_pkl(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl *)o;
  tmp = ((PyObject*)p->__pyx_v_compute_pkl);
  p->__pyx_v_compute_pkl = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9classy_sz_Class *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9classy_sz___pyx_scope_struct_3_get_pkl},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9classy_sz___pyx_scope_struct_3_get_pkl},
  {Py_tp_clear, (void *)__pyx_tp_clear_9classy_sz___pyx_scope_struct_3_get_pkl},
  {Py_tp_new, (void *)__pyx_tp_new_9classy_sz___pyx_scope_struct_3_get_pkl},
  {0, 0},
};
static PyType_Spec __pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl_spec = {
  "classy_sz.__pyx_scope_struct_3_get_pkl",
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl_slots,
};
#else

static PyTypeObject __pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""__pyx_scope_struct_3_get_pkl", /*tp_name*/
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_3_get_pkl), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_3_get_pkl, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9classy_sz___pyx_scope_struct_3_get_pkl, /*tp_traverse*/
  __pyx_tp_clear_9classy_sz___pyx_scope_struct_3_get_pkl, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9classy_sz___pyx_scope_struct_3_get_pkl, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

#if CYTHON_USE_FREELISTS
static struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *__pyx_freelist_9classy_sz___pyx_scope_struct_4_get_pknl[8];
static int __pyx_freecount_9classy_sz___pyx_scope_struct_4_get_pknl = 0;
#endif

static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_4_get_pknl(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_4_get_pknl > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl)))) {
    o = (PyObject*)__pyx_freelist_9classy_sz___pyx_scope_struct_4_get_pknl[--__pyx_freecount_9classy_sz___pyx_scope_struct_4_get_pknl];
    memset(o, 0, sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_4_get_pknl(PyObject *o) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_4_get_pknl) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_compute_pknl);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_4_get_pknl < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl)))) {
    __pyx_freelist_9classy_sz___pyx_scope_struct_4_get_pknl[__pyx_freecount_9classy_sz___pyx_scope_struct_4_get_pknl++] = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_9classy_sz___pyx_scope_struct_4_get_pknl(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *)o;
  if (p->__pyx_v_compute_pknl) {
    e = (*v)(p->__pyx_v_compute_pknl, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9classy_sz___pyx_scope_struct_4_get_pknl(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl *)o;
  tmp = ((PyObject*)p->__pyx_v_compute_pknl);
  p->__pyx_v_compute_pknl = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9classy_sz_Class *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9classy_sz___pyx_scope_struct_4_get_pknl},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9classy_sz___pyx_scope_struct_4_get_pknl},
  {Py_tp_clear, (void *)__pyx_tp_clear_9classy_sz___pyx_scope_struct_4_get_pknl},
  {Py_tp_new, (void *)__pyx_tp_new_9classy_sz___pyx_scope_struct_4_get_pknl},
  {0, 0},
};
static PyType_Spec __pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl_spec = {
  "classy_sz.__pyx_scope_struct_4_get_pknl",
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl_slots,
};
#else

static PyTypeObject __pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""__pyx_scope_struct_4_get_pknl", /*tp_name*/
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_4_get_pknl), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_4_get_pknl, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9classy_sz___pyx_scope_struct_4_get_pknl, /*tp_traverse*/
  __pyx_tp_clear_9classy_sz___pyx_scope_struct_4_get_pknl, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9classy_sz___pyx_scope_struct_4_get_pknl, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

#if CYTHON_USE_FREELISTS
static struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *__pyx_freelist_9classy_sz___pyx_scope_struct_5_get_uk_nfw[8];
static int __pyx_freecount_9classy_sz___pyx_scope_struct_5_get_uk_nfw = 0;
#endif

static PyObject *__pyx_tp_new_9classy_sz___pyx_scope_struct_5_get_uk_nfw(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_5_get_uk_nfw > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw)))) {
    o = (PyObject*)__pyx_freelist_9classy_sz___pyx_scope_struct_5_get_uk_nfw[--__pyx_freecount_9classy_sz___pyx_scope_struct_5_get_uk_nfw];
    memset(o, 0, sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_5_get_uk_nfw(PyObject *o) {
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_5_get_uk_nfw) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_compute_profile);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_USE_FREELISTS
  if (((int)(__pyx_freecount_9classy_sz___pyx_scope_struct_5_get_uk_nfw < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw)))) {
    __pyx_freelist_9classy_sz___pyx_scope_struct_5_get_uk_nfw[__pyx_freecount_9classy_sz___pyx_scope_struct_5_get_uk_nfw++] = ((struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_9classy_sz___pyx_scope_struct_5_get_uk_nfw(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *)o;
  if (p->__pyx_v_compute_profile) {
    e = (*v)(p->__pyx_v_compute_profile, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9classy_sz___pyx_scope_struct_5_get_uk_nfw(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *p = (struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw *)o;
  tmp = ((PyObject*)p->__pyx_v_compute_profile);
  p->__pyx_v_compute_profile = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_9classy_sz_Class *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9classy_sz___pyx_scope_struct_5_get_uk_nfw},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9classy_sz___pyx_scope_struct_5_get_uk_nfw},
  {Py_tp_clear, (void *)__pyx_tp_clear_9classy_sz___pyx_scope_struct_5_get_uk_nfw},
  {Py_tp_new, (void *)__pyx_tp_new_9classy_sz___pyx_scope_struct_5_get_uk_nfw},
  {0, 0},
};
static PyType_Spec __pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw_spec = {
  "classy_sz.__pyx_scope_struct_5_get_uk_nfw",
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw_slots,
};
#else

static PyTypeObject __pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""__pyx_scope_struct_5_get_uk_nfw", /*tp_name*/
  sizeof(struct __pyx_obj_9classy_sz___pyx_scope_struct_5_get_uk_nfw), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9classy_sz___pyx_scope_struct_5_get_uk_nfw, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9classy_sz___pyx_scope_struct_5_get_uk_nfw, /*tp_traverse*/
  __pyx_tp_clear_9classy_sz___pyx_scope_struct_5_get_uk_nfw, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9classy_sz___pyx_scope_struct_5_get_uk_nfw, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_array __pyx_vtable_array;

static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_array_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_array_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_array;
  p->mode = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_format = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_array___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_array(PyObject *o) {
  struct __pyx_array_obj *p = (struct __pyx_array_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_array) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_array___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->mode);
  Py_CLEAR(p->_format);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}
static PyObject *__pyx_sq_item_array(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_array(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_array___setitem__(o, i, v);
  }
  else {
    __Pyx_TypeName o_type_name;
    o_type_name = __Pyx_PyType_GetName(Py_TYPE(o));
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by " __Pyx_FMT_TYPENAME, o_type_name);
    __Pyx_DECREF_TypeName(o_type_name);
    return -1;
  }
}

static PyObject *__pyx_tp_getattro_array(PyObject *o, PyObject *n) {
  PyObject *v = __Pyx_PyObject_GenericGetAttr(o, n);
  if (!v && PyErr_ExceptionMatches(PyExc_AttributeError)) {
    PyErr_Clear();
    v = __pyx_array___getattr__(o, n);
  }
  return v;
}

static PyObject *__pyx_getprop___pyx_array_memview(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(o);
}

static PyMethodDef __pyx_methods_array[] = {
  {"__getattr__", (PyCFunction)__pyx_array___getattr__, METH_O|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_array_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_array_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_array[] = {
  {(char *)"memview", __pyx_getprop___pyx_array_memview, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
#if !CYTHON_COMPILING_IN_LIMITED_API

static PyBufferProcs __pyx_tp_as_buffer_array = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_array_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};
#endif
static PyType_Slot __pyx_type___pyx_array_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_array},
  {Py_sq_length, (void *)__pyx_array___len__},
  {Py_sq_item, (void *)__pyx_sq_item_array},
  {Py_mp_length, (void *)__pyx_array___len__},
  {Py_mp_subscript, (void *)__pyx_array___getitem__},
  {Py_mp_ass_subscript, (void *)__pyx_mp_ass_subscript_array},
  {Py_tp_getattro, (void *)__pyx_tp_getattro_array},
  #if defined(Py_bf_getbuffer)
  {Py_bf_getbuffer, (void *)__pyx_array_getbuffer},
  #endif
  {Py_tp_methods, (void *)__pyx_methods_array},
  {Py_tp_getset, (void *)__pyx_getsets_array},
  {Py_tp_new, (void *)__pyx_tp_new_array},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_array_spec = {
  "classy_sz.array",
  sizeof(struct __pyx_array_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_SEQUENCE,
  __pyx_type___pyx_array_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_array = {
  __pyx_array___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_array, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_array = {
  __pyx_array___len__, /*mp_length*/
  __pyx_array___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_array, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_array = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_array_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_array = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""array", /*tp_name*/
  sizeof(struct __pyx_array_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_array, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_array, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_array, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  __pyx_tp_getattro_array, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_array, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_SEQUENCE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_array, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_array, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_array, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_MemviewEnum_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_MemviewEnum_obj *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_Enum(PyObject *o) {
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_Enum) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_Enum(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_Enum(PyObject *o) {
  PyObject* tmp;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_specialmethod___pyx_MemviewEnum___repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_MemviewEnum___repr__(self);
}

static PyMethodDef __pyx_methods_Enum[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_MemviewEnum___repr__, METH_NOARGS|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_MemviewEnum_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_MemviewEnum_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type___pyx_MemviewEnum_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_Enum},
  {Py_tp_repr, (void *)__pyx_MemviewEnum___repr__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_Enum},
  {Py_tp_clear, (void *)__pyx_tp_clear_Enum},
  {Py_tp_methods, (void *)__pyx_methods_Enum},
  {Py_tp_init, (void *)__pyx_MemviewEnum___init__},
  {Py_tp_new, (void *)__pyx_tp_new_Enum},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_MemviewEnum_spec = {
  "classy_sz.Enum",
  sizeof(struct __pyx_MemviewEnum_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type___pyx_MemviewEnum_slots,
};
#else

static PyTypeObject __pyx_type___pyx_MemviewEnum = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""Enum", /*tp_name*/
  sizeof(struct __pyx_MemviewEnum_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_Enum, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_MemviewEnum___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_Enum, /*tp_traverse*/
  __pyx_tp_clear_Enum, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_Enum, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_MemviewEnum___init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_Enum, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_memoryview __pyx_vtable_memoryview;

static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryview_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_memoryview_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_memoryview;
  p->obj = Py_None; Py_INCREF(Py_None);
  p->_size = Py_None; Py_INCREF(Py_None);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  p->view.obj = NULL;
  if (unlikely(__pyx_memoryview___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_memoryview(PyObject *o) {
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_memoryview) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryview___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->obj);
  Py_CLEAR(p->_size);
  Py_CLEAR(p->_array_interface);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_memoryview(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  if (p->obj) {
    e = (*v)(p->obj, a); if (e) return e;
  }
  if (p->_size) {
    e = (*v)(p->_size, a); if (e) return e;
  }
  if (p->_array_interface) {
    e = (*v)(p->_array_interface, a); if (e) return e;
  }
  if (p->view.obj) {
    e = (*v)(p->view.obj, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_memoryview(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  tmp = ((PyObject*)p->obj);
  p->obj = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_size);
  p->_size = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_array_interface);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  Py_CLEAR(p->view.obj);
  return 0;
}
static PyObject *__pyx_sq_item_memoryview(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_memoryview(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_memoryview___setitem__(o, i, v);
  }
  else {
    __Pyx_TypeName o_type_name;
    o_type_name = __Pyx_PyType_GetName(Py_TYPE(o));
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by " __Pyx_FMT_TYPENAME, o_type_name);
    __Pyx_DECREF_TypeName(o_type_name);
    return -1;
  }
}

static PyObject *__pyx_getprop___pyx_memoryview_T(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_base(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_shape(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_strides(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_suboffsets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_ndim(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_itemsize(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_nbytes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(o);
}

static PyObject *__pyx_specialmethod___pyx_memoryview___repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_memoryview___repr__(self);
}

static PyMethodDef __pyx_methods_memoryview[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_memoryview___repr__, METH_NOARGS|METH_COEXIST, 0},
  {"is_c_contig", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_is_c_contig, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_f_contig", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_is_f_contig, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"copy_fortran", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_copy_fortran, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryview_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryview_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_memoryview[] = {
  {(char *)"T", __pyx_getprop___pyx_memoryview_T, 0, (char *)0, 0},
  {(char *)"base", __pyx_getprop___pyx_memoryview_base, 0, (char *)0, 0},
  {(char *)"shape", __pyx_getprop___pyx_memoryview_shape, 0, (char *)0, 0},
  {(char *)"strides", __pyx_getprop___pyx_memoryview_strides, 0, (char *)0, 0},
  {(char *)"suboffsets", __pyx_getprop___pyx_memoryview_suboffsets, 0, (char *)0, 0},
  {(char *)"ndim", __pyx_getprop___pyx_memoryview_ndim, 0, (char *)0, 0},
  {(char *)"itemsize", __pyx_getprop___pyx_memoryview_itemsize, 0, (char *)0, 0},
  {(char *)"nbytes", __pyx_getprop___pyx_memoryview_nbytes, 0, (char *)0, 0},
  {(char *)"size", __pyx_getprop___pyx_memoryview_size, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
#if !CYTHON_COMPILING_IN_LIMITED_API

static PyBufferProcs __pyx_tp_as_buffer_memoryview = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_memoryview_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};
#endif
static PyType_Slot __pyx_type___pyx_memoryview_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_memoryview},
  {Py_tp_repr, (void *)__pyx_memoryview___repr__},
  {Py_sq_length, (void *)__pyx_memoryview___len__},
  {Py_sq_item, (void *)__pyx_sq_item_memoryview},
  {Py_mp_length, (void *)__pyx_memoryview___len__},
  {Py_mp_subscript, (void *)__pyx_memoryview___getitem__},
  {Py_mp_ass_subscript, (void *)__pyx_mp_ass_subscript_memoryview},
  {Py_tp_str, (void *)__pyx_memoryview___str__},
  #if defined(Py_bf_getbuffer)
  {Py_bf_getbuffer, (void *)__pyx_memoryview_getbuffer},
  #endif
  {Py_tp_traverse, (void *)__pyx_tp_traverse_memoryview},
  {Py_tp_clear, (void *)__pyx_tp_clear_memoryview},
  {Py_tp_methods, (void *)__pyx_methods_memoryview},
  {Py_tp_getset, (void *)__pyx_getsets_memoryview},
  {Py_tp_new, (void *)__pyx_tp_new_memoryview},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_memoryview_spec = {
  "classy_sz.memoryview",
  sizeof(struct __pyx_memoryview_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type___pyx_memoryview_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_memoryview = {
  __pyx_memoryview___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_memoryview, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_memoryview = {
  __pyx_memoryview___len__, /*mp_length*/
  __pyx_memoryview___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_memoryview, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_memoryview = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_memoryview_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_memoryview = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""memoryview", /*tp_name*/
  sizeof(struct __pyx_memoryview_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_memoryview, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_memoryview___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_memoryview, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_memoryview, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_memoryview___str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_memoryview, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_memoryview, /*tp_traverse*/
  __pyx_tp_clear_memoryview, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_memoryview, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_memoryview, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_memoryview, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct__memoryviewslice __pyx_vtable__memoryviewslice;

static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryviewslice_obj *p;
  PyObject *o = __pyx_tp_new_memoryview(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_memoryviewslice_obj *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_memoryview*)__pyx_vtabptr__memoryviewslice;
  p->from_object = Py_None; Py_INCREF(Py_None);
  p->from_slice.memview = NULL;
  return o;
}

static void __pyx_tp_dealloc__memoryviewslice(PyObject *o) {
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc__memoryviewslice) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryviewslice___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->from_object);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_memoryview(o);
}

static int __pyx_tp_traverse__memoryviewslice(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  e = __pyx_tp_traverse_memoryview(o, v, a); if (e) return e;
  if (p->from_object) {
    e = (*v)(p->from_object, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear__memoryviewslice(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  __pyx_tp_clear_memoryview(o);
  tmp = ((PyObject*)p->from_object);
  p->from_object = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  __PYX_XCLEAR_MEMVIEW(&p->from_slice, 1);
  return 0;
}

static PyMethodDef __pyx_methods__memoryviewslice[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryviewslice_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryviewslice_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type___pyx_memoryviewslice_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc__memoryviewslice},
  {Py_tp_doc, (void *)PyDoc_STR("Internal class for passing memoryview slices to Python")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse__memoryviewslice},
  {Py_tp_clear, (void *)__pyx_tp_clear__memoryviewslice},
  {Py_tp_methods, (void *)__pyx_methods__memoryviewslice},
  {Py_tp_new, (void *)__pyx_tp_new__memoryviewslice},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_memoryviewslice_spec = {
  "classy_sz._memoryviewslice",
  sizeof(struct __pyx_memoryviewslice_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_SEQUENCE,
  __pyx_type___pyx_memoryviewslice_slots,
};
#else

static PyTypeObject __pyx_type___pyx_memoryviewslice = {
  PyVarObject_HEAD_INIT(0, 0)
  "classy_sz.""_memoryviewslice", /*tp_name*/
  sizeof(struct __pyx_memoryviewslice_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc__memoryviewslice, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_memoryview___repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_memoryview___str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_SEQUENCE, /*tp_flags*/
  PyDoc_STR("Internal class for passing memoryview slices to Python"), /*tp_doc*/
  __pyx_tp_traverse__memoryviewslice, /*tp_traverse*/
  __pyx_tp_clear__memoryviewslice, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods__memoryviewslice, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new__memoryviewslice, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
    {&__pyx_kp_u_100_theta_s, __pyx_k_100_theta_s, sizeof(__pyx_k_100_theta_s), 0, 1, 0, 0},
    {&__pyx_kp_u_100_theta_star, __pyx_k_100_theta_star, sizeof(__pyx_k_100_theta_star), 0, 1, 0, 0},
    {&__pyx_kp_u_1h, __pyx_k_1h, sizeof(__pyx_k_1h), 0, 1, 0, 0},
    {&__pyx_kp_u_1h_2h_3h, __pyx_k_1h_2h_3h, sizeof(__pyx_k_1h_2h_3h), 0, 1, 0, 0},
    {&__pyx_kp_u_1h_2h_hf_3h_covmat_lensing_te, __pyx_k_1h_2h_hf_3h_covmat_lensing_te, sizeof(__pyx_k_1h_2h_hf_3h_covmat_lensing_te), 0, 1, 0, 0},
    {&__pyx_kp_u_1h_slow, __pyx_k_1h_slow, sizeof(__pyx_k_1h_slow), 0, 1, 0, 0},
    {&__pyx_kp_u_2h, __pyx_k_2h, sizeof(__pyx_k_2h), 0, 1, 0, 0},
    {&__pyx_kp_u_2h_slow, __pyx_k_2h_slow, sizeof(__pyx_k_2h_slow), 0, 1, 0, 0},
    {&__pyx_kp_u_3h, __pyx_k_3h, sizeof(__pyx_k_3h), 0, 1, 0, 0},
    {&__pyx_kp_u_3h_slow, __pyx_k_3h_slow, sizeof(__pyx_k_3h_slow), 0, 1, 0, 0},
    {&__pyx_n_s_A, __pyx_k_A, sizeof(__pyx_k_A), 0, 0, 1, 1},
    {&__pyx_n_u_A10_file, __pyx_k_A10_file, sizeof(__pyx_k_A10_file), 0, 1, 0, 1},
    {&__pyx_n_s_ASCII, __pyx_k_ASCII, sizeof(__pyx_k_ASCII), 0, 0, 1, 1},
    {&__pyx_n_u_A_IA, __pyx_k_A_IA, sizeof(__pyx_k_A_IA), 0, 1, 0, 1},
    {&__pyx_n_s_A_P0, __pyx_k_A_P0, sizeof(__pyx_k_A_P0), 0, 0, 1, 1},
    {&__pyx_n_s_A_alpha, __pyx_k_A_alpha, sizeof(__pyx_k_A_alpha), 0, 0, 1, 1},
    {&__pyx_n_u_A_alpha, __pyx_k_A_alpha, sizeof(__pyx_k_A_alpha), 0, 1, 0, 1},
    {&__pyx_n_s_A_beta, __pyx_k_A_beta, sizeof(__pyx_k_A_beta), 0, 0, 1, 1},
    {&__pyx_n_u_A_beta, __pyx_k_A_beta, sizeof(__pyx_k_A_beta), 0, 1, 0, 1},
    {&__pyx_n_s_A_cib, __pyx_k_A_cib, sizeof(__pyx_k_A_cib), 0, 0, 1, 1},
    {&__pyx_n_s_A_cn, __pyx_k_A_cn, sizeof(__pyx_k_A_cn), 0, 0, 1, 1},
    {&__pyx_n_s_A_ir, __pyx_k_A_ir, sizeof(__pyx_k_A_ir), 0, 0, 1, 1},
    {&__pyx_n_s_A_rho0, __pyx_k_A_rho0, sizeof(__pyx_k_A_rho0), 0, 0, 1, 1},
    {&__pyx_n_u_A_rho0, __pyx_k_A_rho0, sizeof(__pyx_k_A_rho0), 0, 1, 0, 1},
    {&__pyx_n_s_A_rs, __pyx_k_A_rs, sizeof(__pyx_k_A_rs), 0, 0, 1, 1},
    {&__pyx_n_u_A_s, __pyx_k_A_s, sizeof(__pyx_k_A_s), 0, 1, 0, 1},
    {&__pyx_n_s_A_s_fast, __pyx_k_A_s_fast, sizeof(__pyx_k_A_s_fast), 0, 0, 1, 1},
    {&__pyx_n_s_A_sn, __pyx_k_A_sn, sizeof(__pyx_k_A_sn), 0, 0, 1, 1},
    {&__pyx_n_s_A_xc, __pyx_k_A_xc, sizeof(__pyx_k_A_xc), 0, 0, 1, 1},
    {&__pyx_kp_s_All_dimensions_preceding_dimensi, __pyx_k_All_dimensions_preceding_dimensi, sizeof(__pyx_k_All_dimensions_preceding_dimensi), 0, 0, 1, 0},
    {&__pyx_kp_u_All_inputs_should_be_floats_or_1, __pyx_k_All_inputs_should_be_floats_or_1, sizeof(__pyx_k_All_inputs_should_be_floats_or_1), 0, 1, 0, 0},
    {&__pyx_n_u_As, __pyx_k_As, sizeof(__pyx_k_As), 0, 1, 0, 1},
    {&__pyx_n_s_AssertionError, __pyx_k_AssertionError, sizeof(__pyx_k_AssertionError), 0, 0, 1, 1},
    {&__pyx_n_s_B, __pyx_k_B, sizeof(__pyx_k_B), 0, 0, 1, 1},
    {&__pyx_n_s_B_sz, __pyx_k_B_sz, sizeof(__pyx_k_B_sz), 0, 0, 1, 1},
    {&__pyx_kp_s_Buffer_view_does_not_expose_stri, __pyx_k_Buffer_view_does_not_expose_stri, sizeof(__pyx_k_Buffer_view_does_not_expose_stri), 0, 0, 1, 0},
    {&__pyx_n_s_CRITICAL, __pyx_k_CRITICAL, sizeof(__pyx_k_CRITICAL), 0, 0, 1, 1},
    {&__pyx_kp_u_Can_only_compute_up_to_lmax_d, __pyx_k_Can_only_compute_up_to_lmax_d, sizeof(__pyx_k_Can_only_compute_up_to_lmax_d), 0, 1, 0, 0},
    {&__pyx_kp_s_Can_only_create_a_buffer_that_is, __pyx_k_Can_only_create_a_buffer_that_is, sizeof(__pyx_k_Can_only_create_a_buffer_that_is), 0, 0, 1, 0},
    {&__pyx_kp_s_Cannot_assign_to_read_only_memor, __pyx_k_Cannot_assign_to_read_only_memor, sizeof(__pyx_k_Cannot_assign_to_read_only_memor), 0, 0, 1, 0},
    {&__pyx_kp_s_Cannot_create_writable_memory_vi, __pyx_k_Cannot_create_writable_memory_vi, sizeof(__pyx_k_Cannot_create_writable_memory_vi), 0, 0, 1, 0},
    {&__pyx_kp_u_Cannot_index_with_type, __pyx_k_Cannot_index_with_type, sizeof(__pyx_k_Cannot_index_with_type), 0, 1, 0, 0},
    {&__pyx_kp_s_Cannot_transpose_memoryview_with, __pyx_k_Cannot_transpose_memoryview_with, sizeof(__pyx_k_Cannot_transpose_memoryview_with), 0, 0, 1, 0},
    {&__pyx_n_s_Class, __pyx_k_Class, sizeof(__pyx_k_Class), 0, 0, 1, 1},
    {&__pyx_n_s_Class_A_cib, __pyx_k_Class_A_cib, sizeof(__pyx_k_Class_A_cib), 0, 0, 1, 1},
    {&__pyx_n_s_Class_A_cn, __pyx_k_Class_A_cn, sizeof(__pyx_k_Class_A_cn), 0, 0, 1, 1},
    {&__pyx_n_s_Class_A_ir, __pyx_k_Class_A_ir, sizeof(__pyx_k_Class_A_ir), 0, 0, 1, 1},
    {&__pyx_n_s_Class_A_rs, __pyx_k_Class_A_rs, sizeof(__pyx_k_Class_A_rs), 0, 0, 1, 1},
    {&__pyx_n_s_Class_A_sn, __pyx_k_Class_A_sn, sizeof(__pyx_k_Class_A_sn), 0, 0, 1, 1},
    {&__pyx_n_s_Class_B_sz, __pyx_k_Class_B_sz, sizeof(__pyx_k_Class_B_sz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Hubble, __pyx_k_Class_Hubble, sizeof(__pyx_k_Class_Hubble), 0, 0, 1, 1},
    {&__pyx_n_s_Class_M1SZ, __pyx_k_Class_M1SZ, sizeof(__pyx_k_Class_M1SZ), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Neff, __pyx_k_Class_Neff, sizeof(__pyx_k_Class_Neff), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Om_m, __pyx_k_Class_Om_m, sizeof(__pyx_k_Class_Om_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega0_b, __pyx_k_Class_Omega0_b, sizeof(__pyx_k_Class_Omega0_b), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega0_cdm, __pyx_k_Class_Omega0_cdm, sizeof(__pyx_k_Class_Omega0_cdm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega0_k, __pyx_k_Class_Omega0_k, sizeof(__pyx_k_Class_Omega0_k), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega0_m, __pyx_k_Class_Omega0_m, sizeof(__pyx_k_Class_Omega0_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega_Lambda, __pyx_k_Class_Omega_Lambda, sizeof(__pyx_k_Class_Omega_Lambda), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega_b, __pyx_k_Class_Omega_b, sizeof(__pyx_k_Class_Omega_b), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega_g, __pyx_k_Class_Omega_g, sizeof(__pyx_k_Class_Omega_g), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega_m, __pyx_k_Class_Omega_m, sizeof(__pyx_k_Class_Omega_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Omega_r, __pyx_k_Class_Omega_r, sizeof(__pyx_k_Class_Omega_r), 0, 0, 1, 1},
    {&__pyx_n_s_Class_Rho_crit_0, __pyx_k_Class_Rho_crit_0, sizeof(__pyx_k_Class_Rho_crit_0), 0, 0, 1, 1},
    {&__pyx_n_s_Class_T_cmb, __pyx_k_Class_T_cmb, sizeof(__pyx_k_Class_T_cmb), 0, 0, 1, 1},
    {&__pyx_n_s_Class___reduce_cython, __pyx_k_Class___reduce_cython, sizeof(__pyx_k_Class___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Class___setstate_cython, __pyx_k_Class___setstate_cython, sizeof(__pyx_k_Class___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Class__check_task_dependency, __pyx_k_Class__check_task_dependency, sizeof(__pyx_k_Class__check_task_dependency), 0, 0, 1, 1},
    {&__pyx_n_s_Class__cumulativeNumberDensity, __pyx_k_Class__cumulativeNumberDensity, sizeof(__pyx_k_Class__cumulativeNumberDensity), 0, 0, 1, 1},
    {&__pyx_n_s_Class__fillparfile, __pyx_k_Class__fillparfile, sizeof(__pyx_k_Class__fillparfile), 0, 0, 1, 1},
    {&__pyx_n_s_Class__pars_check, __pyx_k_Class__pars_check, sizeof(__pyx_k_Class__pars_check), 0, 0, 1, 1},
    {&__pyx_n_s_Class_age, __pyx_k_Class_age, sizeof(__pyx_k_Class_age), 0, 0, 1, 1},
    {&__pyx_n_s_Class_alpha, __pyx_k_Class_alpha, sizeof(__pyx_k_Class_alpha), 0, 0, 1, 1},
    {&__pyx_n_s_Class_angular_distance, __pyx_k_Class_angular_distance, sizeof(__pyx_k_Class_angular_distance), 0, 0, 1, 1},
    {&__pyx_n_s_Class_b_tty, __pyx_k_Class_b_tty, sizeof(__pyx_k_Class_b_tty), 0, 0, 1, 1},
    {&__pyx_n_s_Class_b_yyy, __pyx_k_Class_b_yyy, sizeof(__pyx_k_Class_b_yyy), 0, 0, 1, 1},
    {&__pyx_n_s_Class_baryon_temperature, __pyx_k_Class_baryon_temperature, sizeof(__pyx_k_Class_baryon_temperature), 0, 0, 1, 1},
    {&__pyx_n_s_Class_bk_at_z_hm, __pyx_k_Class_bk_at_z_hm, sizeof(__pyx_k_Class_bk_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_bk_ttg_at_z_hm, __pyx_k_Class_bk_ttg_at_z_hm, sizeof(__pyx_k_Class_bk_ttg_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_calcFRel, __pyx_k_Class_calcFRel, sizeof(__pyx_k_Class_calcFRel), 0, 0, 1, 1},
    {&__pyx_n_s_Class_calculate_pkl_fftlog_alpha, __pyx_k_Class_calculate_pkl_fftlog_alpha, sizeof(__pyx_k_Class_calculate_pkl_fftlog_alpha), 0, 0, 1, 1},
    {&__pyx_n_s_Class_chi_star, __pyx_k_Class_chi_star, sizeof(__pyx_k_Class_chi_star), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cib_monopole, __pyx_k_Class_cib_monopole, sizeof(__pyx_k_Class_cib_monopole), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cib_shotnoise, __pyx_k_Class_cib_shotnoise, sizeof(__pyx_k_Class_cib_shotnoise), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_IA_g, __pyx_k_Class_cl_IA_g, sizeof(__pyx_k_Class_cl_IA_g), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_c1_gal, __pyx_k_Class_cl_c1_gal, sizeof(__pyx_k_Class_cl_c1_gal), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_c1_gallens, __pyx_k_Class_cl_c1_gallens, sizeof(__pyx_k_Class_cl_c1_gallens), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_c1_lens, __pyx_k_Class_cl_c1_lens, sizeof(__pyx_k_Class_cl_c1_lens), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_c1_tSZ, __pyx_k_Class_cl_c1_tSZ, sizeof(__pyx_k_Class_cl_c1_tSZ), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_c1c1, __pyx_k_Class_cl_c1c1, sizeof(__pyx_k_Class_cl_c1c1), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_cib_cib, __pyx_k_Class_cl_cib_cib, sizeof(__pyx_k_Class_cl_cib_cib), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_custom1_cib, __pyx_k_Class_cl_custom1_cib, sizeof(__pyx_k_Class_cl_custom1_cib), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_ee, __pyx_k_Class_cl_ee, sizeof(__pyx_k_Class_cl_ee), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_eg, __pyx_k_Class_cl_eg, sizeof(__pyx_k_Class_cl_eg), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_gal_cib, __pyx_k_Class_cl_gal_cib, sizeof(__pyx_k_Class_cl_gal_cib), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_gal_gal_kcmb, __pyx_k_Class_cl_gal_gal_kcmb, sizeof(__pyx_k_Class_cl_gal_gal_kcmb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_galn_IA, __pyx_k_Class_cl_galn_IA, sizeof(__pyx_k_Class_cl_galn_IA), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_galn_gallens, __pyx_k_Class_cl_galn_gallens, sizeof(__pyx_k_Class_cl_galn_gallens), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_galn_galn, __pyx_k_Class_cl_galn_galn, sizeof(__pyx_k_Class_cl_galn_galn), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_galn_lens, __pyx_k_Class_cl_galn_lens, sizeof(__pyx_k_Class_cl_galn_lens), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_galn_tsz, __pyx_k_Class_cl_galn_tsz, sizeof(__pyx_k_Class_cl_galn_tsz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_gg, __pyx_k_Class_cl_gg, sizeof(__pyx_k_Class_cl_gg), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_ggamma, __pyx_k_Class_cl_ggamma, sizeof(__pyx_k_Class_cl_ggamma), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_gm, __pyx_k_Class_cl_gm, sizeof(__pyx_k_Class_cl_gm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kSZ_kSZ_g, __pyx_k_Class_cl_kSZ_kSZ_g, sizeof(__pyx_k_Class_cl_kSZ_kSZ_g), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kSZ_kSZ_kcmb, __pyx_k_Class_cl_kSZ_kSZ_kcmb, sizeof(__pyx_k_Class_cl_kSZ_kSZ_kcmb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kSZ_kSZ_kg, __pyx_k_Class_cl_kSZ_kSZ_kg, sizeof(__pyx_k_Class_cl_kSZ_kSZ_kg), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kg, __pyx_k_Class_cl_kg, sizeof(__pyx_k_Class_cl_kg), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kg_cib, __pyx_k_Class_cl_kg_cib, sizeof(__pyx_k_Class_cl_kg_cib), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kg_k, __pyx_k_Class_cl_kg_k, sizeof(__pyx_k_Class_cl_kg_k), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kg_kg, __pyx_k_Class_cl_kg_kg, sizeof(__pyx_k_Class_cl_kg_kg), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kg_m, __pyx_k_Class_cl_kg_m, sizeof(__pyx_k_Class_cl_kg_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_kk, __pyx_k_Class_cl_kk, sizeof(__pyx_k_Class_cl_kk), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_km, __pyx_k_Class_cl_km, sizeof(__pyx_k_Class_cl_km), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_ksz, __pyx_k_Class_cl_ksz, sizeof(__pyx_k_Class_cl_ksz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_lens_cib, __pyx_k_Class_cl_lens_cib, sizeof(__pyx_k_Class_cl_lens_cib), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_lensmagn_gallens, __pyx_k_Class_cl_lensmagn_gallens, sizeof(__pyx_k_Class_cl_lensmagn_gallens), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_lensmagn_tsz, __pyx_k_Class_cl_lensmagn_tsz, sizeof(__pyx_k_Class_cl_lensmagn_tsz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_mm, __pyx_k_Class_cl_mm, sizeof(__pyx_k_Class_cl_mm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_sz, __pyx_k_Class_cl_sz, sizeof(__pyx_k_Class_cl_sz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_sz_at_nu_in_GHz_in_micr, __pyx_k_Class_cl_sz_at_nu_in_GHz_in_micr, sizeof(__pyx_k_Class_cl_sz_at_nu_in_GHz_in_micr), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_t2t2f, __pyx_k_Class_cl_t2t2f, sizeof(__pyx_k_Class_cl_t2t2f), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_tSZ_cib, __pyx_k_Class_cl_tSZ_cib, sizeof(__pyx_k_Class_cl_tSZ_cib), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_te_y_y, __pyx_k_Class_cl_te_y_y, sizeof(__pyx_k_Class_cl_te_y_y), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_y_kcmb, __pyx_k_Class_cl_y_kcmb, sizeof(__pyx_k_Class_cl_y_kcmb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_yg, __pyx_k_Class_cl_yg, sizeof(__pyx_k_Class_cl_yg), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_ykg, __pyx_k_Class_cl_ykg, sizeof(__pyx_k_Class_cl_ykg), 0, 0, 1, 1},
    {&__pyx_n_s_Class_cl_ym, __pyx_k_Class_cl_ym, sizeof(__pyx_k_Class_cl_ym), 0, 0, 1, 1},
    {&__pyx_n_s_Class_compute, __pyx_k_Class_compute, sizeof(__pyx_k_Class_compute), 0, 0, 1, 1},
    {&__pyx_n_s_Class_compute_class_sz, __pyx_k_Class_compute_class_sz, sizeof(__pyx_k_Class_compute_class_sz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_compute_class_szfast, __pyx_k_Class_compute_class_szfast, sizeof(__pyx_k_Class_compute_class_szfast), 0, 0, 1, 1},
    {&__pyx_n_s_Class_delta_def_custom1, __pyx_k_Class_delta_def_custom1, sizeof(__pyx_k_Class_delta_def_custom1), 0, 0, 1, 1},
    {&__pyx_n_s_Class_density_cl, __pyx_k_Class_density_cl, sizeof(__pyx_k_Class_density_cl), 0, 0, 1, 1},
    {&__pyx_kp_u_Class_did_not_read_input_paramet, __pyx_k_Class_did_not_read_input_paramet, sizeof(__pyx_k_Class_did_not_read_input_paramet), 0, 1, 0, 0},
    {&__pyx_n_s_Class_dl_isw_sz, __pyx_k_Class_dl_isw_sz, sizeof(__pyx_k_Class_dl_isw_sz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_dndzdy_theoretical, __pyx_k_Class_dndzdy_theoretical, sizeof(__pyx_k_Class_dndzdy_theoretical), 0, 0, 1, 1},
    {&__pyx_n_s_Class_effective_f_sigma8, __pyx_k_Class_effective_f_sigma8, sizeof(__pyx_k_Class_effective_f_sigma8), 0, 0, 1, 1},
    {&__pyx_n_s_Class_effective_galaxy_bias, __pyx_k_Class_effective_galaxy_bias, sizeof(__pyx_k_Class_effective_galaxy_bias), 0, 0, 1, 1},
    {&__pyx_n_s_Class_empty, __pyx_k_Class_empty, sizeof(__pyx_k_Class_empty), 0, 0, 1, 1},
    {&__pyx_n_s_Class_gamma_ggamma, __pyx_k_Class_gamma_ggamma, sizeof(__pyx_k_Class_gamma_ggamma), 0, 0, 1, 1},
    {&__pyx_n_s_Class_getM500_from_y0_H13, __pyx_k_Class_getM500_from_y0_H13, sizeof(__pyx_k_Class_getM500_from_y0_H13), 0, 0, 1, 1},
    {&__pyx_n_s_Class_getPLog10M, __pyx_k_Class_getPLog10M, sizeof(__pyx_k_Class_getPLog10M), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_1e6xdy_from_battaglia, __pyx_k_Class_get_1e6xdy_from_battaglia, sizeof(__pyx_k_Class_get_1e6xdy_from_battaglia), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_1e6xdy_from_gnfw_press, __pyx_k_Class_get_1e6xdy_from_gnfw_press, sizeof(__pyx_k_Class_get_1e6xdy_from_gnfw_press), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_Delta_c_of_Omega_m, __pyx_k_Class_get_Delta_c_of_Omega_m, sizeof(__pyx_k_Class_get_Delta_c_of_Omega_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_Ez, __pyx_k_Class_get_Ez, sizeof(__pyx_k_Class_get_Ez), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_H, __pyx_k_Class_get_H, sizeof(__pyx_k_Class_get_H), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_IA_of_z, __pyx_k_Class_get_IA_of_z, sizeof(__pyx_k_Class_get_IA_of_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_N_centrals, __pyx_k_Class_get_N_centrals, sizeof(__pyx_k_Class_get_N_centrals), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_N_satellites, __pyx_k_Class_get_N_satellites, sizeof(__pyx_k_Class_get_N_satellites), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_Omega_m_0, __pyx_k_Class_get_Omega_m_0, sizeof(__pyx_k_Class_get_Omega_m_0), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_Omega_m_at_z, __pyx_k_Class_get_Omega_m_at_z, sizeof(__pyx_k_Class_get_Omega_m_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_Omega_r_0, __pyx_k_Class_get_Omega_r_0, sizeof(__pyx_k_Class_get_Omega_r_0), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_P_delta_at_m_and_z_b12, __pyx_k_Class_get_P_delta_at_m_and_z_b12, sizeof(__pyx_k_Class_get_P_delta_at_m_and_z_b12), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_T10_alpha_at_z, __pyx_k_Class_get_T10_alpha_at_z, sizeof(__pyx_k_Class_get_T10_alpha_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_arcmin_to_rad, __pyx_k_Class_get_arcmin_to_rad, sizeof(__pyx_k_Class_get_arcmin_to_rad), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_background, __pyx_k_Class_get_background, sizeof(__pyx_k_Class_get_background), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_bispectrum_f2_kernel, __pyx_k_Class_get_bispectrum_f2_kernel, sizeof(__pyx_k_Class_get_bispectrum_f2_kernel), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_c200c_at_m_and_z, __pyx_k_Class_get_c200c_at_m_and_z, sizeof(__pyx_k_Class_get_c200c_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_c200c_at_m_and_z_B13, __pyx_k_Class_get_c200c_at_m_and_z_B13, sizeof(__pyx_k_Class_get_c200c_at_m_and_z_B13), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_c200c_at_m_and_z_D08, __pyx_k_Class_get_c200c_at_m_and_z_D08, sizeof(__pyx_k_Class_get_c200c_at_m_and_z_D08), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_c200m_at_m_and_z, __pyx_k_Class_get_c200m_at_m_and_z, sizeof(__pyx_k_Class_get_c200m_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_c200m_at_m_and_z_D08, __pyx_k_Class_get_c200m_at_m_and_z_D08, sizeof(__pyx_k_Class_get_c200m_at_m_and_z_D08), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_c500c_at_m_and_z, __pyx_k_Class_get_c500c_at_m_and_z, sizeof(__pyx_k_Class_get_c500c_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_c_delta_at_m_and_z, __pyx_k_Class_get_c_delta_at_m_and_z, sizeof(__pyx_k_Class_get_c_delta_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_chi, __pyx_k_Class_get_chi, sizeof(__pyx_k_Class_get_chi), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_cib_Snu_z_and_nu, __pyx_k_Class_get_cib_Snu_z_and_nu, sizeof(__pyx_k_Class_get_cib_Snu_z_and_nu), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_comoving_volume, __pyx_k_Class_get_comoving_volume, sizeof(__pyx_k_Class_get_comoving_volume), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_cov_N_N, __pyx_k_Class_get_cov_N_N, sizeof(__pyx_k_Class_get_cov_N_N), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_current_derived_parame, __pyx_k_Class_get_current_derived_parame, sizeof(__pyx_k_Class_get_current_derived_parame), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_custom1_bias_at_z, __pyx_k_Class_get_custom1_bias_at_z, sizeof(__pyx_k_Class_get_custom1_bias_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_custom1_profile_at_k_m, __pyx_k_Class_get_custom1_profile_at_k_m, sizeof(__pyx_k_Class_get_custom1_profile_at_k_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_custom1_profile_at_x_m, __pyx_k_Class_get_custom1_profile_at_x_m, sizeof(__pyx_k_Class_get_custom1_profile_at_x_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_cvir_of_mvir_at_z, __pyx_k_Class_get_cvir_of_mvir_at_z, sizeof(__pyx_k_Class_get_cvir_of_mvir_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dA, __pyx_k_Class_get_dA, sizeof(__pyx_k_Class_get_dA), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dA_z1z2, __pyx_k_Class_get_dA_z1z2, sizeof(__pyx_k_Class_get_dA_z1z2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dcib0dz_at_z_and_nu, __pyx_k_Class_get_dcib0dz_at_z_and_nu, sizeof(__pyx_k_Class_get_dcib0dz_at_z_and_nu), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_delta_from_delta_def_a, __pyx_k_Class_get_delta_from_delta_def_a, sizeof(__pyx_k_Class_get_delta_from_delta_def_a), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_delta_mean_from_delta, __pyx_k_Class_get_delta_mean_from_delta, sizeof(__pyx_k_Class_get_delta_mean_from_delta), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dkappacmbdz_at_l_and_z, __pyx_k_Class_get_dkappacmbdz_at_l_and_z, sizeof(__pyx_k_Class_get_dkappacmbdz_at_l_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dlnsigma_dlnR_at_z_and, __pyx_k_Class_get_dlnsigma_dlnR_at_z_and, sizeof(__pyx_k_Class_get_dlnsigma_dlnR_at_z_and), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dndlnM_at_z_and_M, __pyx_k_Class_get_dndlnM_at_z_and_M, sizeof(__pyx_k_Class_get_dndlnM_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dndlnm, __pyx_k_Class_get_dndlnm, sizeof(__pyx_k_Class_get_dndlnm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dydz_at_z, __pyx_k_Class_get_dydz_at_z, sizeof(__pyx_k_Class_get_dydz_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_dydzdlnm_at_z_and_m, __pyx_k_Class_get_dydzdlnm_at_z_and_m, sizeof(__pyx_k_Class_get_dydzdlnm_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_effective_f_sigma8, __pyx_k_Class_get_effective_f_sigma8, sizeof(__pyx_k_Class_get_effective_f_sigma8), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_f_b, __pyx_k_Class_get_f_b, sizeof(__pyx_k_Class_get_f_b), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_f_free, __pyx_k_Class_get_f_free, sizeof(__pyx_k_Class_get_f_free), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_f_of_sigma_at_m_and_z, __pyx_k_Class_get_f_of_sigma_at_m_and_z, sizeof(__pyx_k_Class_get_f_of_sigma_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_f_tinker08_at_nu_and_z, __pyx_k_Class_get_f_tinker08_at_nu_and_z, sizeof(__pyx_k_Class_get_f_tinker08_at_nu_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_f_tinker10_at_nu_and_z, __pyx_k_Class_get_f_tinker10_at_nu_and_z, sizeof(__pyx_k_Class_get_f_tinker10_at_nu_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_fftlog_ComputeXiLMsloz, __pyx_k_Class_get_fftlog_ComputeXiLMsloz, sizeof(__pyx_k_Class_get_fftlog_ComputeXiLMsloz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_first_order_bias_at_z, __pyx_k_Class_get_first_order_bias_at_z, sizeof(__pyx_k_Class_get_first_order_bias_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_first_order_bias_at_z_2, __pyx_k_Class_get_first_order_bias_at_z_2, sizeof(__pyx_k_Class_get_first_order_bias_at_z_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_first_order_bias_at_z_3, __pyx_k_Class_get_first_order_bias_at_z_3, sizeof(__pyx_k_Class_get_first_order_bias_at_z_3), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_fstar_of_m_at_z, __pyx_k_Class_get_fstar_of_m_at_z, sizeof(__pyx_k_Class_get_fstar_of_m_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_galaxy_number_counts, __pyx_k_Class_get_galaxy_number_counts, sizeof(__pyx_k_Class_get_galaxy_number_counts), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_gas_density_profile_at, __pyx_k_Class_get_gas_density_profile_at, sizeof(__pyx_k_Class_get_gas_density_profile_at), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_gas_pressure_2h_at_r_a, __pyx_k_Class_get_gas_pressure_2h_at_r_a, sizeof(__pyx_k_Class_get_gas_pressure_2h_at_r_a), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_gas_profile_at_x_M_z_b, __pyx_k_Class_get_gas_profile_at_x_M_z_b, sizeof(__pyx_k_Class_get_gas_profile_at_x_M_z_b), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_gas_profile_at_x_M_z_b_2, __pyx_k_Class_get_gas_profile_at_x_M_z_b_2, sizeof(__pyx_k_Class_get_gas_profile_at_x_M_z_b_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_gas_profile_at_x_M_z_n, __pyx_k_Class_get_gas_profile_at_x_M_z_n, sizeof(__pyx_k_Class_get_gas_profile_at_x_M_z_n), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_gas_profile_at_x_M_z_n_2, __pyx_k_Class_get_gas_profile_at_x_M_z_n_2, sizeof(__pyx_k_Class_get_gas_profile_at_x_M_z_n_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_gnu_tsz_of_nu_in_ghz, __pyx_k_Class_get_gnu_tsz_of_nu_in_ghz, sizeof(__pyx_k_Class_get_gnu_tsz_of_nu_in_ghz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_hmf_counter_term_b1min, __pyx_k_Class_get_hmf_counter_term_b1min, sizeof(__pyx_k_Class_get_hmf_counter_term_b1min), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_hmf_counter_term_b2min, __pyx_k_Class_get_hmf_counter_term_b2min, sizeof(__pyx_k_Class_get_hmf_counter_term_b2min), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_hmf_counter_term_nmin, __pyx_k_Class_get_hmf_counter_term_nmin, sizeof(__pyx_k_Class_get_hmf_counter_term_nmin), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_lensing_noise_at_ell, __pyx_k_Class_get_lensing_noise_at_ell, sizeof(__pyx_k_Class_get_lensing_noise_at_ell), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m200c_to_m200m_at_z_an, __pyx_k_Class_get_m200c_to_m200m_at_z_an, sizeof(__pyx_k_Class_get_m200c_to_m200m_at_z_an), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m200c_to_m500c_at_z_an, __pyx_k_Class_get_m200c_to_m500c_at_z_an, sizeof(__pyx_k_Class_get_m200c_to_m500c_at_z_an), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m200m_to_m200c_at_z_an, __pyx_k_Class_get_m200m_to_m200c_at_z_an, sizeof(__pyx_k_Class_get_m200m_to_m200c_at_z_an), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m200m_to_m500c_at_z_an, __pyx_k_Class_get_m200m_to_m500c_at_z_an, sizeof(__pyx_k_Class_get_m200m_to_m500c_at_z_an), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m500c_to_m200c_at_z_an, __pyx_k_Class_get_m500c_to_m200c_at_z_an, sizeof(__pyx_k_Class_get_m500c_to_m200c_at_z_an), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m500c_to_m200m_at_z_an, __pyx_k_Class_get_m500c_to_m200m_at_z_an, sizeof(__pyx_k_Class_get_m500c_to_m200m_at_z_an), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m_nfw, __pyx_k_Class_get_m_nfw, sizeof(__pyx_k_Class_get_m_nfw), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_m_to_xout_at_z_and_m, __pyx_k_Class_get_m_to_xout_at_z_and_m, sizeof(__pyx_k_Class_get_m_to_xout_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_mass_profile_at_x_M_z, __pyx_k_Class_get_mass_profile_at_x_M_z, sizeof(__pyx_k_Class_get_mass_profile_at_x_M_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_matter_bispectrum_at_z, __pyx_k_Class_get_matter_bispectrum_at_z, sizeof(__pyx_k_Class_get_matter_bispectrum_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_matter_bispectrum_at_z_2, __pyx_k_Class_get_matter_bispectrum_at_z_2, sizeof(__pyx_k_Class_get_matter_bispectrum_at_z_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_matter_bispectrum_at_z_3, __pyx_k_Class_get_matter_bispectrum_at_z_3, sizeof(__pyx_k_Class_get_matter_bispectrum_at_z_3), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_matter_bispectrum_at_z_4, __pyx_k_Class_get_matter_bispectrum_at_z_4, sizeof(__pyx_k_Class_get_matter_bispectrum_at_z_4), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_mean_galaxy_bias_at_z, __pyx_k_Class_get_mean_galaxy_bias_at_z, sizeof(__pyx_k_Class_get_mean_galaxy_bias_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_mean_y, __pyx_k_Class_get_mean_y, sizeof(__pyx_k_Class_get_mean_y), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_mu_e, __pyx_k_Class_get_mu_e, sizeof(__pyx_k_Class_get_mu_e), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_n5k_cl_K1_at_chi, __pyx_k_Class_get_n5k_cl_K1_at_chi, sizeof(__pyx_k_Class_get_n5k_cl_K1_at_chi), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_n5k_pk_at_z_and_k, __pyx_k_Class_get_n5k_pk_at_z_and_k, sizeof(__pyx_k_Class_get_n5k_pk_at_z_and_k), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_n5k_z_of_chi, __pyx_k_Class_get_n5k_z_of_chi, sizeof(__pyx_k_Class_get_n5k_z_of_chi), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_ng_bar_at_z, __pyx_k_Class_get_ng_bar_at_z, sizeof(__pyx_k_Class_get_ng_bar_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_nl_index_at_z_and_k, __pyx_k_Class_get_nl_index_at_z_and_k, sizeof(__pyx_k_Class_get_nl_index_at_z_and_k), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_nl_index_at_z_and_k_no, __pyx_k_Class_get_nl_index_at_z_and_k_no, sizeof(__pyx_k_Class_get_nl_index_at_z_and_k_no), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_normalization_gas_dens, __pyx_k_Class_get_normalization_gas_dens, sizeof(__pyx_k_Class_get_normalization_gas_dens), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_nu_at_z_and_m, __pyx_k_Class_get_nu_at_z_and_m, sizeof(__pyx_k_Class_get_nu_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_params_sz, __pyx_k_Class_get_params_sz, sizeof(__pyx_k_Class_get_params_sz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_perturbations, __pyx_k_Class_get_perturbations, sizeof(__pyx_k_Class_get_perturbations), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk, __pyx_k_Class_get_pk, sizeof(__pyx_k_Class_get_pk), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_and_k_and_z, __pyx_k_Class_get_pk_and_k_and_z, sizeof(__pyx_k_Class_get_pk_and_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_array, __pyx_k_Class_get_pk_array, sizeof(__pyx_k_Class_get_pk_array), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_cb, __pyx_k_Class_get_pk_cb, sizeof(__pyx_k_Class_get_pk_cb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_cb_array, __pyx_k_Class_get_pk_cb_array, sizeof(__pyx_k_Class_get_pk_cb_array), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_cb_lin, __pyx_k_Class_get_pk_cb_lin, sizeof(__pyx_k_Class_get_pk_cb_lin), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_lin, __pyx_k_Class_get_pk_lin, sizeof(__pyx_k_Class_get_pk_lin), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_lin_at_k_and_z, __pyx_k_Class_get_pk_lin_at_k_and_z, sizeof(__pyx_k_Class_get_pk_lin_at_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_lin_at_k_and_z_fast, __pyx_k_Class_get_pk_lin_at_k_and_z_fast, sizeof(__pyx_k_Class_get_pk_lin_at_k_and_z_fast), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_nonlin_at_k_and_z, __pyx_k_Class_get_pk_nonlin_at_k_and_z, sizeof(__pyx_k_Class_get_pk_nonlin_at_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pk_nonlin_at_k_and_z_f, __pyx_k_Class_get_pk_nonlin_at_k_and_z_f, sizeof(__pyx_k_Class_get_pk_nonlin_at_k_and_z_f), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pkl, __pyx_k_Class_get_pkl, sizeof(__pyx_k_Class_get_pkl), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pkl_at_z, __pyx_k_Class_get_pkl_at_z, sizeof(__pyx_k_Class_get_pkl_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pkl_reconstructed_from, __pyx_k_Class_get_pkl_reconstructed_from, sizeof(__pyx_k_Class_get_pkl_reconstructed_from), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pkl_unvectorized, __pyx_k_Class_get_pkl_unvectorized, sizeof(__pyx_k_Class_get_pkl_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pknl, __pyx_k_Class_get_pknl, sizeof(__pyx_k_Class_get_pknl), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pknl_at_z, __pyx_k_Class_get_pknl_at_z, sizeof(__pyx_k_Class_get_pknl_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pknl_unvectorized, __pyx_k_Class_get_pknl_unvectorized, sizeof(__pyx_k_Class_get_pknl_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_planck_sigma_at_theta5, __pyx_k_Class_get_planck_sigma_at_theta5, sizeof(__pyx_k_Class_get_planck_sigma_at_theta5), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pressure_P_over_P_delt, __pyx_k_Class_get_pressure_P_over_P_delt, sizeof(__pyx_k_Class_get_pressure_P_over_P_delt), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_pressure_P_over_P_delt_2, __pyx_k_Class_get_pressure_P_over_P_delt_2, sizeof(__pyx_k_Class_get_pressure_P_over_P_delt_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_primordial, __pyx_k_Class_get_primordial, sizeof(__pyx_k_Class_get_primordial), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_r_delta_of_m_delta_at, __pyx_k_Class_get_r_delta_of_m_delta_at, sizeof(__pyx_k_Class_get_r_delta_of_m_delta_at), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_rad_to_arcmin, __pyx_k_Class_get_rad_to_arcmin, sizeof(__pyx_k_Class_get_rad_to_arcmin), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_radial_kernel_W_custom, __pyx_k_Class_get_radial_kernel_W_custom, sizeof(__pyx_k_Class_get_radial_kernel_W_custom), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_radial_kernel_W_galaxy, __pyx_k_Class_get_radial_kernel_W_galaxy, sizeof(__pyx_k_Class_get_radial_kernel_W_galaxy), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_radial_kernel_W_galaxy_2, __pyx_k_Class_get_radial_kernel_W_galaxy_2, sizeof(__pyx_k_Class_get_radial_kernel_W_galaxy_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_rho_2h_at_r_and_m_and, __pyx_k_Class_get_rho_2h_at_r_and_m_and, sizeof(__pyx_k_Class_get_rho_2h_at_r_and_m_and), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_rho_crit_at_z, __pyx_k_Class_get_rho_crit_at_z, sizeof(__pyx_k_Class_get_rho_crit_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_rvir_of_m200c_at_z, __pyx_k_Class_get_rvir_of_m200c_at_z, sizeof(__pyx_k_Class_get_rvir_of_m200c_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_rvir_of_mvir_at_z, __pyx_k_Class_get_rvir_of_mvir_at_z, sizeof(__pyx_k_Class_get_rvir_of_mvir_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_scale_dependent_bias_a, __pyx_k_Class_get_scale_dependent_bias_a, sizeof(__pyx_k_Class_get_scale_dependent_bias_a), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_second_order_bias_at_z, __pyx_k_Class_get_second_order_bias_at_z, sizeof(__pyx_k_Class_get_second_order_bias_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_sigma8_at_z, __pyx_k_Class_get_sigma8_at_z, sizeof(__pyx_k_Class_get_sigma8_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_sigma_at_z_and_m, __pyx_k_Class_get_sigma_at_z_and_m, sizeof(__pyx_k_Class_get_sigma_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_source_galaxy_number_c, __pyx_k_Class_get_source_galaxy_number_c, sizeof(__pyx_k_Class_get_source_galaxy_number_c), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_szcounts_dndzdq_at_z_q, __pyx_k_Class_get_szcounts_dndzdq_at_z_q, sizeof(__pyx_k_Class_get_szcounts_dndzdq_at_z_q), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_szcountsz_sigma_at_the, __pyx_k_Class_get_szcountsz_sigma_at_the, sizeof(__pyx_k_Class_get_szcountsz_sigma_at_the), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_te_of_m500c_at_z_arnau, __pyx_k_Class_get_te_of_m500c_at_z_arnau, sizeof(__pyx_k_Class_get_te_of_m500c_at_z_arnau), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_te_of_m500c_at_z_lee, __pyx_k_Class_get_te_of_m500c_at_z_lee, sizeof(__pyx_k_Class_get_te_of_m500c_at_z_lee), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_thermodynamics, __pyx_k_Class_get_thermodynamics, sizeof(__pyx_k_Class_get_thermodynamics), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_theta_at_m_and_z, __pyx_k_Class_get_theta_at_m_and_z, sizeof(__pyx_k_Class_get_theta_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_transfer, __pyx_k_Class_get_transfer, sizeof(__pyx_k_Class_get_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_truncated_nfw_profile, __pyx_k_Class_get_truncated_nfw_profile, sizeof(__pyx_k_Class_get_truncated_nfw_profile), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_truncated_nfw_profile_2, __pyx_k_Class_get_truncated_nfw_profile_2, sizeof(__pyx_k_Class_get_truncated_nfw_profile_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_ttg_bispectrum_at_z_ef, __pyx_k_Class_get_ttg_bispectrum_at_z_ef, sizeof(__pyx_k_Class_get_ttg_bispectrum_at_z_ef), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_ttg_bispectrum_at_z_tr, __pyx_k_Class_get_ttg_bispectrum_at_z_tr, sizeof(__pyx_k_Class_get_ttg_bispectrum_at_z_tr), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_uk, __pyx_k_Class_get_uk, sizeof(__pyx_k_Class_get_uk), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_uk_nfw, __pyx_k_Class_get_uk_nfw, sizeof(__pyx_k_Class_get_uk_nfw), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_unwise_m_min_cut_at_z, __pyx_k_Class_get_unwise_m_min_cut_at_z, sizeof(__pyx_k_Class_get_unwise_m_min_cut_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_upp_from_gnfw_pressure, __pyx_k_Class_get_upp_from_gnfw_pressure, sizeof(__pyx_k_Class_get_upp_from_gnfw_pressure), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_volume_dVdzdOmega_at_z, __pyx_k_Class_get_volume_dVdzdOmega_at_z, sizeof(__pyx_k_Class_get_volume_dVdzdOmega_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_vrms2_at_z, __pyx_k_Class_get_vrms2_at_z, sizeof(__pyx_k_Class_get_vrms2_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_y_at_m_and_z, __pyx_k_Class_get_y_at_m_and_z, sizeof(__pyx_k_Class_get_y_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_yc_at_m_and_z_H13, __pyx_k_Class_get_yc_at_m_and_z_H13, sizeof(__pyx_k_Class_get_yc_at_m_and_z_H13), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_z_of_chi, __pyx_k_Class_get_z_of_chi, sizeof(__pyx_k_Class_get_z_of_chi), 0, 0, 1, 1},
    {&__pyx_n_s_Class_get_z_of_chi_unvectorized, __pyx_k_Class_get_z_of_chi_unvectorized, sizeof(__pyx_k_Class_get_z_of_chi_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_Class_h, __pyx_k_Class_h, sizeof(__pyx_k_Class_h), 0, 0, 1, 1},
    {&__pyx_n_s_Class_ionization_fraction, __pyx_k_Class_ionization_fraction, sizeof(__pyx_k_Class_ionization_fraction), 0, 0, 1, 1},
    {&__pyx_n_s_Class_k_eq, __pyx_k_Class_k_eq, sizeof(__pyx_k_Class_k_eq), 0, 0, 1, 1},
    {&__pyx_n_s_Class_lensed_cl, __pyx_k_Class_lensed_cl, sizeof(__pyx_k_Class_lensed_cl), 0, 0, 1, 1},
    {&__pyx_n_s_Class_load_n5k_cl_K1, __pyx_k_Class_load_n5k_cl_K1, sizeof(__pyx_k_Class_load_n5k_cl_K1), 0, 0, 1, 1},
    {&__pyx_n_s_Class_load_n5k_pk_zk, __pyx_k_Class_load_n5k_pk_zk, sizeof(__pyx_k_Class_load_n5k_pk_zk), 0, 0, 1, 1},
    {&__pyx_n_s_Class_load_n5k_z_of_chi, __pyx_k_Class_load_n5k_z_of_chi, sizeof(__pyx_k_Class_load_n5k_z_of_chi), 0, 0, 1, 1},
    {&__pyx_n_s_Class_luminosity_distance, __pyx_k_Class_luminosity_distance, sizeof(__pyx_k_Class_luminosity_distance), 0, 0, 1, 1},
    {&__pyx_n_s_Class_n_s, __pyx_k_Class_n_s, sizeof(__pyx_k_Class_n_s), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigma8, __pyx_k_Class_nonlinear_hmcode_sigma8, sizeof(__pyx_k_Class_nonlinear_hmcode_sigma8), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigma8_cb, __pyx_k_Class_nonlinear_hmcode_sigma8_cb, sizeof(__pyx_k_Class_nonlinear_hmcode_sigma8_cb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigmadisp, __pyx_k_Class_nonlinear_hmcode_sigmadisp, sizeof(__pyx_k_Class_nonlinear_hmcode_sigmadisp), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_2, __pyx_k_Class_nonlinear_hmcode_sigmadisp_2, sizeof(__pyx_k_Class_nonlinear_hmcode_sigmadisp_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_3, __pyx_k_Class_nonlinear_hmcode_sigmadisp_3, sizeof(__pyx_k_Class_nonlinear_hmcode_sigmadisp_3), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigmadisp_4, __pyx_k_Class_nonlinear_hmcode_sigmadisp_4, sizeof(__pyx_k_Class_nonlinear_hmcode_sigmadisp_4), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigmaprim, __pyx_k_Class_nonlinear_hmcode_sigmaprim, sizeof(__pyx_k_Class_nonlinear_hmcode_sigmaprim), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_sigmaprim_2, __pyx_k_Class_nonlinear_hmcode_sigmaprim_2, sizeof(__pyx_k_Class_nonlinear_hmcode_sigmaprim_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_hmcode_window_nf, __pyx_k_Class_nonlinear_hmcode_window_nf, sizeof(__pyx_k_Class_nonlinear_hmcode_window_nf), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_scale, __pyx_k_Class_nonlinear_scale, sizeof(__pyx_k_Class_nonlinear_scale), 0, 0, 1, 1},
    {&__pyx_n_s_Class_nonlinear_scale_cb, __pyx_k_Class_nonlinear_scale_cb, sizeof(__pyx_k_Class_nonlinear_scale_cb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_omega_b, __pyx_k_Class_omega_b, sizeof(__pyx_k_Class_omega_b), 0, 0, 1, 1},
    {&__pyx_n_s_Class_omega_cdm, __pyx_k_Class_omega_cdm, sizeof(__pyx_k_Class_omega_cdm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk, __pyx_k_Class_pk, sizeof(__pyx_k_Class_pk), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_at_z_hm, __pyx_k_Class_pk_at_z_hm, sizeof(__pyx_k_Class_pk_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_b_at_z_2h, __pyx_k_Class_pk_b_at_z_2h, sizeof(__pyx_k_Class_pk_b_at_z_2h), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_bb_at_z_hm, __pyx_k_Class_pk_bb_at_z_hm, sizeof(__pyx_k_Class_pk_bb_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_cb, __pyx_k_Class_pk_cb, sizeof(__pyx_k_Class_pk_cb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_cb_lin, __pyx_k_Class_pk_cb_lin, sizeof(__pyx_k_Class_pk_cb_lin), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_em_at_z_hm, __pyx_k_Class_pk_em_at_z_hm, sizeof(__pyx_k_Class_pk_em_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_gg_at_z_hm, __pyx_k_Class_pk_gg_at_z_hm, sizeof(__pyx_k_Class_pk_gg_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_lin, __pyx_k_Class_pk_lin, sizeof(__pyx_k_Class_pk_lin), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_lin_unvectorized, __pyx_k_Class_pk_lin_unvectorized, sizeof(__pyx_k_Class_pk_lin_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_nonlin, __pyx_k_Class_pk_nonlin, sizeof(__pyx_k_Class_pk_nonlin), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_tilt, __pyx_k_Class_pk_tilt, sizeof(__pyx_k_Class_pk_tilt), 0, 0, 1, 1},
    {&__pyx_n_s_Class_pk_unvectorized, __pyx_k_Class_pk_unvectorized, sizeof(__pyx_k_Class_pk_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_Class_raw_cl, __pyx_k_Class_raw_cl, sizeof(__pyx_k_Class_raw_cl), 0, 0, 1, 1},
    {&__pyx_n_s_Class_rho0_cb, __pyx_k_Class_rho0_cb, sizeof(__pyx_k_Class_rho0_cb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_rho0_crit, __pyx_k_Class_rho0_crit, sizeof(__pyx_k_Class_rho0_crit), 0, 0, 1, 1},
    {&__pyx_n_s_Class_rho0_m, __pyx_k_Class_rho0_m, sizeof(__pyx_k_Class_rho0_m), 0, 0, 1, 1},
    {&__pyx_n_s_Class_rs_drag, __pyx_k_Class_rs_drag, sizeof(__pyx_k_Class_rs_drag), 0, 0, 1, 1},
    {&__pyx_n_s_Class_scale_independent_growth_f, __pyx_k_Class_scale_independent_growth_f, sizeof(__pyx_k_Class_scale_independent_growth_f), 0, 0, 1, 1},
    {&__pyx_n_s_Class_scale_independent_growth_f_2, __pyx_k_Class_scale_independent_growth_f_2, sizeof(__pyx_k_Class_scale_independent_growth_f_2), 0, 0, 1, 1},
    {&__pyx_n_s_Class_set, __pyx_k_Class_set, sizeof(__pyx_k_Class_set), 0, 0, 1, 1},
    {&__pyx_n_s_Class_set_default, __pyx_k_Class_set_default, sizeof(__pyx_k_Class_set_default), 0, 0, 1, 1},
    {&__pyx_n_s_Class_sigma, __pyx_k_Class_sigma, sizeof(__pyx_k_Class_sigma), 0, 0, 1, 1},
    {&__pyx_n_s_Class_sigma8, __pyx_k_Class_sigma8, sizeof(__pyx_k_Class_sigma8), 0, 0, 1, 1},
    {&__pyx_n_s_Class_sigma8_Pcb, __pyx_k_Class_sigma8_Pcb, sizeof(__pyx_k_Class_sigma8_Pcb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_sigma8_cb, __pyx_k_Class_sigma8_cb, sizeof(__pyx_k_Class_sigma8_cb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_sigmaM, __pyx_k_Class_sigmaM, sizeof(__pyx_k_Class_sigmaM), 0, 0, 1, 1},
    {&__pyx_n_s_Class_sigma_cb, __pyx_k_Class_sigma_cb, sizeof(__pyx_k_Class_sigma_cb), 0, 0, 1, 1},
    {&__pyx_n_s_Class_struct_cleanup, __pyx_k_Class_struct_cleanup, sizeof(__pyx_k_Class_struct_cleanup), 0, 0, 1, 1},
    {&__pyx_n_s_Class_szcounts_ntot, __pyx_k_Class_szcounts_ntot, sizeof(__pyx_k_Class_szcounts_ntot), 0, 0, 1, 1},
    {&__pyx_n_s_Class_szcounts_ntot_rates_loglik, __pyx_k_Class_szcounts_ntot_rates_loglik, sizeof(__pyx_k_Class_szcounts_ntot_rates_loglik), 0, 0, 1, 1},
    {&__pyx_n_s_Class_szfast, __pyx_k_Class_szfast, sizeof(__pyx_k_Class_szfast), 0, 0, 1, 1},
    {&__pyx_n_s_Class_szunbinned_loglike, __pyx_k_Class_szunbinned_loglike, sizeof(__pyx_k_Class_szunbinned_loglike), 0, 0, 1, 1},
    {&__pyx_n_s_Class_tau_reio, __pyx_k_Class_tau_reio, sizeof(__pyx_k_Class_tau_reio), 0, 0, 1, 1},
    {&__pyx_n_s_Class_theta_s_100, __pyx_k_Class_theta_s_100, sizeof(__pyx_k_Class_theta_s_100), 0, 0, 1, 1},
    {&__pyx_n_s_Class_theta_star_100, __pyx_k_Class_theta_star_100, sizeof(__pyx_k_Class_theta_star_100), 0, 0, 1, 1},
    {&__pyx_n_s_Class_tllprime_sz, __pyx_k_Class_tllprime_sz, sizeof(__pyx_k_Class_tllprime_sz), 0, 0, 1, 1},
    {&__pyx_n_s_Class_x_out_custom1, __pyx_k_Class_x_out_custom1, sizeof(__pyx_k_Class_x_out_custom1), 0, 0, 1, 1},
    {&__pyx_n_s_Class_ystar, __pyx_k_Class_ystar, sizeof(__pyx_k_Class_ystar), 0, 0, 1, 1},
    {&__pyx_n_s_Class_z_of_r, __pyx_k_Class_z_of_r, sizeof(__pyx_k_Class_z_of_r), 0, 0, 1, 1},
    {&__pyx_n_s_Class_z_of_tau, __pyx_k_Class_z_of_tau, sizeof(__pyx_k_Class_z_of_tau), 0, 0, 1, 1},
    {&__pyx_n_s_Class_z_reio, __pyx_k_Class_z_reio, sizeof(__pyx_k_Class_z_reio), 0, 0, 1, 1},
    {&__pyx_n_s_CosmoComputationError, __pyx_k_CosmoComputationError, sizeof(__pyx_k_CosmoComputationError), 0, 0, 1, 1},
    {&__pyx_n_s_CosmoError, __pyx_k_CosmoError, sizeof(__pyx_k_CosmoError), 0, 0, 1, 1},
    {&__pyx_n_s_CosmoError___init, __pyx_k_CosmoError___init, sizeof(__pyx_k_CosmoError___init), 0, 0, 1, 1},
    {&__pyx_n_s_CosmoError___str, __pyx_k_CosmoError___str, sizeof(__pyx_k_CosmoError___str), 0, 0, 1, 1},
    {&__pyx_n_s_CosmoSevereError, __pyx_k_CosmoSevereError, sizeof(__pyx_k_CosmoSevereError), 0, 0, 1, 1},
    {&__pyx_n_s_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 0, 1, 1},
    {&__pyx_n_s_DEBUG, __pyx_k_DEBUG, sizeof(__pyx_k_DEBUG), 0, 0, 1, 1},
    {&__pyx_n_s_D_A, __pyx_k_D_A, sizeof(__pyx_k_D_A), 0, 0, 1, 1},
    {&__pyx_n_s_Delta_c, __pyx_k_Delta_c, sizeof(__pyx_k_Delta_c), 0, 0, 1, 1},
    {&__pyx_n_u_Deprecated, __pyx_k_Deprecated, sizeof(__pyx_k_Deprecated), 0, 1, 0, 1},
    {&__pyx_kp_s_Dimension_d_is_not_direct, __pyx_k_Dimension_d_is_not_direct, sizeof(__pyx_k_Dimension_d_is_not_direct), 0, 0, 1, 0},
    {&__pyx_n_u_Dust_temperature_today_in_Kelvin, __pyx_k_Dust_temperature_today_in_Kelvin, sizeof(__pyx_k_Dust_temperature_today_in_Kelvin), 0, 1, 0, 1},
    {&__pyx_n_s_Dz, __pyx_k_Dz, sizeof(__pyx_k_Dz), 0, 0, 1, 1},
    {&__pyx_n_s_Dzmax, __pyx_k_Dzmax, sizeof(__pyx_k_Dzmax), 0, 0, 1, 1},
    {&__pyx_n_s_Eh, __pyx_k_Eh, sizeof(__pyx_k_Eh), 0, 0, 1, 1},
    {&__pyx_n_s_Ellipsis, __pyx_k_Ellipsis, sizeof(__pyx_k_Ellipsis), 0, 0, 1, 1},
    {&__pyx_n_u_Emissivity_index_of_sed, __pyx_k_Emissivity_index_of_sed, sizeof(__pyx_k_Emissivity_index_of_sed), 0, 1, 0, 1},
    {&__pyx_kp_s_Empty_shape_tuple_for_cython_arr, __pyx_k_Empty_shape_tuple_for_cython_arr, sizeof(__pyx_k_Empty_shape_tuple_for_cython_arr), 0, 0, 1, 0},
    {&__pyx_kp_u_Error_in_Class, __pyx_k_Error_in_Class, sizeof(__pyx_k_Error_in_Class), 0, 1, 0, 0},
    {&__pyx_n_s_Ez, __pyx_k_Ez, sizeof(__pyx_k_Ez), 0, 0, 1, 1},
    {&__pyx_n_s_F, __pyx_k_F, sizeof(__pyx_k_F), 0, 0, 1, 1},
    {&__pyx_n_s_G, __pyx_k_G, sizeof(__pyx_k_G), 0, 0, 1, 1},
    {&__pyx_n_u_Gamma_0_nadm, __pyx_k_Gamma_0_nadm, sizeof(__pyx_k_Gamma_0_nadm), 0, 1, 0, 1},
    {&__pyx_n_s_H, __pyx_k_H, sizeof(__pyx_k_H), 0, 0, 1, 1},
    {&__pyx_n_u_H0, __pyx_k_H0, sizeof(__pyx_k_H0), 0, 1, 0, 1},
    {&__pyx_n_s_H_array, __pyx_k_H_array, sizeof(__pyx_k_H_array), 0, 0, 1, 1},
    {&__pyx_n_s_H_over_c_in_h_over_Mpc_array, __pyx_k_H_over_c_in_h_over_Mpc_array, sizeof(__pyx_k_H_over_c_in_h_over_Mpc_array), 0, 0, 1, 1},
    {&__pyx_n_s_Hankel, __pyx_k_Hankel, sizeof(__pyx_k_Hankel), 0, 0, 1, 1},
    {&__pyx_n_s_Hubble, __pyx_k_Hubble, sizeof(__pyx_k_Hubble), 0, 0, 1, 1},
    {&__pyx_n_u_I0, __pyx_k_I0, sizeof(__pyx_k_I0), 0, 1, 0, 1},
    {&__pyx_n_s_INFO, __pyx_k_INFO, sizeof(__pyx_k_INFO), 0, 0, 1, 1},
    {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
    {&__pyx_kp_u_In_order_to_get_pk_tilt_at_k_e_1, __pyx_k_In_order_to_get_pk_tilt_at_k_e_1, sizeof(__pyx_k_In_order_to_get_pk_tilt_at_k_e_1), 0, 1, 0, 0},
    {&__pyx_kp_u_In_order_to_get_sigma_R_z_you_mu, __pyx_k_In_order_to_get_sigma_R_z_you_mu, sizeof(__pyx_k_In_order_to_get_sigma_R_z_you_mu), 0, 1, 0, 0},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
    {&__pyx_kp_s_Index_out_of_bounds_axis_d, __pyx_k_Index_out_of_bounds_axis_d, sizeof(__pyx_k_Index_out_of_bounds_axis_d), 0, 0, 1, 0},
    {&__pyx_kp_s_Indirect_dimensions_not_supporte, __pyx_k_Indirect_dimensions_not_supporte, sizeof(__pyx_k_Indirect_dimensions_not_supporte), 0, 0, 1, 0},
    {&__pyx_kp_u_Input_should_be_a_float_or_a_1D, __pyx_k_Input_should_be_a_float_or_a_1D, sizeof(__pyx_k_Input_should_be_a_float_or_a_1D), 0, 1, 0, 0},
    {&__pyx_n_s_InterpolatedUnivariateSpline, __pyx_k_InterpolatedUnivariateSpline, sizeof(__pyx_k_InterpolatedUnivariateSpline), 0, 0, 1, 1},
    {&__pyx_kp_u_Invalid_mode_expected_c_or_fortr, __pyx_k_Invalid_mode_expected_c_or_fortr, sizeof(__pyx_k_Invalid_mode_expected_c_or_fortr), 0, 1, 0, 0},
    {&__pyx_kp_u_Invalid_shape_in_axis, __pyx_k_Invalid_shape_in_axis, sizeof(__pyx_k_Invalid_shape_in_axis), 0, 1, 0, 0},
    {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
    {&__pyx_n_s_M, __pyx_k_M, sizeof(__pyx_k_M), 0, 0, 1, 1},
    {&__pyx_n_u_M0_HOD_ngal, __pyx_k_M0_HOD_ngal, sizeof(__pyx_k_M0_HOD_ngal), 0, 1, 0, 1},
    {&__pyx_n_s_M1SZ, __pyx_k_M1SZ, sizeof(__pyx_k_M1SZ), 0, 0, 1, 1},
    {&__pyx_n_s_M1_prime, __pyx_k_M1_prime, sizeof(__pyx_k_M1_prime), 0, 0, 1, 1},
    {&__pyx_n_u_M1_prime_HOD, __pyx_k_M1_prime_HOD, sizeof(__pyx_k_M1_prime_HOD), 0, 1, 0, 1},
    {&__pyx_n_u_M1_prime_HOD_ngal, __pyx_k_M1_prime_HOD_ngal, sizeof(__pyx_k_M1_prime_HOD_ngal), 0, 1, 0, 1},
    {&__pyx_n_s_M500, __pyx_k_M500, sizeof(__pyx_k_M500), 0, 0, 1, 1},
    {&__pyx_n_s_M500c_zk, __pyx_k_M500c_zk, sizeof(__pyx_k_M500c_zk), 0, 0, 1, 1},
    {&__pyx_n_s_MF_extr, __pyx_k_MF_extr, sizeof(__pyx_k_MF_extr), 0, 0, 1, 1},
    {&__pyx_n_s_MUpper, __pyx_k_MUpper, sizeof(__pyx_k_MUpper), 0, 0, 1, 1},
    {&__pyx_n_s_M_halo, __pyx_k_M_halo, sizeof(__pyx_k_M_halo), 0, 0, 1, 1},
    {&__pyx_n_u_M_max, __pyx_k_M_max, sizeof(__pyx_k_M_max), 0, 1, 0, 1},
    {&__pyx_n_s_M_min, __pyx_k_M_min, sizeof(__pyx_k_M_min), 0, 0, 1, 1},
    {&__pyx_n_u_M_min, __pyx_k_M_min, sizeof(__pyx_k_M_min), 0, 1, 0, 1},
    {&__pyx_n_u_M_min_HOD, __pyx_k_M_min_HOD, sizeof(__pyx_k_M_min_HOD), 0, 1, 0, 1},
    {&__pyx_n_u_M_min_HOD_ngal, __pyx_k_M_min_HOD_ngal, sizeof(__pyx_k_M_min_HOD_ngal), 0, 1, 0, 1},
    {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
    {&__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_k_MemoryView_of_r_at_0x_x, sizeof(__pyx_k_MemoryView_of_r_at_0x_x), 0, 0, 1, 0},
    {&__pyx_kp_s_MemoryView_of_r_object, __pyx_k_MemoryView_of_r_object, sizeof(__pyx_k_MemoryView_of_r_object), 0, 0, 1, 0},
    {&__pyx_n_u_Most_efficient_halo_mass_in_Msun, __pyx_k_Most_efficient_halo_mass_in_Msun, sizeof(__pyx_k_Most_efficient_halo_mass_in_Msun), 0, 1, 0, 1},
    {&__pyx_n_s_N, __pyx_k_N, sizeof(__pyx_k_N), 0, 0, 1, 1},
    {&__pyx_n_u_N_dg, __pyx_k_N_dg, sizeof(__pyx_k_N_dg), 0, 1, 0, 1},
    {&__pyx_n_u_N_ncdm, __pyx_k_N_ncdm, sizeof(__pyx_k_N_ncdm), 0, 1, 0, 1},
    {&__pyx_n_s_N_ngal, __pyx_k_N_ngal, sizeof(__pyx_k_N_ngal), 0, 0, 1, 1},
    {&__pyx_n_u_N_ur, __pyx_k_N_ur, sizeof(__pyx_k_N_ur), 0, 1, 0, 1},
    {&__pyx_n_s_Nc, __pyx_k_Nc, sizeof(__pyx_k_Nc), 0, 0, 1, 1},
    {&__pyx_n_s_Nc_mean, __pyx_k_Nc_mean, sizeof(__pyx_k_Nc_mean), 0, 0, 1, 1},
    {&__pyx_n_s_Neff, __pyx_k_Neff, sizeof(__pyx_k_Neff), 0, 0, 1, 1},
    {&__pyx_n_u_Neff, __pyx_k_Neff, sizeof(__pyx_k_Neff), 0, 1, 0, 1},
    {&__pyx_n_s_Nmcfit, __pyx_k_Nmcfit, sizeof(__pyx_k_Nmcfit), 0, 0, 1, 1},
    {&__pyx_kp_u_No_Cl_computed, __pyx_k_No_Cl_computed, sizeof(__pyx_k_No_Cl_computed), 0, 1, 0, 0},
    {&__pyx_kp_u_No_density_Cl_computed, __pyx_k_No_density_Cl_computed, sizeof(__pyx_k_No_density_Cl_computed), 0, 1, 0, 0},
    {&__pyx_kp_u_No_lensed_Cl_computed, __pyx_k_No_lensed_Cl_computed, sizeof(__pyx_k_No_lensed_Cl_computed), 0, 1, 0, 0},
    {&__pyx_kp_u_No_massive_neutrinos_You_must_us, __pyx_k_No_massive_neutrinos_You_must_us, sizeof(__pyx_k_No_massive_neutrinos_You_must_us), 0, 1, 0, 0},
    {&__pyx_kp_u_No_power_spectrum_computed_In_or, __pyx_k_No_power_spectrum_computed_In_or, sizeof(__pyx_k_No_power_spectrum_computed_In_or), 0, 1, 0, 0},
    {&__pyx_kp_u_No_power_spectrum_computed_In_or_2, __pyx_k_No_power_spectrum_computed_In_or_2, sizeof(__pyx_k_No_power_spectrum_computed_In_or_2), 0, 1, 0, 0},
    {&__pyx_kp_u_No_power_spectrum_computed_You_m, __pyx_k_No_power_spectrum_computed_You_m, sizeof(__pyx_k_No_power_spectrum_computed_You_m), 0, 1, 0, 0},
    {&__pyx_kp_u_Normalisation_of_L___M_relation, __pyx_k_Normalisation_of_L___M_relation, sizeof(__pyx_k_Normalisation_of_L___M_relation), 0, 1, 0, 0},
    {&__pyx_n_s_NotImplementedError, __pyx_k_NotImplementedError, sizeof(__pyx_k_NotImplementedError), 0, 0, 1, 1},
    {&__pyx_n_s_Ns, __pyx_k_Ns, sizeof(__pyx_k_Ns), 0, 0, 1, 1},
    {&__pyx_n_s_Ntot, __pyx_k_Ntot, sizeof(__pyx_k_Ntot), 0, 0, 1, 1},
    {&__pyx_n_s_Nz, __pyx_k_Nz, sizeof(__pyx_k_Nz), 0, 0, 1, 1},
    {&__pyx_n_b_O, __pyx_k_O, sizeof(__pyx_k_O), 0, 0, 0, 1},
    {&__pyx_n_s_Om_m, __pyx_k_Om_m, sizeof(__pyx_k_Om_m), 0, 0, 1, 1},
    {&__pyx_n_s_Omega0_b, __pyx_k_Omega0_b, sizeof(__pyx_k_Omega0_b), 0, 0, 1, 1},
    {&__pyx_n_s_Omega0_cdm, __pyx_k_Omega0_cdm, sizeof(__pyx_k_Omega0_cdm), 0, 0, 1, 1},
    {&__pyx_n_u_Omega0_fld, __pyx_k_Omega0_fld, sizeof(__pyx_k_Omega0_fld), 0, 1, 0, 1},
    {&__pyx_n_s_Omega0_k, __pyx_k_Omega0_k, sizeof(__pyx_k_Omega0_k), 0, 0, 1, 1},
    {&__pyx_n_u_Omega0_lambda, __pyx_k_Omega0_lambda, sizeof(__pyx_k_Omega0_lambda), 0, 1, 0, 1},
    {&__pyx_n_s_Omega0_m, __pyx_k_Omega0_m, sizeof(__pyx_k_Omega0_m), 0, 0, 1, 1},
    {&__pyx_n_s_Omega_Lambda, __pyx_k_Omega_Lambda, sizeof(__pyx_k_Omega_Lambda), 0, 0, 1, 1},
    {&__pyx_n_u_Omega_Lambda, __pyx_k_Omega_Lambda, sizeof(__pyx_k_Omega_Lambda), 0, 1, 0, 1},
    {&__pyx_n_s_Omega_b, __pyx_k_Omega_b, sizeof(__pyx_k_Omega_b), 0, 0, 1, 1},
    {&__pyx_n_u_Omega_b, __pyx_k_Omega_b, sizeof(__pyx_k_Omega_b), 0, 1, 0, 1},
    {&__pyx_n_u_Omega_c, __pyx_k_Omega_c, sizeof(__pyx_k_Omega_c), 0, 1, 0, 1},
    {&__pyx_n_u_Omega_cdm, __pyx_k_Omega_cdm, sizeof(__pyx_k_Omega_cdm), 0, 1, 0, 1},
    {&__pyx_n_s_Omega_g, __pyx_k_Omega_g, sizeof(__pyx_k_Omega_g), 0, 0, 1, 1},
    {&__pyx_n_s_Omega_m, __pyx_k_Omega_m, sizeof(__pyx_k_Omega_m), 0, 0, 1, 1},
    {&__pyx_n_u_Omega_m, __pyx_k_Omega_m, sizeof(__pyx_k_Omega_m), 0, 1, 0, 1},
    {&__pyx_n_s_Omega_r, __pyx_k_Omega_r, sizeof(__pyx_k_Omega_r), 0, 0, 1, 1},
    {&__pyx_kp_u_Out_of_bounds_on_buffer_access_a, __pyx_k_Out_of_bounds_on_buffer_access_a, sizeof(__pyx_k_Out_of_bounds_on_buffer_access_a), 0, 1, 0, 0},
    {&__pyx_n_s_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 0, 1, 1},
    {&__pyx_n_s_P0GNFW, __pyx_k_P0GNFW, sizeof(__pyx_k_P0GNFW), 0, 0, 1, 1},
    {&__pyx_n_u_P0GNFW, __pyx_k_P0GNFW, sizeof(__pyx_k_P0GNFW), 0, 1, 0, 1},
    {&__pyx_n_u_P0_B12, __pyx_k_P0_B12, sizeof(__pyx_k_P0_B12), 0, 1, 0, 1},
    {&__pyx_n_u_P13_file, __pyx_k_P13_file, sizeof(__pyx_k_P13_file), 0, 1, 0, 1},
    {&__pyx_n_s_P200, __pyx_k_P200, sizeof(__pyx_k_P200), 0, 0, 1, 1},
    {&__pyx_n_s_PATH_TO_CLASS_SZ_DATA, __pyx_k_PATH_TO_CLASS_SZ_DATA, sizeof(__pyx_k_PATH_TO_CLASS_SZ_DATA), 0, 0, 1, 1},
    {&__pyx_n_s_PArr, __pyx_k_PArr, sizeof(__pyx_k_PArr), 0, 0, 1, 1},
    {&__pyx_n_s_PLog10M, __pyx_k_PLog10M, sizeof(__pyx_k_PLog10M), 0, 0, 1, 1},
    {&__pyx_n_s_PLog10M_full, __pyx_k_PLog10M_full, sizeof(__pyx_k_PLog10M_full), 0, 0, 1, 1},
    {&__pyx_kp_u_P_cb_not_computed_by_CLASS_proba, __pyx_k_P_cb_not_computed_by_CLASS_proba, sizeof(__pyx_k_P_cb_not_computed_by_CLASS_proba), 0, 1, 0, 0},
    {&__pyx_kp_u_P_cb_not_computed_probably_becau, __pyx_k_P_cb_not_computed_probably_becau, sizeof(__pyx_k_P_cb_not_computed_probably_becau), 0, 1, 0, 0},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_n_u_Power_law_index_of_SED_at_high_f, __pyx_k_Power_law_index_of_SED_at_high_f, sizeof(__pyx_k_Power_law_index_of_SED_at_high_f), 0, 1, 0, 1},
    {&__pyx_kp_u_Profile, __pyx_k_Profile, sizeof(__pyx_k_Profile), 0, 1, 0, 0},
    {&__pyx_n_s_Py0GivenM, __pyx_k_Py0GivenM, sizeof(__pyx_k_Py0GivenM), 0, 0, 1, 1},
    {&__pyx_n_s_Pz, __pyx_k_Pz, sizeof(__pyx_k_Pz), 0, 0, 1, 1},
    {&__pyx_n_s_QF, __pyx_k_QF, sizeof(__pyx_k_QF), 0, 0, 1, 1},
    {&__pyx_n_s_R, __pyx_k_R, sizeof(__pyx_k_R), 0, 0, 1, 1},
    {&__pyx_kp_s_Raised_when_Class_could_not_com, __pyx_k_Raised_when_Class_could_not_com, sizeof(__pyx_k_Raised_when_Class_could_not_com), 0, 0, 1, 0},
    {&__pyx_kp_s_Raised_when_Class_failed_to_und, __pyx_k_Raised_when_Class_failed_to_und, sizeof(__pyx_k_Raised_when_Class_failed_to_und), 0, 0, 1, 0},
    {&__pyx_kp_u_Redshift_evolution_of_L___M_norm, __pyx_k_Redshift_evolution_of_L___M_norm, sizeof(__pyx_k_Redshift_evolution_of_L___M_norm), 0, 1, 0, 0},
    {&__pyx_n_u_Redshift_evolution_of_dust_tempe, __pyx_k_Redshift_evolution_of_dust_tempe, sizeof(__pyx_k_Redshift_evolution_of_dust_tempe), 0, 1, 0, 1},
    {&__pyx_n_s_Rho_crit_0, __pyx_k_Rho_crit_0, sizeof(__pyx_k_Rho_crit_0), 0, 0, 1, 1},
    {&__pyx_n_u_SZ_cat_file, __pyx_k_SZ_cat_file, sizeof(__pyx_k_SZ_cat_file), 0, 1, 0, 1},
    {&__pyx_n_s_Sequence, __pyx_k_Sequence, sizeof(__pyx_k_Sequence), 0, 0, 1, 1},
    {&__pyx_n_u_Size_of_halo_masses_sourcing_CIB, __pyx_k_Size_of_halo_masses_sourcing_CIB, sizeof(__pyx_k_Size_of_halo_masses_sourcing_CIB), 0, 1, 0, 1},
    {&__pyx_kp_s_Step_may_not_be_zero_axis_d, __pyx_k_Step_may_not_be_zero_axis_d, sizeof(__pyx_k_Step_may_not_be_zero_axis_d), 0, 0, 1, 0},
    {&__pyx_n_s_Stw, __pyx_k_Stw, sizeof(__pyx_k_Stw), 0, 0, 1, 1},
    {&__pyx_kp_b_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 0, 0, 0},
    {&__pyx_n_s_TCMB, __pyx_k_TCMB, sizeof(__pyx_k_TCMB), 0, 0, 1, 1},
    {&__pyx_n_s_TKelvin, __pyx_k_TKelvin, sizeof(__pyx_k_TKelvin), 0, 0, 1, 1},
    {&__pyx_n_s_T_cmb, __pyx_k_T_cmb, sizeof(__pyx_k_T_cmb), 0, 0, 1, 1},
    {&__pyx_n_s_T_ll_arr, __pyx_k_T_ll_arr, sizeof(__pyx_k_T_ll_arr), 0, 0, 1, 1},
    {&__pyx_n_s_Tb, __pyx_k_Tb, sizeof(__pyx_k_Tb), 0, 0, 1, 1},
    {&__pyx_n_s_Tcmb, __pyx_k_Tcmb, sizeof(__pyx_k_Tcmb), 0, 0, 1, 1},
    {&__pyx_n_s_Tcmb_gNU, __pyx_k_Tcmb_gNU, sizeof(__pyx_k_Tcmb_gNU), 0, 0, 1, 1},
    {&__pyx_n_u_Tinker_et_al_10_alpha_consistenc, __pyx_k_Tinker_et_al_10_alpha_consistenc, sizeof(__pyx_k_Tinker_et_al_10_alpha_consistenc), 0, 1, 0, 1},
    {&__pyx_n_s_TkeV, __pyx_k_TkeV, sizeof(__pyx_k_TkeV), 0, 0, 1, 1},
    {&__pyx_kp_u_Type, __pyx_k_Type, sizeof(__pyx_k_Type), 0, 1, 0, 0},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_kp_s_Unable_to_convert_item_to_object, __pyx_k_Unable_to_convert_item_to_object, sizeof(__pyx_k_Unable_to_convert_item_to_object), 0, 0, 1, 0},
    {&__pyx_kp_u_Users_boris_Work_CLASS_SZ_SO_SZ, __pyx_k_Users_boris_Work_CLASS_SZ_SO_SZ, sizeof(__pyx_k_Users_boris_Work_CLASS_SZ_SO_SZ), 0, 1, 0, 0},
    {&__pyx_n_u_V_0, __pyx_k_V_0, sizeof(__pyx_k_V_0), 0, 1, 0, 1},
    {&__pyx_n_u_V_1, __pyx_k_V_1, sizeof(__pyx_k_V_1), 0, 1, 0, 1},
    {&__pyx_n_u_V_2, __pyx_k_V_2, sizeof(__pyx_k_V_2), 0, 1, 0, 1},
    {&__pyx_n_u_V_3, __pyx_k_V_3, sizeof(__pyx_k_V_3), 0, 1, 0, 1},
    {&__pyx_n_u_V_4, __pyx_k_V_4, sizeof(__pyx_k_V_4), 0, 1, 0, 1},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_s_View_MemoryView, __pyx_k_View_MemoryView, sizeof(__pyx_k_View_MemoryView), 0, 0, 1, 1},
    {&__pyx_n_s_Wg, __pyx_k_Wg, sizeof(__pyx_k_Wg), 0, 0, 1, 1},
    {&__pyx_n_s_X, __pyx_k_X, sizeof(__pyx_k_X), 0, 0, 1, 1},
    {&__pyx_n_s_Xtw, __pyx_k_Xtw, sizeof(__pyx_k_Xtw), 0, 0, 1, 1},
    {&__pyx_n_s_Y0, __pyx_k_Y0, sizeof(__pyx_k_Y0), 0, 0, 1, 1},
    {&__pyx_n_s_Y1, __pyx_k_Y1, sizeof(__pyx_k_Y1), 0, 0, 1, 1},
    {&__pyx_n_s_Y2, __pyx_k_Y2, sizeof(__pyx_k_Y2), 0, 0, 1, 1},
    {&__pyx_n_s_Y3, __pyx_k_Y3, sizeof(__pyx_k_Y3), 0, 0, 1, 1},
    {&__pyx_n_s_Y4, __pyx_k_Y4, sizeof(__pyx_k_Y4), 0, 0, 1, 1},
    {&__pyx_n_u_YHe, __pyx_k_YHe, sizeof(__pyx_k_YHe), 0, 1, 0, 1},
    {&__pyx_kp_u_You_ask_classy_to_return_an_arra, __pyx_k_You_ask_classy_to_return_an_arra, sizeof(__pyx_k_You_ask_classy_to_return_an_arra), 0, 1, 0, 0},
    {&__pyx_kp_u_You_ask_classy_to_return_an_arra_2, __pyx_k_You_ask_classy_to_return_an_arra_2, sizeof(__pyx_k_You_ask_classy_to_return_an_arra_2), 0, 1, 0, 0},
    {&__pyx_kp_u_You_ask_classy_to_return_an_arra_3, __pyx_k_You_ask_classy_to_return_an_arra_3, sizeof(__pyx_k_You_ask_classy_to_return_an_arra_3), 0, 1, 0, 0},
    {&__pyx_kp_b__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 0, 0, 0},
    {&__pyx_kp_u__10, __pyx_k__10, sizeof(__pyx_k__10), 0, 1, 0, 0},
    {&__pyx_kp_b__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 0, 0, 0},
    {&__pyx_kp_b__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 0, 0, 0},
    {&__pyx_kp_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 0},
    {&__pyx_kp_u__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 1, 0, 0},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_kp_u__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 1, 0, 0},
    {&__pyx_kp_u__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 1, 0, 0},
    {&__pyx_n_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 1},
    {&__pyx_kp_u__46, __pyx_k__46, sizeof(__pyx_k__46), 0, 1, 0, 0},
    {&__pyx_n_s__554, __pyx_k__554, sizeof(__pyx_k__554), 0, 0, 1, 1},
    {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
    {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
    {&__pyx_kp_b__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 0, 0, 0},
    {&__pyx_n_u_a_dark, __pyx_k_a_dark, sizeof(__pyx_k_a_dark), 0, 1, 0, 1},
    {&__pyx_n_s_abc, __pyx_k_abc, sizeof(__pyx_k_abc), 0, 0, 1, 1},
    {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
    {&__pyx_n_s_age, __pyx_k_age, sizeof(__pyx_k_age), 0, 0, 1, 1},
    {&__pyx_n_u_age, __pyx_k_age, sizeof(__pyx_k_age), 0, 1, 0, 1},
    {&__pyx_n_s_allocate_buffer, __pyx_k_allocate_buffer, sizeof(__pyx_k_allocate_buffer), 0, 0, 1, 1},
    {&__pyx_n_s_alpha, __pyx_k_alpha, sizeof(__pyx_k_alpha), 0, 0, 1, 1},
    {&__pyx_n_s_alphaGNFW, __pyx_k_alphaGNFW, sizeof(__pyx_k_alphaGNFW), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_B12, __pyx_k_alpha_B12, sizeof(__pyx_k_alpha_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_c_P0, __pyx_k_alpha_c_P0, sizeof(__pyx_k_alpha_c_P0), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_c_P0_B12, __pyx_k_alpha_c_P0_B12, sizeof(__pyx_k_alpha_c_P0_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_c_alpha, __pyx_k_alpha_c_alpha, sizeof(__pyx_k_alpha_c_alpha), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_c_alpha, __pyx_k_alpha_c_alpha, sizeof(__pyx_k_alpha_c_alpha), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_c_beta, __pyx_k_alpha_c_beta, sizeof(__pyx_k_alpha_c_beta), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_c_beta, __pyx_k_alpha_c_beta, sizeof(__pyx_k_alpha_c_beta), 0, 1, 0, 1},
    {&__pyx_n_u_alpha_c_beta_B12, __pyx_k_alpha_c_beta_B12, sizeof(__pyx_k_alpha_c_beta_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_c_rho0, __pyx_k_alpha_c_rho0, sizeof(__pyx_k_alpha_c_rho0), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_c_rho0, __pyx_k_alpha_c_rho0, sizeof(__pyx_k_alpha_c_rho0), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_c_xc, __pyx_k_alpha_c_xc, sizeof(__pyx_k_alpha_c_xc), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_c_xc_B12, __pyx_k_alpha_c_xc_B12, sizeof(__pyx_k_alpha_c_xc_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_m_P0, __pyx_k_alpha_m_P0, sizeof(__pyx_k_alpha_m_P0), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_m_P0_B12, __pyx_k_alpha_m_P0_B12, sizeof(__pyx_k_alpha_m_P0_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_m_alpha, __pyx_k_alpha_m_alpha, sizeof(__pyx_k_alpha_m_alpha), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_m_alpha, __pyx_k_alpha_m_alpha, sizeof(__pyx_k_alpha_m_alpha), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_m_beta, __pyx_k_alpha_m_beta, sizeof(__pyx_k_alpha_m_beta), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_m_beta, __pyx_k_alpha_m_beta, sizeof(__pyx_k_alpha_m_beta), 0, 1, 0, 1},
    {&__pyx_n_u_alpha_m_beta_B12, __pyx_k_alpha_m_beta_B12, sizeof(__pyx_k_alpha_m_beta_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_m_rho0, __pyx_k_alpha_m_rho0, sizeof(__pyx_k_alpha_m_rho0), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_m_rho0, __pyx_k_alpha_m_rho0, sizeof(__pyx_k_alpha_m_rho0), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_m_xc, __pyx_k_alpha_m_xc, sizeof(__pyx_k_alpha_m_xc), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_m_xc_B12, __pyx_k_alpha_m_xc_B12, sizeof(__pyx_k_alpha_m_xc_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_s, __pyx_k_alpha_s, sizeof(__pyx_k_alpha_s), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_s, __pyx_k_alpha_s, sizeof(__pyx_k_alpha_s), 0, 1, 0, 1},
    {&__pyx_n_u_alpha_s_HOD, __pyx_k_alpha_s_HOD, sizeof(__pyx_k_alpha_s_HOD), 0, 1, 0, 1},
    {&__pyx_n_u_alpha_s_HOD_ngal, __pyx_k_alpha_s_HOD_ngal, sizeof(__pyx_k_alpha_s_HOD_ngal), 0, 1, 0, 1},
    {&__pyx_n_u_alpha_t, __pyx_k_alpha_t, sizeof(__pyx_k_alpha_t), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_z_P0, __pyx_k_alpha_z_P0, sizeof(__pyx_k_alpha_z_P0), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_z_P0_B12, __pyx_k_alpha_z_P0_B12, sizeof(__pyx_k_alpha_z_P0_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_z_alpha, __pyx_k_alpha_z_alpha, sizeof(__pyx_k_alpha_z_alpha), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_z_alpha, __pyx_k_alpha_z_alpha, sizeof(__pyx_k_alpha_z_alpha), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_z_beta, __pyx_k_alpha_z_beta, sizeof(__pyx_k_alpha_z_beta), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_z_beta, __pyx_k_alpha_z_beta, sizeof(__pyx_k_alpha_z_beta), 0, 1, 0, 1},
    {&__pyx_n_u_alpha_z_beta_B12, __pyx_k_alpha_z_beta_B12, sizeof(__pyx_k_alpha_z_beta_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_z_rho0, __pyx_k_alpha_z_rho0, sizeof(__pyx_k_alpha_z_rho0), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_z_rho0, __pyx_k_alpha_z_rho0, sizeof(__pyx_k_alpha_z_rho0), 0, 1, 0, 1},
    {&__pyx_n_s_alpha_z_xc, __pyx_k_alpha_z_xc, sizeof(__pyx_k_alpha_z_xc), 0, 0, 1, 1},
    {&__pyx_n_u_alpha_z_xc_B12, __pyx_k_alpha_z_xc_B12, sizeof(__pyx_k_alpha_z_xc_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alphap_m_P0, __pyx_k_alphap_m_P0, sizeof(__pyx_k_alphap_m_P0), 0, 0, 1, 1},
    {&__pyx_n_u_alphap_m_P0_B12, __pyx_k_alphap_m_P0_B12, sizeof(__pyx_k_alphap_m_P0_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alphap_m_alpha, __pyx_k_alphap_m_alpha, sizeof(__pyx_k_alphap_m_alpha), 0, 0, 1, 1},
    {&__pyx_n_u_alphap_m_alpha, __pyx_k_alphap_m_alpha, sizeof(__pyx_k_alphap_m_alpha), 0, 1, 0, 1},
    {&__pyx_n_s_alphap_m_beta, __pyx_k_alphap_m_beta, sizeof(__pyx_k_alphap_m_beta), 0, 0, 1, 1},
    {&__pyx_n_u_alphap_m_beta, __pyx_k_alphap_m_beta, sizeof(__pyx_k_alphap_m_beta), 0, 1, 0, 1},
    {&__pyx_n_u_alphap_m_beta_B12, __pyx_k_alphap_m_beta_B12, sizeof(__pyx_k_alphap_m_beta_B12), 0, 1, 0, 1},
    {&__pyx_n_s_alphap_m_rho0, __pyx_k_alphap_m_rho0, sizeof(__pyx_k_alphap_m_rho0), 0, 0, 1, 1},
    {&__pyx_n_u_alphap_m_rho0, __pyx_k_alphap_m_rho0, sizeof(__pyx_k_alphap_m_rho0), 0, 1, 0, 1},
    {&__pyx_n_s_alphap_m_xc, __pyx_k_alphap_m_xc, sizeof(__pyx_k_alphap_m_xc), 0, 0, 1, 1},
    {&__pyx_n_u_alphap_m_xc_B12, __pyx_k_alphap_m_xc_B12, sizeof(__pyx_k_alphap_m_xc_B12), 0, 1, 0, 1},
    {&__pyx_kp_u_and, __pyx_k_and, sizeof(__pyx_k_and), 0, 1, 0, 0},
    {&__pyx_n_s_angular_distance, __pyx_k_angular_distance, sizeof(__pyx_k_angular_distance), 0, 0, 1, 1},
    {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
    {&__pyx_n_s_applyMFDebiasCorrection, __pyx_k_applyMFDebiasCorrection, sizeof(__pyx_k_applyMFDebiasCorrection), 0, 0, 1, 1},
    {&__pyx_n_s_arange, __pyx_k_arange, sizeof(__pyx_k_arange), 0, 0, 1, 1},
    {&__pyx_n_s_argmax, __pyx_k_argmax, sizeof(__pyx_k_argmax), 0, 0, 1, 1},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_u_arr_0, __pyx_k_arr_0, sizeof(__pyx_k_arr_0), 0, 1, 0, 1},
    {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
    {&__pyx_n_s_asarray, __pyx_k_asarray, sizeof(__pyx_k_asarray), 0, 0, 1, 1},
    {&__pyx_n_s_assume_sorted, __pyx_k_assume_sorted, sizeof(__pyx_k_assume_sorted), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_atleast_1d, __pyx_k_atleast_1d, sizeof(__pyx_k_atleast_1d), 0, 0, 1, 1},
    {&__pyx_n_s_axis, __pyx_k_axis, sizeof(__pyx_k_axis), 0, 0, 1, 1},
    {&__pyx_n_s_b_tty, __pyx_k_b_tty, sizeof(__pyx_k_b_tty), 0, 0, 1, 1},
    {&__pyx_n_s_b_yyy, __pyx_k_b_yyy, sizeof(__pyx_k_b_yyy), 0, 0, 1, 1},
    {&__pyx_n_s_background, __pyx_k_background, sizeof(__pyx_k_background), 0, 0, 1, 1},
    {&__pyx_n_u_background, __pyx_k_background, sizeof(__pyx_k_background), 0, 1, 0, 1},
    {&__pyx_kp_u_bad_call, __pyx_k_bad_call, sizeof(__pyx_k_bad_call), 0, 1, 0, 0},
    {&__pyx_n_s_baryon_temperature, __pyx_k_baryon_temperature, sizeof(__pyx_k_baryon_temperature), 0, 0, 1, 1},
    {&__pyx_n_s_base, __pyx_k_base, sizeof(__pyx_k_base), 0, 0, 1, 1},
    {&__pyx_n_s_basicConfig, __pyx_k_basicConfig, sizeof(__pyx_k_basicConfig), 0, 0, 1, 1},
    {&__pyx_n_u_bb, __pyx_k_bb, sizeof(__pyx_k_bb), 0, 1, 0, 1},
    {&__pyx_kp_u_bbn_PRIMAT21_class_format_dat, __pyx_k_bbn_PRIMAT21_class_format_dat, sizeof(__pyx_k_bbn_PRIMAT21_class_format_dat), 0, 1, 0, 0},
    {&__pyx_n_s_betaGNFW, __pyx_k_betaGNFW, sizeof(__pyx_k_betaGNFW), 0, 0, 1, 1},
    {&__pyx_n_u_betaGNFW, __pyx_k_betaGNFW, sizeof(__pyx_k_betaGNFW), 0, 1, 0, 1},
    {&__pyx_n_u_beta_B12, __pyx_k_beta_B12, sizeof(__pyx_k_beta_B12), 0, 1, 0, 1},
    {&__pyx_n_u_beta_s, __pyx_k_beta_s, sizeof(__pyx_k_beta_s), 0, 1, 0, 1},
    {&__pyx_n_s_bh, __pyx_k_bh, sizeof(__pyx_k_bh), 0, 0, 1, 1},
    {&__pyx_n_s_bk_at_z_hm, __pyx_k_bk_at_z_hm, sizeof(__pyx_k_bk_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_bk_ttg_at_z_hm, __pyx_k_bk_ttg_at_z_hm, sizeof(__pyx_k_bk_ttg_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_u_boundary, __pyx_k_boundary, sizeof(__pyx_k_boundary), 0, 1, 0, 1},
    {&__pyx_n_s_bounds_error, __pyx_k_bounds_error, sizeof(__pyx_k_bounds_error), 0, 0, 1, 1},
    {&__pyx_n_s_broadcast_arrays, __pyx_k_broadcast_arrays, sizeof(__pyx_k_broadcast_arrays), 0, 0, 1, 1},
    {&__pyx_kp_u_but_you_asked_a_l_i, __pyx_k_but_you_asked_a_l_i, sizeof(__pyx_k_but_you_asked_a_l_i), 0, 1, 0, 0},
    {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
    {&__pyx_n_u_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 1, 0, 1},
    {&__pyx_n_s_c500, __pyx_k_c500, sizeof(__pyx_k_c500), 0, 0, 1, 1},
    {&__pyx_n_u_c500, __pyx_k_c500, sizeof(__pyx_k_c500), 0, 1, 0, 1},
    {&__pyx_n_u_c_B12, __pyx_k_c_B12, sizeof(__pyx_k_c_B12), 0, 1, 0, 1},
    {&__pyx_n_u_c_B16, __pyx_k_c_B16, sizeof(__pyx_k_c_B16), 0, 1, 0, 1},
    {&__pyx_n_s_c_asked, __pyx_k_c_asked, sizeof(__pyx_k_c_asked), 0, 0, 1, 1},
    {&__pyx_n_s_c_delta, __pyx_k_c_delta, sizeof(__pyx_k_c_delta), 0, 0, 1, 1},
    {&__pyx_n_s_calcErrors, __pyx_k_calcErrors, sizeof(__pyx_k_calcErrors), 0, 0, 1, 1},
    {&__pyx_n_s_calcFRel, __pyx_k_calcFRel, sizeof(__pyx_k_calcFRel), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_chi, __pyx_k_calculate_chi, sizeof(__pyx_k_calculate_chi), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_cmb, __pyx_k_calculate_cmb, sizeof(__pyx_k_calculate_cmb), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_hubble, __pyx_k_calculate_hubble, sizeof(__pyx_k_calculate_hubble), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_pkl, __pyx_k_calculate_pkl, sizeof(__pyx_k_calculate_pkl), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_pkl_at_z, __pyx_k_calculate_pkl_at_z, sizeof(__pyx_k_calculate_pkl_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_pkl_fftlog_alphas, __pyx_k_calculate_pkl_fftlog_alphas, sizeof(__pyx_k_calculate_pkl_fftlog_alphas), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_pknl, __pyx_k_calculate_pknl, sizeof(__pyx_k_calculate_pknl), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_pknl_at_z, __pyx_k_calculate_pknl_at_z, sizeof(__pyx_k_calculate_pknl_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_sigma, __pyx_k_calculate_sigma, sizeof(__pyx_k_calculate_sigma), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_sigma8_and_der, __pyx_k_calculate_sigma8_and_der, sizeof(__pyx_k_calculate_sigma8_and_der), 0, 0, 1, 1},
    {&__pyx_n_s_calculate_sigma8_at_z, __pyx_k_calculate_sigma8_at_z, sizeof(__pyx_k_calculate_sigma8_at_z), 0, 0, 1, 1},
    {&__pyx_n_u_camb, __pyx_k_camb, sizeof(__pyx_k_camb), 0, 1, 0, 1},
    {&__pyx_n_s_check_task_dependency, __pyx_k_check_task_dependency, sizeof(__pyx_k_check_task_dependency), 0, 0, 1, 1},
    {&__pyx_n_s_chi, __pyx_k_chi, sizeof(__pyx_k_chi), 0, 0, 1, 1},
    {&__pyx_n_s_chi_star, __pyx_k_chi_star, sizeof(__pyx_k_chi_star), 0, 0, 1, 1},
    {&__pyx_n_u_cib_Snu_file_nu, __pyx_k_cib_Snu_file_nu, sizeof(__pyx_k_cib_Snu_file_nu), 0, 1, 0, 1},
    {&__pyx_n_u_cib_Snu_file_snu, __pyx_k_cib_Snu_file_snu, sizeof(__pyx_k_cib_Snu_file_snu), 0, 1, 0, 1},
    {&__pyx_n_u_cib_Snu_file_z, __pyx_k_cib_Snu_file_z, sizeof(__pyx_k_cib_Snu_file_z), 0, 1, 0, 1},
    {&__pyx_n_s_cib_monopole, __pyx_k_cib_monopole, sizeof(__pyx_k_cib_monopole), 0, 0, 1, 1},
    {&__pyx_n_s_cib_shotnoise, __pyx_k_cib_shotnoise, sizeof(__pyx_k_cib_shotnoise), 0, 0, 1, 1},
    {&__pyx_n_s_cl, __pyx_k_cl, sizeof(__pyx_k_cl), 0, 0, 1, 1},
    {&__pyx_n_s_cl_IA_g, __pyx_k_cl_IA_g, sizeof(__pyx_k_cl_IA_g), 0, 0, 1, 1},
    {&__pyx_n_s_cl_c1_gal, __pyx_k_cl_c1_gal, sizeof(__pyx_k_cl_c1_gal), 0, 0, 1, 1},
    {&__pyx_n_s_cl_c1_gallens, __pyx_k_cl_c1_gallens, sizeof(__pyx_k_cl_c1_gallens), 0, 0, 1, 1},
    {&__pyx_n_s_cl_c1_lens, __pyx_k_cl_c1_lens, sizeof(__pyx_k_cl_c1_lens), 0, 0, 1, 1},
    {&__pyx_n_s_cl_c1_tSZ, __pyx_k_cl_c1_tSZ, sizeof(__pyx_k_cl_c1_tSZ), 0, 0, 1, 1},
    {&__pyx_n_s_cl_c1c1, __pyx_k_cl_c1c1, sizeof(__pyx_k_cl_c1c1), 0, 0, 1, 1},
    {&__pyx_n_s_cl_cib, __pyx_k_cl_cib, sizeof(__pyx_k_cl_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_cib_cib, __pyx_k_cl_cib_cib, sizeof(__pyx_k_cl_cib_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_custom1_cib, __pyx_k_cl_custom1_cib, sizeof(__pyx_k_cl_custom1_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_ee, __pyx_k_cl_ee, sizeof(__pyx_k_cl_ee), 0, 0, 1, 1},
    {&__pyx_n_s_cl_eg, __pyx_k_cl_eg, sizeof(__pyx_k_cl_eg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gIA, __pyx_k_cl_gIA, sizeof(__pyx_k_cl_gIA), 0, 0, 1, 1},
    {&__pyx_n_s_cl_g_cib, __pyx_k_cl_g_cib, sizeof(__pyx_k_cl_g_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_g_gamma_1h, __pyx_k_cl_g_gamma_1h, sizeof(__pyx_k_cl_g_gamma_1h), 0, 0, 1, 1},
    {&__pyx_n_s_cl_g_gamma_2h, __pyx_k_cl_g_gamma_2h, sizeof(__pyx_k_cl_g_gamma_2h), 0, 0, 1, 1},
    {&__pyx_n_s_cl_g_gamma_ell, __pyx_k_cl_g_gamma_ell, sizeof(__pyx_k_cl_g_gamma_ell), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gal_cib, __pyx_k_cl_gal_cib, sizeof(__pyx_k_cl_gal_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gal_gal_kcmb, __pyx_k_cl_gal_gal_kcmb, sizeof(__pyx_k_cl_gal_gal_kcmb), 0, 0, 1, 1},
    {&__pyx_n_s_cl_galn_IA, __pyx_k_cl_galn_IA, sizeof(__pyx_k_cl_galn_IA), 0, 0, 1, 1},
    {&__pyx_n_s_cl_galn_gallens, __pyx_k_cl_galn_gallens, sizeof(__pyx_k_cl_galn_gallens), 0, 0, 1, 1},
    {&__pyx_n_s_cl_galn_galn, __pyx_k_cl_galn_galn, sizeof(__pyx_k_cl_galn_galn), 0, 0, 1, 1},
    {&__pyx_n_s_cl_galn_lens, __pyx_k_cl_galn_lens, sizeof(__pyx_k_cl_galn_lens), 0, 0, 1, 1},
    {&__pyx_n_s_cl_galn_tsz, __pyx_k_cl_galn_tsz, sizeof(__pyx_k_cl_galn_tsz), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gg, __pyx_k_cl_gg, sizeof(__pyx_k_cl_gg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_ggamma, __pyx_k_cl_ggamma, sizeof(__pyx_k_cl_ggamma), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gk, __pyx_k_cl_gk, sizeof(__pyx_k_cl_gk), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gkg, __pyx_k_cl_gkg, sizeof(__pyx_k_cl_gkg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gm, __pyx_k_cl_gm, sizeof(__pyx_k_cl_gm), 0, 0, 1, 1},
    {&__pyx_n_s_cl_gy, __pyx_k_cl_gy, sizeof(__pyx_k_cl_gy), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kSZ_kSZ_g, __pyx_k_cl_kSZ_kSZ_g, sizeof(__pyx_k_cl_kSZ_kSZ_g), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kSZ_kSZ_kcmb, __pyx_k_cl_kSZ_kSZ_kcmb, sizeof(__pyx_k_cl_kSZ_kSZ_kcmb), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kSZ_kSZ_kg, __pyx_k_cl_kSZ_kSZ_kg, sizeof(__pyx_k_cl_kSZ_kSZ_kg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kg, __pyx_k_cl_kg, sizeof(__pyx_k_cl_kg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kg_cib, __pyx_k_cl_kg_cib, sizeof(__pyx_k_cl_kg_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kg_k, __pyx_k_cl_kg_k, sizeof(__pyx_k_cl_kg_k), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kg_kg, __pyx_k_cl_kg_kg, sizeof(__pyx_k_cl_kg_kg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kg_m, __pyx_k_cl_kg_m, sizeof(__pyx_k_cl_kg_m), 0, 0, 1, 1},
    {&__pyx_n_s_cl_kk, __pyx_k_cl_kk, sizeof(__pyx_k_cl_kk), 0, 0, 1, 1},
    {&__pyx_n_s_cl_km, __pyx_k_cl_km, sizeof(__pyx_k_cl_km), 0, 0, 1, 1},
    {&__pyx_n_s_cl_ksz, __pyx_k_cl_ksz, sizeof(__pyx_k_cl_ksz), 0, 0, 1, 1},
    {&__pyx_n_s_cl_lens_cib, __pyx_k_cl_lens_cib, sizeof(__pyx_k_cl_lens_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_lensmagn_gallens, __pyx_k_cl_lensmagn_gallens, sizeof(__pyx_k_cl_lensmagn_gallens), 0, 0, 1, 1},
    {&__pyx_n_s_cl_lensmagn_tsz, __pyx_k_cl_lensmagn_tsz, sizeof(__pyx_k_cl_lensmagn_tsz), 0, 0, 1, 1},
    {&__pyx_n_s_cl_md, __pyx_k_cl_md, sizeof(__pyx_k_cl_md), 0, 0, 1, 1},
    {&__pyx_n_s_cl_md_ic, __pyx_k_cl_md_ic, sizeof(__pyx_k_cl_md_ic), 0, 0, 1, 1},
    {&__pyx_n_s_cl_mkg, __pyx_k_cl_mkg, sizeof(__pyx_k_cl_mkg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_mm, __pyx_k_cl_mm, sizeof(__pyx_k_cl_mm), 0, 0, 1, 1},
    {&__pyx_n_s_cl_my, __pyx_k_cl_my, sizeof(__pyx_k_cl_my), 0, 0, 1, 1},
    {&__pyx_n_s_cl_phi_cib, __pyx_k_cl_phi_cib, sizeof(__pyx_k_cl_phi_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_sz, __pyx_k_cl_sz, sizeof(__pyx_k_cl_sz), 0, 0, 1, 1},
    {&__pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2, __pyx_k_cl_sz_at_nu_in_GHz_in_microK2, sizeof(__pyx_k_cl_sz_at_nu_in_GHz_in_microK2), 0, 0, 1, 1},
    {&__pyx_n_s_cl_t2t2f, __pyx_k_cl_t2t2f, sizeof(__pyx_k_cl_t2t2f), 0, 0, 1, 1},
    {&__pyx_n_s_cl_tSZ_cib, __pyx_k_cl_tSZ_cib, sizeof(__pyx_k_cl_tSZ_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_te_y_y, __pyx_k_cl_te_y_y, sizeof(__pyx_k_cl_te_y_y), 0, 0, 1, 1},
    {&__pyx_n_s_cl_y_cib, __pyx_k_cl_y_cib, sizeof(__pyx_k_cl_y_cib), 0, 0, 1, 1},
    {&__pyx_n_s_cl_y_kcmb, __pyx_k_cl_y_kcmb, sizeof(__pyx_k_cl_y_kcmb), 0, 0, 1, 1},
    {&__pyx_n_s_cl_yg, __pyx_k_cl_yg, sizeof(__pyx_k_cl_yg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_ykg, __pyx_k_cl_ykg, sizeof(__pyx_k_cl_ykg), 0, 0, 1, 1},
    {&__pyx_n_s_cl_ym, __pyx_k_cl_ym, sizeof(__pyx_k_cl_ym), 0, 0, 1, 1},
    {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
    {&__pyx_n_u_class_2, __pyx_k_class_2, sizeof(__pyx_k_class_2), 0, 1, 0, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ, __pyx_k_class_sz_auxiliary_files_includ, sizeof(__pyx_k_class_sz_auxiliary_files_includ), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_10, __pyx_k_class_sz_auxiliary_files_includ_10, sizeof(__pyx_k_class_sz_auxiliary_files_includ_10), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_11, __pyx_k_class_sz_auxiliary_files_includ_11, sizeof(__pyx_k_class_sz_auxiliary_files_includ_11), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_12, __pyx_k_class_sz_auxiliary_files_includ_12, sizeof(__pyx_k_class_sz_auxiliary_files_includ_12), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_13, __pyx_k_class_sz_auxiliary_files_includ_13, sizeof(__pyx_k_class_sz_auxiliary_files_includ_13), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_2, __pyx_k_class_sz_auxiliary_files_includ_2, sizeof(__pyx_k_class_sz_auxiliary_files_includ_2), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_3, __pyx_k_class_sz_auxiliary_files_includ_3, sizeof(__pyx_k_class_sz_auxiliary_files_includ_3), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_4, __pyx_k_class_sz_auxiliary_files_includ_4, sizeof(__pyx_k_class_sz_auxiliary_files_includ_4), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_5, __pyx_k_class_sz_auxiliary_files_includ_5, sizeof(__pyx_k_class_sz_auxiliary_files_includ_5), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_6, __pyx_k_class_sz_auxiliary_files_includ_6, sizeof(__pyx_k_class_sz_auxiliary_files_includ_6), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_7, __pyx_k_class_sz_auxiliary_files_includ_7, sizeof(__pyx_k_class_sz_auxiliary_files_includ_7), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_8, __pyx_k_class_sz_auxiliary_files_includ_8, sizeof(__pyx_k_class_sz_auxiliary_files_includ_8), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_auxiliary_files_includ_9, __pyx_k_class_sz_auxiliary_files_includ_9, sizeof(__pyx_k_class_sz_auxiliary_files_includ_9), 0, 1, 0, 0},
    {&__pyx_kp_u_class_sz_class_sz, __pyx_k_class_sz_class_sz, sizeof(__pyx_k_class_sz_class_sz), 0, 1, 0, 0},
    {&__pyx_n_u_class_sz_cosmo, __pyx_k_class_sz_cosmo, sizeof(__pyx_k_class_sz_cosmo), 0, 1, 0, 1},
    {&__pyx_n_s_class_sz_in_dict_output, __pyx_k_class_sz_in_dict_output, sizeof(__pyx_k_class_sz_in_dict_output), 0, 0, 1, 1},
    {&__pyx_n_u_class_sz_integrate, __pyx_k_class_sz_integrate, sizeof(__pyx_k_class_sz_integrate), 0, 1, 0, 1},
    {&__pyx_kp_s_class_sz_python_classy_pyx, __pyx_k_class_sz_python_classy_pyx, sizeof(__pyx_k_class_sz_python_classy_pyx), 0, 0, 1, 0},
    {&__pyx_n_u_class_sz_tabulate, __pyx_k_class_sz_tabulate, sizeof(__pyx_k_class_sz_tabulate), 0, 1, 0, 1},
    {&__pyx_n_s_classy_sz, __pyx_k_classy_sz, sizeof(__pyx_k_classy_sz), 0, 0, 1, 1},
    {&__pyx_n_u_classy_sz_verbose, __pyx_k_classy_sz_verbose, sizeof(__pyx_k_classy_sz_verbose), 0, 1, 0, 1},
    {&__pyx_n_s_classy_szfast, __pyx_k_classy_szfast, sizeof(__pyx_k_classy_szfast), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
    {&__pyx_n_s_cltot, __pyx_k_cltot, sizeof(__pyx_k_cltot), 0, 0, 1, 1},
    {&__pyx_n_s_cltotfunc, __pyx_k_cltotfunc, sizeof(__pyx_k_cltotfunc), 0, 0, 1, 1},
    {&__pyx_n_s_clusterLogM500, __pyx_k_clusterLogM500, sizeof(__pyx_k_clusterLogM500), 0, 0, 1, 1},
    {&__pyx_n_s_clusterLogM500Max, __pyx_k_clusterLogM500Max, sizeof(__pyx_k_clusterLogM500Max), 0, 0, 1, 1},
    {&__pyx_n_s_clusterLogM500Min, __pyx_k_clusterLogM500Min, sizeof(__pyx_k_clusterLogM500Min), 0, 0, 1, 1},
    {&__pyx_n_s_clusterM500, __pyx_k_clusterM500, sizeof(__pyx_k_clusterM500), 0, 0, 1, 1},
    {&__pyx_n_s_clusterM500MinusErr, __pyx_k_clusterM500MinusErr, sizeof(__pyx_k_clusterM500MinusErr), 0, 0, 1, 1},
    {&__pyx_n_s_clusterM500PlusErr, __pyx_k_clusterM500PlusErr, sizeof(__pyx_k_clusterM500PlusErr), 0, 0, 1, 1},
    {&__pyx_n_s_cnew, __pyx_k_cnew, sizeof(__pyx_k_cnew), 0, 0, 1, 1},
    {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
    {&__pyx_kp_s_collections_abc, __pyx_k_collections_abc, sizeof(__pyx_k_collections_abc), 0, 0, 1, 0},
    {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
    {&__pyx_n_s_compute, __pyx_k_compute, sizeof(__pyx_k_compute), 0, 0, 1, 1},
    {&__pyx_n_s_compute_class_sz, __pyx_k_compute_class_sz, sizeof(__pyx_k_compute_class_sz), 0, 0, 1, 1},
    {&__pyx_n_s_compute_class_szfast, __pyx_k_compute_class_szfast, sizeof(__pyx_k_compute_class_szfast), 0, 0, 1, 1},
    {&__pyx_n_s_compute_class_szfast_locals_gene, __pyx_k_compute_class_szfast_locals_gene, sizeof(__pyx_k_compute_class_szfast_locals_gene), 0, 0, 1, 1},
    {&__pyx_n_s_compute_pkl, __pyx_k_compute_pkl, sizeof(__pyx_k_compute_pkl), 0, 0, 1, 1},
    {&__pyx_n_s_compute_pknl, __pyx_k_compute_pknl, sizeof(__pyx_k_compute_pknl), 0, 0, 1, 1},
    {&__pyx_n_s_compute_profile, __pyx_k_compute_profile, sizeof(__pyx_k_compute_profile), 0, 0, 1, 1},
    {&__pyx_n_u_concentration_parameter, __pyx_k_concentration_parameter, sizeof(__pyx_k_concentration_parameter), 0, 1, 0, 1},
    {&__pyx_kp_u_concentration_parameter_2, __pyx_k_concentration_parameter_2, sizeof(__pyx_k_concentration_parameter_2), 0, 1, 0, 0},
    {&__pyx_n_s_configure_logging, __pyx_k_configure_logging, sizeof(__pyx_k_configure_logging), 0, 0, 1, 1},
    {&__pyx_n_u_conformal_age, __pyx_k_conformal_age, sizeof(__pyx_k_conformal_age), 0, 1, 0, 1},
    {&__pyx_n_s_contains, __pyx_k_contains, sizeof(__pyx_k_contains), 0, 0, 1, 1},
    {&__pyx_n_s_contains_specific_keys, __pyx_k_contains_specific_keys, sizeof(__pyx_k_contains_specific_keys), 0, 0, 1, 1},
    {&__pyx_n_s_contains_specific_pattern_or_key, __pyx_k_contains_specific_pattern_or_key, sizeof(__pyx_k_contains_specific_pattern_or_key), 0, 0, 1, 1},
    {&__pyx_n_s_contextlib, __pyx_k_contextlib, sizeof(__pyx_k_contextlib), 0, 0, 1, 1},
    {&__pyx_n_s_contextmanager, __pyx_k_contextmanager, sizeof(__pyx_k_contextmanager), 0, 0, 1, 1},
    {&__pyx_kp_s_contiguous_and_direct, __pyx_k_contiguous_and_direct, sizeof(__pyx_k_contiguous_and_direct), 0, 0, 1, 0},
    {&__pyx_kp_s_contiguous_and_indirect, __pyx_k_contiguous_and_indirect, sizeof(__pyx_k_contiguous_and_indirect), 0, 0, 1, 0},
    {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
    {&__pyx_n_s_cosh, __pyx_k_cosh, sizeof(__pyx_k_cosh), 0, 0, 1, 1},
    {&__pyx_n_u_cosmo, __pyx_k_cosmo, sizeof(__pyx_k_cosmo), 0, 1, 0, 1},
    {&__pyx_n_s_cosmo_arguments, __pyx_k_cosmo_arguments, sizeof(__pyx_k_cosmo_arguments), 0, 0, 1, 1},
    {&__pyx_n_s_cosmo_model, __pyx_k_cosmo_model, sizeof(__pyx_k_cosmo_model), 0, 0, 1, 1},
    {&__pyx_n_u_cosmo_model, __pyx_k_cosmo_model, sizeof(__pyx_k_cosmo_model), 0, 1, 0, 1},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_kp_u_cov_N_N, __pyx_k_cov_N_N, sizeof(__pyx_k_cov_N_N), 0, 1, 0, 0},
    {&__pyx_n_u_covmat, __pyx_k_covmat, sizeof(__pyx_k_covmat), 0, 1, 0, 1},
    {&__pyx_n_u_cp_B12, __pyx_k_cp_B12, sizeof(__pyx_k_cp_B12), 0, 1, 0, 1},
    {&__pyx_n_u_cp_B16, __pyx_k_cp_B16, sizeof(__pyx_k_cp_B16), 0, 1, 0, 1},
    {&__pyx_n_s_cp_pkl_fftlog_alphas_nus, __pyx_k_cp_pkl_fftlog_alphas_nus, sizeof(__pyx_k_cp_pkl_fftlog_alphas_nus), 0, 0, 1, 1},
    {&__pyx_n_s_cp_predicted_ee_spectrum, __pyx_k_cp_predicted_ee_spectrum, sizeof(__pyx_k_cp_predicted_ee_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_cp_predicted_pp_spectrum, __pyx_k_cp_predicted_pp_spectrum, sizeof(__pyx_k_cp_predicted_pp_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_cp_predicted_te_spectrum, __pyx_k_cp_predicted_te_spectrum, sizeof(__pyx_k_cp_predicted_te_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_cp_predicted_tt_spectrum, __pyx_k_cp_predicted_tt_spectrum, sizeof(__pyx_k_cp_predicted_tt_spectrum), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast, __pyx_k_cszfast, sizeof(__pyx_k_cszfast), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_dsigma2_flat, __pyx_k_cszfast_pk_grid_dsigma2_flat, sizeof(__pyx_k_cszfast_pk_grid_dsigma2_flat), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_k, __pyx_k_cszfast_pk_grid_k, sizeof(__pyx_k_cszfast_pk_grid_k), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_ln1pz, __pyx_k_cszfast_pk_grid_ln1pz, sizeof(__pyx_k_cszfast_pk_grid_ln1pz), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_lnk, __pyx_k_cszfast_pk_grid_lnk, sizeof(__pyx_k_cszfast_pk_grid_lnk), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_lnr, __pyx_k_cszfast_pk_grid_lnr, sizeof(__pyx_k_cszfast_pk_grid_lnr), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_lnsigma2_flat, __pyx_k_cszfast_pk_grid_lnsigma2_flat, sizeof(__pyx_k_cszfast_pk_grid_lnsigma2_flat), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_pkl_flat, __pyx_k_cszfast_pk_grid_pkl_flat, sizeof(__pyx_k_cszfast_pk_grid_pkl_flat), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_pknl, __pyx_k_cszfast_pk_grid_pknl, sizeof(__pyx_k_cszfast_pk_grid_pknl), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_pknl_flat, __pyx_k_cszfast_pk_grid_pknl_flat, sizeof(__pyx_k_cszfast_pk_grid_pknl_flat), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_z, __pyx_k_cszfast_pk_grid_z, sizeof(__pyx_k_cszfast_pk_grid_z), 0, 0, 1, 1},
    {&__pyx_n_s_cszfast_pk_grid_zmax, __pyx_k_cszfast_pk_grid_zmax, sizeof(__pyx_k_cszfast_pk_grid_zmax), 0, 0, 1, 1},
    {&__pyx_n_s_ctx, __pyx_k_ctx, sizeof(__pyx_k_ctx), 0, 0, 1, 1},
    {&__pyx_n_u_cubic, __pyx_k_cubic, sizeof(__pyx_k_cubic), 0, 1, 0, 1},
    {&__pyx_n_s_cumtrapz, __pyx_k_cumtrapz, sizeof(__pyx_k_cumtrapz), 0, 0, 1, 1},
    {&__pyx_n_s_cumulativeNumberDensity, __pyx_k_cumulativeNumberDensity, sizeof(__pyx_k_cumulativeNumberDensity), 0, 0, 1, 1},
    {&__pyx_n_u_current, __pyx_k_current, sizeof(__pyx_k_current), 0, 1, 0, 1},
    {&__pyx_n_s_custom1_W, __pyx_k_custom1_W, sizeof(__pyx_k_custom1_W), 0, 0, 1, 1},
    {&__pyx_n_s_custom1_b, __pyx_k_custom1_b, sizeof(__pyx_k_custom1_b), 0, 0, 1, 1},
    {&__pyx_n_s_custom1_ux, __pyx_k_custom1_ux, sizeof(__pyx_k_custom1_ux), 0, 0, 1, 1},
    {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
    {&__pyx_n_u_d_ell, __pyx_k_d_ell, sizeof(__pyx_k_d_ell), 0, 1, 0, 1},
    {&__pyx_n_u_da_rec, __pyx_k_da_rec, sizeof(__pyx_k_da_rec), 0, 1, 0, 1},
    {&__pyx_n_u_da_rec_h, __pyx_k_da_rec_h, sizeof(__pyx_k_da_rec_h), 0, 1, 0, 1},
    {&__pyx_n_u_da_star, __pyx_k_da_star, sizeof(__pyx_k_da_star), 0, 1, 0, 1},
    {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
    {&__pyx_n_u_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 1, 0, 1},
    {&__pyx_n_s_dcl, __pyx_k_dcl, sizeof(__pyx_k_dcl), 0, 0, 1, 1},
    {&__pyx_n_u_dd, __pyx_k_dd, sizeof(__pyx_k_dd), 0, 1, 0, 1},
    {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
    {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
    {&__pyx_n_s_defaultdict, __pyx_k_defaultdict, sizeof(__pyx_k_defaultdict), 0, 0, 1, 1},
    {&__pyx_n_u_deg_ncdm, __pyx_k_deg_ncdm, sizeof(__pyx_k_deg_ncdm), 0, 1, 0, 1},
    {&__pyx_n_s_delta, __pyx_k_delta, sizeof(__pyx_k_delta), 0, 0, 1, 1},
    {&__pyx_n_s_deltaSZE, __pyx_k_deltaSZE, sizeof(__pyx_k_deltaSZE), 0, 0, 1, 1},
    {&__pyx_n_s_delta_crit, __pyx_k_delta_crit, sizeof(__pyx_k_delta_crit), 0, 0, 1, 1},
    {&__pyx_n_s_delta_def, __pyx_k_delta_def, sizeof(__pyx_k_delta_def), 0, 0, 1, 1},
    {&__pyx_n_s_delta_def_custom1, __pyx_k_delta_def_custom1, sizeof(__pyx_k_delta_def_custom1), 0, 0, 1, 1},
    {&__pyx_n_s_density_cl, __pyx_k_density_cl, sizeof(__pyx_k_density_cl), 0, 0, 1, 1},
    {&__pyx_n_s_derived, __pyx_k_derived, sizeof(__pyx_k_derived), 0, 0, 1, 1},
    {&__pyx_n_u_derived, __pyx_k_derived, sizeof(__pyx_k_derived), 0, 1, 0, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_dl, __pyx_k_dl, sizeof(__pyx_k_dl), 0, 0, 1, 1},
    {&__pyx_n_u_dl, __pyx_k_dl, sizeof(__pyx_k_dl), 0, 1, 0, 1},
    {&__pyx_n_s_dl_isw_sz, __pyx_k_dl_isw_sz, sizeof(__pyx_k_dl_isw_sz), 0, 0, 1, 1},
    {&__pyx_n_s_dndM, __pyx_k_dndM, sizeof(__pyx_k_dndM), 0, 0, 1, 1},
    {&__pyx_n_u_dndM, __pyx_k_dndM, sizeof(__pyx_k_dndM), 0, 1, 0, 1},
    {&__pyx_n_s_dndlnM, __pyx_k_dndlnM, sizeof(__pyx_k_dndlnM), 0, 0, 1, 1},
    {&__pyx_n_u_dndlnM, __pyx_k_dndlnM, sizeof(__pyx_k_dndlnM), 0, 1, 0, 1},
    {&__pyx_n_u_dndlnm, __pyx_k_dndlnm, sizeof(__pyx_k_dndlnm), 0, 1, 0, 1},
    {&__pyx_n_u_dndm, __pyx_k_dndm, sizeof(__pyx_k_dndm), 0, 1, 0, 1},
    {&__pyx_n_u_dndz_shift_gal, __pyx_k_dndz_shift_gal, sizeof(__pyx_k_dndz_shift_gal), 0, 1, 0, 1},
    {&__pyx_n_u_dndz_shift_ngal, __pyx_k_dndz_shift_ngal, sizeof(__pyx_k_dndz_shift_ngal), 0, 1, 0, 1},
    {&__pyx_n_u_dndz_shift_source_gal, __pyx_k_dndz_shift_source_gal, sizeof(__pyx_k_dndz_shift_source_gal), 0, 1, 0, 1},
    {&__pyx_n_u_dndz_stretch_gal, __pyx_k_dndz_stretch_gal, sizeof(__pyx_k_dndz_stretch_gal), 0, 1, 0, 1},
    {&__pyx_n_u_dndz_stretch_ngal, __pyx_k_dndz_stretch_ngal, sizeof(__pyx_k_dndz_stretch_ngal), 0, 1, 0, 1},
    {&__pyx_n_u_dndz_stretch_source_gal, __pyx_k_dndz_stretch_source_gal, sizeof(__pyx_k_dndz_stretch_source_gal), 0, 1, 0, 1},
    {&__pyx_n_s_dndzdy, __pyx_k_dndzdy, sizeof(__pyx_k_dndzdy), 0, 0, 1, 1},
    {&__pyx_n_u_dndzdy, __pyx_k_dndzdy, sizeof(__pyx_k_dndzdy), 0, 1, 0, 1},
    {&__pyx_n_s_dndzdy_index_z, __pyx_k_dndzdy_index_z, sizeof(__pyx_k_dndzdy_index_z), 0, 0, 1, 1},
    {&__pyx_n_s_dndzdy_theoretical, __pyx_k_dndzdy_theoretical, sizeof(__pyx_k_dndzdy_theoretical), 0, 0, 1, 1},
    {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
    {&__pyx_n_s_double, __pyx_k_double, sizeof(__pyx_k_double), 0, 0, 1, 1},
    {&__pyx_n_u_ds_d, __pyx_k_ds_d, sizeof(__pyx_k_ds_d), 0, 1, 0, 1},
    {&__pyx_n_u_ds_d_h, __pyx_k_ds_d_h, sizeof(__pyx_k_ds_d_h), 0, 1, 0, 1},
    {&__pyx_n_u_ds_rec, __pyx_k_ds_rec, sizeof(__pyx_k_ds_rec), 0, 1, 0, 1},
    {&__pyx_n_u_ds_rec_h, __pyx_k_ds_rec_h, sizeof(__pyx_k_ds_rec_h), 0, 1, 0, 1},
    {&__pyx_n_u_ds_star, __pyx_k_ds_star, sizeof(__pyx_k_ds_star), 0, 1, 0, 1},
    {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
    {&__pyx_n_s_dtype_is_object, __pyx_k_dtype_is_object, sizeof(__pyx_k_dtype_is_object), 0, 0, 1, 1},
    {&__pyx_n_s_dumc, __pyx_k_dumc, sizeof(__pyx_k_dumc), 0, 0, 1, 1},
    {&__pyx_n_s_dumcp, __pyx_k_dumcp, sizeof(__pyx_k_dumcp), 0, 0, 1, 1},
    {&__pyx_n_s_dx, __pyx_k_dx, sizeof(__pyx_k_dx), 0, 0, 1, 1},
    {&__pyx_n_u_dydz, __pyx_k_dydz, sizeof(__pyx_k_dydz), 0, 1, 0, 1},
    {&__pyx_n_s_dzdr, __pyx_k_dzdr, sizeof(__pyx_k_dzdr), 0, 0, 1, 1},
    {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
    {&__pyx_n_u_ee, __pyx_k_ee, sizeof(__pyx_k_ee), 0, 1, 0, 1},
    {&__pyx_n_s_effective_f_sigma8, __pyx_k_effective_f_sigma8, sizeof(__pyx_k_effective_f_sigma8), 0, 0, 1, 1},
    {&__pyx_n_s_effective_galaxy_bias, __pyx_k_effective_galaxy_bias, sizeof(__pyx_k_effective_galaxy_bias), 0, 0, 1, 1},
    {&__pyx_n_s_elem, __pyx_k_elem, sizeof(__pyx_k_elem), 0, 0, 1, 1},
    {&__pyx_n_s_ell, __pyx_k_ell, sizeof(__pyx_k_ell), 0, 0, 1, 1},
    {&__pyx_n_u_ell, __pyx_k_ell, sizeof(__pyx_k_ell), 0, 1, 0, 1},
    {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
    {&__pyx_n_s_empty_like, __pyx_k_empty_like, sizeof(__pyx_k_empty_like), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
    {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
    {&__pyx_n_s_endpoint, __pyx_k_endpoint, sizeof(__pyx_k_endpoint), 0, 0, 1, 1},
    {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
    {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
    {&__pyx_n_s_eps1, __pyx_k_eps1, sizeof(__pyx_k_eps1), 0, 0, 1, 1},
    {&__pyx_n_s_eps2, __pyx_k_eps2, sizeof(__pyx_k_eps2), 0, 0, 1, 1},
    {&__pyx_n_s_eps23, __pyx_k_eps23, sizeof(__pyx_k_eps23), 0, 0, 1, 1},
    {&__pyx_n_u_epsilon_V, __pyx_k_epsilon_V, sizeof(__pyx_k_epsilon_V), 0, 1, 0, 1},
    {&__pyx_n_s_errmsg, __pyx_k_errmsg, sizeof(__pyx_k_errmsg), 0, 0, 1, 1},
    {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
    {&__pyx_n_u_eta_V, __pyx_k_eta_V, sizeof(__pyx_k_eta_V), 0, 1, 0, 1},
    {&__pyx_n_s_even, __pyx_k_even, sizeof(__pyx_k_even), 0, 0, 1, 1},
    {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
    {&__pyx_n_s_exp, __pyx_k_exp, sizeof(__pyx_k_exp), 0, 0, 1, 1},
    {&__pyx_n_u_exp_m_2_tau_As, __pyx_k_exp_m_2_tau_As, sizeof(__pyx_k_exp_m_2_tau_As), 0, 1, 0, 1},
    {&__pyx_n_u_extensive, __pyx_k_extensive, sizeof(__pyx_k_extensive), 0, 1, 0, 1},
    {&__pyx_n_s_extrap, __pyx_k_extrap, sizeof(__pyx_k_extrap), 0, 0, 1, 1},
    {&__pyx_n_u_extrapolate, __pyx_k_extrapolate, sizeof(__pyx_k_extrapolate), 0, 1, 0, 1},
    {&__pyx_n_s_extrapolator, __pyx_k_extrapolator, sizeof(__pyx_k_extrapolator), 0, 0, 1, 1},
    {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
    {&__pyx_n_u_fNL, __pyx_k_fNL, sizeof(__pyx_k_fNL), 0, 1, 0, 1},
    {&__pyx_n_s_fRel, __pyx_k_fRel, sizeof(__pyx_k_fRel), 0, 0, 1, 1},
    {&__pyx_n_s_f_b, __pyx_k_f_b, sizeof(__pyx_k_f_b), 0, 0, 1, 1},
    {&__pyx_n_s_f_rel, __pyx_k_f_rel, sizeof(__pyx_k_f_rel), 0, 0, 1, 1},
    {&__pyx_n_s_fac, __pyx_k_fac, sizeof(__pyx_k_fac), 0, 0, 1, 1},
    {&__pyx_n_s_fc, __pyx_k_fc, sizeof(__pyx_k_fc), 0, 0, 1, 1},
    {&__pyx_n_s_fill_value, __pyx_k_fill_value, sizeof(__pyx_k_fill_value), 0, 0, 1, 1},
    {&__pyx_n_s_fillparfile, __pyx_k_fillparfile, sizeof(__pyx_k_fillparfile), 0, 0, 1, 1},
    {&__pyx_n_s_filterwarnings, __pyx_k_filterwarnings, sizeof(__pyx_k_filterwarnings), 0, 0, 1, 1},
    {&__pyx_n_s_find_As, __pyx_k_find_As, sizeof(__pyx_k_find_As), 0, 0, 1, 1},
    {&__pyx_n_s_fineLog10M, __pyx_k_fineLog10M, sizeof(__pyx_k_fineLog10M), 0, 0, 1, 1},
    {&__pyx_n_s_fineP, __pyx_k_fineP, sizeof(__pyx_k_fineP), 0, 0, 1, 1},
    {&__pyx_n_u_first, __pyx_k_first, sizeof(__pyx_k_first), 0, 1, 0, 1},
    {&__pyx_n_s_flag, __pyx_k_flag, sizeof(__pyx_k_flag), 0, 0, 1, 1},
    {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
    {&__pyx_n_s_flatten, __pyx_k_flatten, sizeof(__pyx_k_flatten), 0, 0, 1, 1},
    {&__pyx_n_s_float64, __pyx_k_float64, sizeof(__pyx_k_float64), 0, 0, 1, 1},
    {&__pyx_n_u_float64, __pyx_k_float64, sizeof(__pyx_k_float64), 0, 1, 0, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_s_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 0, 1, 1},
    {&__pyx_n_u_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 1, 0, 1},
    {&__pyx_n_s_frequency_in_Hz, __pyx_k_frequency_in_Hz, sizeof(__pyx_k_frequency_in_Hz), 0, 0, 1, 1},
    {&__pyx_n_u_full_path_and_prefix_to_dndz_nga, __pyx_k_full_path_and_prefix_to_dndz_nga, sizeof(__pyx_k_full_path_and_prefix_to_dndz_nga), 0, 1, 0, 1},
    {&__pyx_n_u_full_path_to_dndz_gal, __pyx_k_full_path_to_dndz_gal, sizeof(__pyx_k_full_path_to_dndz_gal), 0, 1, 0, 1},
    {&__pyx_n_u_full_path_to_source_dndz_gal, __pyx_k_full_path_to_source_dndz_gal, sizeof(__pyx_k_full_path_to_source_dndz_gal), 0, 1, 0, 1},
    {&__pyx_n_u_galaxy_samples_list_num, __pyx_k_galaxy_samples_list_num, sizeof(__pyx_k_galaxy_samples_list_num), 0, 1, 0, 1},
    {&__pyx_n_s_gamma, __pyx_k_gamma, sizeof(__pyx_k_gamma), 0, 0, 1, 1},
    {&__pyx_n_s_gammaGNFW, __pyx_k_gammaGNFW, sizeof(__pyx_k_gammaGNFW), 0, 0, 1, 1},
    {&__pyx_n_u_gamma_B12, __pyx_k_gamma_B12, sizeof(__pyx_k_gamma_B12), 0, 1, 0, 1},
    {&__pyx_n_u_gamma_B16, __pyx_k_gamma_B16, sizeof(__pyx_k_gamma_B16), 0, 1, 0, 1},
    {&__pyx_n_s_gamma_ggamma, __pyx_k_gamma_ggamma, sizeof(__pyx_k_gamma_ggamma), 0, 0, 1, 1},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_geomspace, __pyx_k_geomspace, sizeof(__pyx_k_geomspace), 0, 0, 1, 1},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_getData, __pyx_k_getData, sizeof(__pyx_k_getData), 0, 0, 1, 1},
    {&__pyx_n_s_getLogger, __pyx_k_getLogger, sizeof(__pyx_k_getLogger), 0, 0, 1, 1},
    {&__pyx_n_s_getM500_from_y0_H13, __pyx_k_getM500_from_y0_H13, sizeof(__pyx_k_getM500_from_y0_H13), 0, 0, 1, 1},
    {&__pyx_n_s_getPLog10M, __pyx_k_getPLog10M, sizeof(__pyx_k_getPLog10M), 0, 0, 1, 1},
    {&__pyx_n_s_get_1e6xdy_from_battaglia_pressu, __pyx_k_get_1e6xdy_from_battaglia_pressu, sizeof(__pyx_k_get_1e6xdy_from_battaglia_pressu), 0, 0, 1, 1},
    {&__pyx_n_s_get_1e6xdy_from_gnfw_pressure_at, __pyx_k_get_1e6xdy_from_gnfw_pressure_at, sizeof(__pyx_k_get_1e6xdy_from_gnfw_pressure_at), 0, 0, 1, 1},
    {&__pyx_n_s_get_Delta_c_of_Omega_m, __pyx_k_get_Delta_c_of_Omega_m, sizeof(__pyx_k_get_Delta_c_of_Omega_m), 0, 0, 1, 1},
    {&__pyx_n_s_get_Ez, __pyx_k_get_Ez, sizeof(__pyx_k_get_Ez), 0, 0, 1, 1},
    {&__pyx_n_s_get_H, __pyx_k_get_H, sizeof(__pyx_k_get_H), 0, 0, 1, 1},
    {&__pyx_n_s_get_H0_from_thetas, __pyx_k_get_H0_from_thetas, sizeof(__pyx_k_get_H0_from_thetas), 0, 0, 1, 1},
    {&__pyx_n_s_get_IA_of_z, __pyx_k_get_IA_of_z, sizeof(__pyx_k_get_IA_of_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_N_centrals, __pyx_k_get_N_centrals, sizeof(__pyx_k_get_N_centrals), 0, 0, 1, 1},
    {&__pyx_n_s_get_N_satellites, __pyx_k_get_N_satellites, sizeof(__pyx_k_get_N_satellites), 0, 0, 1, 1},
    {&__pyx_n_s_get_Omega_m_0, __pyx_k_get_Omega_m_0, sizeof(__pyx_k_get_Omega_m_0), 0, 0, 1, 1},
    {&__pyx_n_s_get_Omega_m_at_z, __pyx_k_get_Omega_m_at_z, sizeof(__pyx_k_get_Omega_m_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_Omega_r_0, __pyx_k_get_Omega_r_0, sizeof(__pyx_k_get_Omega_r_0), 0, 0, 1, 1},
    {&__pyx_n_s_get_P_delta_at_m_and_z_b12, __pyx_k_get_P_delta_at_m_and_z_b12, sizeof(__pyx_k_get_P_delta_at_m_and_z_b12), 0, 0, 1, 1},
    {&__pyx_n_s_get_Q_of_theta500, __pyx_k_get_Q_of_theta500, sizeof(__pyx_k_get_Q_of_theta500), 0, 0, 1, 1},
    {&__pyx_n_s_get_T10_alpha_at_z, __pyx_k_get_T10_alpha_at_z, sizeof(__pyx_k_get_T10_alpha_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_arcmin_to_rad, __pyx_k_get_arcmin_to_rad, sizeof(__pyx_k_get_arcmin_to_rad), 0, 0, 1, 1},
    {&__pyx_n_s_get_background, __pyx_k_get_background, sizeof(__pyx_k_get_background), 0, 0, 1, 1},
    {&__pyx_n_s_get_bispectrum_f2_kernel, __pyx_k_get_bispectrum_f2_kernel, sizeof(__pyx_k_get_bispectrum_f2_kernel), 0, 0, 1, 1},
    {&__pyx_n_s_get_c200c_at_m_and_z, __pyx_k_get_c200c_at_m_and_z, sizeof(__pyx_k_get_c200c_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_c200c_at_m_and_z_B13, __pyx_k_get_c200c_at_m_and_z_B13, sizeof(__pyx_k_get_c200c_at_m_and_z_B13), 0, 0, 1, 1},
    {&__pyx_n_s_get_c200c_at_m_and_z_D08, __pyx_k_get_c200c_at_m_and_z_D08, sizeof(__pyx_k_get_c200c_at_m_and_z_D08), 0, 0, 1, 1},
    {&__pyx_n_s_get_c200m_at_m_and_z, __pyx_k_get_c200m_at_m_and_z, sizeof(__pyx_k_get_c200m_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_c200m_at_m_and_z_D08, __pyx_k_get_c200m_at_m_and_z_D08, sizeof(__pyx_k_get_c200m_at_m_and_z_D08), 0, 0, 1, 1},
    {&__pyx_n_s_get_c500c_at_m_and_z, __pyx_k_get_c500c_at_m_and_z, sizeof(__pyx_k_get_c500c_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_c_delta_at_m_and_z, __pyx_k_get_c_delta_at_m_and_z, sizeof(__pyx_k_get_c_delta_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_chi, __pyx_k_get_chi, sizeof(__pyx_k_get_chi), 0, 0, 1, 1},
    {&__pyx_n_s_get_cib_Snu_z_and_nu, __pyx_k_get_cib_Snu_z_and_nu, sizeof(__pyx_k_get_cib_Snu_z_and_nu), 0, 0, 1, 1},
    {&__pyx_n_s_get_comoving_volume, __pyx_k_get_comoving_volume, sizeof(__pyx_k_get_comoving_volume), 0, 0, 1, 1},
    {&__pyx_n_s_get_cov_N_N, __pyx_k_get_cov_N_N, sizeof(__pyx_k_get_cov_N_N), 0, 0, 1, 1},
    {&__pyx_n_s_get_current_derived_parameters, __pyx_k_get_current_derived_parameters, sizeof(__pyx_k_get_current_derived_parameters), 0, 0, 1, 1},
    {&__pyx_n_s_get_custom1_bias_at_z, __pyx_k_get_custom1_bias_at_z, sizeof(__pyx_k_get_custom1_bias_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_custom1_profile_at_k_m_z, __pyx_k_get_custom1_profile_at_k_m_z, sizeof(__pyx_k_get_custom1_profile_at_k_m_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_custom1_profile_at_x_m_z, __pyx_k_get_custom1_profile_at_x_m_z, sizeof(__pyx_k_get_custom1_profile_at_x_m_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_cvir_of_mvir_at_z, __pyx_k_get_cvir_of_mvir_at_z, sizeof(__pyx_k_get_cvir_of_mvir_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_dA, __pyx_k_get_dA, sizeof(__pyx_k_get_dA), 0, 0, 1, 1},
    {&__pyx_n_s_get_dA_z1z2, __pyx_k_get_dA_z1z2, sizeof(__pyx_k_get_dA_z1z2), 0, 0, 1, 1},
    {&__pyx_n_s_get_dcib0dz_at_z_and_nu, __pyx_k_get_dcib0dz_at_z_and_nu, sizeof(__pyx_k_get_dcib0dz_at_z_and_nu), 0, 0, 1, 1},
    {&__pyx_n_s_get_delta_from_delta_def_at_z, __pyx_k_get_delta_from_delta_def_at_z, sizeof(__pyx_k_get_delta_from_delta_def_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_delta_mean_from_delta_crit_a, __pyx_k_get_delta_mean_from_delta_crit_a, sizeof(__pyx_k_get_delta_mean_from_delta_crit_a), 0, 0, 1, 1},
    {&__pyx_n_s_get_dkappacmbdz_at_l_and_z, __pyx_k_get_dkappacmbdz_at_l_and_z, sizeof(__pyx_k_get_dkappacmbdz_at_l_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_dlnsigma_dlnR_at_z_and_m, __pyx_k_get_dlnsigma_dlnR_at_z_and_m, sizeof(__pyx_k_get_dlnsigma_dlnR_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_get_dndlnM_at_z_and_M, __pyx_k_get_dndlnM_at_z_and_M, sizeof(__pyx_k_get_dndlnM_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_get_dndlnm, __pyx_k_get_dndlnm, sizeof(__pyx_k_get_dndlnm), 0, 0, 1, 1},
    {&__pyx_n_s_get_dndzdq, __pyx_k_get_dndzdq, sizeof(__pyx_k_get_dndzdq), 0, 0, 1, 1},
    {&__pyx_n_s_get_dydz_at_z, __pyx_k_get_dydz_at_z, sizeof(__pyx_k_get_dydz_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_dydzdlnm_at_z_and_m, __pyx_k_get_dydzdlnm_at_z_and_m, sizeof(__pyx_k_get_dydzdlnm_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_get_effective_f_sigma8, __pyx_k_get_effective_f_sigma8, sizeof(__pyx_k_get_effective_f_sigma8), 0, 0, 1, 1},
    {&__pyx_n_s_get_f_b, __pyx_k_get_f_b, sizeof(__pyx_k_get_f_b), 0, 0, 1, 1},
    {&__pyx_n_s_get_f_free, __pyx_k_get_f_free, sizeof(__pyx_k_get_f_free), 0, 0, 1, 1},
    {&__pyx_n_s_get_f_of_sigma_at_m_and_z, __pyx_k_get_f_of_sigma_at_m_and_z, sizeof(__pyx_k_get_f_of_sigma_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_f_tinker08_at_nu_and_z, __pyx_k_get_f_tinker08_at_nu_and_z, sizeof(__pyx_k_get_f_tinker08_at_nu_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_f_tinker10_at_nu_and_z, __pyx_k_get_f_tinker10_at_nu_and_z, sizeof(__pyx_k_get_f_tinker10_at_nu_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_fftlog_ComputeXiLMsloz, __pyx_k_get_fftlog_ComputeXiLMsloz, sizeof(__pyx_k_get_fftlog_ComputeXiLMsloz), 0, 0, 1, 1},
    {&__pyx_n_s_get_first_order_bias_at_z_and_m, __pyx_k_get_first_order_bias_at_z_and_m, sizeof(__pyx_k_get_first_order_bias_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_get_first_order_bias_at_z_and_m_2, __pyx_k_get_first_order_bias_at_z_and_m_2, sizeof(__pyx_k_get_first_order_bias_at_z_and_m_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_first_order_bias_at_z_and_nu, __pyx_k_get_first_order_bias_at_z_and_nu, sizeof(__pyx_k_get_first_order_bias_at_z_and_nu), 0, 0, 1, 1},
    {&__pyx_n_s_get_fstar_of_m_at_z, __pyx_k_get_fstar_of_m_at_z, sizeof(__pyx_k_get_fstar_of_m_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_galaxy_number_counts, __pyx_k_get_galaxy_number_counts, sizeof(__pyx_k_get_galaxy_number_counts), 0, 0, 1, 1},
    {&__pyx_n_s_get_gas_density_profile_at_k_M_z, __pyx_k_get_gas_density_profile_at_k_M_z, sizeof(__pyx_k_get_gas_density_profile_at_k_M_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_gas_pressure_2h_at_r_and_m_a, __pyx_k_get_gas_pressure_2h_at_r_and_m_a, sizeof(__pyx_k_get_gas_pressure_2h_at_r_and_m_a), 0, 0, 1, 1},
    {&__pyx_n_s_get_gas_profile_at_x_M_z_b16_200, __pyx_k_get_gas_profile_at_x_M_z_b16_200, sizeof(__pyx_k_get_gas_profile_at_x_M_z_b16_200), 0, 0, 1, 1},
    {&__pyx_n_s_get_gas_profile_at_x_M_z_bcm_200, __pyx_k_get_gas_profile_at_x_M_z_bcm_200, sizeof(__pyx_k_get_gas_profile_at_x_M_z_bcm_200), 0, 0, 1, 1},
    {&__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200, __pyx_k_get_gas_profile_at_x_M_z_nfw_200, sizeof(__pyx_k_get_gas_profile_at_x_M_z_nfw_200), 0, 0, 1, 1},
    {&__pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2, __pyx_k_get_gas_profile_at_x_M_z_nfw_200_2, sizeof(__pyx_k_get_gas_profile_at_x_M_z_nfw_200_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_gnu_tsz_of_nu_in_ghz, __pyx_k_get_gnu_tsz_of_nu_in_ghz, sizeof(__pyx_k_get_gnu_tsz_of_nu_in_ghz), 0, 0, 1, 1},
    {&__pyx_n_s_get_hmf_counter_term_b1min_at_z, __pyx_k_get_hmf_counter_term_b1min_at_z, sizeof(__pyx_k_get_hmf_counter_term_b1min_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_hmf_counter_term_b2min_at_z, __pyx_k_get_hmf_counter_term_b2min_at_z, sizeof(__pyx_k_get_hmf_counter_term_b2min_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_hmf_counter_term_nmin_at_z, __pyx_k_get_hmf_counter_term_nmin_at_z, sizeof(__pyx_k_get_hmf_counter_term_nmin_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_hubble, __pyx_k_get_hubble, sizeof(__pyx_k_get_hubble), 0, 0, 1, 1},
    {&__pyx_n_s_get_lensing_noise_at_ell, __pyx_k_get_lensing_noise_at_ell, sizeof(__pyx_k_get_lensing_noise_at_ell), 0, 0, 1, 1},
    {&__pyx_n_s_get_m200c_to_m200m_at_z_and_M, __pyx_k_get_m200c_to_m200m_at_z_and_M, sizeof(__pyx_k_get_m200c_to_m200m_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_get_m200c_to_m500c_at_z_and_M, __pyx_k_get_m200c_to_m500c_at_z_and_M, sizeof(__pyx_k_get_m200c_to_m500c_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_get_m200m_to_m200c_at_z_and_M, __pyx_k_get_m200m_to_m200c_at_z_and_M, sizeof(__pyx_k_get_m200m_to_m200c_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_get_m200m_to_m500c_at_z_and_M, __pyx_k_get_m200m_to_m500c_at_z_and_M, sizeof(__pyx_k_get_m200m_to_m500c_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_get_m500c_to_m200c_at_z_and_M, __pyx_k_get_m500c_to_m200c_at_z_and_M, sizeof(__pyx_k_get_m500c_to_m200c_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_get_m500c_to_m200m_at_z_and_M, __pyx_k_get_m500c_to_m200m_at_z_and_M, sizeof(__pyx_k_get_m500c_to_m200m_at_z_and_M), 0, 0, 1, 1},
    {&__pyx_n_s_get_m_nfw, __pyx_k_get_m_nfw, sizeof(__pyx_k_get_m_nfw), 0, 0, 1, 1},
    {&__pyx_n_s_get_m_to_xout_at_z_and_m, __pyx_k_get_m_to_xout_at_z_and_m, sizeof(__pyx_k_get_m_to_xout_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_get_mass_profile_at_x_M_z_nfw_20, __pyx_k_get_mass_profile_at_x_M_z_nfw_20, sizeof(__pyx_k_get_mass_profile_at_x_M_z_nfw_20), 0, 0, 1, 1},
    {&__pyx_n_s_get_matter_bispectrum_at_z_effec, __pyx_k_get_matter_bispectrum_at_z_effec, sizeof(__pyx_k_get_matter_bispectrum_at_z_effec), 0, 0, 1, 1},
    {&__pyx_n_s_get_matter_bispectrum_at_z_effec_2, __pyx_k_get_matter_bispectrum_at_z_effec_2, sizeof(__pyx_k_get_matter_bispectrum_at_z_effec_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_matter_bispectrum_at_z_effec_3, __pyx_k_get_matter_bispectrum_at_z_effec_3, sizeof(__pyx_k_get_matter_bispectrum_at_z_effec_3), 0, 0, 1, 1},
    {&__pyx_n_s_get_matter_bispectrum_at_z_tree, __pyx_k_get_matter_bispectrum_at_z_tree, sizeof(__pyx_k_get_matter_bispectrum_at_z_tree), 0, 0, 1, 1},
    {&__pyx_n_s_get_mcmc_parameters, __pyx_k_get_mcmc_parameters, sizeof(__pyx_k_get_mcmc_parameters), 0, 0, 1, 1},
    {&__pyx_n_s_get_mean_galaxy_bias_at_z, __pyx_k_get_mean_galaxy_bias_at_z, sizeof(__pyx_k_get_mean_galaxy_bias_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_mean_y, __pyx_k_get_mean_y, sizeof(__pyx_k_get_mean_y), 0, 0, 1, 1},
    {&__pyx_n_s_get_mu_e, __pyx_k_get_mu_e, sizeof(__pyx_k_get_mu_e), 0, 0, 1, 1},
    {&__pyx_n_s_get_n5k_cl_K1_at_chi, __pyx_k_get_n5k_cl_K1_at_chi, sizeof(__pyx_k_get_n5k_cl_K1_at_chi), 0, 0, 1, 1},
    {&__pyx_n_s_get_n5k_pk_at_z_and_k, __pyx_k_get_n5k_pk_at_z_and_k, sizeof(__pyx_k_get_n5k_pk_at_z_and_k), 0, 0, 1, 1},
    {&__pyx_n_s_get_n5k_z_of_chi, __pyx_k_get_n5k_z_of_chi, sizeof(__pyx_k_get_n5k_z_of_chi), 0, 0, 1, 1},
    {&__pyx_n_s_get_ng_bar_at_z, __pyx_k_get_ng_bar_at_z, sizeof(__pyx_k_get_ng_bar_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_nl_index_at_z_and_k, __pyx_k_get_nl_index_at_z_and_k, sizeof(__pyx_k_get_nl_index_at_z_and_k), 0, 0, 1, 1},
    {&__pyx_n_s_get_nl_index_at_z_and_k_no_wiggl, __pyx_k_get_nl_index_at_z_and_k_no_wiggl, sizeof(__pyx_k_get_nl_index_at_z_and_k_no_wiggl), 0, 0, 1, 1},
    {&__pyx_n_s_get_normalization_gas_density_pr, __pyx_k_get_normalization_gas_density_pr, sizeof(__pyx_k_get_normalization_gas_density_pr), 0, 0, 1, 1},
    {&__pyx_n_s_get_nu_at_z_and_m, __pyx_k_get_nu_at_z_and_m, sizeof(__pyx_k_get_nu_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_get_params_sz, __pyx_k_get_params_sz, sizeof(__pyx_k_get_params_sz), 0, 0, 1, 1},
    {&__pyx_n_s_get_perturbations, __pyx_k_get_perturbations, sizeof(__pyx_k_get_perturbations), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk, __pyx_k_get_pk, sizeof(__pyx_k_get_pk), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_and_k_and_z, __pyx_k_get_pk_and_k_and_z, sizeof(__pyx_k_get_pk_and_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_array, __pyx_k_get_pk_array, sizeof(__pyx_k_get_pk_array), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_cb, __pyx_k_get_pk_cb, sizeof(__pyx_k_get_pk_cb), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_cb_array, __pyx_k_get_pk_cb_array, sizeof(__pyx_k_get_pk_cb_array), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_cb_lin, __pyx_k_get_pk_cb_lin, sizeof(__pyx_k_get_pk_cb_lin), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_lin, __pyx_k_get_pk_lin, sizeof(__pyx_k_get_pk_lin), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_lin_at_k_and_z, __pyx_k_get_pk_lin_at_k_and_z, sizeof(__pyx_k_get_pk_lin_at_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_lin_at_k_and_z_fast, __pyx_k_get_pk_lin_at_k_and_z_fast, sizeof(__pyx_k_get_pk_lin_at_k_and_z_fast), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_nonlin_at_k_and_z, __pyx_k_get_pk_nonlin_at_k_and_z, sizeof(__pyx_k_get_pk_nonlin_at_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_pk_nonlin_at_k_and_z_fast, __pyx_k_get_pk_nonlin_at_k_and_z_fast, sizeof(__pyx_k_get_pk_nonlin_at_k_and_z_fast), 0, 0, 1, 1},
    {&__pyx_n_s_get_pkl, __pyx_k_get_pkl, sizeof(__pyx_k_get_pkl), 0, 0, 1, 1},
    {&__pyx_n_s_get_pkl_at_k_and_z, __pyx_k_get_pkl_at_k_and_z, sizeof(__pyx_k_get_pkl_at_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_pkl_at_z, __pyx_k_get_pkl_at_z, sizeof(__pyx_k_get_pkl_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_pkl_locals_compute_pkl, __pyx_k_get_pkl_locals_compute_pkl, sizeof(__pyx_k_get_pkl_locals_compute_pkl), 0, 0, 1, 1},
    {&__pyx_n_s_get_pkl_locals_handle_combinatio, __pyx_k_get_pkl_locals_handle_combinatio, sizeof(__pyx_k_get_pkl_locals_handle_combinatio), 0, 0, 1, 1},
    {&__pyx_n_s_get_pkl_reconstructed_from_fftlo, __pyx_k_get_pkl_reconstructed_from_fftlo, sizeof(__pyx_k_get_pkl_reconstructed_from_fftlo), 0, 0, 1, 1},
    {&__pyx_n_s_get_pkl_unvectorized, __pyx_k_get_pkl_unvectorized, sizeof(__pyx_k_get_pkl_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_get_pknl, __pyx_k_get_pknl, sizeof(__pyx_k_get_pknl), 0, 0, 1, 1},
    {&__pyx_n_s_get_pknl_at_k_and_z, __pyx_k_get_pknl_at_k_and_z, sizeof(__pyx_k_get_pknl_at_k_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_pknl_at_z, __pyx_k_get_pknl_at_z, sizeof(__pyx_k_get_pknl_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_pknl_locals_compute_pknl, __pyx_k_get_pknl_locals_compute_pknl, sizeof(__pyx_k_get_pknl_locals_compute_pknl), 0, 0, 1, 1},
    {&__pyx_n_s_get_pknl_locals_handle_combinati, __pyx_k_get_pknl_locals_handle_combinati, sizeof(__pyx_k_get_pknl_locals_handle_combinati), 0, 0, 1, 1},
    {&__pyx_n_s_get_pknl_unvectorized, __pyx_k_get_pknl_unvectorized, sizeof(__pyx_k_get_pknl_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_get_planck_sigma_at_theta500, __pyx_k_get_planck_sigma_at_theta500, sizeof(__pyx_k_get_planck_sigma_at_theta500), 0, 0, 1, 1},
    {&__pyx_n_s_get_pressure_P_over_P_delta_at_x, __pyx_k_get_pressure_P_over_P_delta_at_x, sizeof(__pyx_k_get_pressure_P_over_P_delta_at_x), 0, 0, 1, 1},
    {&__pyx_n_s_get_pressure_P_over_P_delta_at_x_2, __pyx_k_get_pressure_P_over_P_delta_at_x_2, sizeof(__pyx_k_get_pressure_P_over_P_delta_at_x_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_primordial, __pyx_k_get_primordial, sizeof(__pyx_k_get_primordial), 0, 0, 1, 1},
    {&__pyx_n_s_get_r_delta_of_m_delta_at_z, __pyx_k_get_r_delta_of_m_delta_at_z, sizeof(__pyx_k_get_r_delta_of_m_delta_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_rad_to_arcmin, __pyx_k_get_rad_to_arcmin, sizeof(__pyx_k_get_rad_to_arcmin), 0, 0, 1, 1},
    {&__pyx_n_s_get_radial_kernel_W_custom1_at_z, __pyx_k_get_radial_kernel_W_custom1_at_z, sizeof(__pyx_k_get_radial_kernel_W_custom1_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_radial_kernel_W_galaxy_lensi, __pyx_k_get_radial_kernel_W_galaxy_lensi, sizeof(__pyx_k_get_radial_kernel_W_galaxy_lensi), 0, 0, 1, 1},
    {&__pyx_n_s_get_radial_kernel_W_galaxy_ngal, __pyx_k_get_radial_kernel_W_galaxy_ngal, sizeof(__pyx_k_get_radial_kernel_W_galaxy_ngal), 0, 0, 1, 1},
    {&__pyx_n_s_get_rho_2h_at_r_and_m_and_z, __pyx_k_get_rho_2h_at_r_and_m_and_z, sizeof(__pyx_k_get_rho_2h_at_r_and_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_rho_crit_at_z, __pyx_k_get_rho_crit_at_z, sizeof(__pyx_k_get_rho_crit_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_rvir_of_m200c_at_z, __pyx_k_get_rvir_of_m200c_at_z, sizeof(__pyx_k_get_rvir_of_m200c_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_rvir_of_mvir_at_z, __pyx_k_get_rvir_of_mvir_at_z, sizeof(__pyx_k_get_rvir_of_mvir_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_scale_dependent_bias_at_z_an, __pyx_k_get_scale_dependent_bias_at_z_an, sizeof(__pyx_k_get_scale_dependent_bias_at_z_an), 0, 0, 1, 1},
    {&__pyx_n_s_get_second_order_bias_at_z_and_n, __pyx_k_get_second_order_bias_at_z_and_n, sizeof(__pyx_k_get_second_order_bias_at_z_and_n), 0, 0, 1, 1},
    {&__pyx_n_s_get_sigma8_at_z, __pyx_k_get_sigma8_at_z, sizeof(__pyx_k_get_sigma8_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_sigma_at_r_and_z, __pyx_k_get_sigma_at_r_and_z, sizeof(__pyx_k_get_sigma_at_r_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_sigma_at_z_and_m, __pyx_k_get_sigma_at_z_and_m, sizeof(__pyx_k_get_sigma_at_z_and_m), 0, 0, 1, 1},
    {&__pyx_n_s_get_source_galaxy_number_counts, __pyx_k_get_source_galaxy_number_counts, sizeof(__pyx_k_get_source_galaxy_number_counts), 0, 0, 1, 1},
    {&__pyx_n_s_get_szcounts_dndzdq_at_z_q, __pyx_k_get_szcounts_dndzdq_at_z_q, sizeof(__pyx_k_get_szcounts_dndzdq_at_z_q), 0, 0, 1, 1},
    {&__pyx_n_s_get_szcountsz_sigma_at_theta_in, __pyx_k_get_szcountsz_sigma_at_theta_in, sizeof(__pyx_k_get_szcountsz_sigma_at_theta_in), 0, 0, 1, 1},
    {&__pyx_n_s_get_te_of_m500c_at_z_arnaud, __pyx_k_get_te_of_m500c_at_z_arnaud, sizeof(__pyx_k_get_te_of_m500c_at_z_arnaud), 0, 0, 1, 1},
    {&__pyx_n_s_get_te_of_m500c_at_z_lee, __pyx_k_get_te_of_m500c_at_z_lee, sizeof(__pyx_k_get_te_of_m500c_at_z_lee), 0, 0, 1, 1},
    {&__pyx_n_s_get_thermodynamics, __pyx_k_get_thermodynamics, sizeof(__pyx_k_get_thermodynamics), 0, 0, 1, 1},
    {&__pyx_n_s_get_theta_at_m_and_z, __pyx_k_get_theta_at_m_and_z, sizeof(__pyx_k_get_theta_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_transfer, __pyx_k_get_transfer, sizeof(__pyx_k_get_transfer), 0, 0, 1, 1},
    {&__pyx_n_s_get_truncated_nfw_profile_at_z_k, __pyx_k_get_truncated_nfw_profile_at_z_k, sizeof(__pyx_k_get_truncated_nfw_profile_at_z_k), 0, 0, 1, 1},
    {&__pyx_n_s_get_truncated_nfw_profile_at_z_k_2, __pyx_k_get_truncated_nfw_profile_at_z_k_2, sizeof(__pyx_k_get_truncated_nfw_profile_at_z_k_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_ttg_bispectrum_at_z_effectiv, __pyx_k_get_ttg_bispectrum_at_z_effectiv, sizeof(__pyx_k_get_ttg_bispectrum_at_z_effectiv), 0, 0, 1, 1},
    {&__pyx_n_s_get_ttg_bispectrum_at_z_tree_lev, __pyx_k_get_ttg_bispectrum_at_z_tree_lev, sizeof(__pyx_k_get_ttg_bispectrum_at_z_tree_lev), 0, 0, 1, 1},
    {&__pyx_n_s_get_uk, __pyx_k_get_uk, sizeof(__pyx_k_get_uk), 0, 0, 1, 1},
    {&__pyx_n_s_get_uk_nfw, __pyx_k_get_uk_nfw, sizeof(__pyx_k_get_uk_nfw), 0, 0, 1, 1},
    {&__pyx_n_s_get_uk_nfw_locals_compute_profil, __pyx_k_get_uk_nfw_locals_compute_profil, sizeof(__pyx_k_get_uk_nfw_locals_compute_profil), 0, 0, 1, 1},
    {&__pyx_n_s_get_uk_nfw_locals_handle_combina, __pyx_k_get_uk_nfw_locals_handle_combina, sizeof(__pyx_k_get_uk_nfw_locals_handle_combina), 0, 0, 1, 1},
    {&__pyx_n_s_get_unwise_m_min_cut_at_z, __pyx_k_get_unwise_m_min_cut_at_z, sizeof(__pyx_k_get_unwise_m_min_cut_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_upp_from_gnfw_pressure_at_x, __pyx_k_get_upp_from_gnfw_pressure_at_x, sizeof(__pyx_k_get_upp_from_gnfw_pressure_at_x), 0, 0, 1, 1},
    {&__pyx_n_s_get_volume_dVdzdOmega_at_z, __pyx_k_get_volume_dVdzdOmega_at_z, sizeof(__pyx_k_get_volume_dVdzdOmega_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_vrms2_at_z, __pyx_k_get_vrms2_at_z, sizeof(__pyx_k_get_vrms2_at_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_y_at_m_and_z, __pyx_k_get_y_at_m_and_z, sizeof(__pyx_k_get_y_at_m_and_z), 0, 0, 1, 1},
    {&__pyx_n_s_get_yc_at_m_and_z_H13, __pyx_k_get_yc_at_m_and_z_H13, sizeof(__pyx_k_get_yc_at_m_and_z_H13), 0, 0, 1, 1},
    {&__pyx_n_s_get_z_of_chi, __pyx_k_get_z_of_chi, sizeof(__pyx_k_get_z_of_chi), 0, 0, 1, 1},
    {&__pyx_n_s_get_z_of_chi_unvectorized, __pyx_k_get_z_of_chi_unvectorized, sizeof(__pyx_k_get_z_of_chi_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_kp_u_got, __pyx_k_got, sizeof(__pyx_k_got), 0, 1, 0, 0},
    {&__pyx_kp_u_got_differing_extents_in_dimensi, __pyx_k_got_differing_extents_in_dimensi, sizeof(__pyx_k_got_differing_extents_in_dimensi), 0, 1, 0, 0},
    {&__pyx_n_s_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 0, 1, 1},
    {&__pyx_n_u_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 1, 0, 1},
    {&__pyx_n_s_h_P, __pyx_k_h_P, sizeof(__pyx_k_h_P), 0, 0, 1, 1},
    {&__pyx_n_s_h_units, __pyx_k_h_units, sizeof(__pyx_k_h_units), 0, 0, 1, 1},
    {&__pyx_n_s_handle_combinations, __pyx_k_handle_combinations, sizeof(__pyx_k_handle_combinations), 0, 0, 1, 1},
    {&__pyx_n_s_has_flags, __pyx_k_has_flags, sizeof(__pyx_k_has_flags), 0, 0, 1, 1},
    {&__pyx_kp_u_hf, __pyx_k_hf, sizeof(__pyx_k_hf), 0, 1, 0, 0},
    {&__pyx_n_u_hf_2, __pyx_k_hf_2, sizeof(__pyx_k_hf_2), 0, 1, 0, 1},
    {&__pyx_n_u_hmf, __pyx_k_hmf, sizeof(__pyx_k_hmf), 0, 1, 0, 1},
    {&__pyx_n_s_hplanck, __pyx_k_hplanck, sizeof(__pyx_k_hplanck), 0, 0, 1, 1},
    {&__pyx_n_u_hsv, __pyx_k_hsv, sizeof(__pyx_k_hsv), 0, 1, 0, 1},
    {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
    {&__pyx_n_s_ic_info, __pyx_k_ic_info, sizeof(__pyx_k_ic_info), 0, 0, 1, 1},
    {&__pyx_n_s_ic_key, __pyx_k_ic_key, sizeof(__pyx_k_ic_key), 0, 0, 1, 1},
    {&__pyx_n_s_ic_num, __pyx_k_ic_num, sizeof(__pyx_k_ic_num), 0, 0, 1, 1},
    {&__pyx_n_s_ic_suffix, __pyx_k_ic_suffix, sizeof(__pyx_k_ic_suffix), 0, 0, 1, 1},
    {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
    {&__pyx_n_s_id_nu1, __pyx_k_id_nu1, sizeof(__pyx_k_id_nu1), 0, 0, 1, 1},
    {&__pyx_n_s_id_nu2, __pyx_k_id_nu2, sizeof(__pyx_k_id_nu2), 0, 0, 1, 1},
    {&__pyx_n_u_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 1, 0, 1},
    {&__pyx_n_s_imp, __pyx_k_imp, sizeof(__pyx_k_imp), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_n_s_index_M_bins, __pyx_k_index_M_bins, sizeof(__pyx_k_index_M_bins), 0, 0, 1, 1},
    {&__pyx_n_s_index_M_bins_prime, __pyx_k_index_M_bins_prime, sizeof(__pyx_k_index_M_bins_prime), 0, 0, 1, 1},
    {&__pyx_n_s_index_g, __pyx_k_index_g, sizeof(__pyx_k_index_g), 0, 0, 1, 1},
    {&__pyx_n_s_index_ic, __pyx_k_index_ic, sizeof(__pyx_k_index_ic), 0, 0, 1, 1},
    {&__pyx_n_s_index_k, __pyx_k_index_k, sizeof(__pyx_k_index_k), 0, 0, 1, 1},
    {&__pyx_n_s_index_l, __pyx_k_index_l, sizeof(__pyx_k_index_l), 0, 0, 1, 1},
    {&__pyx_n_s_index_l_prime, __pyx_k_index_l_prime, sizeof(__pyx_k_index_l_prime), 0, 0, 1, 1},
    {&__pyx_n_s_index_m, __pyx_k_index_m, sizeof(__pyx_k_index_m), 0, 0, 1, 1},
    {&__pyx_n_s_index_m_z, __pyx_k_index_m_z, sizeof(__pyx_k_index_m_z), 0, 0, 1, 1},
    {&__pyx_n_s_index_md, __pyx_k_index_md, sizeof(__pyx_k_index_md), 0, 0, 1, 1},
    {&__pyx_n_s_index_mu, __pyx_k_index_mu, sizeof(__pyx_k_index_mu), 0, 0, 1, 1},
    {&__pyx_n_s_index_pk, __pyx_k_index_pk, sizeof(__pyx_k_index_pk), 0, 0, 1, 1},
    {&__pyx_n_s_index_r, __pyx_k_index_r, sizeof(__pyx_k_index_r), 0, 0, 1, 1},
    {&__pyx_n_s_index_tau, __pyx_k_index_tau, sizeof(__pyx_k_index_tau), 0, 0, 1, 1},
    {&__pyx_n_s_index_x, __pyx_k_index_x, sizeof(__pyx_k_index_x), 0, 0, 1, 1},
    {&__pyx_n_s_index_y, __pyx_k_index_y, sizeof(__pyx_k_index_y), 0, 0, 1, 1},
    {&__pyx_n_s_index_z, __pyx_k_index_z, sizeof(__pyx_k_index_z), 0, 0, 1, 1},
    {&__pyx_n_s_index_z_r, __pyx_k_index_z_r, sizeof(__pyx_k_index_z_r), 0, 0, 1, 1},
    {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
    {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
    {&__pyx_n_s_initial, __pyx_k_initial, sizeof(__pyx_k_initial), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_u_input, __pyx_k_input, sizeof(__pyx_k_input), 0, 1, 0, 1},
    {&__pyx_n_s_intUpper, __pyx_k_intUpper, sizeof(__pyx_k_intUpper), 0, 0, 1, 1},
    {&__pyx_n_s_integrate, __pyx_k_integrate, sizeof(__pyx_k_integrate), 0, 0, 1, 1},
    {&__pyx_n_s_integrate_only, __pyx_k_integrate_only, sizeof(__pyx_k_integrate_only), 0, 0, 1, 1},
    {&__pyx_n_s_interp1d, __pyx_k_interp1d, sizeof(__pyx_k_interp1d), 0, 0, 1, 1},
    {&__pyx_n_s_interpolate, __pyx_k_interpolate, sizeof(__pyx_k_interpolate), 0, 0, 1, 1},
    {&__pyx_n_s_ionization_fraction, __pyx_k_ionization_fraction, sizeof(__pyx_k_ionization_fraction), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_kp_u_is_not_implemented_yet, __pyx_k_is_not_implemented_yet, sizeof(__pyx_k_is_not_implemented_yet), 0, 1, 0, 0},
    {&__pyx_kp_u_is_not_implemented_yet_Availabl, __pyx_k_is_not_implemented_yet_Availabl, sizeof(__pyx_k_is_not_implemented_yet_Availabl), 0, 1, 0, 0},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_isscalar, __pyx_k_isscalar, sizeof(__pyx_k_isscalar), 0, 0, 1, 1},
    {&__pyx_n_s_issuperset, __pyx_k_issuperset, sizeof(__pyx_k_issuperset), 0, 0, 1, 1},
    {&__pyx_n_u_isw_auto, __pyx_k_isw_auto, sizeof(__pyx_k_isw_auto), 0, 1, 0, 1},
    {&__pyx_n_u_isw_lens, __pyx_k_isw_lens, sizeof(__pyx_k_isw_lens), 0, 1, 0, 1},
    {&__pyx_n_u_isw_tsz, __pyx_k_isw_tsz, sizeof(__pyx_k_isw_tsz), 0, 1, 0, 1},
    {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
    {&__pyx_n_s_itemsize, __pyx_k_itemsize, sizeof(__pyx_k_itemsize), 0, 0, 1, 1},
    {&__pyx_kp_s_itemsize_0_for_cython_array, __pyx_k_itemsize_0_for_cython_array, sizeof(__pyx_k_itemsize_0_for_cython_array), 0, 0, 1, 0},
    {&__pyx_n_s_j, __pyx_k_j, sizeof(__pyx_k_j), 0, 0, 1, 1},
    {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
    {&__pyx_n_s_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 0, 1, 1},
    {&__pyx_n_u_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 1, 0, 1},
    {&__pyx_n_s_k1, __pyx_k_k1, sizeof(__pyx_k_k1), 0, 0, 1, 1},
    {&__pyx_n_s_k1_in_h_over_Mpc, __pyx_k_k1_in_h_over_Mpc, sizeof(__pyx_k_k1_in_h_over_Mpc), 0, 0, 1, 1},
    {&__pyx_n_s_k2, __pyx_k_k2, sizeof(__pyx_k_k2), 0, 0, 1, 1},
    {&__pyx_n_s_k2_in_h_over_Mpc, __pyx_k_k2_in_h_over_Mpc, sizeof(__pyx_k_k2_in_h_over_Mpc), 0, 0, 1, 1},
    {&__pyx_n_s_k3, __pyx_k_k3, sizeof(__pyx_k_k3), 0, 0, 1, 1},
    {&__pyx_n_s_k3_in_h_over_Mpc, __pyx_k_k3_in_h_over_Mpc, sizeof(__pyx_k_k3_in_h_over_Mpc), 0, 0, 1, 1},
    {&__pyx_n_s_kB, __pyx_k_kB, sizeof(__pyx_k_kB), 0, 0, 1, 1},
    {&__pyx_n_s_k_B, __pyx_k_k_B, sizeof(__pyx_k_k_B), 0, 0, 1, 1},
    {&__pyx_kp_u_k_and_z_must_be_broadcastable_to, __pyx_k_k_and_z_must_be_broadcastable_to, sizeof(__pyx_k_k_and_z_must_be_broadcastable_to), 0, 1, 0, 0},
    {&__pyx_n_s_k_array, __pyx_k_k_array, sizeof(__pyx_k_k_array), 0, 0, 1, 1},
    {&__pyx_n_s_k_asked, __pyx_k_k_asked, sizeof(__pyx_k_k_asked), 0, 0, 1, 1},
    {&__pyx_n_s_k_eq, __pyx_k_k_eq, sizeof(__pyx_k_k_eq), 0, 0, 1, 1},
    {&__pyx_n_u_k_eq, __pyx_k_k_eq, sizeof(__pyx_k_k_eq), 0, 1, 0, 1},
    {&__pyx_n_s_k_input, __pyx_k_k_input, sizeof(__pyx_k_k_input), 0, 0, 1, 1},
    {&__pyx_n_s_k_len, __pyx_k_k_len, sizeof(__pyx_k_k_len), 0, 0, 1, 1},
    {&__pyx_n_s_k_nl, __pyx_k_k_nl, sizeof(__pyx_k_k_nl), 0, 0, 1, 1},
    {&__pyx_n_s_k_nl_cb, __pyx_k_k_nl_cb, sizeof(__pyx_k_k_nl_cb), 0, 0, 1, 1},
    {&__pyx_n_s_k_size, __pyx_k_k_size, sizeof(__pyx_k_k_size), 0, 0, 1, 1},
    {&__pyx_n_s_k_vals, __pyx_k_k_vals, sizeof(__pyx_k_k_vals), 0, 0, 1, 1},
    {&__pyx_n_s_kars, __pyx_k_kars, sizeof(__pyx_k_kars), 0, 0, 1, 1},
    {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
    {&__pyx_n_s_kh, __pyx_k_kh, sizeof(__pyx_k_kh), 0, 0, 1, 1},
    {&__pyx_n_s_kh_input, __pyx_k_kh_input, sizeof(__pyx_k_kh_input), 0, 0, 1, 1},
    {&__pyx_n_s_kh_len, __pyx_k_kh_len, sizeof(__pyx_k_kh_len), 0, 0, 1, 1},
    {&__pyx_n_s_kh_vals, __pyx_k_kh_vals, sizeof(__pyx_k_kh_vals), 0, 0, 1, 1},
    {&__pyx_n_s_kind, __pyx_k_kind, sizeof(__pyx_k_kind), 0, 0, 1, 1},
    {&__pyx_n_s_kk, __pyx_k_kk, sizeof(__pyx_k_kk), 0, 0, 1, 1},
    {&__pyx_kp_u_ksi_V_2, __pyx_k_ksi_V_2, sizeof(__pyx_k_ksi_V_2), 0, 1, 0, 0},
    {&__pyx_n_s_l, __pyx_k_l, sizeof(__pyx_k_l), 0, 0, 1, 1},
    {&__pyx_n_u_lCl, __pyx_k_lCl, sizeof(__pyx_k_lCl), 0, 1, 0, 1},
    {&__pyx_n_s_l_asked, __pyx_k_l_asked, sizeof(__pyx_k_l_asked), 0, 0, 1, 1},
    {&__pyx_n_s_l_max_flag, __pyx_k_l_max_flag, sizeof(__pyx_k_l_max_flag), 0, 0, 1, 1},
    {&__pyx_n_u_l_max_lss, __pyx_k_l_max_lss, sizeof(__pyx_k_l_max_lss), 0, 1, 0, 1},
    {&__pyx_n_u_l_max_scalars, __pyx_k_l_max_scalars, sizeof(__pyx_k_l_max_scalars), 0, 1, 0, 1},
    {&__pyx_n_s_last_index, __pyx_k_last_index, sizeof(__pyx_k_last_index), 0, 0, 1, 1},
    {&__pyx_n_s_lcl, __pyx_k_lcl, sizeof(__pyx_k_lcl), 0, 0, 1, 1},
    {&__pyx_n_s_lcp, __pyx_k_lcp, sizeof(__pyx_k_lcp), 0, 0, 1, 1},
    {&__pyx_n_s_lensed_cl, __pyx_k_lensed_cl, sizeof(__pyx_k_lensed_cl), 0, 0, 1, 1},
    {&__pyx_n_u_lensing, __pyx_k_lensing, sizeof(__pyx_k_lensing), 0, 1, 0, 1},
    {&__pyx_kp_u_lensing_term, __pyx_k_lensing_term, sizeof(__pyx_k_lensing_term), 0, 1, 0, 0},
    {&__pyx_n_s_level, __pyx_k_level, sizeof(__pyx_k_level), 0, 0, 1, 1},
    {&__pyx_kp_u_levelname_s_message_s, __pyx_k_levelname_s_message_s, sizeof(__pyx_k_levelname_s_message_s), 0, 1, 0, 0},
    {&__pyx_n_s_levels, __pyx_k_levels, sizeof(__pyx_k_levels), 0, 0, 1, 1},
    {&__pyx_n_s_likelihood_mode, __pyx_k_likelihood_mode, sizeof(__pyx_k_likelihood_mode), 0, 0, 1, 1},
    {&__pyx_n_u_lin, __pyx_k_lin, sizeof(__pyx_k_lin), 0, 1, 0, 1},
    {&__pyx_n_s_linspace, __pyx_k_linspace, sizeof(__pyx_k_linspace), 0, 0, 1, 1},
    {&__pyx_n_u_ll, __pyx_k_ll, sizeof(__pyx_k_ll), 0, 1, 0, 1},
    {&__pyx_n_s_lmax, __pyx_k_lmax, sizeof(__pyx_k_lmax), 0, 0, 1, 1},
    {&__pyx_n_s_lmaxR, __pyx_k_lmaxR, sizeof(__pyx_k_lmaxR), 0, 0, 1, 1},
    {&__pyx_kp_u_ln10_10_A_s, __pyx_k_ln10_10_A_s, sizeof(__pyx_k_ln10_10_A_s), 0, 1, 0, 0},
    {&__pyx_n_s_ln1pzc, __pyx_k_ln1pzc, sizeof(__pyx_k_ln1pzc), 0, 0, 1, 1},
    {&__pyx_n_s_lna, __pyx_k_lna, sizeof(__pyx_k_lna), 0, 0, 1, 1},
    {&__pyx_n_s_load_n5k_cl_K1, __pyx_k_load_n5k_cl_K1, sizeof(__pyx_k_load_n5k_cl_K1), 0, 0, 1, 1},
    {&__pyx_n_s_load_n5k_pk_zk, __pyx_k_load_n5k_pk_zk, sizeof(__pyx_k_load_n5k_pk_zk), 0, 0, 1, 1},
    {&__pyx_n_s_load_n5k_z_of_chi, __pyx_k_load_n5k_z_of_chi, sizeof(__pyx_k_load_n5k_z_of_chi), 0, 0, 1, 1},
    {&__pyx_n_s_loadtxt, __pyx_k_loadtxt, sizeof(__pyx_k_loadtxt), 0, 0, 1, 1},
    {&__pyx_n_s_log, __pyx_k_log, sizeof(__pyx_k_log), 0, 0, 1, 1},
    {&__pyx_n_s_log10, __pyx_k_log10, sizeof(__pyx_k_log10), 0, 0, 1, 1},
    {&__pyx_n_s_log10M, __pyx_k_log10M, sizeof(__pyx_k_log10M), 0, 0, 1, 1},
    {&__pyx_n_s_log10M500c_zk, __pyx_k_log10M500c_zk, sizeof(__pyx_k_log10M500c_zk), 0, 0, 1, 1},
    {&__pyx_n_s_log10Ms, __pyx_k_log10Ms, sizeof(__pyx_k_log10Ms), 0, 0, 1, 1},
    {&__pyx_n_s_log10x_num, __pyx_k_log10x_num, sizeof(__pyx_k_log10x_num), 0, 0, 1, 1},
    {&__pyx_n_s_log10xmax_mcfit, __pyx_k_log10xmax_mcfit, sizeof(__pyx_k_log10xmax_mcfit), 0, 0, 1, 1},
    {&__pyx_n_s_log10xmin_mcfit, __pyx_k_log10xmin_mcfit, sizeof(__pyx_k_log10xmin_mcfit), 0, 0, 1, 1},
    {&__pyx_n_s_log10y_center, __pyx_k_log10y_center, sizeof(__pyx_k_log10y_center), 0, 0, 1, 1},
    {&__pyx_n_u_log10y_center, __pyx_k_log10y_center, sizeof(__pyx_k_log10y_center), 0, 1, 0, 1},
    {&__pyx_n_s_log10y_edges, __pyx_k_log10y_edges, sizeof(__pyx_k_log10y_edges), 0, 0, 1, 1},
    {&__pyx_n_u_log10y_edges, __pyx_k_log10y_edges, sizeof(__pyx_k_log10y_edges), 0, 1, 0, 1},
    {&__pyx_n_u_logA, __pyx_k_logA, sizeof(__pyx_k_logA), 0, 1, 0, 1},
    {&__pyx_n_s_logA_fast, __pyx_k_logA_fast, sizeof(__pyx_k_logA_fast), 0, 0, 1, 1},
    {&__pyx_n_s_log_y0, __pyx_k_log_y0, sizeof(__pyx_k_log_y0), 0, 0, 1, 1},
    {&__pyx_n_s_log_y0Err, __pyx_k_log_y0Err, sizeof(__pyx_k_log_y0Err), 0, 0, 1, 1},
    {&__pyx_n_s_log_y0pred, __pyx_k_log_y0pred, sizeof(__pyx_k_log_y0pred), 0, 0, 1, 1},
    {&__pyx_n_s_logging, __pyx_k_logging, sizeof(__pyx_k_logging), 0, 0, 1, 1},
    {&__pyx_n_s_loglike, __pyx_k_loglike, sizeof(__pyx_k_loglike), 0, 0, 1, 1},
    {&__pyx_n_u_loglike, __pyx_k_loglike, sizeof(__pyx_k_loglike), 0, 1, 0, 1},
    {&__pyx_n_s_logspace, __pyx_k_logspace, sizeof(__pyx_k_logspace), 0, 0, 1, 1},
    {&__pyx_n_s_lowring, __pyx_k_lowring, sizeof(__pyx_k_lowring), 0, 0, 1, 1},
    {&__pyx_n_s_lum_distance, __pyx_k_lum_distance, sizeof(__pyx_k_lum_distance), 0, 0, 1, 1},
    {&__pyx_n_s_luminosity_distance, __pyx_k_luminosity_distance, sizeof(__pyx_k_luminosity_distance), 0, 0, 1, 1},
    {&__pyx_n_s_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 0, 1, 1},
    {&__pyx_n_u_mPk, __pyx_k_mPk, sizeof(__pyx_k_mPk), 0, 1, 0, 1},
    {&__pyx_n_s_m_asked, __pyx_k_m_asked, sizeof(__pyx_k_m_asked), 0, 0, 1, 1},
    {&__pyx_n_s_m_broadcasted, __pyx_k_m_broadcasted, sizeof(__pyx_k_m_broadcasted), 0, 0, 1, 1},
    {&__pyx_kp_u_m_d_a_zA_Z__to_m_d_a_zA_Z, __pyx_k_m_d_a_zA_Z__to_m_d_a_zA_Z, sizeof(__pyx_k_m_d_a_zA_Z__to_m_d_a_zA_Z), 0, 1, 0, 0},
    {&__pyx_n_s_m_delta, __pyx_k_m_delta, sizeof(__pyx_k_m_delta), 0, 0, 1, 1},
    {&__pyx_n_s_m_flattened, __pyx_k_m_flattened, sizeof(__pyx_k_m_flattened), 0, 0, 1, 1},
    {&__pyx_n_s_m_input, __pyx_k_m_input, sizeof(__pyx_k_m_input), 0, 0, 1, 1},
    {&__pyx_kp_u_m_input_should_be_a_float_or_a_1, __pyx_k_m_input_should_be_a_float_or_a_1, sizeof(__pyx_k_m_input_should_be_a_float_or_a_1), 0, 1, 0, 0},
    {&__pyx_n_s_m_len, __pyx_k_m_len, sizeof(__pyx_k_m_len), 0, 0, 1, 1},
    {&__pyx_n_u_m_ncdm, __pyx_k_m_ncdm, sizeof(__pyx_k_m_ncdm), 0, 1, 0, 1},
    {&__pyx_n_u_m_ncdm_in_eV, __pyx_k_m_ncdm_in_eV, sizeof(__pyx_k_m_ncdm_in_eV), 0, 1, 0, 1},
    {&__pyx_n_u_m_ncdm_tot, __pyx_k_m_ncdm_tot, sizeof(__pyx_k_m_ncdm_tot), 0, 1, 0, 1},
    {&__pyx_n_s_m_vals, __pyx_k_m_vals, sizeof(__pyx_k_m_vals), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_u_mass_bin_edges, __pyx_k_mass_bin_edges, sizeof(__pyx_k_mass_bin_edges), 0, 1, 0, 1},
    {&__pyx_n_u_mass_function, __pyx_k_mass_function, sizeof(__pyx_k_mass_function), 0, 1, 0, 1},
    {&__pyx_kp_u_mass_function_2, __pyx_k_mass_function_2, sizeof(__pyx_k_mass_function_2), 0, 1, 0, 0},
    {&__pyx_n_s_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 0, 1, 1},
    {&__pyx_n_s_math, __pyx_k_math, sizeof(__pyx_k_math), 0, 0, 1, 1},
    {&__pyx_n_s_max, __pyx_k_max, sizeof(__pyx_k_max), 0, 0, 1, 1},
    {&__pyx_n_s_maxIndex, __pyx_k_maxIndex, sizeof(__pyx_k_maxIndex), 0, 0, 1, 1},
    {&__pyx_n_s_mcfit, __pyx_k_mcfit, sizeof(__pyx_k_mcfit), 0, 0, 1, 1},
    {&__pyx_n_s_mcfitx, __pyx_k_mcfitx, sizeof(__pyx_k_mcfitx), 0, 0, 1, 1},
    {&__pyx_n_s_mcmc_parameters, __pyx_k_mcmc_parameters, sizeof(__pyx_k_mcmc_parameters), 0, 0, 1, 1},
    {&__pyx_n_s_mcut, __pyx_k_mcut, sizeof(__pyx_k_mcut), 0, 0, 1, 1},
    {&__pyx_n_u_mcut, __pyx_k_mcut, sizeof(__pyx_k_mcut), 0, 1, 0, 1},
    {&__pyx_n_u_mcut_B12, __pyx_k_mcut_B12, sizeof(__pyx_k_mcut_B12), 0, 1, 0, 1},
    {&__pyx_n_s_me, __pyx_k_me, sizeof(__pyx_k_me), 0, 0, 1, 1},
    {&__pyx_n_s_memview, __pyx_k_memview, sizeof(__pyx_k_memview), 0, 0, 1, 1},
    {&__pyx_n_s_message, __pyx_k_message, sizeof(__pyx_k_message), 0, 0, 1, 1},
    {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
    {&__pyx_n_s_min, __pyx_k_min, sizeof(__pyx_k_min), 0, 0, 1, 1},
    {&__pyx_n_s_minIndex, __pyx_k_minIndex, sizeof(__pyx_k_minIndex), 0, 0, 1, 1},
    {&__pyx_n_u_minimal, __pyx_k_minimal, sizeof(__pyx_k_minimal), 0, 1, 0, 1},
    {&__pyx_n_s_mm, __pyx_k_mm, sizeof(__pyx_k_mm), 0, 0, 1, 1},
    {&__pyx_n_u_mnu, __pyx_k_mnu, sizeof(__pyx_k_mnu), 0, 1, 0, 1},
    {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
    {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
    {&__pyx_n_s_mro_entries, __pyx_k_mro_entries, sizeof(__pyx_k_mro_entries), 0, 0, 1, 1},
    {&__pyx_n_s_mu_size, __pyx_k_mu_size, sizeof(__pyx_k_mu_size), 0, 0, 1, 1},
    {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
    {&__pyx_n_u_n5k, __pyx_k_n5k, sizeof(__pyx_k_n5k), 0, 1, 0, 1},
    {&__pyx_n_u_nCl, __pyx_k_nCl, sizeof(__pyx_k_nCl), 0, 1, 0, 1},
    {&__pyx_n_u_n_e, __pyx_k_n_e, sizeof(__pyx_k_n_e), 0, 1, 0, 1},
    {&__pyx_n_s_n_s, __pyx_k_n_s, sizeof(__pyx_k_n_s), 0, 0, 1, 1},
    {&__pyx_n_u_n_s, __pyx_k_n_s, sizeof(__pyx_k_n_s), 0, 1, 0, 1},
    {&__pyx_n_u_n_t, __pyx_k_n_t, sizeof(__pyx_k_n_t), 0, 1, 0, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_names, __pyx_k_names, sizeof(__pyx_k_names), 0, 0, 1, 1},
    {&__pyx_n_s_ndim, __pyx_k_ndim, sizeof(__pyx_k_ndim), 0, 0, 1, 1},
    {&__pyx_n_u_ndim_masses, __pyx_k_ndim_masses, sizeof(__pyx_k_ndim_masses), 0, 1, 0, 1},
    {&__pyx_n_u_ndim_redshifts, __pyx_k_ndim_redshifts, sizeof(__pyx_k_ndim_redshifts), 0, 1, 0, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_n_s_newaxis, __pyx_k_newaxis, sizeof(__pyx_k_newaxis), 0, 0, 1, 1},
    {&__pyx_n_u_nfw, __pyx_k_nfw, sizeof(__pyx_k_nfw), 0, 1, 0, 1},
    {&__pyx_n_s_ngtm, __pyx_k_ngtm, sizeof(__pyx_k_ngtm), 0, 0, 1, 1},
    {&__pyx_n_s_nl, __pyx_k_nl, sizeof(__pyx_k_nl), 0, 0, 1, 1},
    {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
    {&__pyx_n_s_nofail, __pyx_k_nofail, sizeof(__pyx_k_nofail), 0, 0, 1, 1},
    {&__pyx_n_s_non_class_sz_keys, __pyx_k_non_class_sz_keys, sizeof(__pyx_k_non_class_sz_keys), 0, 0, 1, 1},
    {&__pyx_n_u_non_linear, __pyx_k_non_linear, sizeof(__pyx_k_non_linear), 0, 1, 0, 1},
    {&__pyx_n_s_non_linear_check, __pyx_k_non_linear_check, sizeof(__pyx_k_non_linear_check), 0, 0, 1, 1},
    {&__pyx_n_u_none, __pyx_k_none, sizeof(__pyx_k_none), 0, 1, 0, 1},
    {&__pyx_n_u_nonlin, __pyx_k_nonlin, sizeof(__pyx_k_nonlin), 0, 1, 0, 1},
    {&__pyx_n_s_nonlinear, __pyx_k_nonlinear, sizeof(__pyx_k_nonlinear), 0, 0, 1, 1},
    {&__pyx_n_u_nonlinear, __pyx_k_nonlinear, sizeof(__pyx_k_nonlinear), 0, 1, 0, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigma8, __pyx_k_nonlinear_hmcode_sigma8, sizeof(__pyx_k_nonlinear_hmcode_sigma8), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigma8_cb, __pyx_k_nonlinear_hmcode_sigma8_cb, sizeof(__pyx_k_nonlinear_hmcode_sigma8_cb), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigmadisp, __pyx_k_nonlinear_hmcode_sigmadisp, sizeof(__pyx_k_nonlinear_hmcode_sigmadisp), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigmadisp100, __pyx_k_nonlinear_hmcode_sigmadisp100, sizeof(__pyx_k_nonlinear_hmcode_sigmadisp100), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigmadisp100_cb, __pyx_k_nonlinear_hmcode_sigmadisp100_cb, sizeof(__pyx_k_nonlinear_hmcode_sigmadisp100_cb), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigmadisp_cb, __pyx_k_nonlinear_hmcode_sigmadisp_cb, sizeof(__pyx_k_nonlinear_hmcode_sigmadisp_cb), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigmaprime, __pyx_k_nonlinear_hmcode_sigmaprime, sizeof(__pyx_k_nonlinear_hmcode_sigmaprime), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_sigmaprime_cb, __pyx_k_nonlinear_hmcode_sigmaprime_cb, sizeof(__pyx_k_nonlinear_hmcode_sigmaprime_cb), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_hmcode_window_nfw, __pyx_k_nonlinear_hmcode_window_nfw, sizeof(__pyx_k_nonlinear_hmcode_window_nfw), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_scale, __pyx_k_nonlinear_scale, sizeof(__pyx_k_nonlinear_scale), 0, 0, 1, 1},
    {&__pyx_n_s_nonlinear_scale_cb, __pyx_k_nonlinear_scale_cb, sizeof(__pyx_k_nonlinear_scale_cb), 0, 0, 1, 1},
    {&__pyx_n_s_normalize, __pyx_k_normalize, sizeof(__pyx_k_normalize), 0, 0, 1, 1},
    {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
    {&__pyx_n_s_nq, __pyx_k_nq, sizeof(__pyx_k_nq), 0, 0, 1, 1},
    {&__pyx_n_u_ns, __pyx_k_ns, sizeof(__pyx_k_ns), 0, 1, 0, 1},
    {&__pyx_n_u_ntot, __pyx_k_ntot, sizeof(__pyx_k_ntot), 0, 1, 0, 1},
    {&__pyx_n_s_nu, __pyx_k_nu, sizeof(__pyx_k_nu), 0, 0, 1, 1},
    {&__pyx_n_u_nu, __pyx_k_nu, sizeof(__pyx_k_nu), 0, 1, 0, 1},
    {&__pyx_n_s_nu1, __pyx_k_nu1, sizeof(__pyx_k_nu1), 0, 0, 1, 1},
    {&__pyx_n_s_nu2, __pyx_k_nu2, sizeof(__pyx_k_nu2), 0, 0, 1, 1},
    {&__pyx_n_s_nu_in_GHz, __pyx_k_nu_in_GHz, sizeof(__pyx_k_nu_in_GHz), 0, 0, 1, 1},
    {&__pyx_n_s_nu_in_ghz, __pyx_k_nu_in_ghz, sizeof(__pyx_k_nu_in_ghz), 0, 0, 1, 1},
    {&__pyx_n_s_num, __pyx_k_num, sizeof(__pyx_k_num), 0, 0, 1, 1},
    {&__pyx_n_s_numberDensity, __pyx_k_numberDensity, sizeof(__pyx_k_numberDensity), 0, 0, 1, 1},
    {&__pyx_n_s_number_of_titles, __pyx_k_number_of_titles, sizeof(__pyx_k_number_of_titles), 0, 0, 1, 1},
    {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
    {&__pyx_kp_u_numpy__core_multiarray_failed_to, __pyx_k_numpy__core_multiarray_failed_to, sizeof(__pyx_k_numpy__core_multiarray_failed_to), 0, 1, 0, 0},
    {&__pyx_kp_u_numpy__core_umath_failed_to_impo, __pyx_k_numpy__core_umath_failed_to_impo, sizeof(__pyx_k_numpy__core_umath_failed_to_impo), 0, 1, 0, 0},
    {&__pyx_n_s_nz, __pyx_k_nz, sizeof(__pyx_k_nz), 0, 0, 1, 1},
    {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
    {&__pyx_n_s_obsFreqGHz, __pyx_k_obsFreqGHz, sizeof(__pyx_k_obsFreqGHz), 0, 0, 1, 1},
    {&__pyx_n_s_oldpars, __pyx_k_oldpars, sizeof(__pyx_k_oldpars), 0, 0, 1, 1},
    {&__pyx_n_u_ombh2, __pyx_k_ombh2, sizeof(__pyx_k_ombh2), 0, 1, 0, 1},
    {&__pyx_n_u_omch2, __pyx_k_omch2, sizeof(__pyx_k_omch2), 0, 1, 0, 1},
    {&__pyx_n_s_omega, __pyx_k_omega, sizeof(__pyx_k_omega), 0, 0, 1, 1},
    {&__pyx_n_s_omega_b, __pyx_k_omega_b, sizeof(__pyx_k_omega_b), 0, 0, 1, 1},
    {&__pyx_n_u_omega_b, __pyx_k_omega_b, sizeof(__pyx_k_omega_b), 0, 1, 0, 1},
    {&__pyx_n_u_omega_c, __pyx_k_omega_c, sizeof(__pyx_k_omega_c), 0, 1, 0, 1},
    {&__pyx_n_s_omega_cdm, __pyx_k_omega_cdm, sizeof(__pyx_k_omega_cdm), 0, 0, 1, 1},
    {&__pyx_n_u_omega_cdm, __pyx_k_omega_cdm, sizeof(__pyx_k_omega_cdm), 0, 1, 0, 1},
    {&__pyx_n_u_omega_mh2, __pyx_k_omega_mh2, sizeof(__pyx_k_omega_mh2), 0, 1, 0, 1},
    {&__pyx_n_s_only_clustering_species, __pyx_k_only_clustering_species, sizeof(__pyx_k_only_clustering_species), 0, 0, 1, 1},
    {&__pyx_n_s_other_class_sz_keys, __pyx_k_other_class_sz_keys, sizeof(__pyx_k_other_class_sz_keys), 0, 0, 1, 1},
    {&__pyx_n_s_outf, __pyx_k_outf, sizeof(__pyx_k_outf), 0, 0, 1, 1},
    {&__pyx_n_u_output, __pyx_k_output, sizeof(__pyx_k_output), 0, 1, 0, 1},
    {&__pyx_n_s_output_format, __pyx_k_output_format, sizeof(__pyx_k_output_format), 0, 0, 1, 1},
    {&__pyx_n_s_output_keys, __pyx_k_output_keys, sizeof(__pyx_k_output_keys), 0, 0, 1, 1},
    {&__pyx_n_s_output_string, __pyx_k_output_string, sizeof(__pyx_k_output_string), 0, 0, 1, 1},
    {&__pyx_n_s_p, __pyx_k_p, sizeof(__pyx_k_p), 0, 0, 1, 1},
    {&__pyx_n_u_pCl, __pyx_k_pCl, sizeof(__pyx_k_pCl), 0, 1, 0, 1},
    {&__pyx_n_s_pack, __pyx_k_pack, sizeof(__pyx_k_pack), 0, 0, 1, 1},
    {&__pyx_n_s_params_for_emulators, __pyx_k_params_for_emulators, sizeof(__pyx_k_params_for_emulators), 0, 0, 1, 1},
    {&__pyx_n_s_params_settings, __pyx_k_params_settings, sizeof(__pyx_k_params_settings), 0, 0, 1, 1},
    {&__pyx_n_s_params_values_dict, __pyx_k_params_values_dict, sizeof(__pyx_k_params_values_dict), 0, 0, 1, 1},
    {&__pyx_n_s_pars, __pyx_k_pars, sizeof(__pyx_k_pars), 0, 0, 1, 1},
    {&__pyx_n_s_pars_2, __pyx_k_pars_2, sizeof(__pyx_k_pars_2), 0, 0, 1, 1},
    {&__pyx_n_s_pars_check, __pyx_k_pars_check, sizeof(__pyx_k_pars_check), 0, 0, 1, 1},
    {&__pyx_n_s_path_to_cosmopower_organization, __pyx_k_path_to_cosmopower_organization, sizeof(__pyx_k_path_to_cosmopower_organization), 0, 0, 1, 1},
    {&__pyx_n_s_pattern1, __pyx_k_pattern1, sizeof(__pyx_k_pattern1), 0, 0, 1, 1},
    {&__pyx_n_s_pattern2, __pyx_k_pattern2, sizeof(__pyx_k_pattern2), 0, 0, 1, 1},
    {&__pyx_n_s_pattern3, __pyx_k_pattern3, sizeof(__pyx_k_pattern3), 0, 0, 1, 1},
    {&__pyx_n_s_pdict_to_update, __pyx_k_pdict_to_update, sizeof(__pyx_k_pdict_to_update), 0, 0, 1, 1},
    {&__pyx_n_u_perturb, __pyx_k_perturb, sizeof(__pyx_k_perturb), 0, 1, 0, 1},
    {&__pyx_n_u_phi_max, __pyx_k_phi_max, sizeof(__pyx_k_phi_max), 0, 1, 0, 1},
    {&__pyx_n_u_phi_min, __pyx_k_phi_min, sizeof(__pyx_k_phi_min), 0, 1, 0, 1},
    {&__pyx_n_s_pi, __pyx_k_pi, sizeof(__pyx_k_pi), 0, 0, 1, 1},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_n_s_pk, __pyx_k_pk, sizeof(__pyx_k_pk), 0, 0, 1, 1},
    {&__pyx_n_s_pk_array, __pyx_k_pk_array, sizeof(__pyx_k_pk_array), 0, 0, 1, 1},
    {&__pyx_n_s_pk_at_k_z, __pyx_k_pk_at_k_z, sizeof(__pyx_k_pk_at_k_z), 0, 0, 1, 1},
    {&__pyx_n_s_pk_at_z_hm, __pyx_k_pk_at_z_hm, sizeof(__pyx_k_pk_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_pk_b_at_z_2h, __pyx_k_pk_b_at_z_2h, sizeof(__pyx_k_pk_b_at_z_2h), 0, 0, 1, 1},
    {&__pyx_n_s_pk_bb_at_z_hm, __pyx_k_pk_bb_at_z_hm, sizeof(__pyx_k_pk_bb_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_pk_cb, __pyx_k_pk_cb, sizeof(__pyx_k_pk_cb), 0, 0, 1, 1},
    {&__pyx_n_s_pk_cb_lin, __pyx_k_pk_cb_lin, sizeof(__pyx_k_pk_cb_lin), 0, 0, 1, 1},
    {&__pyx_n_s_pk_em_at_z_hm, __pyx_k_pk_em_at_z_hm, sizeof(__pyx_k_pk_em_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_pk_gg_at_z_hm, __pyx_k_pk_gg_at_z_hm, sizeof(__pyx_k_pk_gg_at_z_hm), 0, 0, 1, 1},
    {&__pyx_n_s_pk_lin, __pyx_k_pk_lin, sizeof(__pyx_k_pk_lin), 0, 0, 1, 1},
    {&__pyx_n_s_pk_lin_array, __pyx_k_pk_lin_array, sizeof(__pyx_k_pk_lin_array), 0, 0, 1, 1},
    {&__pyx_n_s_pk_lin_unvectorized, __pyx_k_pk_lin_unvectorized, sizeof(__pyx_k_pk_lin_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_pk_linzmax, __pyx_k_pk_linzmax, sizeof(__pyx_k_pk_linzmax), 0, 0, 1, 1},
    {&__pyx_n_s_pk_nonlin, __pyx_k_pk_nonlin, sizeof(__pyx_k_pk_nonlin), 0, 0, 1, 1},
    {&__pyx_n_s_pk_tilt, __pyx_k_pk_tilt, sizeof(__pyx_k_pk_tilt), 0, 0, 1, 1},
    {&__pyx_n_s_pk_unvectorized, __pyx_k_pk_unvectorized, sizeof(__pyx_k_pk_unvectorized), 0, 0, 1, 1},
    {&__pyx_n_s_pknl_in_output, __pyx_k_pknl_in_output, sizeof(__pyx_k_pknl_in_output), 0, 0, 1, 1},
    {&__pyx_n_s_pknl_key_value_checks, __pyx_k_pknl_key_value_checks, sizeof(__pyx_k_pknl_key_value_checks), 0, 0, 1, 1},
    {&__pyx_n_u_poisson, __pyx_k_poisson, sizeof(__pyx_k_poisson), 0, 1, 0, 1},
    {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
    {&__pyx_n_s_power, __pyx_k_power, sizeof(__pyx_k_power), 0, 0, 1, 1},
    {&__pyx_n_u_pp, __pyx_k_pp, sizeof(__pyx_k_pp), 0, 1, 0, 1},
    {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
    {&__pyx_n_u_pressure_profile, __pyx_k_pressure_profile, sizeof(__pyx_k_pressure_profile), 0, 1, 0, 1},
    {&__pyx_kp_u_pressure_profile_2, __pyx_k_pressure_profile_2, sizeof(__pyx_k_pressure_profile_2), 0, 1, 0, 0},
    {&__pyx_n_s_primordial, __pyx_k_primordial, sizeof(__pyx_k_primordial), 0, 0, 1, 1},
    {&__pyx_n_u_primordial, __pyx_k_primordial, sizeof(__pyx_k_primordial), 0, 1, 0, 1},
    {&__pyx_n_s_problem_flag, __pyx_k_problem_flag, sizeof(__pyx_k_problem_flag), 0, 0, 1, 1},
    {&__pyx_n_s_problematic_parameters, __pyx_k_problematic_parameters, sizeof(__pyx_k_problematic_parameters), 0, 0, 1, 1},
    {&__pyx_n_s_profile, __pyx_k_profile, sizeof(__pyx_k_profile), 0, 0, 1, 1},
    {&__pyx_n_s_pvecback, __pyx_k_pvecback, sizeof(__pyx_k_pvecback), 0, 0, 1, 1},
    {&__pyx_n_s_pvecthermo, __pyx_k_pvecthermo, sizeof(__pyx_k_pvecthermo), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_Enum, __pyx_k_pyx_unpickle_Enum, sizeof(__pyx_k_pyx_unpickle_Enum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
    {&__pyx_n_s_q, __pyx_k_q, sizeof(__pyx_k_q), 0, 0, 1, 1},
    {&__pyx_n_s_q_arr, __pyx_k_q_arr, sizeof(__pyx_k_q_arr), 0, 0, 1, 1},
    {&__pyx_n_s_q_max, __pyx_k_q_max, sizeof(__pyx_k_q_max), 0, 0, 1, 1},
    {&__pyx_n_s_q_threshold, __pyx_k_q_threshold, sizeof(__pyx_k_q_threshold), 0, 0, 1, 1},
    {&__pyx_n_s_qmax, __pyx_k_qmax, sizeof(__pyx_k_qmax), 0, 0, 1, 1},
    {&__pyx_n_s_qobs_asked, __pyx_k_qobs_asked, sizeof(__pyx_k_qobs_asked), 0, 0, 1, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
    {&__pyx_n_u_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 1, 0, 1},
    {&__pyx_n_s_r200c, __pyx_k_r200c, sizeof(__pyx_k_r200c), 0, 0, 1, 1},
    {&__pyx_n_u_r_0002, __pyx_k_r_0002, sizeof(__pyx_k_r_0002), 0, 1, 0, 1},
    {&__pyx_n_s_r_asked, __pyx_k_r_asked, sizeof(__pyx_k_r_asked), 0, 0, 1, 1},
    {&__pyx_n_s_r_delta, __pyx_k_r_delta, sizeof(__pyx_k_r_delta), 0, 0, 1, 1},
    {&__pyx_n_u_ra_rec, __pyx_k_ra_rec, sizeof(__pyx_k_ra_rec), 0, 1, 0, 1},
    {&__pyx_n_u_ra_rec_h, __pyx_k_ra_rec_h, sizeof(__pyx_k_ra_rec_h), 0, 1, 0, 1},
    {&__pyx_n_u_ra_star, __pyx_k_ra_star, sizeof(__pyx_k_ra_star), 0, 1, 0, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_rates, __pyx_k_rates, sizeof(__pyx_k_rates), 0, 0, 1, 1},
    {&__pyx_n_u_rates, __pyx_k_rates, sizeof(__pyx_k_rates), 0, 1, 0, 1},
    {&__pyx_n_s_raw_cl, __pyx_k_raw_cl, sizeof(__pyx_k_raw_cl), 0, 0, 1, 1},
    {&__pyx_n_s_rcl, __pyx_k_rcl, sizeof(__pyx_k_rcl), 0, 0, 1, 1},
    {&__pyx_n_u_rd_star, __pyx_k_rd_star, sizeof(__pyx_k_rd_star), 0, 1, 0, 1},
    {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
    {&__pyx_n_s_redshift, __pyx_k_redshift, sizeof(__pyx_k_redshift), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_register, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
    {&__pyx_n_s_resetwarnings, __pyx_k_resetwarnings, sizeof(__pyx_k_resetwarnings), 0, 0, 1, 1},
    {&__pyx_n_s_reshape, __pyx_k_reshape, sizeof(__pyx_k_reshape), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_rho0_cb, __pyx_k_rho0_cb, sizeof(__pyx_k_rho0_cb), 0, 0, 1, 1},
    {&__pyx_n_s_rho0_crit, __pyx_k_rho0_crit, sizeof(__pyx_k_rho0_crit), 0, 0, 1, 1},
    {&__pyx_n_s_rho0_m, __pyx_k_rho0_m, sizeof(__pyx_k_rho0_m), 0, 0, 1, 1},
    {&__pyx_n_s_rhoc, __pyx_k_rhoc, sizeof(__pyx_k_rhoc), 0, 0, 1, 1},
    {&__pyx_n_u_rs_d, __pyx_k_rs_d, sizeof(__pyx_k_rs_d), 0, 1, 0, 1},
    {&__pyx_n_u_rs_d_h, __pyx_k_rs_d_h, sizeof(__pyx_k_rs_d_h), 0, 1, 0, 1},
    {&__pyx_n_s_rs_drag, __pyx_k_rs_drag, sizeof(__pyx_k_rs_drag), 0, 0, 1, 1},
    {&__pyx_n_u_rs_rec, __pyx_k_rs_rec, sizeof(__pyx_k_rs_rec), 0, 1, 0, 1},
    {&__pyx_n_u_rs_rec_h, __pyx_k_rs_rec_h, sizeof(__pyx_k_rs_rec_h), 0, 1, 0, 1},
    {&__pyx_n_u_rs_star, __pyx_k_rs_star, sizeof(__pyx_k_rs_star), 0, 1, 0, 1},
    {&__pyx_n_s_rv, __pyx_k_rv, sizeof(__pyx_k_rv), 0, 0, 1, 1},
    {&__pyx_kp_u_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 1, 0, 0},
    {&__pyx_kp_u_sBBN_file, __pyx_k_sBBN_file, sizeof(__pyx_k_sBBN_file), 0, 1, 0, 0},
    {&__pyx_kp_u_s_was_not_recognized_as_a_deriv, __pyx_k_s_was_not_recognized_as_a_deriv, sizeof(__pyx_k_s_was_not_recognized_as_a_deriv), 0, 1, 0, 0},
    {&__pyx_n_s_sample_id, __pyx_k_sample_id, sizeof(__pyx_k_sample_id), 0, 0, 1, 1},
    {&__pyx_n_u_scalar, __pyx_k_scalar, sizeof(__pyx_k_scalar), 0, 1, 0, 1},
    {&__pyx_n_u_scale, __pyx_k_scale, sizeof(__pyx_k_scale), 0, 1, 0, 1},
    {&__pyx_n_u_scale_dependent_bias, __pyx_k_scale_dependent_bias, sizeof(__pyx_k_scale_dependent_bias), 0, 1, 0, 1},
    {&__pyx_n_s_scale_independent_growth_factor, __pyx_k_scale_independent_growth_factor, sizeof(__pyx_k_scale_independent_growth_factor), 0, 0, 1, 1},
    {&__pyx_n_s_scale_independent_growth_factor_2, __pyx_k_scale_independent_growth_factor_2, sizeof(__pyx_k_scale_independent_growth_factor_2), 0, 0, 1, 1},
    {&__pyx_n_s_scipy, __pyx_k_scipy, sizeof(__pyx_k_scipy), 0, 0, 1, 1},
    {&__pyx_n_s_scipy_interpolate, __pyx_k_scipy_interpolate, sizeof(__pyx_k_scipy_interpolate), 0, 0, 1, 1},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
    {&__pyx_n_s_sep, __pyx_k_sep, sizeof(__pyx_k_sep), 0, 0, 1, 1},
    {&__pyx_n_s_set, __pyx_k_set, sizeof(__pyx_k_set), 0, 0, 1, 1},
    {&__pyx_n_s_set_default, __pyx_k_set_default, sizeof(__pyx_k_set_default), 0, 0, 1, 1},
    {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
    {&__pyx_n_s_set_verbosity, __pyx_k_set_verbosity, sizeof(__pyx_k_set_verbosity), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_shape, __pyx_k_shape, sizeof(__pyx_k_shape), 0, 0, 1, 1},
    {&__pyx_n_u_shear_calibration_m, __pyx_k_shear_calibration_m, sizeof(__pyx_k_shear_calibration_m), 0, 1, 0, 1},
    {&__pyx_n_u_shotnoise, __pyx_k_shotnoise, sizeof(__pyx_k_shotnoise), 0, 1, 0, 1},
    {&__pyx_n_s_sigma, __pyx_k_sigma, sizeof(__pyx_k_sigma), 0, 0, 1, 1},
    {&__pyx_n_s_sigma8, __pyx_k_sigma8, sizeof(__pyx_k_sigma8), 0, 0, 1, 1},
    {&__pyx_n_u_sigma8, __pyx_k_sigma8, sizeof(__pyx_k_sigma8), 0, 1, 0, 1},
    {&__pyx_n_s_sigma8_Pcb, __pyx_k_sigma8_Pcb, sizeof(__pyx_k_sigma8_Pcb), 0, 0, 1, 1},
    {&__pyx_n_s_sigma8_cb, __pyx_k_sigma8_cb, sizeof(__pyx_k_sigma8_cb), 0, 0, 1, 1},
    {&__pyx_n_u_sigma8_cb, __pyx_k_sigma8_cb, sizeof(__pyx_k_sigma8_cb), 0, 1, 0, 1},
    {&__pyx_n_s_sigmaM, __pyx_k_sigmaM, sizeof(__pyx_k_sigmaM), 0, 0, 1, 1},
    {&__pyx_n_s_sigmaT, __pyx_k_sigmaT, sizeof(__pyx_k_sigmaT), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_8, __pyx_k_sigma_8, sizeof(__pyx_k_sigma_8), 0, 0, 1, 1},
    {&__pyx_n_u_sigma_8, __pyx_k_sigma_8, sizeof(__pyx_k_sigma_8), 0, 1, 0, 1},
    {&__pyx_n_s_sigma_8_cb, __pyx_k_sigma_8_cb, sizeof(__pyx_k_sigma_8_cb), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_cb, __pyx_k_sigma_cb, sizeof(__pyx_k_sigma_cb), 0, 0, 1, 1},
    {&__pyx_kp_u_sigma_cb_not_computed_by_CLASS_p, __pyx_k_sigma_cb_not_computed_by_CLASS_p, sizeof(__pyx_k_sigma_cb_not_computed_by_CLASS_p), 0, 1, 0, 0},
    {&__pyx_n_s_sigma_disp, __pyx_k_sigma_disp, sizeof(__pyx_k_sigma_disp), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_disp_100, __pyx_k_sigma_disp_100, sizeof(__pyx_k_sigma_disp_100), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_disp_100_cb, __pyx_k_sigma_disp_100_cb, sizeof(__pyx_k_sigma_disp_100_cb), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_disp_cb, __pyx_k_sigma_disp_cb, sizeof(__pyx_k_sigma_disp_cb), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_int, __pyx_k_sigma_int, sizeof(__pyx_k_sigma_int), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_log10M, __pyx_k_sigma_log10M, sizeof(__pyx_k_sigma_log10M), 0, 0, 1, 1},
    {&__pyx_n_u_sigma_log10M_HOD, __pyx_k_sigma_log10M_HOD, sizeof(__pyx_k_sigma_log10M_HOD), 0, 1, 0, 1},
    {&__pyx_n_u_sigma_log10M_HOD_ngal, __pyx_k_sigma_log10M_HOD_ngal, sizeof(__pyx_k_sigma_log10M_HOD_ngal), 0, 1, 0, 1},
    {&__pyx_n_s_sigma_prime, __pyx_k_sigma_prime, sizeof(__pyx_k_sigma_prime), 0, 0, 1, 1},
    {&__pyx_n_s_sigma_prime_cb, __pyx_k_sigma_prime_cb, sizeof(__pyx_k_sigma_prime_cb), 0, 0, 1, 1},
    {&__pyx_n_s_simps, __pyx_k_simps, sizeof(__pyx_k_simps), 0, 0, 1, 1},
    {&__pyx_n_s_sinh, __pyx_k_sinh, sizeof(__pyx_k_sinh), 0, 0, 1, 1},
    {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
    {&__pyx_n_s_size_ic_data, __pyx_k_size_ic_data, sizeof(__pyx_k_size_ic_data), 0, 0, 1, 1},
    {&__pyx_n_s_skip_background_and_thermo, __pyx_k_skip_background_and_thermo, sizeof(__pyx_k_skip_background_and_thermo), 0, 0, 1, 1},
    {&__pyx_n_u_skip_background_and_thermo, __pyx_k_skip_background_and_thermo, sizeof(__pyx_k_skip_background_and_thermo), 0, 1, 0, 1},
    {&__pyx_n_u_skip_chi, __pyx_k_skip_chi, sizeof(__pyx_k_skip_chi), 0, 1, 0, 1},
    {&__pyx_n_u_skip_class_sz, __pyx_k_skip_class_sz, sizeof(__pyx_k_skip_class_sz), 0, 1, 0, 1},
    {&__pyx_n_u_skip_cmb, __pyx_k_skip_cmb, sizeof(__pyx_k_skip_cmb), 0, 1, 0, 1},
    {&__pyx_n_u_skip_hubble, __pyx_k_skip_hubble, sizeof(__pyx_k_skip_hubble), 0, 1, 0, 1},
    {&__pyx_n_u_skip_input, __pyx_k_skip_input, sizeof(__pyx_k_skip_input), 0, 1, 0, 1},
    {&__pyx_n_u_skip_pkl, __pyx_k_skip_pkl, sizeof(__pyx_k_skip_pkl), 0, 1, 0, 1},
    {&__pyx_n_u_skip_pknl, __pyx_k_skip_pknl, sizeof(__pyx_k_skip_pknl), 0, 1, 0, 1},
    {&__pyx_n_u_skip_sigma8_and_der, __pyx_k_skip_sigma8_and_der, sizeof(__pyx_k_skip_sigma8_and_der), 0, 1, 0, 1},
    {&__pyx_n_u_skip_sigma8_at_z, __pyx_k_skip_sigma8_at_z, sizeof(__pyx_k_skip_sigma8_at_z), 0, 1, 0, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_specific_keys, __pyx_k_specific_keys, sizeof(__pyx_k_specific_keys), 0, 0, 1, 1},
    {&__pyx_n_s_spectra, __pyx_k_spectra, sizeof(__pyx_k_spectra), 0, 0, 1, 1},
    {&__pyx_n_u_spectra, __pyx_k_spectra, sizeof(__pyx_k_spectra), 0, 1, 0, 1},
    {&__pyx_n_s_splev, __pyx_k_splev, sizeof(__pyx_k_splev), 0, 0, 1, 1},
    {&__pyx_n_s_spline, __pyx_k_spline, sizeof(__pyx_k_spline), 0, 0, 1, 1},
    {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
    {&__pyx_n_s_splrep, __pyx_k_splrep, sizeof(__pyx_k_splrep), 0, 0, 1, 1},
    {&__pyx_n_s_sqrt, __pyx_k_sqrt, sizeof(__pyx_k_sqrt), 0, 0, 1, 1},
    {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_step, __pyx_k_step, sizeof(__pyx_k_step), 0, 0, 1, 1},
    {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
    {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
    {&__pyx_kp_s_strided_and_direct, __pyx_k_strided_and_direct, sizeof(__pyx_k_strided_and_direct), 0, 0, 1, 0},
    {&__pyx_kp_s_strided_and_direct_or_indirect, __pyx_k_strided_and_direct_or_indirect, sizeof(__pyx_k_strided_and_direct_or_indirect), 0, 0, 1, 0},
    {&__pyx_kp_s_strided_and_indirect, __pyx_k_strided_and_indirect, sizeof(__pyx_k_strided_and_indirect), 0, 0, 1, 0},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
    {&__pyx_n_s_struct, __pyx_k_struct, sizeof(__pyx_k_struct), 0, 0, 1, 1},
    {&__pyx_n_s_struct_cleanup, __pyx_k_struct_cleanup, sizeof(__pyx_k_struct_cleanup), 0, 0, 1, 1},
    {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
    {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
    {&__pyx_n_s_suppress_warnings, __pyx_k_suppress_warnings, sizeof(__pyx_k_suppress_warnings), 0, 0, 1, 1},
    {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
    {&__pyx_n_u_sz_cluster_counts, __pyx_k_sz_cluster_counts, sizeof(__pyx_k_sz_cluster_counts), 0, 1, 0, 1},
    {&__pyx_n_u_sz_cluster_counts_fft, __pyx_k_sz_cluster_counts_fft, sizeof(__pyx_k_sz_cluster_counts_fft), 0, 1, 0, 1},
    {&__pyx_n_u_sz_selection_function_skyfracs_f, __pyx_k_sz_selection_function_skyfracs_f, sizeof(__pyx_k_sz_selection_function_skyfracs_f), 0, 1, 0, 1},
    {&__pyx_n_u_sz_selection_function_thetas_fil, __pyx_k_sz_selection_function_thetas_fil, sizeof(__pyx_k_sz_selection_function_thetas_fil), 0, 1, 0, 1},
    {&__pyx_n_u_sz_selection_function_ylims_file, __pyx_k_sz_selection_function_ylims_file, sizeof(__pyx_k_sz_selection_function_ylims_file), 0, 1, 0, 1},
    {&__pyx_n_u_sz_unbinned_cluster_counts, __pyx_k_sz_unbinned_cluster_counts, sizeof(__pyx_k_sz_unbinned_cluster_counts), 0, 1, 0, 1},
    {&__pyx_n_s_szcat_snr, __pyx_k_szcat_snr, sizeof(__pyx_k_szcat_snr), 0, 0, 1, 1},
    {&__pyx_n_u_szcat_snr, __pyx_k_szcat_snr, sizeof(__pyx_k_szcat_snr), 0, 1, 0, 1},
    {&__pyx_n_s_szcat_z, __pyx_k_szcat_z, sizeof(__pyx_k_szcat_z), 0, 0, 1, 1},
    {&__pyx_n_u_szcat_z, __pyx_k_szcat_z, sizeof(__pyx_k_szcat_z), 0, 1, 0, 1},
    {&__pyx_n_u_szcount, __pyx_k_szcount, sizeof(__pyx_k_szcount), 0, 1, 0, 1},
    {&__pyx_n_s_szcounts_ntot, __pyx_k_szcounts_ntot, sizeof(__pyx_k_szcounts_ntot), 0, 0, 1, 1},
    {&__pyx_n_s_szcounts_ntot_rates_loglike, __pyx_k_szcounts_ntot_rates_loglike, sizeof(__pyx_k_szcounts_ntot_rates_loglike), 0, 0, 1, 1},
    {&__pyx_n_s_szunbinned_loglike, __pyx_k_szunbinned_loglike, sizeof(__pyx_k_szunbinned_loglike), 0, 0, 1, 1},
    {&__pyx_n_u_t2t2f, __pyx_k_t2t2f, sizeof(__pyx_k_t2t2f), 0, 1, 0, 1},
    {&__pyx_n_u_tCl, __pyx_k_tCl, sizeof(__pyx_k_tCl), 0, 1, 0, 1},
    {&__pyx_n_u_tabulate_rhob_xout_at_m_and_z, __pyx_k_tabulate_rhob_xout_at_m_and_z, sizeof(__pyx_k_tabulate_rhob_xout_at_m_and_z), 0, 1, 0, 1},
    {&__pyx_n_s_tanh, __pyx_k_tanh, sizeof(__pyx_k_tanh), 0, 0, 1, 1},
    {&__pyx_n_s_tau, __pyx_k_tau, sizeof(__pyx_k_tau), 0, 0, 1, 1},
    {&__pyx_n_u_tau, __pyx_k_tau, sizeof(__pyx_k_tau), 0, 1, 0, 1},
    {&__pyx_n_u_tau_d, __pyx_k_tau_d, sizeof(__pyx_k_tau_d), 0, 1, 0, 1},
    {&__pyx_n_u_tau_rec, __pyx_k_tau_rec, sizeof(__pyx_k_tau_rec), 0, 1, 0, 1},
    {&__pyx_n_s_tau_reio, __pyx_k_tau_reio, sizeof(__pyx_k_tau_reio), 0, 0, 1, 1},
    {&__pyx_n_u_tau_reio, __pyx_k_tau_reio, sizeof(__pyx_k_tau_reio), 0, 1, 0, 1},
    {&__pyx_n_u_tau_star, __pyx_k_tau_star, sizeof(__pyx_k_tau_star), 0, 1, 0, 1},
    {&__pyx_n_s_tckP, __pyx_k_tckP, sizeof(__pyx_k_tckP), 0, 0, 1, 1},
    {&__pyx_n_u_td, __pyx_k_td, sizeof(__pyx_k_td), 0, 1, 0, 1},
    {&__pyx_n_u_te, __pyx_k_te, sizeof(__pyx_k_te), 0, 1, 0, 1},
    {&__pyx_n_u_te_y_y, __pyx_k_te_y_y, sizeof(__pyx_k_te_y_y), 0, 1, 0, 1},
    {&__pyx_n_u_tensor, __pyx_k_tensor, sizeof(__pyx_k_tensor), 0, 1, 0, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_u_teyy, __pyx_k_teyy, sizeof(__pyx_k_teyy), 0, 1, 0, 1},
    {&__pyx_kp_u_the_s_spectrum_was_computed_unti, __pyx_k_the_s_spectrum_was_computed_unti, sizeof(__pyx_k_the_s_spectrum_was_computed_unti), 0, 1, 0, 0},
    {&__pyx_n_s_thermodynamics, __pyx_k_thermodynamics, sizeof(__pyx_k_thermodynamics), 0, 0, 1, 1},
    {&__pyx_n_u_thermodynamics, __pyx_k_thermodynamics, sizeof(__pyx_k_thermodynamics), 0, 1, 0, 1},
    {&__pyx_n_u_theta, __pyx_k_theta, sizeof(__pyx_k_theta), 0, 1, 0, 1},
    {&__pyx_n_s_theta500, __pyx_k_theta500, sizeof(__pyx_k_theta500), 0, 0, 1, 1},
    {&__pyx_n_s_theta_500, __pyx_k_theta_500, sizeof(__pyx_k_theta_500), 0, 0, 1, 1},
    {&__pyx_n_s_theta_arcmin, __pyx_k_theta_arcmin, sizeof(__pyx_k_theta_arcmin), 0, 0, 1, 1},
    {&__pyx_n_s_theta_mcfit, __pyx_k_theta_mcfit, sizeof(__pyx_k_theta_mcfit), 0, 0, 1, 1},
    {&__pyx_n_s_theta_rad, __pyx_k_theta_rad, sizeof(__pyx_k_theta_rad), 0, 0, 1, 1},
    {&__pyx_n_s_theta_s_100, __pyx_k_theta_s_100, sizeof(__pyx_k_theta_s_100), 0, 0, 1, 1},
    {&__pyx_n_s_theta_star_100, __pyx_k_theta_star_100, sizeof(__pyx_k_theta_star_100), 0, 0, 1, 1},
    {&__pyx_n_s_thetae, __pyx_k_thetae, sizeof(__pyx_k_thetae), 0, 0, 1, 1},
    {&__pyx_n_u_thetas, __pyx_k_thetas, sizeof(__pyx_k_thetas), 0, 1, 0, 1},
    {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
    {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
    {&__pyx_n_s_timesteps, __pyx_k_timesteps, sizeof(__pyx_k_timesteps), 0, 0, 1, 1},
    {&__pyx_n_s_titles, __pyx_k_titles, sizeof(__pyx_k_titles), 0, 0, 1, 1},
    {&__pyx_n_u_tl, __pyx_k_tl, sizeof(__pyx_k_tl), 0, 1, 0, 1},
    {&__pyx_n_s_tllprime_sz, __pyx_k_tllprime_sz, sizeof(__pyx_k_tllprime_sz), 0, 0, 1, 1},
    {&__pyx_n_s_tmp, __pyx_k_tmp, sizeof(__pyx_k_tmp), 0, 0, 1, 1},
    {&__pyx_n_s_tmpdict, __pyx_k_tmpdict, sizeof(__pyx_k_tmpdict), 0, 0, 1, 1},
    {&__pyx_n_u_tp, __pyx_k_tp, sizeof(__pyx_k_tp), 0, 1, 0, 1},
    {&__pyx_n_u_transfer, __pyx_k_transfer, sizeof(__pyx_k_transfer), 0, 1, 0, 1},
    {&__pyx_n_s_transfers, __pyx_k_transfers, sizeof(__pyx_k_transfers), 0, 0, 1, 1},
    {&__pyx_n_s_transforms, __pyx_k_transforms, sizeof(__pyx_k_transforms), 0, 0, 1, 1},
    {&__pyx_n_s_trapz, __pyx_k_trapz, sizeof(__pyx_k_trapz), 0, 0, 1, 1},
    {&__pyx_n_u_tt, __pyx_k_tt, sizeof(__pyx_k_tt), 0, 1, 0, 1},
    {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
    {&__pyx_kp_s_unable_to_allocate_array_data, __pyx_k_unable_to_allocate_array_data, sizeof(__pyx_k_unable_to_allocate_array_data), 0, 0, 1, 0},
    {&__pyx_kp_s_unable_to_allocate_shape_and_str, __pyx_k_unable_to_allocate_shape_and_str, sizeof(__pyx_k_unable_to_allocate_shape_and_str), 0, 0, 1, 0},
    {&__pyx_n_s_units, __pyx_k_units, sizeof(__pyx_k_units), 0, 0, 1, 1},
    {&__pyx_n_s_unpack, __pyx_k_unpack, sizeof(__pyx_k_unpack), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
    {&__pyx_n_s_use_pklin, __pyx_k_use_pklin, sizeof(__pyx_k_use_pklin), 0, 0, 1, 1},
    {&__pyx_n_u_use_pknl_in_2hterms, __pyx_k_use_pknl_in_2hterms, sizeof(__pyx_k_use_pknl_in_2hterms), 0, 1, 0, 1},
    {&__pyx_n_u_use_pknl_in_2hterms_IA_only, __pyx_k_use_pknl_in_2hterms_IA_only, sizeof(__pyx_k_use_pknl_in_2hterms_IA_only), 0, 1, 0, 1},
    {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
    {&__pyx_n_s_val, __pyx_k_val, sizeof(__pyx_k_val), 0, 0, 1, 1},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_n_s_vec_theta, __pyx_k_vec_theta, sizeof(__pyx_k_vec_theta), 0, 0, 1, 1},
    {&__pyx_n_u_vector, __pyx_k_vector, sizeof(__pyx_k_vector), 0, 1, 0, 1},
    {&__pyx_n_s_vectorize, __pyx_k_vectorize, sizeof(__pyx_k_vectorize), 0, 0, 1, 1},
    {&__pyx_n_s_verbosity, __pyx_k_verbosity, sizeof(__pyx_k_verbosity), 0, 0, 1, 1},
    {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
    {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
    {&__pyx_n_s_viewdictitems, __pyx_k_viewdictitems, sizeof(__pyx_k_viewdictitems), 0, 0, 1, 1},
    {&__pyx_n_s_viewitems, __pyx_k_viewitems, sizeof(__pyx_k_viewitems), 0, 0, 1, 1},
    {&__pyx_n_u_vrms2, __pyx_k_vrms2, sizeof(__pyx_k_vrms2), 0, 1, 0, 1},
    {&__pyx_n_s_want_ee, __pyx_k_want_ee, sizeof(__pyx_k_want_ee), 0, 0, 1, 1},
    {&__pyx_n_s_want_pp, __pyx_k_want_pp, sizeof(__pyx_k_want_pp), 0, 0, 1, 1},
    {&__pyx_n_s_want_te, __pyx_k_want_te, sizeof(__pyx_k_want_te), 0, 0, 1, 1},
    {&__pyx_n_s_want_tt, __pyx_k_want_tt, sizeof(__pyx_k_want_tt), 0, 0, 1, 1},
    {&__pyx_n_s_warnings, __pyx_k_warnings, sizeof(__pyx_k_warnings), 0, 0, 1, 1},
    {&__pyx_n_s_window_nfw, __pyx_k_window_nfw, sizeof(__pyx_k_window_nfw), 0, 0, 1, 1},
    {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
    {&__pyx_n_u_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 1, 0, 1},
    {&__pyx_n_s_x_asked, __pyx_k_x_asked, sizeof(__pyx_k_x_asked), 0, 0, 1, 1},
    {&__pyx_n_u_x_outSZ, __pyx_k_x_outSZ, sizeof(__pyx_k_x_outSZ), 0, 1, 0, 1},
    {&__pyx_n_s_x_out_custom1, __pyx_k_x_out_custom1, sizeof(__pyx_k_x_out_custom1), 0, 0, 1, 1},
    {&__pyx_n_s_xc, __pyx_k_xc, sizeof(__pyx_k_xc), 0, 0, 1, 1},
    {&__pyx_n_u_xc_B12, __pyx_k_xc_B12, sizeof(__pyx_k_xc_B12), 0, 1, 0, 1},
    {&__pyx_n_u_xc_B16, __pyx_k_xc_B16, sizeof(__pyx_k_xc_B16), 0, 1, 0, 1},
    {&__pyx_n_s_xe, __pyx_k_xe, sizeof(__pyx_k_xe), 0, 0, 1, 1},
    {&__pyx_n_s_xi, __pyx_k_xi, sizeof(__pyx_k_xi), 0, 0, 1, 1},
    {&__pyx_n_u_xi, __pyx_k_xi, sizeof(__pyx_k_xi), 0, 1, 0, 1},
    {&__pyx_n_u_xi_idr, __pyx_k_xi_idr, sizeof(__pyx_k_xi_idr), 0, 1, 0, 1},
    {&__pyx_n_s_xi_mcfit, __pyx_k_xi_mcfit, sizeof(__pyx_k_xi_mcfit), 0, 0, 1, 1},
    {&__pyx_n_s_xout, __pyx_k_xout, sizeof(__pyx_k_xout), 0, 0, 1, 1},
    {&__pyx_n_s_xrange, __pyx_k_xrange, sizeof(__pyx_k_xrange), 0, 0, 1, 1},
    {&__pyx_n_s_y, __pyx_k_y, sizeof(__pyx_k_y), 0, 0, 1, 1},
    {&__pyx_n_s_y0, __pyx_k_y0, sizeof(__pyx_k_y0), 0, 0, 1, 1},
    {&__pyx_n_s_y0Err, __pyx_k_y0Err, sizeof(__pyx_k_y0Err), 0, 0, 1, 1},
    {&__pyx_n_s_yp, __pyx_k_yp, sizeof(__pyx_k_yp), 0, 0, 1, 1},
    {&__pyx_n_s_ystar, __pyx_k_ystar, sizeof(__pyx_k_ystar), 0, 0, 1, 1},
    {&__pyx_n_s_z, __pyx_k_z, sizeof(__pyx_k_z), 0, 0, 1, 1},
    {&__pyx_n_s_z1, __pyx_k_z1, sizeof(__pyx_k_z1), 0, 0, 1, 1},
    {&__pyx_n_s_z2, __pyx_k_z2, sizeof(__pyx_k_z2), 0, 0, 1, 1},
    {&__pyx_n_s_z_arr, __pyx_k_z_arr, sizeof(__pyx_k_z_arr), 0, 0, 1, 1},
    {&__pyx_n_s_z_array, __pyx_k_z_array, sizeof(__pyx_k_z_array), 0, 0, 1, 1},
    {&__pyx_n_s_z_asked, __pyx_k_z_asked, sizeof(__pyx_k_z_asked), 0, 0, 1, 1},
    {&__pyx_n_s_z_broadcasted, __pyx_k_z_broadcasted, sizeof(__pyx_k_z_broadcasted), 0, 0, 1, 1},
    {&__pyx_n_s_z_center, __pyx_k_z_center, sizeof(__pyx_k_z_center), 0, 0, 1, 1},
    {&__pyx_n_u_z_center, __pyx_k_z_center, sizeof(__pyx_k_z_center), 0, 1, 0, 1},
    {&__pyx_n_u_z_d, __pyx_k_z_d, sizeof(__pyx_k_z_d), 0, 1, 0, 1},
    {&__pyx_n_s_z_edges, __pyx_k_z_edges, sizeof(__pyx_k_z_edges), 0, 0, 1, 1},
    {&__pyx_n_u_z_edges, __pyx_k_z_edges, sizeof(__pyx_k_z_edges), 0, 1, 0, 1},
    {&__pyx_n_s_z_flattened, __pyx_k_z_flattened, sizeof(__pyx_k_z_flattened), 0, 0, 1, 1},
    {&__pyx_n_u_z_for_pk_hm, __pyx_k_z_for_pk_hm, sizeof(__pyx_k_z_for_pk_hm), 0, 1, 0, 1},
    {&__pyx_n_s_z_input, __pyx_k_z_input, sizeof(__pyx_k_z_input), 0, 0, 1, 1},
    {&__pyx_kp_u_z_input_should_be_a_float_or_a_1, __pyx_k_z_input_should_be_a_float_or_a_1, sizeof(__pyx_k_z_input_should_be_a_float_or_a_1), 0, 1, 0, 0},
    {&__pyx_n_s_z_len, __pyx_k_z_len, sizeof(__pyx_k_z_len), 0, 0, 1, 1},
    {&__pyx_n_u_z_max, __pyx_k_z_max, sizeof(__pyx_k_z_max), 0, 1, 0, 1},
    {&__pyx_n_s_z_max_nonlinear, __pyx_k_z_max_nonlinear, sizeof(__pyx_k_z_max_nonlinear), 0, 0, 1, 1},
    {&__pyx_n_s_z_max_requested, __pyx_k_z_max_requested, sizeof(__pyx_k_z_max_requested), 0, 0, 1, 1},
    {&__pyx_n_u_z_min, __pyx_k_z_min, sizeof(__pyx_k_z_min), 0, 1, 0, 1},
    {&__pyx_n_s_z_of_r, __pyx_k_z_of_r, sizeof(__pyx_k_z_of_r), 0, 0, 1, 1},
    {&__pyx_n_s_z_of_tau, __pyx_k_z_of_tau, sizeof(__pyx_k_z_of_tau), 0, 0, 1, 1},
    {&__pyx_n_u_z_rec, __pyx_k_z_rec, sizeof(__pyx_k_z_rec), 0, 1, 0, 1},
    {&__pyx_n_s_z_reio, __pyx_k_z_reio, sizeof(__pyx_k_z_reio), 0, 0, 1, 1},
    {&__pyx_n_u_z_reio, __pyx_k_z_reio, sizeof(__pyx_k_z_reio), 0, 1, 0, 1},
    {&__pyx_n_s_z_size, __pyx_k_z_size, sizeof(__pyx_k_z_size), 0, 0, 1, 1},
    {&__pyx_n_u_z_star, __pyx_k_z_star, sizeof(__pyx_k_z_star), 0, 1, 0, 1},
    {&__pyx_n_s_z_step, __pyx_k_z_step, sizeof(__pyx_k_z_step), 0, 0, 1, 1},
    {&__pyx_n_s_z_vals, __pyx_k_z_vals, sizeof(__pyx_k_z_vals), 0, 0, 1, 1},
    {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
    {&__pyx_n_s_zi, __pyx_k_zi, sizeof(__pyx_k_zi), 0, 0, 1, 1},
    {&__pyx_n_s_zmax, __pyx_k_zmax, sizeof(__pyx_k_zmax), 0, 0, 1, 1},
    {&__pyx_n_s_zmin, __pyx_k_zmin, sizeof(__pyx_k_zmin), 0, 0, 1, 1},
    {&__pyx_n_s_zp, __pyx_k_zp, sizeof(__pyx_k_zp), 0, 0, 1, 1},
    {&__pyx_n_s_zpk, __pyx_k_zpk, sizeof(__pyx_k_zpk), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_AssertionError = __Pyx_GetBuiltinName(__pyx_n_s_AssertionError); if (!__pyx_builtin_AssertionError) __PYX_ERR(0, 356, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 610, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 1101, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 1709, __pyx_L1_error)
  #if PY_MAJOR_VERSION >= 3
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_xrange) __PYX_ERR(0, 1927, __pyx_L1_error)
  #else
  __pyx_builtin_xrange = __Pyx_GetBuiltinName(__pyx_n_s_xrange); if (!__pyx_builtin_xrange) __PYX_ERR(0, 1927, __pyx_L1_error)
  #endif
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 2754, __pyx_L1_error)
  __pyx_builtin_NotImplementedError = __Pyx_GetBuiltinName(__pyx_n_s_NotImplementedError); if (!__pyx_builtin_NotImplementedError) __PYX_ERR(0, 4357, __pyx_L1_error)
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_n_s_import); if (!__pyx_builtin___import__) __PYX_ERR(1, 100, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(1, 156, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(1, 159, __pyx_L1_error)
  __pyx_builtin_Ellipsis = __Pyx_GetBuiltinName(__pyx_n_s_Ellipsis); if (!__pyx_builtin_Ellipsis) __PYX_ERR(1, 408, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(1, 618, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(1, 914, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(2, 1026, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "View.MemoryView":582
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
  __pyx_tuple__4 = PyTuple_New(1); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(1, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_INCREF(__pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_int_neg_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_tuple__4, 0, __pyx_int_neg_1)) __PYX_ERR(1, 582, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "View.MemoryView":679
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)
 * 
 *     result = [slice(None)] * ndim             # <<<<<<<<<<<<<<
 *     have_slices = False
 *     seen_ellipsis = False
 */
  __pyx_slice__5 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__5)) __PYX_ERR(1, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__5);
  __Pyx_GIVEREF(__pyx_slice__5);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  __pyx_tuple__8 = PyTuple_Pack(3, __pyx_int_136983863, __pyx_int_112105877, __pyx_int_184977713); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1026
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy._core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_u_numpy__core_multiarray_failed_to); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(2, 1026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "../../../../../private/var/folders/0g/hj_q_pzx65bbjnslxz9n0src0000gn/T/pip-build-env-efw5rvd0/overlay/lib/python3.9/site-packages/numpy/__init__.cython-30.pxd":1032
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy._core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_u_numpy__core_umath_failed_to_impo); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(2, 1032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "class-sz/python/classy.pyx":72
 * 
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__18 = PyTuple_Pack(2, __pyx_n_u_output, __pyx_kp_u__10); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "class-sz/python/classy.pyx":158
 * import sys
 * def viewdictitems(d):
 *     if sys.version_info >= (3,0):             # <<<<<<<<<<<<<<
 *         return d.items()
 *     else:
 */
  __pyx_tuple__19 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_0); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "class-sz/python/classy.pyx":856
 *                 pknl_in_output = re.compile(r'^hf$').match(self._pars['output'])
 * 
 *                 pknl_key_value_checks = any(self._pars.get(key) == 1 for key in ['use_pknl_in_2hterms_IA_only', 'use_pknl_in_2hterms'])             # <<<<<<<<<<<<<<
 * 
 *                 non_linear_check = 'non_linear' in self._pars
 */
  __pyx_tuple__23 = PyTuple_Pack(2, __pyx_n_u_use_pknl_in_2hterms_IA_only, __pyx_n_u_use_pknl_in_2hterms); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "class-sz/python/classy.pyx":1537
 *             if nofail:
 *                 self._pars_check("l_max_lss",lmax)
 *                 self._pars_check("output",'nCl')             # <<<<<<<<<<<<<<
 *                 self.compute()
 *             else:
 */
  __pyx_tuple__24 = PyTuple_Pack(2, __pyx_n_u_output, __pyx_n_u_nCl); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "class-sz/python/classy.pyx":1548
 *         size = int((self.sp.d_size*(self.sp.d_size+1)-(self.sp.d_size-self.sp.non_diag)*
 *                 (self.sp.d_size-1-self.sp.non_diag))/2);
 *         for elem in ['dd', 'll', 'dl']:             # <<<<<<<<<<<<<<
 *             if elem in spectra:
 *                 cl[elem] = {}
 */
  __pyx_tuple__25 = PyTuple_Pack(3, __pyx_n_u_dd, __pyx_n_u_ll, __pyx_n_u_dl); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 1548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "class-sz/python/classy.pyx":1554
 *                     cl[elem][index] = np.zeros(
 *                         lmax+1, dtype=np.double)
 *         for elem in ['td', 'tl']:             # <<<<<<<<<<<<<<
 *             if elem in spectra:
 *                 cl[elem] = np.zeros(lmax+1, dtype=np.double)
 */
  __pyx_tuple__26 = PyTuple_Pack(2, __pyx_n_u_td, __pyx_n_u_tl); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 1554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "class-sz/python/classy.pyx":1710
 *                 k_array, z_array = np.broadcast_arrays(k_array, z_array)
 *             except ValueError:
 *                 raise ValueError("k and z must be broadcastable to the same shape.")             # <<<<<<<<<<<<<<
 * 
 *         n = k_array.size
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_u_k_and_z_must_be_broadcastable_to); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 1710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "class-sz/python/classy.pyx":2754
 * 
 *         else:
 *             raise TypeError("Input should be a float or a 1D NumPy array of type float64.")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_u_Input_should_be_a_float_or_a_1D); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 2754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "class-sz/python/classy.pyx":3973
 *         # Ensure inputs are 1D arrays of type float64
 *         if not (isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")             # <<<<<<<<<<<<<<
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_kp_u_z_input_should_be_a_float_or_a_1); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 3973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "class-sz/python/classy.pyx":3975
 *             raise TypeError("z_input should be a float or a 1D NumPy array of type float64")
 *         if not (isinstance(m_input, np.ndarray) and m_input.ndim == 1 and m_input.dtype == np.float64):
 *             raise TypeError("m_input should be a float or a 1D NumPy array of type float64")             # <<<<<<<<<<<<<<
 * 
 *         # Use broadcasting to handle different sizes
 */
  __pyx_tuple__30 = PyTuple_Pack(1, __pyx_kp_u_m_input_should_be_a_float_or_a_1); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 3975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "class-sz/python/classy.pyx":4251
 *         """
 *         # Helper function to compute the linear power spectrum for given kh and z
 *         def compute_pkl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk_lin(k, z) * self.ba.h**3
 */
  __pyx_tuple__31 = PyTuple_Pack(3, __pyx_n_s_kh, __pyx_n_s_z, __pyx_n_s_k); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 4251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);
  __pyx_codeobj__32 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_compute_pkl, 4251, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__32)) __PYX_ERR(0, 4251, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4264
 *         if not (isinstance(kh_input, np.ndarray) and kh_input.ndim == 1 and kh_input.dtype == np.float64 and
 *                 isinstance(z_input, np.ndarray) and z_input.ndim == 1 and z_input.dtype == np.float64):
 *             raise TypeError("All inputs should be floats or 1D NumPy arrays of type float64.")             # <<<<<<<<<<<<<<
 * 
 *         # Function to handle all combinations of inputs
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_kp_u_All_inputs_should_be_floats_or_1); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 4264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "class-sz/python/classy.pyx":4267
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */
  __pyx_tuple__34 = PyTuple_Pack(7, __pyx_n_s_kh_vals, __pyx_n_s_z_vals, __pyx_n_s_kh_len, __pyx_n_s_z_len, __pyx_n_s_result, __pyx_n_s_i, __pyx_n_s_j); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 4267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_handle_combinations, 4267, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) __PYX_ERR(0, 4267, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4296
 *         """
 *         # Helper function to compute the non-linear power spectrum for given kh and z
 *         def compute_pknl(double kh, double z):             # <<<<<<<<<<<<<<
 *             k = kh * self.ba.h
 *             return self.pk(k, z) * self.ba.h**3
 */
  __pyx_codeobj__36 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_compute_pknl, 4296, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__36)) __PYX_ERR(0, 4296, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4312
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(kh_vals, z_vals):             # <<<<<<<<<<<<<<
 *             kh_len = len(kh_vals)
 *             z_len = len(z_vals)
 */
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_handle_combinations, 4312, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) __PYX_ERR(0, 4312, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4552
 *         """
 *         # Helper function to calculate the profile for a given set of inputs
 *         def compute_profile(double z, double k, double m, double xout):             # <<<<<<<<<<<<<<
 *             delta_def = self.tsz.delta_def_matter_density
 *             delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */
  __pyx_tuple__38 = PyTuple_Pack(8, __pyx_n_s_z, __pyx_n_s_k, __pyx_n_s_m, __pyx_n_s_xout, __pyx_n_s_delta_def, __pyx_n_s_delta, __pyx_n_s_r_delta, __pyx_n_s_c_delta); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 4552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__38, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_compute_profile, 4552, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(0, 4552, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4560
 * 
 *         # Function to handle all combinations of inputs
 *         def handle_combinations(z_vals, k_vals, m_vals):             # <<<<<<<<<<<<<<
 *             z_len = len(z_vals)
 *             k_len = len(k_vals)
 */
  __pyx_tuple__40 = PyTuple_Pack(10, __pyx_n_s_z_vals, __pyx_n_s_k_vals, __pyx_n_s_m_vals, __pyx_n_s_z_len, __pyx_n_s_k_len, __pyx_n_s_m_len, __pyx_n_s_result, __pyx_n_s_i, __pyx_n_s_j, __pyx_n_s_k); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 4560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__40, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_handle_combinations, 4560, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) __PYX_ERR(0, 4560, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4933
 *         h = self.ba.h
 *         QF = np.loadtxt('/Users/boris/Work/CLASS-SZ/SO-SZ/class_sz/sz_auxiliary_files/so_3freqs_020621_theta500arcmin_Q.txt')
 *         get_Q_of_theta500 = interpolate.interp1d(QF[:,0],QF[:,1],fill_value='extrapolate')             # <<<<<<<<<<<<<<
 *         yp = A*pow(Eh,2.)*pow(m/(3.e14*h),1.+B)*f_rel*get_Q_of_theta500(theta_500)
 *         return yp
 */
  __pyx_tuple__42 = PyTuple_Pack(2, __pyx_slice__5, __pyx_int_0); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);
  __pyx_tuple__43 = PyTuple_Pack(2, __pyx_slice__5, __pyx_int_1); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "class-sz/python/classy.pyx":4950
 *         dndlnM=np.vectorize(self.get_dndlnM_at_z_and_M)(z,M)
 *         dndM=dndlnM/M
 *         ngtm=integrate.cumtrapz(dndlnM[::-1], np.log(M), initial = 0)[::-1]             # <<<<<<<<<<<<<<
 * 
 *         MUpper=np.arange(np.log(M[-1]), np.log(10**18), np.log(M[1])-np.log(M[0]))
 */
  __pyx_slice__44 = PySlice_New(Py_None, Py_None, __pyx_int_neg_1); if (unlikely(!__pyx_slice__44)) __PYX_ERR(0, 4950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__44);
  __Pyx_GIVEREF(__pyx_slice__44);

  /* "class-sz/python/classy.pyx":4985
 *         # returns:
 *         # M500*1e14, M500_errPlus*1e14, M500_errMinus*1e14 in Msun
 *         M500c_zk = np.geomspace(1.00000000e+12,1e16,300)             # <<<<<<<<<<<<<<
 *         log10M500c_zk = np.log10(M500c_zk)
 *         #log10M500c_zk
 */
  __pyx_tuple__45 = PyTuple_Pack(3, __pyx_float_1_00000000e_12, __pyx_float_1e16, __pyx_int_300); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 4985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "class-sz/python/classy.pyx":5188
 *         tmp = <bytes> titles
 *         tmp = str(tmp.decode())
 *         names = tmp.split("\t")[:-1]             # <<<<<<<<<<<<<<
 *         number_of_titles = len(names)
 *         timesteps = self.ba.bt_size
 */
  __pyx_slice__47 = PySlice_New(Py_None, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__47)) __PYX_ERR(0, 5188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__47);
  __Pyx_GIVEREF(__pyx_slice__47);

  /* "class-sz/python/classy.pyx":5328
 *         # Doing the exact same thing 3 times, for scalar, vector and tensor. Sorry
 *         # for copy-and-paste here, but I don't know what else to do.
 *         for mode in ['scalar','vector','tensor']:             # <<<<<<<<<<<<<<
 *             if mode=='scalar' and self.pt.has_scalars:
 *                 thetitles = <bytes> self.pt.scalar_titles
 */
  __pyx_tuple__48 = PyTuple_Pack(3, __pyx_n_u_scalar, __pyx_n_u_vector, __pyx_n_u_tensor); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 5328, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "class-sz/python/classy.pyx":5460
 *         """
 *         if type(names) != type([]):
 *             raise TypeError("Deprecated")             # <<<<<<<<<<<<<<
 * 
 *         derived = {}
 */
  __pyx_tuple__49 = PyTuple_Pack(1, __pyx_n_u_Deprecated); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 5460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "class-sz/python/classy.pyx":5962
 *             params[elem] = data.mcmc_parameters[elem]['current']
 * 
 *         ctx.add('boundary', True)             # <<<<<<<<<<<<<<
 *         # Store itself into the context, to be accessed by the likelihoods
 *         ctx.add('cosmo', self)
 */
  __pyx_tuple__50 = PyTuple_Pack(2, __pyx_n_u_boundary, Py_True); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 5962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
  __pyx_tuple__51 = PyTuple_Pack(1, __pyx_n_s_sys); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(1, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);
  __pyx_tuple__52 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_3); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(1, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "View.MemoryView":101
 * try:
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence             # <<<<<<<<<<<<<<
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 */
  __pyx_tuple__53 = PyTuple_Pack(1, __pyx_kp_s_collections_abc); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(1, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "View.MemoryView":103
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence             # <<<<<<<<<<<<<<
 * except:
 * 
 */
  __pyx_tuple__54 = PyTuple_Pack(1, __pyx_n_s_collections); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(1, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "View.MemoryView":309
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct_or_indirect); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(1, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "View.MemoryView":310
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_tuple__56 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(1, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "View.MemoryView":311
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__57 = PyTuple_Pack(1, __pyx_kp_s_strided_and_indirect); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(1, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "View.MemoryView":314
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_tuple__58 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_direct); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(1, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "View.MemoryView":315
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_indirect); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(1, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__60 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__60, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Enum, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":36
 * import logging
 * 
 * def configure_logging(level=logging.INFO):             # <<<<<<<<<<<<<<
 *     logging.basicConfig(
 *         format='%(levelname)s - %(message)s',
 */
  __pyx_tuple__62 = PyTuple_Pack(1, __pyx_n_s_level); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__62, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_configure_logging, 36, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 36, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":42
 *     )
 * 
 * def set_verbosity(verbosity):             # <<<<<<<<<<<<<<
 *     levels = {
 *         'none': logging.CRITICAL,
 */
  __pyx_tuple__64 = PyTuple_Pack(3, __pyx_n_s_verbosity, __pyx_n_s_levels, __pyx_n_s_level); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__64, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_set_verbosity, 42, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(0, 42, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":52
 *     configure_logging(level)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def suppress_warnings():
 *     warnings.filterwarnings("ignore")
 */
  __pyx_codeobj__17 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_suppress_warnings, 52, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__17)) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":60
 *         warnings.resetwarnings()
 * 
 * with suppress_warnings():             # <<<<<<<<<<<<<<
 *     import classy_szfast
 *     from classy_szfast import Class_szfast
 */
  __pyx_tuple__66 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(0, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "class-sz/python/classy.pyx":67
 * 
 * 
 * def class_sz_in_dict_output(d):             # <<<<<<<<<<<<<<
 *     # Define the allowed keys
 *     non_class_sz_keys = {"mPk", "tCl", "lCl", "pCl"}
 */
  __pyx_tuple__67 = PyTuple_Pack(6, __pyx_n_s_d, __pyx_n_s_non_class_sz_keys, __pyx_n_s_output_string, __pyx_n_s_output_keys, __pyx_n_s_key, __pyx_n_s_key); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);
  __pyx_codeobj__68 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__67, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_class_sz_in_dict_output, 67, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__68)) __PYX_ERR(0, 67, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":89
 * 
 * 
 * def contains_specific_keys(d,specific_keys = {"tCl", "lCl", "pCl", "mPk"}):             # <<<<<<<<<<<<<<
 *     # Define the specific keys to check
 * 
 */
  __pyx_tuple__69 = PyTuple_Pack(6, __pyx_n_s_d, __pyx_n_s_specific_keys, __pyx_n_s_output_string, __pyx_n_s_output_keys, __pyx_n_s_key, __pyx_n_s_key); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);
  __pyx_codeobj__70 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__69, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_contains_specific_keys, 89, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__70)) __PYX_ERR(0, 89, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":109
 * 
 * 
 * def contains_specific_pattern_or_keys(d):             # <<<<<<<<<<<<<<
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")
 */
  __pyx_tuple__71 = PyTuple_Pack(9, __pyx_n_s_d, __pyx_n_s_output_string, __pyx_n_s_output_keys, __pyx_n_s_pattern1, __pyx_n_s_pattern2, __pyx_n_s_pattern3, __pyx_n_s_other_class_sz_keys, __pyx_n_s_key, __pyx_n_s_key); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__71, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_contains_specific_pattern_or_key, 109, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(0, 109, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":157
 * # Nils : Added for python 3.x and python 2.x compatibility
 * import sys
 * def viewdictitems(d):             # <<<<<<<<<<<<<<
 *     if sys.version_info >= (3,0):
 *         return d.items()
 */
  __pyx_tuple__73 = PyTuple_Pack(1, __pyx_n_s_d); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__73, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_viewdictitems, 157, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) __PYX_ERR(0, 157, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":180
 * # MontePython to handle things differently.
 * class CosmoError(Exception):
 *     def __init__(self, message=""):             # <<<<<<<<<<<<<<
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 */
  __pyx_tuple__75 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_message); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);
  __pyx_codeobj__76 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__75, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_init, 180, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__76)) __PYX_ERR(0, 180, __pyx_L1_error)
  __pyx_tuple__77 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u__10)); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "class-sz/python/classy.pyx":183
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '\n\nError in Class: ' + self.message
 * 
 */
  __pyx_tuple__78 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);
  __pyx_codeobj__79 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_str, 183, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__79)) __PYX_ERR(0, 183, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":276
 * 
 * # BB: modified for class_sz
 *     def set_default(self):             # <<<<<<<<<<<<<<
 *         # print('setting default')
 *         _pars = {
 */
  __pyx_tuple__80 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pars); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);
  __pyx_codeobj__81 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__80, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_set_default, 276, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__81)) __PYX_ERR(0, 276, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":376
 * 
 *     # Set up the dictionary
 *     def set(self,*pars,**kars):             # <<<<<<<<<<<<<<
 *         oldpars = self._pars.copy()
 *         if len(pars)==1:
 */
  __pyx_tuple__82 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_pars_2, __pyx_n_s_kars, __pyx_n_s_oldpars); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS|CO_VARKEYWORDS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__82, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_set, 376, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 376, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":390
 *         return True
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         self._pars = {}
 *         self.computed = False
 */
  __pyx_codeobj__84 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_empty, 390, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__84)) __PYX_ERR(0, 390, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":396
 *     # Create an equivalent of the parameter file. Non specified values will be
 *     # taken at their default (in Class)
 *     def _fillparfile(self):             # <<<<<<<<<<<<<<
 *         cdef char* dumc
 * 
 */
  __pyx_tuple__85 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_dumc, __pyx_n_s_i, __pyx_n_s_kk, __pyx_n_s_dumcp); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);
  __pyx_codeobj__86 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__85, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_fillparfile, 396, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__86)) __PYX_ERR(0, 396, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":427
 * 
 *     # Called at the end of a run, to free memory
 *     def struct_cleanup(self):             # <<<<<<<<<<<<<<
 *         # print('cleaning up memoryyyy!!!')
 *         # print('level:',self.ncp)
 */
  __pyx_codeobj__87 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_struct_cleanup, 427, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__87)) __PYX_ERR(0, 427, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":458
 *         self.computed = False
 * 
 *     def _check_task_dependency(self, level):             # <<<<<<<<<<<<<<
 *         """
 *         Fill the level list with all the needed modules
 */
  __pyx_tuple__88 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_level); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_check_task_dependency, 458, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(0, 458, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":518
 *         return level
 * 
 *     def _pars_check(self, key, value, contains=False, add=""):             # <<<<<<<<<<<<<<
 *         val = ""
 *         if key in self._pars:
 */
  __pyx_tuple__90 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_value, __pyx_n_s_contains, __pyx_n_s_add, __pyx_n_s_val, __pyx_n_s_sep); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);
  __pyx_codeobj__91 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__90, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pars_check, 518, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__91)) __PYX_ERR(0, 518, __pyx_L1_error)
  __pyx_tuple__92 = PyTuple_Pack(2, Py_False, __pyx_kp_u__10); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "class-sz/python/classy.pyx":540
 *         return False
 * 
 *     def compute(self, level=["szcount"]):             # <<<<<<<<<<<<<<
 *         """
 *         #compute(level=["lensing"])
 */
  __pyx_tuple__93 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_level, __pyx_n_s_errmsg, __pyx_n_s_problem_flag, __pyx_n_s_problematic_parameters, __pyx_n_s_i); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_compute, 540, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) __PYX_ERR(0, 540, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":715
 * 
 * 
 *     def calculate_pkl_fftlog_alphas(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         cnew = self.class_szfast.calculate_pkl_fftlog_alphas(zpk=zpk,**params_settings)
 */
  __pyx_tuple__95 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_zpk, __pyx_n_s_params_settings, __pyx_n_s_cnew); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_calculate_pkl_fftlog_alphas, 715, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) __PYX_ERR(0, 715, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":720
 *         return self.class_szfast.cp_pkl_fftlog_alphas_nus[self.class_szfast.cosmo_model]['arr_0'],cnew
 * 
 *     def get_pkl_reconstructed_from_fftlog(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         return self.class_szfast.get_pkl_reconstructed_from_fftlog(zpk=zpk,**params_settings)
 */
  __pyx_tuple__97 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_zpk, __pyx_n_s_params_settings); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pkl_reconstructed_from_fftlo, 720, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) __PYX_ERR(0, 720, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":727
 *     # @cython.wraparound(False)
 *     # the likelihood_mode parameter is used to identify whether we run within cobaya
 *     def compute_class_szfast(self,likelihood_mode=False):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__99 = PyTuple_Pack(22, __pyx_n_s_self, __pyx_n_s_likelihood_mode, __pyx_n_s_non_linear_check, __pyx_n_s_pknl_in_output, __pyx_n_s_pknl_key_value_checks, __pyx_n_s_skip_background_and_thermo, __pyx_n_s_params_settings, __pyx_n_s_cszfast, __pyx_n_s_start, __pyx_n_s_end, __pyx_n_s_index_z_r, __pyx_n_s_index_z, __pyx_n_s_ln1pzc, __pyx_n_s_index_r, __pyx_n_s_z, __pyx_n_s_index_m_z, __pyx_n_s_index_m, __pyx_n_s_m, __pyx_n_s_index_x, __pyx_n_s_x, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);
  __pyx_codeobj__100 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 22, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__99, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_compute_class_szfast, 727, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__100)) __PYX_ERR(0, 727, __pyx_L1_error)
  __pyx_tuple__101 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "class-sz/python/classy.pyx":1097
 * 
 * 
 *     def compute_class_sz(self,pdict_to_update):             # <<<<<<<<<<<<<<
 *         integrate_only = False
 *         try:
 */
  __pyx_tuple__102 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_pdict_to_update, __pyx_n_s_integrate_only, __pyx_n_s_N_ngal, __pyx_n_s_k, __pyx_n_s_v, __pyx_n_s_index_g); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);
  __pyx_codeobj__103 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__102, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_compute_class_sz, 1097, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__103)) __PYX_ERR(0, 1097, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1287
 * 
 * 
 *     def raw_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         raw_cl(lmax=-1, nofail=False)
 */
  __pyx_tuple__104 = PyTuple_Pack(16, __pyx_n_s_self, __pyx_n_s_lmax, __pyx_n_s_nofail, __pyx_n_s_lmaxR, __pyx_n_s_rcl, __pyx_n_s_cl_md, __pyx_n_s_index_md, __pyx_n_s_cl_md_ic, __pyx_n_s_has_flags, __pyx_n_s_spectra, __pyx_n_s_flag, __pyx_n_s_index, __pyx_n_s_name, __pyx_n_s_cl, __pyx_n_s_elem, __pyx_n_s_ell); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);
  __pyx_codeobj__105 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 16, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__104, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_raw_cl, 1287, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__105)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __pyx_tuple__106 = PyTuple_Pack(2, __pyx_int_neg_1, Py_False); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "class-sz/python/classy.pyx":1377
 *         return cl
 * 
 *     def lensed_cl(self, lmax=-1,nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         lensed_cl(lmax=-1, nofail=False)
 */
  __pyx_tuple__107 = PyTuple_Pack(16, __pyx_n_s_self, __pyx_n_s_lmax, __pyx_n_s_nofail, __pyx_n_s_lmaxR, __pyx_n_s_lcl, __pyx_n_s_cls, __pyx_n_s_nl, __pyx_n_s_lcp, __pyx_n_s_has_flags, __pyx_n_s_spectra, __pyx_n_s_flag, __pyx_n_s_index, __pyx_n_s_name, __pyx_n_s_cl, __pyx_n_s_elem, __pyx_n_s_ell); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);
  __pyx_codeobj__108 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 16, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__107, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_lensed_cl, 1377, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__108)) __PYX_ERR(0, 1377, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1477
 *           return cl
 * 
 *     def density_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         density_cl(lmax=-1, nofail=False)
 */
  __pyx_tuple__109 = PyTuple_Pack(18, __pyx_n_s_self, __pyx_n_s_lmax, __pyx_n_s_nofail, __pyx_n_s_lmaxR, __pyx_n_s_dcl, __pyx_n_s_cl_md, __pyx_n_s_index_md, __pyx_n_s_cl_md_ic, __pyx_n_s_has_flags, __pyx_n_s_spectra, __pyx_n_s_flag, __pyx_n_s_index, __pyx_n_s_name, __pyx_n_s_l_max_flag, __pyx_n_s_cl, __pyx_n_s_size, __pyx_n_s_elem, __pyx_n_s_ell); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);
  __pyx_codeobj__110 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 18, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__109, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_density_cl, 1477, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__110)) __PYX_ERR(0, 1477, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1585
 *         return cl
 * 
 *     def z_of_r (self,z_array):             # <<<<<<<<<<<<<<
 *         """
 *         returns chi [Mpc] vs dzdchi [1/Mpc]
 */
  __pyx_tuple__111 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_z_array, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_r, __pyx_n_s_dzdr, __pyx_n_s_i, __pyx_n_s_redshift); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(0, 1585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);
  __pyx_codeobj__112 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__111, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_z_of_r, 1585, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__112)) __PYX_ERR(0, 1585, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1625
 *         return r[:],dzdr[:]
 * 
 *     def luminosity_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         luminosity_distance(z)
 */
  __pyx_tuple__113 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_lum_distance); if (unlikely(!__pyx_tuple__113)) __PYX_ERR(0, 1625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__113);
  __Pyx_GIVEREF(__pyx_tuple__113);
  __pyx_codeobj__114 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__113, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_luminosity_distance, 1625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__114)) __PYX_ERR(0, 1625, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1643
 *         return lum_distance
 * 
 *     def get_pkl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */
  __pyx_tuple__115 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z_asked, __pyx_n_s_params_values_dict); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(0, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);
  __pyx_codeobj__116 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__115, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pkl_at_z, 1643, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__116)) __PYX_ERR(0, 1643, __pyx_L1_error)
  __pyx_tuple__117 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);

  /* "class-sz/python/classy.pyx":1646
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 *     def get_pknl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pknl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */
  __pyx_codeobj__118 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__115, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pknl_at_z, 1646, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__118)) __PYX_ERR(0, 1646, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1650
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */
  __pyx_tuple__119 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk, __pyx_n_s_zmax, __pyx_n_s_pk_linzmax, __pyx_n_s_Dz, __pyx_n_s_Dzmax); if (unlikely(!__pyx_tuple__119)) __PYX_ERR(0, 1650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);
  __pyx_codeobj__120 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_unvectorized, 1650, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__120)) __PYX_ERR(0, 1650, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1687
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */
  __pyx_tuple__121 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk, __pyx_n_s_k_array, __pyx_n_s_z_array, __pyx_n_s_pk_array, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_zmax, __pyx_n_s_pk_linzmax, __pyx_n_s_Dz, __pyx_n_s_Dzmax); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(0, 1687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);
  __pyx_codeobj__122 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk, 1687, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__122)) __PYX_ERR(0, 1687, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1747
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */
  __pyx_tuple__123 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk_cb); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 1747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);
  __pyx_codeobj__124 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__123, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_cb, 1747, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__124)) __PYX_ERR(0, 1747, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1774
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */
  __pyx_tuple__125 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk_lin, __pyx_n_s_zmax, __pyx_n_s_pk_linzmax, __pyx_n_s_Dz, __pyx_n_s_Dzmax); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(0, 1774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);
  __pyx_codeobj__126 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__125, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_lin_unvectorized, 1774, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__126)) __PYX_ERR(0, 1774, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1810
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */
  __pyx_tuple__127 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk_lin, __pyx_n_s_k_array, __pyx_n_s_z_array, __pyx_n_s_pk_lin_array, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_zmax, __pyx_n_s_pk_linzmax, __pyx_n_s_Dz, __pyx_n_s_Dzmax); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);
  __pyx_codeobj__128 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__127, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_lin, 1810, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__128)) __PYX_ERR(0, 1810, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1867
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_nonlin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */
  __pyx_tuple__129 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk_lin); if (unlikely(!__pyx_tuple__129)) __PYX_ERR(0, 1867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);
  __pyx_codeobj__130 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__129, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_nonlin, 1867, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__130)) __PYX_ERR(0, 1867, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1888
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb_lin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */
  __pyx_tuple__131 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk_cb_lin); if (unlikely(!__pyx_tuple__131)) __PYX_ERR(0, 1888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__131);
  __Pyx_GIVEREF(__pyx_tuple__131);
  __pyx_codeobj__132 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__131, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_cb_lin, 1888, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__132)) __PYX_ERR(0, 1888, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1922
 *     #    return pk
 * 
 *     def get_pk_cb(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */
  __pyx_tuple__133 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_k_size, __pyx_n_s_z_size, __pyx_n_s_mu_size, __pyx_n_s_pk_cb, __pyx_n_s_index_k, __pyx_n_s_index_z, __pyx_n_s_index_mu); if (unlikely(!__pyx_tuple__133)) __PYX_ERR(0, 1922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__133);
  __Pyx_GIVEREF(__pyx_tuple__133);
  __pyx_codeobj__134 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__133, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_cb, 1922, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__134)) __PYX_ERR(0, 1922, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1933
 *         return pk_cb
 * 
 *     def get_pk_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk = np.zeros((k_size,z_size,mu_size),'float64')
 */
  __pyx_tuple__135 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_k_size, __pyx_n_s_z_size, __pyx_n_s_mu_size, __pyx_n_s_pk, __pyx_n_s_index_k, __pyx_n_s_index_z, __pyx_n_s_index_mu); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(0, 1933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);
  __pyx_codeobj__136 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__135, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_lin, 1933, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__136)) __PYX_ERR(0, 1933, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1944
 *         return pk
 * 
 *     def get_pk_cb_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */
  __pyx_codeobj__137 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__133, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_cb_lin, 1944, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__137)) __PYX_ERR(0, 1944, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":1955
 *         return pk_cb
 * 
 *     def get_pk_and_k_and_z(self, nonlinear=True, only_clustering_species = False,h_units=False):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a grid of matter power spectrum values and the z and k
 */
  __pyx_tuple__138 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_nonlinear, __pyx_n_s_only_clustering_species, __pyx_n_s_h_units, __pyx_n_s_pk_at_k_z, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_index_k, __pyx_n_s_index_tau, __pyx_n_s_index_pk, __pyx_n_s_z_max_nonlinear, __pyx_n_s_z_max_requested, __pyx_n_s_units); if (unlikely(!__pyx_tuple__138)) __PYX_ERR(0, 1955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__138);
  __Pyx_GIVEREF(__pyx_tuple__138);
  __pyx_codeobj__139 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__138, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_and_k_and_z, 1955, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__139)) __PYX_ERR(0, 1955, __pyx_L1_error)
  __pyx_tuple__140 = PyTuple_Pack(3, Py_True, Py_False, Py_False); if (unlikely(!__pyx_tuple__140)) __PYX_ERR(0, 1955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__140);
  __Pyx_GIVEREF(__pyx_tuple__140);

  /* "class-sz/python/classy.pyx":2034
 * 
 *     # Gives sigma(R,z) for a given (R,z)
 *     def sigma(self,double R,double z, h_units = False):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (total matter) for a given R and z
 */
  __pyx_tuple__141 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_R, __pyx_n_s_z, __pyx_n_s_h_units, __pyx_n_s_sigma); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);
  __pyx_codeobj__142 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__141, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_sigma, 2034, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__142)) __PYX_ERR(0, 2034, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2069
 * 
 *     # Gives sigma_cb(R,z) for a given (R,z)
 *     def sigma_cb(self,double R,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (cdm+b) for a given R and z
 */
  __pyx_tuple__143 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_R, __pyx_n_s_z, __pyx_n_s_sigma_cb); if (unlikely(!__pyx_tuple__143)) __PYX_ERR(0, 2069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__143);
  __Pyx_GIVEREF(__pyx_tuple__143);
  __pyx_codeobj__144 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__143, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_sigma_cb, 2069, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__144)) __PYX_ERR(0, 2069, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2098
 * 
 *     # Gives effective logarithmic slope of P_L(k,z) (total matter) for a given (k,z)
 *     def pk_tilt(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives effective logarithmic slope of P_L(k,z) (total matter) for a given k and z
 */
  __pyx_tuple__145 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_pk_tilt); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(0, 2098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);
  __pyx_codeobj__146 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__145, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_tilt, 2098, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__146)) __PYX_ERR(0, 2098, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2122
 * 
 *     #calculates the hmcode window_function of the Navarrow Frenk White Profile
 *     def nonlinear_hmcode_window_nfw(self,double k,double rv,double c):             # <<<<<<<<<<<<<<
 *         """
 *         Gives window_nfw for a given wavevector k, virial radius rv and concentration c
 */
  __pyx_tuple__147 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_rv, __pyx_n_s_c, __pyx_n_s_window_nfw); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);
  __pyx_codeobj__148 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__147, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_window_nfw, 2122, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__148)) __PYX_ERR(0, 2122, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2138
 *     #################################
 *     # gives an estimation of f(z)*sigma8(z) at the scale of 8 h/Mpc, computed as (d sigma8/d ln a)
 *     def effective_f_sigma8(self, z, z_step=0.1):             # <<<<<<<<<<<<<<
 *         """
 *         effective_f_sigma8(z)
 */
  __pyx_tuple__149 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_z_step); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(0, 2138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);
  __pyx_codeobj__150 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__149, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_effective_f_sigma8, 2138, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__150)) __PYX_ERR(0, 2138, __pyx_L1_error)
  __pyx_tuple__151 = PyTuple_Pack(1, __pyx_float_0_1); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(0, 2138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);

  /* "class-sz/python/classy.pyx":2177
 * 
 * 
 *     def age(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.ba.age
 */
  __pyx_codeobj__152 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_age, 2177, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__152)) __PYX_ERR(0, 2177, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2184
 *           return self.ba.age
 * 
 *     def h(self):             # <<<<<<<<<<<<<<
 *         return self.ba.h
 * 
 */
  __pyx_codeobj__153 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_h, 2184, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__153)) __PYX_ERR(0, 2184, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2187
 *         return self.ba.h
 * 
 *     def n_s(self):             # <<<<<<<<<<<<<<
 *         return self.pm.n_s
 * 
 */
  __pyx_codeobj__154 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_n_s, 2187, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__154)) __PYX_ERR(0, 2187, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2190
 *         return self.pm.n_s
 * 
 *     def tau_reio(self):             # <<<<<<<<<<<<<<
 *         return self.th.tau_reio
 * 
 */
  __pyx_codeobj__155 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_tau_reio, 2190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__155)) __PYX_ERR(0, 2190, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2193
 *         return self.th.tau_reio
 * 
 *     def Omega_m(self):             # <<<<<<<<<<<<<<
 * 
 *         if self._pars['skip_background_and_thermo']:
 */
  __pyx_tuple__156 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_params_settings, __pyx_n_s_result); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);
  __pyx_codeobj__157 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__156, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega_m, 2193, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__157)) __PYX_ERR(0, 2193, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2207
 *           return self.ba.Omega0_m
 * 
 *     def Omega_r(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_r
 * 
 */
  __pyx_codeobj__158 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega_r, 2207, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__158)) __PYX_ERR(0, 2207, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2210
 *         return self.ba.Omega0_r
 * 
 *     def theta_s_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 */
  __pyx_codeobj__159 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_theta_s_100, 2210, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__159)) __PYX_ERR(0, 2210, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2213
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 *     def theta_star_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 */
  __pyx_codeobj__160 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_theta_star_100, 2213, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__160)) __PYX_ERR(0, 2213, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2216
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 *     def Omega_Lambda(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_lambda
 * 
 */
  __pyx_codeobj__161 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega_Lambda, 2216, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__161)) __PYX_ERR(0, 2216, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2219
 *         return self.ba.Omega0_lambda
 * 
 *     def Omega_g(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_g
 * 
 */
  __pyx_codeobj__162 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega_g, 2219, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__162)) __PYX_ERR(0, 2219, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2222
 *         return self.ba.Omega0_g
 * 
 *     def Omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b
 * 
 */
  __pyx_codeobj__163 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega_b, 2222, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__163)) __PYX_ERR(0, 2222, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2225
 *         return self.ba.Omega0_b
 * 
 *     def omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 */
  __pyx_codeobj__164 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_omega_b, 2225, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__164)) __PYX_ERR(0, 2225, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2228
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 *     def omega_cdm(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 */
  __pyx_codeobj__165 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_omega_cdm, 2228, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__165)) __PYX_ERR(0, 2228, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2231
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 *     def Neff(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.Neff_fast
 */
  __pyx_codeobj__166 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Neff, 2231, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__166)) __PYX_ERR(0, 2231, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2237
 *           return self.ba.Neff
 * 
 *     def k_eq(self):             # <<<<<<<<<<<<<<
 *         self.compute(["background"])
 *         return self.ba.a_eq*self.ba.H_eq
 */
  __pyx_codeobj__167 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_k_eq, 2237, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__167)) __PYX_ERR(0, 2237, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2241
 *         return self.ba.a_eq*self.ba.H_eq
 * 
 *     def sigma8(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.sigma8_fast
 */
  __pyx_codeobj__168 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_sigma8, 2241, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__168)) __PYX_ERR(0, 2241, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2248
 *           return self.nl.sigma8[self.nl.index_pk_m]
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 */
  __pyx_tuple__169 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_z); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(0, 2248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);
  __pyx_codeobj__170 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_sigma8_at_z, 2248, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__170)) __PYX_ERR(0, 2248, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2251
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 *     def get_effective_f_sigma8(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_effective_f_sigma8(z)
 * 
 */
  __pyx_codeobj__171 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_effective_f_sigma8, 2251, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__171)) __PYX_ERR(0, 2251, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2255
 * 
 * 
 *     def get_fstar_of_m_at_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_fstar_of_m_at_z(m,z,&self.tsz)
 * 
 */
  __pyx_tuple__172 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_m, __pyx_n_s_z); if (unlikely(!__pyx_tuple__172)) __PYX_ERR(0, 2255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__172);
  __Pyx_GIVEREF(__pyx_tuple__172);
  __pyx_codeobj__173 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_fstar_of_m_at_z, 2255, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__173)) __PYX_ERR(0, 2255, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2264
 *     #    return self.sp.neff
 * 
 *     def sigma8_cb(self):             # <<<<<<<<<<<<<<
 *         self.compute(["nonlinear"])
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 */
  __pyx_codeobj__174 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_sigma8_cb, 2264, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__174)) __PYX_ERR(0, 2264, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2268
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 * 
 *     def rs_drag(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if self.tsz.skip_background_and_thermo:
 */
  __pyx_codeobj__175 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_rs_drag, 2268, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__175)) __PYX_ERR(0, 2268, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2278
 *           return self.th.rs_d
 * 
 *     def z_reio(self):             # <<<<<<<<<<<<<<
 *         self.compute(["thermodynamics"])
 *         return self.th.z_reio
 */
  __pyx_codeobj__176 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_z_reio, 2278, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__176)) __PYX_ERR(0, 2278, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2282
 *         return self.th.z_reio
 * 
 *     def get_chi(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         chi(z) in h-units
 */
  __pyx_tuple__177 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_h, __pyx_n_s_zi); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 2282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);
  __pyx_codeobj__178 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__177, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_chi, 2282, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__178)) __PYX_ERR(0, 2282, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2303
 * 
 * 
 *     def angular_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z)
 */
  __pyx_tuple__179 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_D_A); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(0, 2303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);
  __pyx_codeobj__180 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__179, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_angular_distance, 2303, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__180)) __PYX_ERR(0, 2303, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2341
 *         return D_A
 * 
 *     def get_radial_kernel_W_galaxy_ngal_at_z(self, z, index_g):             # <<<<<<<<<<<<<<
 *         """
 * 
 */
  __pyx_tuple__181 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_index_g, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_Wg); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 2341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);
  __pyx_codeobj__182 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__181, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_radial_kernel_W_galaxy_ngal, 2341, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__182)) __PYX_ERR(0, 2341, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2376
 * 
 * 
 *     def scale_independent_growth_factor(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor(z)
 */
  __pyx_tuple__183 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_D); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 2376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);
  __pyx_codeobj__184 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__183, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_scale_independent_growth_factor, 2376, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__184)) __PYX_ERR(0, 2376, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2406
 *         return D
 * 
 *     def scale_independent_growth_factor_f(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor_f(z)
 */
  __pyx_tuple__185 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_f); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);
  __pyx_codeobj__186 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_scale_independent_growth_factor_2, 2406, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__186)) __PYX_ERR(0, 2406, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2436
 *         return f
 * 
 *     def z_of_tau(self, tau):             # <<<<<<<<<<<<<<
 *         """
 *         Redshift corresponding to a given conformal time.
 */
  __pyx_tuple__187 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_tau, __pyx_n_s_z, __pyx_n_s_last_index, __pyx_n_s_pvecback); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(0, 2436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);
  __pyx_codeobj__188 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__187, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_z_of_tau, 2436, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__188)) __PYX_ERR(0, 2436, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2460
 *         return z
 * 
 *     def get_Ez(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         E(z)
 */
  __pyx_codeobj__189 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_Ez, 2460, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__189)) __PYX_ERR(0, 2460, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2474
 * 
 * 
 *     def Hubble(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Hubble(z)
 */
  __pyx_tuple__190 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_z_array, __pyx_n_s_H_array, __pyx_n_s_i); if (unlikely(!__pyx_tuple__190)) __PYX_ERR(0, 2474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__190);
  __Pyx_GIVEREF(__pyx_tuple__190);
  __pyx_codeobj__191 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__190, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Hubble, 2474, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__191)) __PYX_ERR(0, 2474, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2537
 *             return H_array
 * 
 *     def get_H(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         get_H(z)
 */
  __pyx_tuple__192 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_z_array, __pyx_n_s_H_over_c_in_h_over_Mpc_array, __pyx_n_s_i, __pyx_n_s_H, __pyx_n_s_h); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);
  __pyx_codeobj__193 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_H, 2537, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__193)) __PYX_ERR(0, 2537, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2575
 *             return H_over_c_in_h_over_Mpc_array
 * 
 *     def Om_m(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Omega_m(z)
 */
  __pyx_tuple__194 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_Om_m); if (unlikely(!__pyx_tuple__194)) __PYX_ERR(0, 2575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__194);
  __Pyx_GIVEREF(__pyx_tuple__194);
  __pyx_codeobj__195 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__194, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Om_m, 2575, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__195)) __PYX_ERR(0, 2575, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2606
 * 
 * 
 *     def ionization_fraction(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         ionization_fraction(z)
 */
  __pyx_tuple__196 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_pvecthermo, __pyx_n_s_xe); if (unlikely(!__pyx_tuple__196)) __PYX_ERR(0, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__196);
  __Pyx_GIVEREF(__pyx_tuple__196);
  __pyx_codeobj__197 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__196, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_ionization_fraction, 2606, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__197)) __PYX_ERR(0, 2606, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2641
 *         return xe
 * 
 *     def baryon_temperature(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         baryon_temperature(z)
 */
  __pyx_tuple__198 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_pvecthermo, __pyx_n_s_Tb); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(0, 2641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);
  __pyx_codeobj__199 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__198, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_baryon_temperature, 2641, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__199)) __PYX_ERR(0, 2641, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2676
 *         return Tb
 * 
 *     def T_cmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the CMB temperature
 */
  __pyx_codeobj__200 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_T_cmb, 2676, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__200)) __PYX_ERR(0, 2676, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2684
 *     # redundent with a previous Omega_m() funciton,
 *     # but we leave it not to break compatibility
 *     def Omega0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the sum of Omega0 for all non-relativistic components
 */
  __pyx_codeobj__201 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega0_m, 2684, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__201)) __PYX_ERR(0, 2684, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2691
 * 
 * 
 *     def cl_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the 1-halo and 2-halo terms of tSZ power spectrum
 */
  __pyx_tuple__202 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__202)) __PYX_ERR(0, 2691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__202);
  __Pyx_GIVEREF(__pyx_tuple__202);
  __pyx_codeobj__203 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_sz, 2691, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__203)) __PYX_ERR(0, 2691, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2706
 * 
 * 
 *     def dl_isw_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (ISW x SZ) Return the ISW x tSZ power spectrum
 */
  __pyx_tuple__204 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_dl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__204)) __PYX_ERR(0, 2706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__204);
  __Pyx_GIVEREF(__pyx_tuple__204);
  __pyx_codeobj__205 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__204, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_dl_isw_sz, 2706, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__205)) __PYX_ERR(0, 2706, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2718
 *         return dl
 * 
 *     def cl_sz_at_nu_in_GHz_in_microK2(self,nu_in_GHz):             # <<<<<<<<<<<<<<
 *         frequency_in_Hz = nu_in_GHz*1e9
 *         T_cmb = self.T_cmb()
 */
  __pyx_tuple__206 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_nu_in_GHz, __pyx_n_s_frequency_in_Hz, __pyx_n_s_T_cmb, __pyx_n_s_h_P, __pyx_n_s_k_B, __pyx_n_s_Tcmb_gNU, __pyx_n_s_r); if (unlikely(!__pyx_tuple__206)) __PYX_ERR(0, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__206);
  __Pyx_GIVEREF(__pyx_tuple__206);
  __pyx_codeobj__207 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__206, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2, 2718, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__207)) __PYX_ERR(0, 2718, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2730
 *         return r
 * 
 *     def get_volume_dVdzdOmega_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_volume_at_z(z,&self.ba)
 * 
 */
  __pyx_codeobj__208 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_volume_dVdzdOmega_at_z, 2730, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__208)) __PYX_ERR(0, 2730, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2734
 * 
 * 
 *     def get_z_of_chi_unvectorized(self,chi):             # <<<<<<<<<<<<<<
 *         return get_z_of_chi(chi,&self.tsz,&self.ba)
 * 
 */
  __pyx_tuple__209 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_chi); if (unlikely(!__pyx_tuple__209)) __PYX_ERR(0, 2734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__209);
  __Pyx_GIVEREF(__pyx_tuple__209);
  __pyx_codeobj__210 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__209, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_z_of_chi_unvectorized, 2734, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__210)) __PYX_ERR(0, 2734, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2738
 * 
 * 
 *     def get_z_of_chi(self,chi):             # <<<<<<<<<<<<<<
 *          # Check if input is a scalar
 *         if isinstance(chi, (float, np.float64)):
 */
  __pyx_tuple__211 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_chi, __pyx_n_s_n, __pyx_n_s_result, __pyx_n_s_i); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(0, 2738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);
  __pyx_codeobj__212 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__211, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_z_of_chi, 2738, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__212)) __PYX_ERR(0, 2738, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2760
 * 
 *     # Define the vectorized method
 *     def get_comoving_volume(self, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the comoving volume at given redshifts.
 */
  __pyx_tuple__213 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_z_input, __pyx_n_s_n, __pyx_n_s_result, __pyx_n_s_i); if (unlikely(!__pyx_tuple__213)) __PYX_ERR(0, 2760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__213);
  __Pyx_GIVEREF(__pyx_tuple__213);
  __pyx_codeobj__214 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__213, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_comoving_volume, 2760, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__214)) __PYX_ERR(0, 2760, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2794
 * 
 * 
 *     def get_IA_of_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_IA_of_z(z,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__215 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_IA_of_z, 2794, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__215)) __PYX_ERR(0, 2794, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2798
 * 
 * 
 *     def get_f_of_sigma_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 */
  __pyx_codeobj__216 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_f_of_sigma_at_m_and_z, 2798, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__216)) __PYX_ERR(0, 2798, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2801
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_delta_mean_from_delta_crit_at_z(self,delta_crit,z):             # <<<<<<<<<<<<<<
 *         return get_delta_mean_from_delta_crit_at_z(delta_crit,z,&self.tsz)
 * 
 */
  __pyx_tuple__217 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_delta_crit, __pyx_n_s_z); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 2801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);
  __pyx_codeobj__218 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__217, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_delta_mean_from_delta_crit_a, 2801, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__218)) __PYX_ERR(0, 2801, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2805
 * 
 * 
 *     def get_galaxy_number_counts(self,z):             # <<<<<<<<<<<<<<
 *         return get_galaxy_number_counts(z,&self.tsz)
 * 
 */
  __pyx_codeobj__219 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_galaxy_number_counts, 2805, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__219)) __PYX_ERR(0, 2805, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2809
 * 
 * 
 *     def get_cov_N_N(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the covariance of cluster number counts
 */
  __pyx_tuple__220 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_cl, __pyx_n_s_index_M_bins, __pyx_n_s_index_M_bins_prime); if (unlikely(!__pyx_tuple__220)) __PYX_ERR(0, 2809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__220);
  __Pyx_GIVEREF(__pyx_tuple__220);
  __pyx_codeobj__221 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__220, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_cov_N_N, 2809, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__221)) __PYX_ERR(0, 2809, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2834
 *         return cl
 * 
 *     def cl_kg_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x galaxy-lensing power spectrum
 */
  __pyx_codeobj__222 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kg_kg, 2834, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__222)) __PYX_ERR(0, 2834, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2848
 *         return cl
 * 
 *     def cl_kg_k(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x cmb-lensing power spectrum
 */
  __pyx_codeobj__223 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kg_k, 2848, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__223)) __PYX_ERR(0, 2848, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2862
 *         return cl
 * 
 *     def cl_yg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x g power spectrum
 */
  __pyx_codeobj__224 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_yg, 2862, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__224)) __PYX_ERR(0, 2862, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2876
 *         return cl
 * 
 *     def cl_IA_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of IA x g power spectrum
 */
  __pyx_codeobj__225 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_IA_g, 2876, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__225)) __PYX_ERR(0, 2876, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2890
 *         return cl
 * 
 *     def cl_kg_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy lensing x lensing magnifications spectrum
 */
  __pyx_codeobj__226 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kg_m, 2890, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__226)) __PYX_ERR(0, 2890, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2904
 *         return cl
 * 
 *     def cl_ykg(self,             # <<<<<<<<<<<<<<
 *                Nmcfit = 1024,
 *                log10xmin_mcfit = -6,
 */
  __pyx_tuple__227 = PyTuple_Pack(20, __pyx_n_s_self, __pyx_n_s_Nmcfit, __pyx_n_s_log10xmin_mcfit, __pyx_n_s_log10xmax_mcfit, __pyx_n_s_log10x_num, __pyx_n_s_cl, __pyx_n_s_index, __pyx_n_s_cl_g_gamma_ell, __pyx_n_s_cl_g_gamma_1h, __pyx_n_s_cl_g_gamma_2h, __pyx_n_s_fac, __pyx_n_s_cltot, __pyx_n_s_cltotfunc, __pyx_n_s_mcfitx, __pyx_n_s_F, __pyx_n_s_H, __pyx_n_s_y, __pyx_n_s_G, __pyx_n_s_theta_mcfit, __pyx_n_s_xi_mcfit); if (unlikely(!__pyx_tuple__227)) __PYX_ERR(0, 2904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__227);
  __Pyx_GIVEREF(__pyx_tuple__227);
  __pyx_codeobj__228 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 20, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__227, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_ykg, 2904, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__228)) __PYX_ERR(0, 2904, __pyx_L1_error)
  __pyx_tuple__229 = PyTuple_Pack(4, __pyx_int_1024, __pyx_int_neg_6, __pyx_int_6, __pyx_int_600); if (unlikely(!__pyx_tuple__229)) __PYX_ERR(0, 2904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__229);
  __Pyx_GIVEREF(__pyx_tuple__229);

  /* "class-sz/python/classy.pyx":2943
 * 
 * 
 *     def cl_kSZ_kSZ_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x g power spectrum
 */
  __pyx_codeobj__230 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kSZ_kSZ_g, 2943, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__230)) __PYX_ERR(0, 2943, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2971
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kg power spectrum
 */
  __pyx_codeobj__231 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kSZ_kSZ_kg, 2971, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__231)) __PYX_ERR(0, 2971, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":2993
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kcmb power spectrum
 */
  __pyx_codeobj__232 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kSZ_kSZ_kcmb, 2993, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__232)) __PYX_ERR(0, 2993, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3015
 *         return cl
 * 
 *     def cl_gal_gal_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of gal x gal x kcmb power spectrum
 */
  __pyx_codeobj__233 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_gal_gal_kcmb, 3015, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__233)) __PYX_ERR(0, 3015, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3032
 * 
 * 
 *     def cl_te_y_y(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return Te x y x y power spectrum
 */
  __pyx_codeobj__234 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_te_y_y, 3032, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__234)) __PYX_ERR(0, 3032, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3044
 *         return cl
 * 
 *     def cl_ym(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x mu (lensing magnification) power spectrum
 */
  __pyx_codeobj__235 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_ym, 3044, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__235)) __PYX_ERR(0, 3044, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3059
 * 
 * 
 *     def cl_y_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x k (cmb lensing) power spectrum
 */
  __pyx_codeobj__236 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_y_kcmb, 3059, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__236)) __PYX_ERR(0, 3059, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3073
 *         return cl
 * 
 *     def cl_t2t2f(self):             # <<<<<<<<<<<<<<
 *         cl = {}
 *         cl['ell'] = []
 */
  __pyx_codeobj__237 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_t2t2f, 3073, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__237)) __PYX_ERR(0, 3073, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3084
 * 
 * 
 *     def cl_gg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gxg power spectrum
 */
  __pyx_codeobj__238 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_gg, 3084, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__238)) __PYX_ERR(0, 3084, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3101
 * 
 * 
 *     def cl_ksz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kszxksz power spectrum
 */
  __pyx_codeobj__239 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_ksz, 3101, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__239)) __PYX_ERR(0, 3101, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3116
 * 
 * 
 *     def cl_ggamma(self,             # <<<<<<<<<<<<<<
 *                   Nmcfit = 1024,
 *                   log10xmin_mcfit = -6,
 */
  __pyx_codeobj__240 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 20, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__227, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_ggamma, 3116, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__240)) __PYX_ERR(0, 3116, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3154
 *         return cl
 * 
 *     def gamma_ggamma(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tangential shear
 */
  __pyx_codeobj__241 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_gamma_ggamma, 3154, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__241)) __PYX_ERR(0, 3154, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3168
 *         return cl
 * 
 *     def cl_ee(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x electron power spectrum
 */
  __pyx_codeobj__242 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_ee, 3168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__242)) __PYX_ERR(0, 3168, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3185
 * 
 * 
 *     def cl_eg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x galaxy power spectrum
 */
  __pyx_codeobj__243 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_eg, 3185, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__243)) __PYX_ERR(0, 3185, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3201
 *         return cl
 * 
 *     def cl_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x galaxy power spectrum
 */
  __pyx_codeobj__244 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kg, 3201, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__244)) __PYX_ERR(0, 3201, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3217
 *         return cl
 * 
 *     def pk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) matter power spectrum
 */
  __pyx_codeobj__245 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_at_z_hm, 3217, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__245)) __PYX_ERR(0, 3217, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3232
 * 
 * 
 *     def bk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) matter bispectrum
 */
  __pyx_codeobj__246 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_bk_at_z_hm, 3232, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__246)) __PYX_ERR(0, 3232, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3249
 * 
 * 
 *     def bk_ttg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) ttg bispectrum
 */
  __pyx_codeobj__247 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_bk_ttg_at_z_hm, 3249, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__247)) __PYX_ERR(0, 3249, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3265
 *         return cl
 * 
 *     def b_yyy(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of tsz bispectrum
 */
  __pyx_codeobj__248 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_b_yyy, 3265, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__248)) __PYX_ERR(0, 3265, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3281
 *         return cl
 * 
 *     def b_tty(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of ksz-ksz-tsz bispectrum
 */
  __pyx_codeobj__249 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_b_tty, 3281, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__249)) __PYX_ERR(0, 3281, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3297
 *         return cl
 * 
 *     def pk_gg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) gg power spectrum
 */
  __pyx_codeobj__250 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_gg_at_z_hm, 3297, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__250)) __PYX_ERR(0, 3297, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3311
 *         return cl
 * 
 *     def pk_b_at_z_2h(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */
  __pyx_codeobj__251 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_b_at_z_2h, 3311, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__251)) __PYX_ERR(0, 3311, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3323
 *         return cl
 * 
 *     def pk_bb_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */
  __pyx_codeobj__252 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_bb_at_z_hm, 3323, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__252)) __PYX_ERR(0, 3323, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3337
 *         return cl
 * 
 *     def pk_em_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) electron-matter power spectrum
 */
  __pyx_codeobj__253 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_pk_em_at_z_hm, 3337, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__253)) __PYX_ERR(0, 3337, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3351
 *         return cl
 * 
 *     def cl_kk(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_codeobj__254 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kk, 3351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__254)) __PYX_ERR(0, 3351, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3367
 *         return cl
 * 
 *     def cl_c1c1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_codeobj__255 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_c1c1, 3367, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__255)) __PYX_ERR(0, 3367, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3382
 *         return cl
 * 
 *     def cl_c1_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_codeobj__256 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_c1_lens, 3382, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__256)) __PYX_ERR(0, 3382, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3397
 *         return cl
 * 
 *     def cl_c1_tSZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_codeobj__257 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_c1_tSZ, 3397, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__257)) __PYX_ERR(0, 3397, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3412
 *         return cl
 * 
 *     def cl_c1_gal(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_codeobj__258 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_c1_gal, 3412, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__258)) __PYX_ERR(0, 3412, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3427
 *         return cl
 * 
 *     def cl_c1_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_codeobj__259 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_c1_gallens, 3427, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__259)) __PYX_ERR(0, 3427, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3442
 *         return cl
 * 
 *     def cib_monopole(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib monopole as a function of frequency
 */
  __pyx_codeobj__260 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cib_monopole, 3442, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__260)) __PYX_ERR(0, 3442, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3454
 *         return cl
 * 
 *     def cib_shotnoise(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib shotnoise as a function of frequency
 */
  __pyx_tuple__261 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_cl, __pyx_n_s_id_nu1, __pyx_n_s_nu1); if (unlikely(!__pyx_tuple__261)) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__261);
  __Pyx_GIVEREF(__pyx_tuple__261);
  __pyx_codeobj__262 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__261, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cib_shotnoise, 3454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__262)) __PYX_ERR(0, 3454, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3467
 *         return cl
 * 
 *     def cl_cib_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of cib x cib power spectrum
 */
  __pyx_tuple__263 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_cl_cib, __pyx_n_s_id_nu1, __pyx_n_s_id_nu2, __pyx_n_s_nu1, __pyx_n_s_nu2, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__263)) __PYX_ERR(0, 3467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__263);
  __Pyx_GIVEREF(__pyx_tuple__263);
  __pyx_codeobj__264 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__263, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_cib_cib, 3467, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__264)) __PYX_ERR(0, 3467, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3489
 *         return cl_cib
 * 
 *     def cl_galn_galn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x gal power spectrum
 */
  __pyx_tuple__265 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_cl_gg, __pyx_n_s_id_nu1, __pyx_n_s_id_nu2, __pyx_n_s_nu1, __pyx_n_s_nu2, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);
  __pyx_codeobj__266 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__265, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_galn_galn, 3489, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__266)) __PYX_ERR(0, 3489, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3513
 *         return cl_gg
 * 
 *     def cl_galn_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_tuple__267 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_gk, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(0, 3513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);
  __pyx_codeobj__268 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__267, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_galn_lens, 3513, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__268)) __PYX_ERR(0, 3513, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3534
 *         return cl_gk
 * 
 *     def cl_galn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_tuple__269 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_gkg, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(0, 3534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__269, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_galn_gallens, 3534, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(0, 3534, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3553
 *         return cl_gkg
 * 
 *     def cl_galn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_tuple__271 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_gy, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 3553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__271, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_galn_tsz, 3553, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(0, 3553, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3571
 *             cl_gy[str(int(nu1))] = cl
 *         return cl_gy
 *     def cl_galn_IA(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 2-halo terms of gal x lens power spectrum
 */
  __pyx_tuple__273 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_gIA, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(0, 3571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);
  __pyx_codeobj__274 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__273, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_galn_IA, 3571, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__274)) __PYX_ERR(0, 3571, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3590
 *         return cl_gIA
 * 
 *     def cl_lensmagn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_tuple__275 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_mkg, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__275)) __PYX_ERR(0, 3590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__275);
  __Pyx_GIVEREF(__pyx_tuple__275);
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__275, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_lensmagn_gallens, 3590, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(0, 3590, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3609
 *         return cl_mkg
 * 
 *     def cl_lensmagn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_tuple__277 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_my, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__277, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_lensmagn_tsz, 3609, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(0, 3609, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3628
 *         return cl_my
 * 
 *     def cl_kg_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kg x cib power spectrum
 */
  __pyx_tuple__279 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_y_cib, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__279)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__279);
  __Pyx_GIVEREF(__pyx_tuple__279);
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__279, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_kg_cib, 3628, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(0, 3628, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3648
 * 
 * 
 *     def cl_custom1_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of custom1 x cib power spectrum
 */
  __pyx_codeobj__281 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__279, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_custom1_cib, 3648, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__281)) __PYX_ERR(0, 3648, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3667
 *         return cl_y_cib
 * 
 *     def cl_tSZ_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tSZ x cib power spectrum
 */
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__279, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_tSZ_cib, 3667, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(0, 3667, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3686
 *         return cl_y_cib
 * 
 *     def cl_gal_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x cib power spectrum
 */
  __pyx_tuple__283 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_g_cib, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__283)) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__283);
  __Pyx_GIVEREF(__pyx_tuple__283);
  __pyx_codeobj__284 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__283, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_gal_cib, 3686, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__284)) __PYX_ERR(0, 3686, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3705
 *         return cl_g_cib
 * 
 *     def cl_lens_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of lens x cib power spectrum
 */
  __pyx_tuple__285 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_cl_phi_cib, __pyx_n_s_id_nu1, __pyx_n_s_nu1, __pyx_n_s_cl, __pyx_n_s_index); if (unlikely(!__pyx_tuple__285)) __PYX_ERR(0, 3705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__285);
  __Pyx_GIVEREF(__pyx_tuple__285);
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__285, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_lens_cib, 3705, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(0, 3705, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3725
 * 
 * 
 *     def cl_km(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x mu (lensing magnification) power spectrum
 */
  __pyx_codeobj__287 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_km, 3725, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__287)) __PYX_ERR(0, 3725, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3741
 *         return cl
 * 
 *     def cl_mm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of mu x mu (lensing magnification) power spectrum
 */
  __pyx_codeobj__288 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_mm, 3741, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__288)) __PYX_ERR(0, 3741, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3757
 *         return cl
 * 
 *     def cl_gm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x mu (lensing magnification) power spectrum
 */
  __pyx_codeobj__289 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cl_gm, 3757, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__289)) __PYX_ERR(0, 3757, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3774
 * 
 * 
 *     def get_scale_dependent_bias_at_z_and_k(self,z_asked,k_asked,bh):             # <<<<<<<<<<<<<<
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 */
  __pyx_tuple__290 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_z_asked, __pyx_n_s_k_asked, __pyx_n_s_bh); if (unlikely(!__pyx_tuple__290)) __PYX_ERR(0, 3774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__290);
  __Pyx_GIVEREF(__pyx_tuple__290);
  __pyx_codeobj__291 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__290, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_scale_dependent_bias_at_z_an, 3774, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__291)) __PYX_ERR(0, 3774, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3777
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 *     def get_szcounts_dndzdq_at_z_q(self,z_asked,qobs_asked):             # <<<<<<<<<<<<<<
 *         return get_szcounts_dndzdq_at_z_q(z_asked, qobs_asked, &self.tsz)
 * 
 */
  __pyx_tuple__292 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z_asked, __pyx_n_s_qobs_asked); if (unlikely(!__pyx_tuple__292)) __PYX_ERR(0, 3777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__292);
  __Pyx_GIVEREF(__pyx_tuple__292);
  __pyx_codeobj__293 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__292, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_szcounts_dndzdq_at_z_q, 3777, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__293)) __PYX_ERR(0, 3777, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3782
 * 
 * 
 *     def get_params_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the current parameters
 */
  __pyx_codeobj__294 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_params_sz, 3782, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__294)) __PYX_ERR(0, 3782, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3789
 * 
 * 
 *     def tllprime_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the trispectrum
 */
  __pyx_tuple__295 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_index_l, __pyx_n_s_index_l_prime, __pyx_n_s_T_ll_arr); if (unlikely(!__pyx_tuple__295)) __PYX_ERR(0, 3789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__295);
  __Pyx_GIVEREF(__pyx_tuple__295);
  __pyx_codeobj__296 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__295, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_tllprime_sz, 3789, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__296)) __PYX_ERR(0, 3789, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3804
 * 
 * 
 *     def A_rs(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_rs coefficient
 */
  __pyx_codeobj__297 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_A_rs, 3804, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__297)) __PYX_ERR(0, 3804, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3810
 *         return self.tsz.A_rs
 * 
 *     def B_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the mass bias
 */
  __pyx_codeobj__298 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_B_sz, 3810, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__298)) __PYX_ERR(0, 3810, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3816
 *         return self.tsz.HSEbias
 * 
 *     def Rho_crit_0(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in Mpc/h, Msun/h units
 */
  __pyx_codeobj__299 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Rho_crit_0, 3816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__299)) __PYX_ERR(0, 3816, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3822
 *         return self.tsz.Rho_crit_0
 * 
 *     def rho0_crit(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in mpc/h, msun/h units at present time.
 */
  __pyx_codeobj__300 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_rho0_crit, 3822, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__300)) __PYX_ERR(0, 3822, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3828
 *         return self.Rho_crit_0()
 * 
 *     def rho0_cb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cdm+baryon density in mpc/h, msun/h units at present time.
 */
  __pyx_codeobj__301 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_rho0_cb, 3828, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__301)) __PYX_ERR(0, 3828, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3834
 *         return self.rho0_crit()*(self.Omega0_b()+self.Omega0_cdm())
 * 
 *     def rho0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the mean density of the sum of Omega0 for all non-relativistic components in mpc/h, msun/h units at present time.
 */
  __pyx_codeobj__302 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_rho0_m, 3834, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__302)) __PYX_ERR(0, 3834, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3840
 *         return self.rho0_crit()*(self.Omega0_m())
 * 
 *     def chi_star(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the comoving distance to recombination in Mpc/h
 */
  __pyx_codeobj__303 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_chi_star, 3840, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__303)) __PYX_ERR(0, 3840, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3846
 *         return self.tsz.chi_star
 * 
 *     def delta_def_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the overdensity definition for custom1 profile
 */
  __pyx_codeobj__304 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_delta_def_custom1, 3846, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__304)) __PYX_ERR(0, 3846, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3852
 *         return self.tsz.delta_def_custom1
 * 
 *     def effective_galaxy_bias(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the effective galaxy bias
 */
  __pyx_codeobj__305 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_effective_galaxy_bias, 3852, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__305)) __PYX_ERR(0, 3852, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3860
 * 
 * 
 *     def x_out_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the truncation for custom1 profile, r_cut = x_out*r_delta
 */
  __pyx_codeobj__306 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_x_out_custom1, 3860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__306)) __PYX_ERR(0, 3860, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3866
 *         return self.tsz.x_out_custom1
 * 
 *     def M1SZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the lower mass bound
 */
  __pyx_codeobj__307 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_M1SZ, 3866, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__307)) __PYX_ERR(0, 3866, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3873
 * 
 * 
 *     def ystar(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return ystar
 */
  __pyx_codeobj__308 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_ystar, 3873, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__308)) __PYX_ERR(0, 3873, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3880
 * 
 * 
 *     def alpha(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return alpha
 */
  __pyx_codeobj__309 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_alpha, 3880, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__309)) __PYX_ERR(0, 3880, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3886
 *         return self.csz.alpha
 * 
 *     def sigmaM(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return sigmaM
 */
  __pyx_codeobj__310 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_sigmaM, 3886, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__310)) __PYX_ERR(0, 3886, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3893
 * 
 * 
 *     def sigma8_Pcb(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.sigma8_Pcb
 * 
 */
  __pyx_codeobj__311 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_sigma8_Pcb, 3893, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__311)) __PYX_ERR(0, 3893, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3896
 *         return self.tsz.sigma8_Pcb
 * 
 *     def A_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */
  __pyx_codeobj__312 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_A_cib, 3896, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__312)) __PYX_ERR(0, 3896, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3902
 *         return self.tsz.A_cib
 * 
 *     def A_sn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */
  __pyx_codeobj__313 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_A_sn, 3902, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__313)) __PYX_ERR(0, 3902, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3909
 * 
 * 
 *     def A_ir(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_ir coefficient
 */
  __pyx_codeobj__314 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_A_ir, 3909, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__314)) __PYX_ERR(0, 3909, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3916
 * 
 * 
 *     def A_cn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the correlated noise A_cn coefficient
 */
  __pyx_codeobj__315 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_A_cn, 3916, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__315)) __PYX_ERR(0, 3916, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3922
 *         return self.tsz.A_cn
 * 
 *     def get_te_of_m500c_at_z_arnaud(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__316 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_te_of_m500c_at_z_arnaud, 3922, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__316)) __PYX_ERR(0, 3922, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3925
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 *     def get_lensing_noise_at_ell(self,l):             # <<<<<<<<<<<<<<
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 */
  __pyx_tuple__317 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_l); if (unlikely(!__pyx_tuple__317)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__317);
  __Pyx_GIVEREF(__pyx_tuple__317);
  __pyx_codeobj__318 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__317, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_lensing_noise_at_ell, 3925, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__318)) __PYX_ERR(0, 3925, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3928
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 *     def get_te_of_m500c_at_z_lee(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__319 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_te_of_m500c_at_z_lee, 3928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__319)) __PYX_ERR(0, 3928, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3931
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 *     def get_f_tinker10_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 */
  __pyx_tuple__320 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_nu, __pyx_n_s_z); if (unlikely(!__pyx_tuple__320)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__320);
  __Pyx_GIVEREF(__pyx_tuple__320);
  __pyx_codeobj__321 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__320, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_f_tinker10_at_nu_and_z, 3931, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__321)) __PYX_ERR(0, 3931, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3934
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 *     def get_f_tinker08_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker08_at_nu_and_z(nu,z,&self.tsz)
 * 
 */
  __pyx_codeobj__322 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__320, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_f_tinker08_at_nu_and_z, 3934, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__322)) __PYX_ERR(0, 3934, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3938
 * 
 * 
 *     def get_T10_alpha_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__323 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_T10_alpha_at_z, 3938, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__323)) __PYX_ERR(0, 3938, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3941
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 *     def get_dndlnM_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 * 
 *         r = get_dndlnM_at_z_and_M(z,m,&self.tsz)
 */
  __pyx_tuple__324 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_m, __pyx_n_s_r); if (unlikely(!__pyx_tuple__324)) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__324);
  __Pyx_GIVEREF(__pyx_tuple__324);
  __pyx_codeobj__325 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__324, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dndlnM_at_z_and_M, 3941, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__325)) __PYX_ERR(0, 3941, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":3948
 * 
 * 
 *     def get_dndlnm(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of dndlnM at given redshifts and masses.
 */
  __pyx_tuple__326 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_z_input, __pyx_n_s_m_input, __pyx_n_s_z_broadcasted, __pyx_n_s_m_broadcasted, __pyx_n_s_z_flattened, __pyx_n_s_m_flattened, __pyx_n_s_result, __pyx_n_s_i); if (unlikely(!__pyx_tuple__326)) __PYX_ERR(0, 3948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__326);
  __Pyx_GIVEREF(__pyx_tuple__326);
  __pyx_codeobj__327 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__326, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dndlnm, 3948, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__327)) __PYX_ERR(0, 3948, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4059
 * 
 * 
 *     def get_dcib0dz_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         r = get_dcib0dz_at_z_and_nu(z,nu,&self.tsz)
 *         return r
 */
  __pyx_tuple__328 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_nu, __pyx_n_s_r); if (unlikely(!__pyx_tuple__328)) __PYX_ERR(0, 4059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__328);
  __Pyx_GIVEREF(__pyx_tuple__328);
  __pyx_codeobj__329 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__328, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dcib0dz_at_z_and_nu, 4059, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__329)) __PYX_ERR(0, 4059, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4063
 *         return r
 * 
 *     def get_dydz_at_z(self,z):             # <<<<<<<<<<<<<<
 *         r = get_dydz_at_z(z,&self.tsz)
 *         return r
 */
  __pyx_tuple__330 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_r); if (unlikely(!__pyx_tuple__330)) __PYX_ERR(0, 4063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__330);
  __Pyx_GIVEREF(__pyx_tuple__330);
  __pyx_codeobj__331 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__330, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dydz_at_z, 4063, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__331)) __PYX_ERR(0, 4063, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4067
 *         return r
 * 
 *     def get_mean_y(self):             # <<<<<<<<<<<<<<
 *         r = self.tsz.y_monopole
 *         return r
 */
  __pyx_tuple__332 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_r); if (unlikely(!__pyx_tuple__332)) __PYX_ERR(0, 4067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__332);
  __Pyx_GIVEREF(__pyx_tuple__332);
  __pyx_codeobj__333 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__332, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_mean_y, 4067, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__333)) __PYX_ERR(0, 4067, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4071
 *         return r
 * 
 *     def get_mean_galaxy_bias_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_mean_galaxy_bias_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_mean_galaxy_bias_at_z, 4071, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(0, 4071, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4075
 * 
 * 
 *     def get_gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb):             # <<<<<<<<<<<<<<
 *         r = gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb)
 *         return r
 */
  __pyx_tuple__335 = PyTuple_Pack(3, __pyx_n_s_nu_in_ghz, __pyx_n_s_Tcmb, __pyx_n_s_r); if (unlikely(!__pyx_tuple__335)) __PYX_ERR(0, 4075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__335);
  __Pyx_GIVEREF(__pyx_tuple__335);
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__335, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_gnu_tsz_of_nu_in_ghz, 4075, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(0, 4075, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4080
 * 
 * 
 *     def get_hmf_counter_term_nmin_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__337 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_hmf_counter_term_nmin_at_z, 4080, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__337)) __PYX_ERR(0, 4080, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4083
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b1min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__338 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_hmf_counter_term_b1min_at_z, 4083, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__338)) __PYX_ERR(0, 4083, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4086
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b2min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__339 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_hmf_counter_term_b2min_at_z, 4086, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__339)) __PYX_ERR(0, 4086, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4089
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 *     def get_gas_density_profile_at_k_M_z(self,l_asked,m_asked,z_asked, normalize = 0):             # <<<<<<<<<<<<<<
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 */
  __pyx_tuple__340 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_l_asked, __pyx_n_s_m_asked, __pyx_n_s_z_asked, __pyx_n_s_normalize); if (unlikely(!__pyx_tuple__340)) __PYX_ERR(0, 4089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__340);
  __Pyx_GIVEREF(__pyx_tuple__340);
  __pyx_codeobj__341 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__340, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_gas_density_profile_at_k_M_z, 4089, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__341)) __PYX_ERR(0, 4089, __pyx_L1_error)
  __pyx_tuple__342 = PyTuple_Pack(1, __pyx_int_0); if (unlikely(!__pyx_tuple__342)) __PYX_ERR(0, 4089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__342);
  __Pyx_GIVEREF(__pyx_tuple__342);

  /* "class-sz/python/classy.pyx":4092
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 *     def get_rho_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */
  __pyx_tuple__343 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_r_asked, __pyx_n_s_m_asked, __pyx_n_s_z_asked); if (unlikely(!__pyx_tuple__343)) __PYX_ERR(0, 4092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__343);
  __Pyx_GIVEREF(__pyx_tuple__343);
  __pyx_codeobj__344 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__343, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_rho_2h_at_r_and_m_and_z, 4092, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__344)) __PYX_ERR(0, 4092, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4096
 * 
 * 
 *     def get_P_delta_at_m_and_z_b12(self,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         # this is in ev/cm3, see https://arxiv.org/pdf/2202.02275.pdf
 *         # return get_P_delta_at_m_and_z_b12(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 */
  __pyx_tuple__345 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_m_asked, __pyx_n_s_z_asked, __pyx_n_s_r200c, __pyx_n_s_f_b, __pyx_n_s_Eh, __pyx_n_s_P200); if (unlikely(!__pyx_tuple__345)) __PYX_ERR(0, 4096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__345);
  __Pyx_GIVEREF(__pyx_tuple__345);
  __pyx_codeobj__346 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__345, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_P_delta_at_m_and_z_b12, 4096, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__346)) __PYX_ERR(0, 4096, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4106
 * 
 * 
 *     def get_gas_pressure_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */
  __pyx_codeobj__347 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__343, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_gas_pressure_2h_at_r_and_m_a, 4106, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__347)) __PYX_ERR(0, 4106, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4109
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):             # <<<<<<<<<<<<<<
 *         if use_pklin == 1:
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 */
  __pyx_tuple__348 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_l, __pyx_n_s_z, __pyx_n_s_use_pklin); if (unlikely(!__pyx_tuple__348)) __PYX_ERR(0, 4109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__348);
  __Pyx_GIVEREF(__pyx_tuple__348);
  __pyx_codeobj__349 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__348, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dkappacmbdz_at_l_and_z, 4109, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__349)) __PYX_ERR(0, 4109, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4115
 *             return get_dkappacmbdz_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_dydzdlnm_at_z_and_m(self,z,m,l=0):             # <<<<<<<<<<<<<<
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 */
  __pyx_tuple__350 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_m, __pyx_n_s_l); if (unlikely(!__pyx_tuple__350)) __PYX_ERR(0, 4115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__350);
  __Pyx_GIVEREF(__pyx_tuple__350);
  __pyx_codeobj__351 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__350, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dydzdlnm_at_z_and_m, 4115, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__351)) __PYX_ERR(0, 4115, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4118
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 */
  __pyx_tuple__352 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_m, __pyx_n_s_z, __pyx_n_s_delta_def, __pyx_n_s_c_delta); if (unlikely(!__pyx_tuple__352)) __PYX_ERR(0, 4118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__352);
  __Pyx_GIVEREF(__pyx_tuple__352);
  __pyx_codeobj__353 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__352, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_c_delta_at_m_and_z, 4118, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__353)) __PYX_ERR(0, 4118, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4129
 *         return c_delta
 * 
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           Omega_m = self.get_Omega_m_at_z(z)
 */
  __pyx_tuple__354 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_delta_def, __pyx_n_s_z, __pyx_n_s_Omega_m, __pyx_n_s_delta, __pyx_n_s_Delta_c); if (unlikely(!__pyx_tuple__354)) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__354);
  __Pyx_GIVEREF(__pyx_tuple__354);
  __pyx_codeobj__355 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__354, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_delta_from_delta_def_at_z, 4129, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__355)) __PYX_ERR(0, 4129, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4143
 *         return delta
 * 
 *     def get_r_delta_of_m_delta_at_z(self,delta,m_delta,z):             # <<<<<<<<<<<<<<
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 */
  __pyx_tuple__356 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_delta, __pyx_n_s_m_delta, __pyx_n_s_z); if (unlikely(!__pyx_tuple__356)) __PYX_ERR(0, 4143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__356);
  __Pyx_GIVEREF(__pyx_tuple__356);
  __pyx_codeobj__357 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__356, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_r_delta_of_m_delta_at_z, 4143, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__357)) __PYX_ERR(0, 4143, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4146
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 */
  __pyx_tuple__358 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z_asked, __pyx_n_s_m_asked); if (unlikely(!__pyx_tuple__358)) __PYX_ERR(0, 4146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__358);
  __Pyx_GIVEREF(__pyx_tuple__358);
  __pyx_codeobj__359 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__358, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m200m_to_m200c_at_z_and_M, 4146, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__359)) __PYX_ERR(0, 4146, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4149
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 *     def get_normalization_gas_density_profile(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 */
  __pyx_codeobj__360 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__358, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_normalization_gas_density_pr, 4149, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__360)) __PYX_ERR(0, 4149, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4152
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 *     def get_m_to_xout_at_z_and_m(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 */
  __pyx_codeobj__361 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__358, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m_to_xout_at_z_and_m, 4152, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__361)) __PYX_ERR(0, 4152, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4155
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__362 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_c200m_at_m_and_z, 4155, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__362)) __PYX_ERR(0, 4155, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4158
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__363 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_c200c_at_m_and_z, 4158, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__363)) __PYX_ERR(0, 4158, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4161
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c500c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_c500c_at_m_and_z, 4161, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(0, 4161, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4164
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 */
  __pyx_tuple__365 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_M, __pyx_n_s_z); if (unlikely(!__pyx_tuple__365)) __PYX_ERR(0, 4164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__365);
  __Pyx_GIVEREF(__pyx_tuple__365);
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_c200m_at_m_and_z_D08, 4164, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(0, 4164, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4167
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 */
  __pyx_codeobj__367 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_c200c_at_m_and_z_D08, 4167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__367)) __PYX_ERR(0, 4167, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4170
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_B13(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_c200c_at_m_and_z_B13, 4170, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(0, 4170, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4173
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 *     def get_f_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 */
  __pyx_codeobj__369 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_f_b, 4173, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__369)) __PYX_ERR(0, 4173, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4176
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 *     def get_f_free(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.f_free
 * 
 */
  __pyx_codeobj__370 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_f_free, 4176, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__370)) __PYX_ERR(0, 4176, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4179
 *         return self.tsz.f_free
 * 
 *     def get_mu_e(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.mu_e
 * 
 */
  __pyx_codeobj__371 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_mu_e, 4179, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__371)) __PYX_ERR(0, 4179, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4182
 *         return self.tsz.mu_e
 * 
 *     def get_Omega_m_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):
 */
  __pyx_codeobj__372 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_Omega_m_0, 4182, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__372)) __PYX_ERR(0, 4182, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4184
 *     def get_Omega_m_0(self):
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_r_0
 * 
 */
  __pyx_codeobj__373 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_Omega_r_0, 4184, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__373)) __PYX_ERR(0, 4184, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4187
 *         return self.tsz.Omega_r_0
 * 
 *     def get_m_nfw(self,x):             # <<<<<<<<<<<<<<
 *         return m_nfw(x)
 * 
 */
  __pyx_tuple__374 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_x); if (unlikely(!__pyx_tuple__374)) __PYX_ERR(0, 4187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__374);
  __Pyx_GIVEREF(__pyx_tuple__374);
  __pyx_codeobj__375 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__374, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m_nfw, 4187, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__375)) __PYX_ERR(0, 4187, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4190
 *         return m_nfw(x)
 * 
 *     def get_rho_crit_at_z(self,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_crit_at_z(z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_tuple__376 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_z_asked); if (unlikely(!__pyx_tuple__376)) __PYX_ERR(0, 4190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__376);
  __Pyx_GIVEREF(__pyx_tuple__376);
  __pyx_codeobj__377 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__376, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_rho_crit_at_z, 4190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__377)) __PYX_ERR(0, 4190, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4194
 * 
 * 
 *     def get_pkl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the linear power spectrum at a given scale and redshift.
 */
  __pyx_tuple__378 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_kh, __pyx_n_s_z, __pyx_n_s_k); if (unlikely(!__pyx_tuple__378)) __PYX_ERR(0, 4194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__378);
  __Pyx_GIVEREF(__pyx_tuple__378);
  __pyx_codeobj__379 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__378, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pkl_unvectorized, 4194, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__379)) __PYX_ERR(0, 4194, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4214
 * 
 * 
 *     def get_pknl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the non-linear power spectrum at a given scale and redshift.
 */
  __pyx_codeobj__380 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__378, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pknl_unvectorized, 4214, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__380)) __PYX_ERR(0, 4214, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4234
 * 
 * 
 *     def get_pkl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the linear power spectrum at given wavenumbers and redshifts.
 */
  __pyx_tuple__381 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_kh_input, __pyx_n_s_z_input, __pyx_n_s_compute_pkl, __pyx_n_s_compute_pkl, __pyx_n_s_handle_combinations, __pyx_n_s_handle_combinations); if (unlikely(!__pyx_tuple__381)) __PYX_ERR(0, 4234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__381);
  __Pyx_GIVEREF(__pyx_tuple__381);
  __pyx_codeobj__382 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__381, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pkl, 4234, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__382)) __PYX_ERR(0, 4234, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4279
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pknl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the non-linear power spectrum at given wavenumbers and redshifts.
 */
  __pyx_tuple__383 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_kh_input, __pyx_n_s_z_input, __pyx_n_s_compute_pknl, __pyx_n_s_compute_pknl, __pyx_n_s_handle_combinations, __pyx_n_s_handle_combinations); if (unlikely(!__pyx_tuple__383)) __PYX_ERR(0, 4279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__383);
  __Pyx_GIVEREF(__pyx_tuple__383);
  __pyx_codeobj__384 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__383, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pknl, 4279, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__384)) __PYX_ERR(0, 4279, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4324
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pk(self, kh_input, z_input, type="lin"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the power spectrum at given wavenumbers and redshifts.
 */
  __pyx_tuple__385 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_kh_input, __pyx_n_s_z_input, __pyx_n_s_type); if (unlikely(!__pyx_tuple__385)) __PYX_ERR(0, 4324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__385);
  __Pyx_GIVEREF(__pyx_tuple__385);
  __pyx_codeobj__386 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__385, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk, 4324, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__386)) __PYX_ERR(0, 4324, __pyx_L1_error)
  __pyx_tuple__387 = PyTuple_Pack(1, __pyx_n_u_lin); if (unlikely(!__pyx_tuple__387)) __PYX_ERR(0, 4324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__387);
  __Pyx_GIVEREF(__pyx_tuple__387);

  /* "class-sz/python/classy.pyx":4360
 * 
 * 
 *     def get_pk_nonlin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_tuple__388 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z); if (unlikely(!__pyx_tuple__388)) __PYX_ERR(0, 4360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__388);
  __Pyx_GIVEREF(__pyx_tuple__388);
  __pyx_codeobj__389 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__388, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_nonlin_at_k_and_z, 4360, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__389)) __PYX_ERR(0, 4360, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4363
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_codeobj__390 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__388, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_lin_at_k_and_z, 4363, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__390)) __PYX_ERR(0, 4363, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4366
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_nonlin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_codeobj__391 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__388, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_nonlin_at_k_and_z_fast, 4366, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__391)) __PYX_ERR(0, 4366, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4369
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_codeobj__392 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__388, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_lin_at_k_and_z_fast, 4369, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__392)) __PYX_ERR(0, 4369, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4372
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_b16_200c(self,             # <<<<<<<<<<<<<<
 *                                           r_asked,
 *                                           m_asked,
 */
  __pyx_tuple__393 = PyTuple_Pack(23, __pyx_n_s_self, __pyx_n_s_r_asked, __pyx_n_s_m_asked, __pyx_n_s_z_asked, __pyx_n_s_c_asked, __pyx_n_s_A_rho0, __pyx_n_s_A_alpha, __pyx_n_s_A_beta, __pyx_n_s_alpha_m_rho0, __pyx_n_s_alpha_m_alpha, __pyx_n_s_alpha_m_beta, __pyx_n_s_alpha_z_rho0, __pyx_n_s_alpha_z_alpha, __pyx_n_s_alpha_z_beta, __pyx_n_s_mcut, __pyx_n_s_alphap_m_rho0, __pyx_n_s_alphap_m_alpha, __pyx_n_s_alphap_m_beta, __pyx_n_s_alpha_c_rho0, __pyx_n_s_alpha_c_alpha, __pyx_n_s_alpha_c_beta, __pyx_n_s_gamma, __pyx_n_s_xc); if (unlikely(!__pyx_tuple__393)) __PYX_ERR(0, 4372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__393);
  __Pyx_GIVEREF(__pyx_tuple__393);
  __pyx_codeobj__394 = (PyObject*)__Pyx_PyCode_New(23, 0, 0, 23, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__393, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_gas_profile_at_x_M_z_b16_200, 4372, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__394)) __PYX_ERR(0, 4372, __pyx_L1_error)
  __pyx_tuple__395 = PyTuple_Pack(19, __pyx_float_0_, __pyx_float_4_e3, __pyx_float_0_88, __pyx_float_3_83, __pyx_float_0_29, __pyx_float_neg_0_03, __pyx_float_0_04, __pyx_float_neg_0_66, __pyx_float_0_19, __pyx_float_neg_0_025, __pyx_float_1e14, __pyx_float_0_29, __pyx_float_neg_0_03, __pyx_float_0_04, __pyx_float_0_, __pyx_float_0_, __pyx_float_0_, __pyx_float_neg_0_2, __pyx_float_0_5); if (unlikely(!__pyx_tuple__395)) __PYX_ERR(0, 4372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__395);
  __Pyx_GIVEREF(__pyx_tuple__395);

  /* "class-sz/python/classy.pyx":4421
 *                                                  &self.tsz)
 * 
 *     def get_pressure_P_over_P_delta_at_x_M_z_b12_200c(self,             # <<<<<<<<<<<<<<
 *                                                         x_asked,
 *                                                         m_asked,
 */
  __pyx_tuple__396 = PyTuple_Pack(23, __pyx_n_s_self, __pyx_n_s_x_asked, __pyx_n_s_m_asked, __pyx_n_s_z_asked, __pyx_n_s_c_asked, __pyx_n_s_A_P0, __pyx_n_s_A_xc, __pyx_n_s_A_beta, __pyx_n_s_alpha_m_P0, __pyx_n_s_alpha_m_xc, __pyx_n_s_alpha_m_beta, __pyx_n_s_alpha_z_P0, __pyx_n_s_alpha_z_xc, __pyx_n_s_alpha_z_beta, __pyx_n_s_mcut, __pyx_n_s_alphap_m_P0, __pyx_n_s_alphap_m_xc, __pyx_n_s_alphap_m_beta, __pyx_n_s_alpha_c_P0, __pyx_n_s_alpha_c_xc, __pyx_n_s_alpha_c_beta, __pyx_n_s_alpha, __pyx_n_s_gamma); if (unlikely(!__pyx_tuple__396)) __PYX_ERR(0, 4421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__396);
  __Pyx_GIVEREF(__pyx_tuple__396);
  __pyx_codeobj__397 = (PyObject*)__Pyx_PyCode_New(23, 0, 0, 23, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__396, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pressure_P_over_P_delta_at_x, 4421, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__397)) __PYX_ERR(0, 4421, __pyx_L1_error)
  __pyx_tuple__398 = PyTuple_Pack(19, __pyx_float_0_, __pyx_float_18_1, __pyx_float_0_497, __pyx_float_4_35, __pyx_float_0_154, __pyx_float_neg_0_00865, __pyx_float_0_0393, __pyx_float_neg_0_758, __pyx_float_0_731, __pyx_float_0_415, __pyx_float_1e14, __pyx_float_0_154, __pyx_float_neg_0_00865, __pyx_float_0_0393, __pyx_float_0_, __pyx_float_0_, __pyx_float_0_, __pyx_float_1_, __pyx_float_neg_0_3); if (unlikely(!__pyx_tuple__398)) __PYX_ERR(0, 4421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__398);
  __Pyx_GIVEREF(__pyx_tuple__398);

  /* "class-sz/python/classy.pyx":4470
 * 
 * 
 *     def get_pressure_P_over_P_delta_at_x_gnfw_500c(self,             # <<<<<<<<<<<<<<
 *                                                      x_asked,
 *                                                      P0GNFW = 8.130,
 */
  __pyx_tuple__399 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_x_asked, __pyx_n_s_P0GNFW, __pyx_n_s_alphaGNFW, __pyx_n_s_betaGNFW, __pyx_n_s_gammaGNFW, __pyx_n_s_c500); if (unlikely(!__pyx_tuple__399)) __PYX_ERR(0, 4470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__399);
  __Pyx_GIVEREF(__pyx_tuple__399);
  __pyx_codeobj__400 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__399, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pressure_P_over_P_delta_at_x_2, 4470, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__400)) __PYX_ERR(0, 4470, __pyx_L1_error)
  __pyx_tuple__401 = PyTuple_Pack(5, __pyx_float_8_130, __pyx_float_1_0620, __pyx_float_5_4807, __pyx_float_0_3292, __pyx_float_1_156); if (unlikely(!__pyx_tuple__401)) __PYX_ERR(0, 4470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__401);
  __Pyx_GIVEREF(__pyx_tuple__401);

  /* "class-sz/python/classy.pyx":4485
 *                                                            &self.ba,
 *                                                            &self.tsz)
 *     def get_dA_z1z2(self,z1,z2):             # <<<<<<<<<<<<<<
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 */
  __pyx_tuple__402 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z1, __pyx_n_s_z2); if (unlikely(!__pyx_tuple__402)) __PYX_ERR(0, 4485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__402);
  __Pyx_GIVEREF(__pyx_tuple__402);
  __pyx_codeobj__403 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__402, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dA_z1z2, 4485, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__403)) __PYX_ERR(0, 4485, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4488
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 *     def get_dA(self,z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z) in Mpc/h
 */
  __pyx_codeobj__404 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__179, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dA, 4488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__404)) __PYX_ERR(0, 4488, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4516
 *         return D_A*self.ba.h
 * 
 *     def get_rad_to_arcmin(self,theta_rad):             # <<<<<<<<<<<<<<
 *         return (60.*180.)/np.pi*theta_rad
 * 
 */
  __pyx_tuple__405 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_theta_rad); if (unlikely(!__pyx_tuple__405)) __PYX_ERR(0, 4516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__405);
  __Pyx_GIVEREF(__pyx_tuple__405);
  __pyx_codeobj__406 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__405, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_rad_to_arcmin, 4516, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__406)) __PYX_ERR(0, 4516, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4519
 *         return (60.*180.)/np.pi*theta_rad
 * 
 *     def get_truncated_nfw_profile_at_z_k_rd_cd_xout(self, double z, double k, double r_delta, double c_delta, double xout=1):             # <<<<<<<<<<<<<<
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 * 
 */
  __pyx_tuple__407 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_k, __pyx_n_s_r_delta, __pyx_n_s_c_delta, __pyx_n_s_xout); if (unlikely(!__pyx_tuple__407)) __PYX_ERR(0, 4519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__407);
  __Pyx_GIVEREF(__pyx_tuple__407);
  __pyx_codeobj__408 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__407, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_truncated_nfw_profile_at_z_k, 4519, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__408)) __PYX_ERR(0, 4519, __pyx_L1_error)
  __pyx_tuple__409 = PyTuple_Pack(1, __pyx_float_1_0); if (unlikely(!__pyx_tuple__409)) __PYX_ERR(0, 4519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__409);
  __Pyx_GIVEREF(__pyx_tuple__409);

  /* "class-sz/python/classy.pyx":4523
 * 
 * 
 *     def get_truncated_nfw_profile_at_z_k_m_xout(self, double z, double k, double m, double xout=1):             # <<<<<<<<<<<<<<
 *         delta_def = self.tsz.delta_def_matter_density
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */
  __pyx_tuple__410 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_k, __pyx_n_s_m, __pyx_n_s_xout, __pyx_n_s_delta_def, __pyx_n_s_delta, __pyx_n_s_r_delta, __pyx_n_s_c_delta); if (unlikely(!__pyx_tuple__410)) __PYX_ERR(0, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__410);
  __Pyx_GIVEREF(__pyx_tuple__410);
  __pyx_codeobj__411 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__410, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_truncated_nfw_profile_at_z_k_2, 4523, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__411)) __PYX_ERR(0, 4523, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4533
 * 
 *     # Define the vectorized method
 *     def get_uk_nfw(self, z_input, k_input, m_input, double xout=1):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the truncated NFW profile at given redshifts, wavenumbers, and masses.
 */
  __pyx_tuple__412 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_z_input, __pyx_n_s_k_input, __pyx_n_s_m_input, __pyx_n_s_xout, __pyx_n_s_compute_profile, __pyx_n_s_compute_profile, __pyx_n_s_handle_combinations, __pyx_n_s_handle_combinations); if (unlikely(!__pyx_tuple__412)) __PYX_ERR(0, 4533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__412);
  __Pyx_GIVEREF(__pyx_tuple__412);
  __pyx_codeobj__413 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__412, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_uk_nfw, 4533, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__413)) __PYX_ERR(0, 4533, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4592
 * 
 *     # Define the general method
 *     def get_uk(self, z_input, k_input, m_input, double xout=1, profile="nfw"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the profile at given redshifts, wavenumbers, and masses.
 */
  __pyx_tuple__414 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z_input, __pyx_n_s_k_input, __pyx_n_s_m_input, __pyx_n_s_xout, __pyx_n_s_profile); if (unlikely(!__pyx_tuple__414)) __PYX_ERR(0, 4592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__414);
  __Pyx_GIVEREF(__pyx_tuple__414);
  __pyx_codeobj__415 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__414, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_uk, 4592, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__415)) __PYX_ERR(0, 4592, __pyx_L1_error)
  __pyx_tuple__416 = PyTuple_Pack(2, __pyx_float_1_0, __pyx_n_u_nfw); if (unlikely(!__pyx_tuple__416)) __PYX_ERR(0, 4592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__416);
  __Pyx_GIVEREF(__pyx_tuple__416);

  /* "class-sz/python/classy.pyx":4619
 * 
 * 
 *     def get_arcmin_to_rad(self,theta_arcmin):             # <<<<<<<<<<<<<<
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 */
  __pyx_tuple__417 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_theta_arcmin); if (unlikely(!__pyx_tuple__417)) __PYX_ERR(0, 4619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__417);
  __Pyx_GIVEREF(__pyx_tuple__417);
  __pyx_codeobj__418 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__417, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_arcmin_to_rad, 4619, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__418)) __PYX_ERR(0, 4619, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4622
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__419 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__343, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_gas_profile_at_x_M_z_nfw_200, 4622, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__419)) __PYX_ERR(0, 4622, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4625
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_bcm_200c(self, x_asked, m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_tuple__420 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_x_asked, __pyx_n_s_m_asked, __pyx_n_s_z); if (unlikely(!__pyx_tuple__420)) __PYX_ERR(0, 4625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__420);
  __Pyx_GIVEREF(__pyx_tuple__420);
  __pyx_codeobj__421 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__420, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_gas_profile_at_x_M_z_bcm_200, 4625, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__421)) __PYX_ERR(0, 4625, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4628
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_rvir_of_m200c_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_tuple__422 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_m_asked, __pyx_n_s_z); if (unlikely(!__pyx_tuple__422)) __PYX_ERR(0, 4628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__422);
  __Pyx_GIVEREF(__pyx_tuple__422);
  __pyx_codeobj__423 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__422, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_rvir_of_m200c_at_z, 4628, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__423)) __PYX_ERR(0, 4628, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4631
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_Delta_c_of_Omega_m(self,Omega_m):             # <<<<<<<<<<<<<<
 *         return Delta_c_of_Omega_m(Omega_m)
 * 
 */
  __pyx_tuple__424 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_Omega_m); if (unlikely(!__pyx_tuple__424)) __PYX_ERR(0, 4631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__424);
  __Pyx_GIVEREF(__pyx_tuple__424);
  __pyx_codeobj__425 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__424, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_Delta_c_of_Omega_m, 4631, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__425)) __PYX_ERR(0, 4631, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4635
 * 
 * 
 *     def get_cvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 */
  __pyx_codeobj__426 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__422, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_cvir_of_mvir_at_z, 4635, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__426)) __PYX_ERR(0, 4635, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4638
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 *     def get_Omega_m_at_z(self,z):             # <<<<<<<<<<<<<<
 *         cdef double tau
 *         cdef int last_index #junk
 */
  __pyx_tuple__427 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_tau, __pyx_n_s_last_index, __pyx_n_s_pvecback, __pyx_n_s_omega); if (unlikely(!__pyx_tuple__427)) __PYX_ERR(0, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__427);
  __Pyx_GIVEREF(__pyx_tuple__427);
  __pyx_codeobj__428 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__427, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_Omega_m_at_z, 4638, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__428)) __PYX_ERR(0, 4638, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4655
 *         return omega
 * 
 *     def get_rvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         omega = self.get_Omega_m_at_z(z)
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)
 */
  __pyx_tuple__429 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_m_asked, __pyx_n_s_z, __pyx_n_s_omega, __pyx_n_s_Delta_c, __pyx_n_s_rhoc); if (unlikely(!__pyx_tuple__429)) __PYX_ERR(0, 4655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__429);
  __Pyx_GIVEREF(__pyx_tuple__429);
  __pyx_codeobj__430 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__429, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_rvir_of_mvir_at_z, 4655, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__430)) __PYX_ERR(0, 4655, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4661
 *         return evaluate_rvir_of_mvir(m_asked,Delta_c,rhoc,&self.tsz);
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200c(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__431 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__343, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2, 4661, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__431)) __PYX_ERR(0, 4661, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4664
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_mass_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__432 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__343, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_mass_profile_at_x_M_z_nfw_20, 4664, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__432)) __PYX_ERR(0, 4664, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4667
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_planck_sigma_at_theta500(self, theta500):             # <<<<<<<<<<<<<<
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 */
  __pyx_tuple__433 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_theta500); if (unlikely(!__pyx_tuple__433)) __PYX_ERR(0, 4667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__433);
  __Pyx_GIVEREF(__pyx_tuple__433);
  __pyx_codeobj__434 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__433, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_planck_sigma_at_theta500, 4667, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__434)) __PYX_ERR(0, 4667, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4670
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 *     def get_szcountsz_sigma_at_theta_in_patch(self, id,theta500):             # <<<<<<<<<<<<<<
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 */
  __pyx_tuple__435 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_id, __pyx_n_s_theta500); if (unlikely(!__pyx_tuple__435)) __PYX_ERR(0, 4670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__435);
  __Pyx_GIVEREF(__pyx_tuple__435);
  __pyx_codeobj__436 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__435, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_szcountsz_sigma_at_theta_in, 4670, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__436)) __PYX_ERR(0, 4670, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4673
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 *     def get_second_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 */
  __pyx_tuple__437 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_nu); if (unlikely(!__pyx_tuple__437)) __PYX_ERR(0, 4673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__437);
  __Pyx_GIVEREF(__pyx_tuple__437);
  __pyx_codeobj__438 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__437, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_second_order_bias_at_z_and_n, 4673, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__438)) __PYX_ERR(0, 4673, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4676
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 *     def get_first_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 */
  __pyx_codeobj__439 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__437, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_first_order_bias_at_z_and_nu, 4676, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__439)) __PYX_ERR(0, 4676, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4679
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_first_order_bias_at_z_and_m_unvectorized(self,z,m):             # <<<<<<<<<<<<<<
 *         nu = self.get_nu_at_z_and_m(z,m)
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 */
  __pyx_tuple__440 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_m, __pyx_n_s_nu); if (unlikely(!__pyx_tuple__440)) __PYX_ERR(0, 4679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__440);
  __Pyx_GIVEREF(__pyx_tuple__440);
  __pyx_codeobj__441 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__440, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_first_order_bias_at_z_and_m, 4679, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__441)) __PYX_ERR(0, 4679, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4685
 * 
 *    # Define the vectorized method
 *     def get_first_order_bias_at_z_and_m(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the first order bias at given redshifts and masses.
 */
  __pyx_codeobj__442 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__326, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_first_order_bias_at_z_and_m_2, 4685, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__442)) __PYX_ERR(0, 4685, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4791
 *     #         raise TypeError("Inputs should be floats or 1D NumPy arrays of type float64, and when both are arrays, they should have the same length.")
 * 
 *     def get_cib_Snu_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 */
  __pyx_codeobj__443 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__437, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_cib_Snu_z_and_nu, 4791, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__443)) __PYX_ERR(0, 4791, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4794
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_sigma_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */
  __pyx_tuple__444 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_m); if (unlikely(!__pyx_tuple__444)) __PYX_ERR(0, 4794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__444);
  __Pyx_GIVEREF(__pyx_tuple__444);
  __pyx_codeobj__445 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_sigma_at_z_and_m, 4794, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__445)) __PYX_ERR(0, 4794, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4797
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_dlnsigma_dlnR_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */
  __pyx_codeobj__446 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_dlnsigma_dlnR_at_z_and_m, 4797, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__446)) __PYX_ERR(0, 4797, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4800
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):
 */
  __pyx_codeobj__447 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_sigma8_at_z, 4800, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__447)) __PYX_ERR(0, 4800, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4802
 *     def get_sigma8_at_z(self,z):
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */
  __pyx_codeobj__448 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_y_at_m_and_z, 4802, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__448)) __PYX_ERR(0, 4802, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4805
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_theta_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */
  __pyx_codeobj__449 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_theta_at_m_and_z, 4805, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__449)) __PYX_ERR(0, 4805, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4808
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_m200m_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_codeobj__450 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m200m_to_m500c_at_z_and_M, 4808, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__450)) __PYX_ERR(0, 4808, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4811
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200c_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_codeobj__451 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m200c_to_m500c_at_z_and_M, 4811, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__451)) __PYX_ERR(0, 4811, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4815
 * 
 * 
 *     def get_m200c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_codeobj__452 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m200c_to_m200m_at_z_and_M, 4815, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__452)) __PYX_ERR(0, 4815, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4818
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_codeobj__453 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m200m_to_m200c_at_z_and_M, 4818, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__453)) __PYX_ERR(0, 4818, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4823
 * 
 * 
 *     def get_m500c_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_codeobj__454 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m500c_to_m200c_at_z_and_M, 4823, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__454)) __PYX_ERR(0, 4823, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4827
 * 
 * 
 *     def get_m500c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_codeobj__455 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_m500c_to_m200m_at_z_and_M, 4827, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__455)) __PYX_ERR(0, 4827, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4831
 * 
 * 
 *     def calcFRel(self,z, M500, obsFreqGHz = 148.0):             # <<<<<<<<<<<<<<
 *         """Calculates relativistic correction to SZ effect at specified frequency, given z, M500 in MSun.
 * 
 */
  __pyx_tuple__456 = PyTuple_Pack(29, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_M500, __pyx_n_s_obsFreqGHz, __pyx_n_s_h, __pyx_n_s_Ez, __pyx_n_s_Eh, __pyx_n_s_hplanck, __pyx_n_s_kB, __pyx_n_s_sigmaT, __pyx_n_s_me, __pyx_n_s_e, __pyx_n_s_c, __pyx_n_s_TCMB, __pyx_n_s_A, __pyx_n_s_B, __pyx_n_s_TkeV, __pyx_n_s_TKelvin, __pyx_n_s_thetae, __pyx_n_s_X, __pyx_n_s_Xtw, __pyx_n_s_Stw, __pyx_n_s_Y0, __pyx_n_s_Y1, __pyx_n_s_Y2, __pyx_n_s_Y3, __pyx_n_s_Y4, __pyx_n_s_deltaSZE, __pyx_n_s_fRel); if (unlikely(!__pyx_tuple__456)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__456);
  __Pyx_GIVEREF(__pyx_tuple__456);
  __pyx_codeobj__457 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 29, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__456, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_calcFRel, 4831, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__457)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __pyx_tuple__458 = PyTuple_Pack(1, __pyx_float_148_0); if (unlikely(!__pyx_tuple__458)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__458);
  __Pyx_GIVEREF(__pyx_tuple__458);

  /* "class-sz/python/classy.pyx":4893
 *         return fRel
 * 
 *     def get_radial_kernel_W_galaxy_lensing_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__459 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_radial_kernel_W_galaxy_lensi, 4893, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__459)) __PYX_ERR(0, 4893, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4896
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 *     def get_custom1_bias_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__460 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_custom1_bias_at_z, 4896, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__460)) __PYX_ERR(0, 4896, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4899
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 *     def get_radial_kernel_W_custom1_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__461 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_radial_kernel_W_custom1_at_z, 4899, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__461)) __PYX_ERR(0, 4899, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4902
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 *     def get_custom1_profile_at_x_m_z(self,double x, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 */
  __pyx_tuple__462 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_x, __pyx_n_s_m, __pyx_n_s_z); if (unlikely(!__pyx_tuple__462)) __PYX_ERR(0, 4902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__462);
  __Pyx_GIVEREF(__pyx_tuple__462);
  __pyx_codeobj__463 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__462, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_custom1_profile_at_x_m_z, 4902, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__463)) __PYX_ERR(0, 4902, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4905
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 *     def get_custom1_profile_at_k_m_z(self,double k, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 */
  __pyx_tuple__464 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_m, __pyx_n_s_z); if (unlikely(!__pyx_tuple__464)) __PYX_ERR(0, 4905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__464);
  __Pyx_GIVEREF(__pyx_tuple__464);
  __pyx_codeobj__465 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__464, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_custom1_profile_at_k_m_z, 4905, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__465)) __PYX_ERR(0, 4905, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4908
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 *     def get_ng_bar_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 */
  __pyx_codeobj__466 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_ng_bar_at_z, 4908, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__466)) __PYX_ERR(0, 4908, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4911
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 *     def get_source_galaxy_number_counts(self,double z):             # <<<<<<<<<<<<<<
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 */
  __pyx_codeobj__467 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_source_galaxy_number_counts, 4911, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__467)) __PYX_ERR(0, 4911, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4914
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 *     def get_N_satellites(self,double z,double M_halo,double Nc_mean,double M_min,double alpha_s,double M1_prime):             # <<<<<<<<<<<<<<
 *         Ns = HOD_mean_number_of_satellite_galaxies(z,M_halo,Nc_mean,M_min,alpha_s,M1_prime,&self.tsz,&self.ba)
 *         return Ns
 */
  __pyx_tuple__468 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_M_halo, __pyx_n_s_Nc_mean, __pyx_n_s_M_min, __pyx_n_s_alpha_s, __pyx_n_s_M1_prime, __pyx_n_s_Ns); if (unlikely(!__pyx_tuple__468)) __PYX_ERR(0, 4914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__468);
  __Pyx_GIVEREF(__pyx_tuple__468);
  __pyx_codeobj__469 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__468, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_N_satellites, 4914, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__469)) __PYX_ERR(0, 4914, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4918
 *         return Ns
 * 
 *     def get_N_centrals(self,double z,double M_halo,double M_min,double sigma_log10M,double fc):             # <<<<<<<<<<<<<<
 *         Nc = HOD_mean_number_of_central_galaxies(z,M_halo,M_min,sigma_log10M,fc,&self.tsz,&self.ba)
 *         return Nc
 */
  __pyx_tuple__470 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_M_halo, __pyx_n_s_M_min, __pyx_n_s_sigma_log10M, __pyx_n_s_fc, __pyx_n_s_Nc); if (unlikely(!__pyx_tuple__470)) __PYX_ERR(0, 4918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__470);
  __Pyx_GIVEREF(__pyx_tuple__470);
  __pyx_codeobj__471 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__470, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_N_centrals, 4918, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__471)) __PYX_ERR(0, 4918, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4923
 * 
 * 
 *     def get_unwise_m_min_cut_at_z(self,double z,int sample_id):             # <<<<<<<<<<<<<<
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 */
  __pyx_tuple__472 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_sample_id); if (unlikely(!__pyx_tuple__472)) __PYX_ERR(0, 4923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__472);
  __Pyx_GIVEREF(__pyx_tuple__472);
  __pyx_codeobj__473 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__472, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_unwise_m_min_cut_at_z, 4923, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__473)) __PYX_ERR(0, 4923, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4926
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 *     def get_yc_at_m_and_z_H13(self,m,z,A,B):             # <<<<<<<<<<<<<<
 *         Eh = self.Hubble(z)/self.Hubble(0)
 *         f_rel = self.calcFRel(z, m)
 */
  __pyx_tuple__474 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_m, __pyx_n_s_z, __pyx_n_s_A, __pyx_n_s_B, __pyx_n_s_Eh, __pyx_n_s_f_rel, __pyx_n_s_vec_theta, __pyx_n_s_theta_500, __pyx_n_s_h, __pyx_n_s_QF, __pyx_n_s_get_Q_of_theta500, __pyx_n_s_yp); if (unlikely(!__pyx_tuple__474)) __PYX_ERR(0, 4926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__474);
  __Pyx_GIVEREF(__pyx_tuple__474);
  __pyx_codeobj__475 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__474, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_yc_at_m_and_z_H13, 4926, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__475)) __PYX_ERR(0, 4926, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4937
 *         return yp
 * 
 *     def _cumulativeNumberDensity(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Returns N > M (per cubic Mpc).
 */
  __pyx_tuple__476 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_h, __pyx_n_s_mm, __pyx_n_s_imp, __pyx_n_s_M, __pyx_n_s_dndlnM, __pyx_n_s_dndM, __pyx_n_s_ngtm, __pyx_n_s_MUpper, __pyx_n_s_extrapolator, __pyx_n_s_MF_extr, __pyx_n_s_intUpper); if (unlikely(!__pyx_tuple__476)) __PYX_ERR(0, 4937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__476);
  __Pyx_GIVEREF(__pyx_tuple__476);
  __pyx_codeobj__477 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__476, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_cumulativeNumberDensity, 4937, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__477)) __PYX_ERR(0, 4937, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4961
 * 
 * 
 *     def getPLog10M(self, z):             # <<<<<<<<<<<<<<
 *         """Returns the log10(mass) probability distribution at the given z, for the logarithmic mass
 *         binning and mass definition set when the MockSurvey object was constructed.
 */
  __pyx_tuple__478 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_numberDensity, __pyx_n_s_mm, __pyx_n_s_imp, __pyx_n_s_M, __pyx_n_s_PLog10M); if (unlikely(!__pyx_tuple__478)) __PYX_ERR(0, 4961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__478);
  __Pyx_GIVEREF(__pyx_tuple__478);
  __pyx_codeobj__479 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__478, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_getPLog10M, 4961, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__479)) __PYX_ERR(0, 4961, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":4980
 *         return PLog10M
 * 
 *     def getM500_from_y0_H13(self,y0,y0Err,A,B,sigma_int,z,applyMFDebiasCorrection = True):             # <<<<<<<<<<<<<<
 *         # y0 is fixed_y_c*1e-4 in the catalogue
 *         # log_y0Err is fixed_err_y_c in the catalogue
 */
  __pyx_tuple__480 = PyTuple_Pack(40, __pyx_n_s_self, __pyx_n_s_y0, __pyx_n_s_y0Err, __pyx_n_s_A, __pyx_n_s_B, __pyx_n_s_sigma_int, __pyx_n_s_z, __pyx_n_s_applyMFDebiasCorrection, __pyx_n_s_M500c_zk, __pyx_n_s_log10M500c_zk, __pyx_n_s_log_y0, __pyx_n_s_log_y0Err, __pyx_n_s_h, __pyx_n_s_m, __pyx_n_s_log_y0pred, __pyx_n_s_Py0GivenM, __pyx_n_s_PLog10M_full, __pyx_n_s_log10Ms, __pyx_n_s_mm, __pyx_n_s_imp, __pyx_n_s_PLog10M, __pyx_n_s_Pz, __pyx_n_s_P, __pyx_n_s_PArr, __pyx_n_s_calcErrors, __pyx_n_s_log10M, __pyx_n_s_tckP, __pyx_n_s_fineLog10M, __pyx_n_s_fineP, __pyx_n_s_index, __pyx_n_s_clusterLogM500, __pyx_n_s_clusterM500, __pyx_n_s_n, __pyx_n_s_minIndex, __pyx_n_s_maxIndex, __pyx_n_s_clusterM500MinusErr, __pyx_n_s_clusterM500PlusErr, __pyx_n_s_p, __pyx_n_s_clusterLogM500Min, __pyx_n_s_clusterLogM500Max); if (unlikely(!__pyx_tuple__480)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__480);
  __Pyx_GIVEREF(__pyx_tuple__480);
  __pyx_codeobj__481 = (PyObject*)__Pyx_PyCode_New(8, 0, 0, 40, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__480, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_getM500_from_y0_H13, 4980, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__481)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __pyx_tuple__482 = PyTuple_Pack(1, Py_True); if (unlikely(!__pyx_tuple__482)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__482);
  __Pyx_GIVEREF(__pyx_tuple__482);

  /* "class-sz/python/classy.pyx":5048
 * 
 * 
 *     def get_bispectrum_f2_kernel(self, double k1, double k2, double k3):             # <<<<<<<<<<<<<<
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 */
  __pyx_tuple__483 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_k1, __pyx_n_s_k2, __pyx_n_s_k3); if (unlikely(!__pyx_tuple__483)) __PYX_ERR(0, 5048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__483);
  __Pyx_GIVEREF(__pyx_tuple__483);
  __pyx_codeobj__484 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__483, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_bispectrum_f2_kernel, 5048, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__484)) __PYX_ERR(0, 5048, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5051
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 *     def get_nu_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         # (delc/sigma)**2
 *         return get_nu_at_z_and_m(z,m,&self.tsz,&self.ba)
 */
  __pyx_codeobj__485 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__444, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_nu_at_z_and_m, 5051, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__485)) __PYX_ERR(0, 5051, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5056
 * 
 * 
 *     def get_matter_bispectrum_at_z_effective_approach_smoothed(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_tuple__486 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_k1_in_h_over_Mpc, __pyx_n_s_k2_in_h_over_Mpc, __pyx_n_s_k3_in_h_over_Mpc, __pyx_n_s_z); if (unlikely(!__pyx_tuple__486)) __PYX_ERR(0, 5056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__486);
  __Pyx_GIVEREF(__pyx_tuple__486);
  __pyx_codeobj__487 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_matter_bispectrum_at_z_effec, 5056, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__487)) __PYX_ERR(0, 5056, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5059
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_codeobj__488 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_ttg_bispectrum_at_z_effectiv, 5059, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__488)) __PYX_ERR(0, 5059, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5062
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_codeobj__489 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_ttg_bispectrum_at_z_tree_lev, 5062, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__489)) __PYX_ERR(0, 5062, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5065
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */
  __pyx_codeobj__490 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_matter_bispectrum_at_z_effec_2, 5065, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__490)) __PYX_ERR(0, 5065, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5067
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */
  __pyx_codeobj__491 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_matter_bispectrum_at_z_effec_3, 5067, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__491)) __PYX_ERR(0, 5067, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5069
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_codeobj__492 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__486, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_matter_bispectrum_at_z_tree, 5069, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__492)) __PYX_ERR(0, 5069, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5072
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):
 */
  __pyx_tuple__493 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_k1_in_h_over_Mpc); if (unlikely(!__pyx_tuple__493)) __PYX_ERR(0, 5072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__493);
  __Pyx_GIVEREF(__pyx_tuple__493);
  __pyx_codeobj__494 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__493, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_nl_index_at_z_and_k, 5072, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__494)) __PYX_ERR(0, 5072, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5074
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k_no_wiggles(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 * 
 */
  __pyx_codeobj__495 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__493, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_nl_index_at_z_and_k_no_wiggl, 5074, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__495)) __PYX_ERR(0, 5074, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5079
 * 
 * 
 *     def get_vrms2_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_vrms2_at_z(z,&self.tsz)
 * 
 */
  __pyx_codeobj__496 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_vrms2_at_z, 5079, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__496)) __PYX_ERR(0, 5079, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5083
 * 
 * 
 *     def get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(self,z,m,x):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 */
  __pyx_tuple__497 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_m, __pyx_n_s_x); if (unlikely(!__pyx_tuple__497)) __PYX_ERR(0, 5083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__497);
  __Pyx_GIVEREF(__pyx_tuple__497);
  __pyx_codeobj__498 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__497, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_1e6xdy_from_battaglia_pressu, 5083, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__498)) __PYX_ERR(0, 5083, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5086
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 *     def get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */
  __pyx_tuple__499 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_m, __pyx_n_s_x, __pyx_n_s_d); if (unlikely(!__pyx_tuple__499)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__499);
  __Pyx_GIVEREF(__pyx_tuple__499);
  __pyx_codeobj__500 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__499, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_1e6xdy_from_gnfw_pressure_at, 5086, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__500)) __PYX_ERR(0, 5086, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5089
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def get_upp_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */
  __pyx_codeobj__501 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__499, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_upp_from_gnfw_pressure_at_x, 5089, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__501)) __PYX_ERR(0, 5089, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5092
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def szunbinned_loglike(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):
 */
  __pyx_codeobj__502 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_szunbinned_loglike, 5092, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__502)) __PYX_ERR(0, 5092, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5094
 *     def szunbinned_loglike(self):
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):
 */
  __pyx_codeobj__503 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_szcounts_ntot, 5094, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__503)) __PYX_ERR(0, 5094, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5096
 *     def szcounts_ntot(self):
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):             # <<<<<<<<<<<<<<
 *         # # lndndzdq =  []
 *         # # print(self.tsz.szcat_size)
 */
  __pyx_tuple__504 = PyTuple_Pack(17, __pyx_n_s_self, __pyx_n_s_nq, __pyx_n_s_qmax, __pyx_n_s_zmin, __pyx_n_s_zmax, __pyx_n_s_nz, __pyx_n_s_q_threshold, __pyx_n_s_q_max, __pyx_n_s_q_arr, __pyx_n_s_z_arr, __pyx_n_s_get_dndzdq, __pyx_n_s_Nz, __pyx_n_s_zp, __pyx_n_s_Ntot, __pyx_n_s_rates, __pyx_n_s_index, __pyx_n_s_loglike); if (unlikely(!__pyx_tuple__504)) __PYX_ERR(0, 5096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__504);
  __Pyx_GIVEREF(__pyx_tuple__504);
  __pyx_codeobj__505 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 17, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__504, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_szcounts_ntot_rates_loglike, 5096, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__505)) __PYX_ERR(0, 5096, __pyx_L1_error)
  __pyx_tuple__506 = PyTuple_Pack(2, __pyx_int_500, __pyx_float_neg_1_0); if (unlikely(!__pyx_tuple__506)) __PYX_ERR(0, 5096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__506);
  __Pyx_GIVEREF(__pyx_tuple__506);

  /* "class-sz/python/classy.pyx":5125
 *         # return Nz
 * 
 *     def dndzdy_theoretical(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the dndzdy theoretical
 */
  __pyx_tuple__507 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_dndzdy, __pyx_n_s_z_center, __pyx_n_s_z_edges, __pyx_n_s_log10y_center, __pyx_n_s_log10y_edges, __pyx_n_s_index_y, __pyx_n_s_index_z, __pyx_n_s_dndzdy_index_z, __pyx_n_s_szcat_z, __pyx_n_s_szcat_snr); if (unlikely(!__pyx_tuple__507)) __PYX_ERR(0, 5125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__507);
  __Pyx_GIVEREF(__pyx_tuple__507);
  __pyx_codeobj__508 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__507, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_dndzdy_theoretical, 5125, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__508)) __PYX_ERR(0, 5125, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5168
 * 
 * 
 *     def get_background(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return an array of the background quantities at all times.
 */
  __pyx_tuple__509 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_titles, __pyx_n_s_data, __pyx_n_s_tmp, __pyx_n_s_names, __pyx_n_s_number_of_titles, __pyx_n_s_timesteps, __pyx_n_s_background, __pyx_n_s_i, __pyx_n_s_index); if (unlikely(!__pyx_tuple__509)) __PYX_ERR(0, 5168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__509);
  __Pyx_GIVEREF(__pyx_tuple__509);
  __pyx_codeobj__510 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__509, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_background, 5168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__510)) __PYX_ERR(0, 5168, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5208
 *         return background
 * 
 *     def get_thermodynamics(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the thermodynamics quantities.
 */
  __pyx_tuple__511 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_titles, __pyx_n_s_data, __pyx_n_s_tmp, __pyx_n_s_names, __pyx_n_s_number_of_titles, __pyx_n_s_timesteps, __pyx_n_s_thermodynamics, __pyx_n_s_i, __pyx_n_s_index); if (unlikely(!__pyx_tuple__511)) __PYX_ERR(0, 5208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__511);
  __Pyx_GIVEREF(__pyx_tuple__511);
  __pyx_codeobj__512 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__511, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_thermodynamics, 5208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__512)) __PYX_ERR(0, 5208, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5246
 *         return thermodynamics
 * 
 *     def get_primordial(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the primordial scalar and/or tensor spectrum depending on 'modes'.
 */
  __pyx_tuple__513 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_titles, __pyx_n_s_data, __pyx_n_s_tmp, __pyx_n_s_names, __pyx_n_s_number_of_titles, __pyx_n_s_timesteps, __pyx_n_s_primordial, __pyx_n_s_i, __pyx_n_s_index); if (unlikely(!__pyx_tuple__513)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__513);
  __Pyx_GIVEREF(__pyx_tuple__513);
  __pyx_codeobj__514 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__513, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_primordial, 5246, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__514)) __PYX_ERR(0, 5246, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5286
 * 
 * 
 *     @cython.returns(dict)             # <<<<<<<<<<<<<<
 *     @cython.initializedcheck(False)
 *     @cython.boundscheck(False)
 */
  __pyx_codeobj__515 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_perturbations, 5286, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__515)) __PYX_ERR(0, 5286, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5359
 *         return perturbations
 * 
 *     def get_transfer(self, z=0., output_format='class'):             # <<<<<<<<<<<<<<
 *         """
 *         Return the density and/or velocity transfer functions for all initial
 */
  __pyx_tuple__516 = PyTuple_Pack(21, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_output_format, __pyx_n_s_titles, __pyx_n_s_data, __pyx_n_s_ic_info, __pyx_n_s_ic_suffix, __pyx_n_s_outf, __pyx_n_s_index_md, __pyx_n_s_tmp, __pyx_n_s_names, __pyx_n_s_number_of_titles, __pyx_n_s_timesteps, __pyx_n_s_size_ic_data, __pyx_n_s_ic_num, __pyx_n_s_transfers, __pyx_n_s_index_ic, __pyx_n_s_ic_key, __pyx_n_s_tmpdict, __pyx_n_s_i, __pyx_n_s_index); if (unlikely(!__pyx_tuple__516)) __PYX_ERR(0, 5359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__516);
  __Pyx_GIVEREF(__pyx_tuple__516);
  __pyx_codeobj__517 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 21, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__516, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_transfer, 5359, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__517)) __PYX_ERR(0, 5359, __pyx_L1_error)
  __pyx_tuple__518 = PyTuple_Pack(2, __pyx_float_0_, __pyx_n_u_class_2); if (unlikely(!__pyx_tuple__518)) __PYX_ERR(0, 5359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__518);
  __Pyx_GIVEREF(__pyx_tuple__518);

  /* "class-sz/python/classy.pyx":5433
 *         return transfers
 * 
 *     def get_current_derived_parameters(self, names):             # <<<<<<<<<<<<<<
 *         """
 *         get_current_derived_parameters(names)
 */
  __pyx_tuple__519 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_names, __pyx_n_s_derived, __pyx_n_s_name, __pyx_n_s_value, __pyx_n_s_params_settings, __pyx_n_s_lna, __pyx_n_s_eps1, __pyx_n_s_eps2, __pyx_n_s_eps23); if (unlikely(!__pyx_tuple__519)) __PYX_ERR(0, 5433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__519);
  __Pyx_GIVEREF(__pyx_tuple__519);
  __pyx_codeobj__520 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__519, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_current_derived_parameters, 5433, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__520)) __PYX_ERR(0, 5433, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5696
 *         return derived
 * 
 *     def nonlinear_scale(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_scale(z, z_size)
 */
  __pyx_tuple__521 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_z_size, __pyx_n_s_index_z, __pyx_n_s_k_nl, __pyx_n_s_k_nl_cb); if (unlikely(!__pyx_tuple__521)) __PYX_ERR(0, 5696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__521);
  __Pyx_GIVEREF(__pyx_tuple__521);
  __pyx_codeobj__522 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__521, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_scale, 5696, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__522)) __PYX_ERR(0, 5696, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5721
 *         return k_nl
 * 
 *     def nonlinear_scale_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 * 
 */
  __pyx_codeobj__523 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__521, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_scale_cb, 5721, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__523)) __PYX_ERR(0, 5721, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5752
 *         return k_nl_cb
 * 
 *     def nonlinear_hmcode_sigma8(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */
  __pyx_tuple__524 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_z_size, __pyx_n_s_index_z, __pyx_n_s_sigma_8, __pyx_n_s_sigma_8_cb); if (unlikely(!__pyx_tuple__524)) __PYX_ERR(0, 5752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__524);
  __Pyx_GIVEREF(__pyx_tuple__524);
  __pyx_codeobj__525 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__524, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigma8, 5752, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__525)) __PYX_ERR(0, 5752, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5770
 *         return sigma_8
 * 
 *     def nonlinear_hmcode_sigma8_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */
  __pyx_codeobj__526 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__524, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigma8_cb, 5770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__526)) __PYX_ERR(0, 5770, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5788
 *         return sigma_8_cb
 * 
 *     def nonlinear_hmcode_sigmadisp(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */
  __pyx_tuple__527 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_z_size, __pyx_n_s_index_z, __pyx_n_s_sigma_disp, __pyx_n_s_sigma_disp_cb); if (unlikely(!__pyx_tuple__527)) __PYX_ERR(0, 5788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__527);
  __Pyx_GIVEREF(__pyx_tuple__527);
  __pyx_codeobj__528 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__527, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigmadisp, 5788, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__528)) __PYX_ERR(0, 5788, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5812
 *         return sigma_disp
 * 
 *     def nonlinear_hmcode_sigmadisp_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */
  __pyx_codeobj__529 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__527, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigmadisp_cb, 5812, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__529)) __PYX_ERR(0, 5812, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5836
 *         return sigma_disp_cb
 * 
 *     def nonlinear_hmcode_sigmadisp100(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */
  __pyx_tuple__530 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_z_size, __pyx_n_s_index_z, __pyx_n_s_sigma_disp_100, __pyx_n_s_sigma_disp_100_cb); if (unlikely(!__pyx_tuple__530)) __PYX_ERR(0, 5836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__530);
  __Pyx_GIVEREF(__pyx_tuple__530);
  __pyx_codeobj__531 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__530, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigmadisp100, 5836, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__531)) __PYX_ERR(0, 5836, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5860
 *         return sigma_disp_100
 * 
 *     def nonlinear_hmcode_sigmadisp100_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */
  __pyx_codeobj__532 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__530, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigmadisp100_cb, 5860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__532)) __PYX_ERR(0, 5860, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5884
 *         return sigma_disp_100_cb
 * 
 *     def nonlinear_hmcode_sigmaprime(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */
  __pyx_tuple__533 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_z, __pyx_n_s_z_size, __pyx_n_s_index_z, __pyx_n_s_sigma_prime, __pyx_n_s_sigma_prime_cb); if (unlikely(!__pyx_tuple__533)) __PYX_ERR(0, 5884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__533);
  __Pyx_GIVEREF(__pyx_tuple__533);
  __pyx_codeobj__534 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__533, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigmaprime, 5884, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__534)) __PYX_ERR(0, 5884, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5908
 *         return sigma_prime
 * 
 *     def nonlinear_hmcode_sigmaprime_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */
  __pyx_codeobj__535 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__533, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_nonlinear_hmcode_sigmaprime_cb, 5908, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__535)) __PYX_ERR(0, 5908, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5966
 *         ctx.add('cosmo', self)
 * 
 *     def get_pk_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */
  __pyx_tuple__536 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_k, __pyx_n_s_z, __pyx_n_s_k_size, __pyx_n_s_z_size, __pyx_n_s_nonlinear, __pyx_n_s_pk, __pyx_n_s_pk_cb); if (unlikely(!__pyx_tuple__536)) __PYX_ERR(0, 5966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__536);
  __Pyx_GIVEREF(__pyx_tuple__536);
  __pyx_codeobj__537 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__536, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_array, 5966, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__537)) __PYX_ERR(0, 5966, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5979
 *         return pk
 * 
 *     def get_pk_cb_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */
  __pyx_codeobj__538 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__536, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_pk_cb_array, 5979, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__538)) __PYX_ERR(0, 5979, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5992
 *         return pk_cb
 * 
 *     def get_fftlog_ComputeXiLMsloz(self, int l, int m, int N, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] pk, np.ndarray[DTYPE_t,ndim=1] r, np.ndarray[DTYPE_t,ndim=1] xi):             # <<<<<<<<<<<<<<
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 */
  __pyx_tuple__539 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_l, __pyx_n_s_m, __pyx_n_s_N, __pyx_n_s_k, __pyx_n_s_pk, __pyx_n_s_r, __pyx_n_s_xi); if (unlikely(!__pyx_tuple__539)) __PYX_ERR(0, 5992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__539);
  __Pyx_GIVEREF(__pyx_tuple__539);
  __pyx_codeobj__540 = (PyObject*)__Pyx_PyCode_New(8, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__539, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_fftlog_ComputeXiLMsloz, 5992, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__540)) __PYX_ERR(0, 5992, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5995
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 *     def get_n5k_z_of_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 */
  __pyx_codeobj__541 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__209, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_n5k_z_of_chi, 5995, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__541)) __PYX_ERR(0, 5995, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":5998
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 *     def get_n5k_pk_at_z_and_k(self, double z_asked, double k_asked):             # <<<<<<<<<<<<<<
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 */
  __pyx_tuple__542 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_z_asked, __pyx_n_s_k_asked); if (unlikely(!__pyx_tuple__542)) __PYX_ERR(0, 5998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__542);
  __Pyx_GIVEREF(__pyx_tuple__542);
  __pyx_codeobj__543 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__542, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_n5k_pk_at_z_and_k, 5998, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__543)) __PYX_ERR(0, 5998, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":6001
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 *     def get_n5k_cl_K1_at_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 */
  __pyx_codeobj__544 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__209, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_get_n5k_cl_K1_at_chi, 6001, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__544)) __PYX_ERR(0, 6001, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":6004
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 *     def load_n5k_cl_K1(self):             # <<<<<<<<<<<<<<
 *         load_n5k_cl_K1(&self.tsz)
 *         return 1
 */
  __pyx_codeobj__545 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_load_n5k_cl_K1, 6004, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__545)) __PYX_ERR(0, 6004, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":6008
 *         return 1
 * 
 *     def load_n5k_pk_zk(self):             # <<<<<<<<<<<<<<
 *         load_n5k_pk_zk(&self.tsz)
 *         return 1
 */
  __pyx_codeobj__546 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_load_n5k_pk_zk, 6008, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__546)) __PYX_ERR(0, 6008, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":6012
 *         return 1
 * 
 *     def load_n5k_z_of_chi(self):             # <<<<<<<<<<<<<<
 *         load_n5k_z_of_chi(&self.tsz)
 *         return 1
 */
  __pyx_codeobj__547 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_load_n5k_z_of_chi, 6012, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__547)) __PYX_ERR(0, 6012, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":6017
 * 
 * 
 *     def Omega0_k(self):             # <<<<<<<<<<<<<<
 *         """ Curvature contribution """
 *         return self.ba.Omega0_k
 */
  __pyx_codeobj__548 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega0_k, 6017, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__548)) __PYX_ERR(0, 6017, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":6021
 *         return self.ba.Omega0_k
 * 
 *     def Omega0_cdm(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the cold dark matter density parameter at present time.
 */
  __pyx_codeobj__549 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega0_cdm, 6021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__549)) __PYX_ERR(0, 6021, __pyx_L1_error)

  /* "class-sz/python/classy.pyx":6030
 *         return self.ba.Omega0_cdm
 * 
 *     def Omega0_b(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the baryon density parameter at present time.
 */
  __pyx_codeobj__550 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_class_sz_python_classy_pyx, __pyx_n_s_Omega0_b, 6030, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__550)) __PYX_ERR(0, 6030, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__551 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__78, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__551)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_tuple__552 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__552)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__552);
  __Pyx_GIVEREF(__pyx_tuple__552);
  __pyx_codeobj__553 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__552, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__553)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_get.method_name = &__pyx_n_s_get;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_float_0_ = PyFloat_FromDouble(0.); if (unlikely(!__pyx_float_0_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_ = PyFloat_FromDouble(1.); if (unlikely(!__pyx_float_1_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_ = PyFloat_FromDouble(2.); if (unlikely(!__pyx_float_2_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_ = PyFloat_FromDouble(3.); if (unlikely(!__pyx_float_3_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4_ = PyFloat_FromDouble(4.); if (unlikely(!__pyx_float_4_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5_ = PyFloat_FromDouble(5.); if (unlikely(!__pyx_float_5_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_0 = PyFloat_FromDouble(0.0); if (unlikely(!__pyx_float_0_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_1 = PyFloat_FromDouble(0.1); if (unlikely(!__pyx_float_0_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_5 = PyFloat_FromDouble(0.5); if (unlikely(!__pyx_float_0_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_0 = PyFloat_FromDouble(1.0); if (unlikely(!__pyx_float_1_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_10_ = PyFloat_FromDouble(10.); if (unlikely(!__pyx_float_10_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1e9 = PyFloat_FromDouble(1e9); if (unlikely(!__pyx_float_1e9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_02 = PyFloat_FromDouble(0.02); if (unlikely(!__pyx_float_0_02)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_04 = PyFloat_FromDouble(0.04); if (unlikely(!__pyx_float_0_04)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_19 = PyFloat_FromDouble(0.19); if (unlikely(!__pyx_float_0_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_29 = PyFloat_FromDouble(0.29); if (unlikely(!__pyx_float_0_29)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_88 = PyFloat_FromDouble(0.88); if (unlikely(!__pyx_float_0_88)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_100_ = PyFloat_FromDouble(100.); if (unlikely(!__pyx_float_100_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_18_1 = PyFloat_FromDouble(18.1); if (unlikely(!__pyx_float_18_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1e14 = PyFloat_FromDouble(1e14); if (unlikely(!__pyx_float_1e14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1e16 = PyFloat_FromDouble(1e16); if (unlikely(!__pyx_float_1e16)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_200_ = PyFloat_FromDouble(200.); if (unlikely(!__pyx_float_200_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_3_83 = PyFloat_FromDouble(3.83); if (unlikely(!__pyx_float_3_83)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4_35 = PyFloat_FromDouble(4.35); if (unlikely(!__pyx_float_4_35)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_4_e3 = PyFloat_FromDouble(4.e3); if (unlikely(!__pyx_float_4_e3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_500_ = PyFloat_FromDouble(500.); if (unlikely(!__pyx_float_500_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_154 = PyFloat_FromDouble(0.154); if (unlikely(!__pyx_float_0_154)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_415 = PyFloat_FromDouble(0.415); if (unlikely(!__pyx_float_0_415)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_497 = PyFloat_FromDouble(0.497); if (unlikely(!__pyx_float_0_497)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_731 = PyFloat_FromDouble(0.731); if (unlikely(!__pyx_float_0_731)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_156 = PyFloat_FromDouble(1.156); if (unlikely(!__pyx_float_1_156)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_148_0 = PyFloat_FromDouble(148.0); if (unlikely(!__pyx_float_148_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1eneg_10 = PyFloat_FromDouble(1e-10); if (unlikely(!__pyx_float_1eneg_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_8_130 = PyFloat_FromDouble(8.130); if (unlikely(!__pyx_float_8_130)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_0393 = PyFloat_FromDouble(0.0393); if (unlikely(!__pyx_float_0_0393)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_3292 = PyFloat_FromDouble(0.3292); if (unlikely(!__pyx_float_0_3292)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_6827 = PyFloat_FromDouble(0.6827); if (unlikely(!__pyx_float_0_6827)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_9665 = PyFloat_FromDouble(0.9665); if (unlikely(!__pyx_float_0_9665)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_0620 = PyFloat_FromDouble(1.0620); if (unlikely(!__pyx_float_1_0620)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1eneg_100 = PyFloat_FromDouble(1e-100); if (unlikely(!__pyx_float_1eneg_100)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_5_4807 = PyFloat_FromDouble(5.4807); if (unlikely(!__pyx_float_5_4807)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_00441 = PyFloat_FromDouble(0.00441); if (unlikely(!__pyx_float_0_00441)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_022383 = PyFloat_FromDouble(0.022383); if (unlikely(!__pyx_float_0_022383)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_2_61051eneg_18 = PyFloat_FromDouble(2.61051e-18); if (unlikely(!__pyx_float_2_61051eneg_18)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_1_00000000e_12 = PyFloat_FromDouble(1.00000000e+12); if (unlikely(!__pyx_float_1_00000000e_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_2_ = PyFloat_FromDouble(-2.); if (unlikely(!__pyx_float_neg_2_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_2 = PyFloat_FromDouble(-0.2); if (unlikely(!__pyx_float_neg_0_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_3 = PyFloat_FromDouble(-0.3); if (unlikely(!__pyx_float_neg_0_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_1_0 = PyFloat_FromDouble(-1.0); if (unlikely(!__pyx_float_neg_1_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_10_ = PyFloat_FromDouble(-10.); if (unlikely(!__pyx_float_neg_10_)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_03 = PyFloat_FromDouble(-0.03); if (unlikely(!__pyx_float_neg_0_03)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_66 = PyFloat_FromDouble(-0.66); if (unlikely(!__pyx_float_neg_0_66)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_025 = PyFloat_FromDouble(-0.025); if (unlikely(!__pyx_float_neg_0_025)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_758 = PyFloat_FromDouble(-0.758); if (unlikely(!__pyx_float_neg_0_758)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_neg_0_00865 = PyFloat_FromDouble(-0.00865); if (unlikely(!__pyx_float_neg_0_00865)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_9 = PyInt_FromLong(9); if (unlikely(!__pyx_int_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_100 = PyInt_FromLong(100); if (unlikely(!__pyx_int_100)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_200 = PyInt_FromLong(200); if (unlikely(!__pyx_int_200)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_300 = PyInt_FromLong(300); if (unlikely(!__pyx_int_300)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_500 = PyInt_FromLong(500); if (unlikely(!__pyx_int_500)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_600 = PyInt_FromLong(600); if (unlikely(!__pyx_int_600)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1024 = PyInt_FromLong(1024); if (unlikely(!__pyx_int_1024)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10000 = PyInt_FromLong(10000L); if (unlikely(!__pyx_int_10000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_20000 = PyInt_FromLong(20000L); if (unlikely(!__pyx_int_20000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_112105877 = PyInt_FromLong(112105877L); if (unlikely(!__pyx_int_112105877)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_136983863 = PyInt_FromLong(136983863L); if (unlikely(!__pyx_int_136983863)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_184977713 = PyInt_FromLong(184977713L); if (unlikely(!__pyx_int_184977713)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10000000000 = PyInt_FromString((char *)"10000000000", 0, 0); if (unlikely(!__pyx_int_10000000000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0xde0b6b3a7640000 = PyInt_FromString((char *)"0xde0b6b3a7640000", 0, 0); if (unlikely(!__pyx_int_0xde0b6b3a7640000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_4 = PyInt_FromLong(-4); if (unlikely(!__pyx_int_neg_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_6 = PyInt_FromLong(-6); if (unlikely(!__pyx_int_neg_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* NumpyImportArray.init */
  /*
 * Cython has automatically inserted a call to _import_array since
 * you didn't include one when you cimported numpy. To disable this
 * add the line
 *   <void>numpy._import_array
 */
#ifdef NPY_FEATURE_VERSION
#ifndef NO_IMPORT_ARRAY
if (unlikely(_import_array() == -1)) {
    PyErr_SetString(PyExc_ImportError, "numpy.core.multiarray failed to import "
    "(auto-generated because you didn't call 'numpy.import_array()' after cimporting numpy; "
    "use '<void>numpy._import_array' to disable if you are certain you don't need it).");
}
#endif
#endif

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_collections_abc_Sequence = Py_None; Py_INCREF(Py_None);
  generic = Py_None; Py_INCREF(Py_None);
  strided = Py_None; Py_INCREF(Py_None);
  indirect = Py_None; Py_INCREF(Py_None);
  contiguous = Py_None; Py_INCREF(Py_None);
  indirect_contiguous = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_9classy_sz_Class = &__pyx_vtable_9classy_sz_Class;
  __pyx_vtable_9classy_sz_Class.get_perturbations = (PyObject *(*)(struct __pyx_obj_9classy_sz_Class *, int __pyx_skip_dispatch))__pyx_f_9classy_sz_5Class_get_perturbations;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9classy_sz_Class = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9classy_sz_Class_spec, NULL); if (unlikely(!__pyx_ptype_9classy_sz_Class)) __PYX_ERR(0, 208, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9classy_sz_Class_spec, __pyx_ptype_9classy_sz_Class) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  #else
  __pyx_ptype_9classy_sz_Class = &__pyx_type_9classy_sz_Class;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9classy_sz_Class) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9classy_sz_Class->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9classy_sz_Class->tp_dictoffset && __pyx_ptype_9classy_sz_Class->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9classy_sz_Class->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_UPDATE_DESCRIPTOR_DOC
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)__pyx_ptype_9classy_sz_Class, "__call__"); if (unlikely(!wrapper)) __PYX_ERR(0, 208, __pyx_L1_error)
    if (__Pyx_IS_TYPE(wrapper, &PyWrapperDescr_Type)) {
      __pyx_wrapperbase_9classy_sz_5Class_598__call__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_9classy_sz_5Class_598__call__.doc = __pyx_doc_9classy_sz_5Class_598__call__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_9classy_sz_5Class_598__call__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_9classy_sz_Class, __pyx_vtabptr_9classy_sz_Class) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_9classy_sz_Class) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Class, (PyObject *) __pyx_ptype_9classy_sz_Class) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_9classy_sz_Class) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings_spec, NULL); if (unlikely(!__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings)) __PYX_ERR(0, 52, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings_spec, __pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  #else
  __pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings = &__pyx_type_9classy_sz___pyx_scope_struct__suppress_warnings;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings->tp_dictoffset && __pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9classy_sz___pyx_scope_struct__suppress_warnings->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast_spec, NULL); if (unlikely(!__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast)) __PYX_ERR(0, 727, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast_spec, __pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast) < 0) __PYX_ERR(0, 727, __pyx_L1_error)
  #else
  __pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast = &__pyx_type_9classy_sz___pyx_scope_struct_1_compute_class_szfast;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast) < 0) __PYX_ERR(0, 727, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast->tp_dictoffset && __pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9classy_sz___pyx_scope_struct_1_compute_class_szfast->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9classy_sz___pyx_scope_struct_2_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr)) __PYX_ERR(0, 856, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9classy_sz___pyx_scope_struct_2_genexpr_spec, __pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 856, __pyx_L1_error)
  #else
  __pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr = &__pyx_type_9classy_sz___pyx_scope_struct_2_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr) < 0) __PYX_ERR(0, 856, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr->tp_dictoffset && __pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9classy_sz___pyx_scope_struct_2_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl_spec, NULL); if (unlikely(!__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl)) __PYX_ERR(0, 4234, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl_spec, __pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl) < 0) __PYX_ERR(0, 4234, __pyx_L1_error)
  #else
  __pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl = &__pyx_type_9classy_sz___pyx_scope_struct_3_get_pkl;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl) < 0) __PYX_ERR(0, 4234, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl->tp_dictoffset && __pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9classy_sz___pyx_scope_struct_3_get_pkl->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl_spec, NULL); if (unlikely(!__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl)) __PYX_ERR(0, 4279, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl_spec, __pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl) < 0) __PYX_ERR(0, 4279, __pyx_L1_error)
  #else
  __pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl = &__pyx_type_9classy_sz___pyx_scope_struct_4_get_pknl;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl) < 0) __PYX_ERR(0, 4279, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl->tp_dictoffset && __pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9classy_sz___pyx_scope_struct_4_get_pknl->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw_spec, NULL); if (unlikely(!__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw)) __PYX_ERR(0, 4533, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw_spec, __pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw) < 0) __PYX_ERR(0, 4533, __pyx_L1_error)
  #else
  __pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw = &__pyx_type_9classy_sz___pyx_scope_struct_5_get_uk_nfw;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw) < 0) __PYX_ERR(0, 4533, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw->tp_dictoffset && __pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_9classy_sz___pyx_scope_struct_5_get_uk_nfw->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  __pyx_vtabptr_array = &__pyx_vtable_array;
  __pyx_vtable_array.get_memview = (PyObject *(*)(struct __pyx_array_obj *))__pyx_array_get_memview;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_array_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_array_spec, NULL); if (unlikely(!__pyx_array_type)) __PYX_ERR(1, 114, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_array_type->tp_as_buffer = &__pyx_tp_as_buffer_array;
  if (!__pyx_array_type->tp_as_buffer->bf_releasebuffer && __pyx_array_type->tp_base->tp_as_buffer && __pyx_array_type->tp_base->tp_as_buffer->bf_releasebuffer) {
    __pyx_array_type->tp_as_buffer->bf_releasebuffer = __pyx_array_type->tp_base->tp_as_buffer->bf_releasebuffer;
  }
  #elif defined(Py_bf_getbuffer) && defined(Py_bf_releasebuffer)
  /* PY_VERSION_HEX >= 0x03090000 || Py_LIMITED_API >= 0x030B0000 */
  #elif defined(_MSC_VER)
  #pragma message ("The buffer protocol is not supported in the Limited C-API < 3.11.")
  #else
  #warning "The buffer protocol is not supported in the Limited C-API < 3.11."
  #endif
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_array_spec, __pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #else
  __pyx_array_type = &__pyx_type___pyx_array;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_array_type->tp_print = 0;
  #endif
  if (__Pyx_SetVtable(__pyx_array_type, __pyx_vtabptr_array) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_MemviewEnum_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_MemviewEnum_spec, NULL); if (unlikely(!__pyx_MemviewEnum_type)) __PYX_ERR(1, 302, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_MemviewEnum_spec, __pyx_MemviewEnum_type) < 0) __PYX_ERR(1, 302, __pyx_L1_error)
  #else
  __pyx_MemviewEnum_type = &__pyx_type___pyx_MemviewEnum;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_MemviewEnum_type) < 0) __PYX_ERR(1, 302, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_MemviewEnum_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_MemviewEnum_type->tp_dictoffset && __pyx_MemviewEnum_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_MemviewEnum_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_MemviewEnum_type) < 0) __PYX_ERR(1, 302, __pyx_L1_error)
  #endif
  __pyx_vtabptr_memoryview = &__pyx_vtable_memoryview;
  __pyx_vtable_memoryview.get_item_pointer = (char *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_get_item_pointer;
  __pyx_vtable_memoryview.is_slice = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_is_slice;
  __pyx_vtable_memoryview.setitem_slice_assignment = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_slice_assignment;
  __pyx_vtable_memoryview.setitem_slice_assign_scalar = (PyObject *(*)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_setitem_slice_assign_scalar;
  __pyx_vtable_memoryview.setitem_indexed = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_indexed;
  __pyx_vtable_memoryview.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryview_convert_item_to_object;
  __pyx_vtable_memoryview.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryview_assign_item_from_object;
  __pyx_vtable_memoryview._get_base = (PyObject *(*)(struct __pyx_memoryview_obj *))__pyx_memoryview__get_base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_memoryview_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_memoryview_spec, NULL); if (unlikely(!__pyx_memoryview_type)) __PYX_ERR(1, 337, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_memoryview_type->tp_as_buffer = &__pyx_tp_as_buffer_memoryview;
  if (!__pyx_memoryview_type->tp_as_buffer->bf_releasebuffer && __pyx_memoryview_type->tp_base->tp_as_buffer && __pyx_memoryview_type->tp_base->tp_as_buffer->bf_releasebuffer) {
    __pyx_memoryview_type->tp_as_buffer->bf_releasebuffer = __pyx_memoryview_type->tp_base->tp_as_buffer->bf_releasebuffer;
  }
  #elif defined(Py_bf_getbuffer) && defined(Py_bf_releasebuffer)
  /* PY_VERSION_HEX >= 0x03090000 || Py_LIMITED_API >= 0x030B0000 */
  #elif defined(_MSC_VER)
  #pragma message ("The buffer protocol is not supported in the Limited C-API < 3.11.")
  #else
  #warning "The buffer protocol is not supported in the Limited C-API < 3.11."
  #endif
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_memoryview_spec, __pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #else
  __pyx_memoryview_type = &__pyx_type___pyx_memoryview;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_memoryview_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_memoryview_type->tp_dictoffset && __pyx_memoryview_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_memoryview_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_memoryview_type, __pyx_vtabptr_memoryview) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #endif
  __pyx_vtabptr__memoryviewslice = &__pyx_vtable__memoryviewslice;
  __pyx_vtable__memoryviewslice.__pyx_base = *__pyx_vtabptr_memoryview;
  __pyx_vtable__memoryviewslice.__pyx_base.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryviewslice_convert_item_to_object;
  __pyx_vtable__memoryviewslice.__pyx_base.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryviewslice_assign_item_from_object;
  __pyx_vtable__memoryviewslice.__pyx_base._get_base = (PyObject *(*)(struct __pyx_memoryview_obj *))__pyx_memoryviewslice__get_base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_memoryview_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_memoryviewslice_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_memoryviewslice_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_memoryviewslice_type)) __PYX_ERR(1, 952, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_memoryviewslice_spec, __pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #else
  __pyx_memoryviewslice_type = &__pyx_type___pyx_memoryviewslice;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_memoryviewslice_type->tp_base = __pyx_memoryview_type;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_memoryviewslice_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_memoryviewslice_type->tp_dictoffset && __pyx_memoryviewslice_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_memoryviewslice_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_memoryviewslice_type, __pyx_vtabptr__memoryviewslice) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_0_11(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyArray_Descr),__Pyx_ImportType_CheckSize_Ignore_3_0_11); if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(2, 271, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyArrayIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_11); if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(2, 316, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyArrayMultiIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_11); if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(2, 320, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyArrayObject),__Pyx_ImportType_CheckSize_Ignore_3_0_11); if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(2, 359, __pyx_L1_error)
  __pyx_ptype_5numpy_generic = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "generic", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_generic) __PYX_ERR(2, 848, __pyx_L1_error)
  __pyx_ptype_5numpy_number = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "number", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_number) __PYX_ERR(2, 850, __pyx_L1_error)
  __pyx_ptype_5numpy_integer = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "integer", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_integer) __PYX_ERR(2, 852, __pyx_L1_error)
  __pyx_ptype_5numpy_signedinteger = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "signedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_signedinteger) __PYX_ERR(2, 854, __pyx_L1_error)
  __pyx_ptype_5numpy_unsignedinteger = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "unsignedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_unsignedinteger) __PYX_ERR(2, 856, __pyx_L1_error)
  __pyx_ptype_5numpy_inexact = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "inexact", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_inexact) __PYX_ERR(2, 858, __pyx_L1_error)
  __pyx_ptype_5numpy_floating = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "floating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_floating) __PYX_ERR(2, 860, __pyx_L1_error)
  __pyx_ptype_5numpy_complexfloating = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "complexfloating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_complexfloating) __PYX_ERR(2, 862, __pyx_L1_error)
  __pyx_ptype_5numpy_flexible = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "flexible", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_flexible) __PYX_ERR(2, 864, __pyx_L1_error)
  __pyx_ptype_5numpy_character = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "character", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_11); if (!__pyx_ptype_5numpy_character) __PYX_ERR(2, 866, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType_3_0_11(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_11(PyUFuncObject),__Pyx_ImportType_CheckSize_Ignore_3_0_11); if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(2, 930, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_classy_sz(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_classy_sz},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "classy_sz",
      __pyx_k_module_classy_sz_synopsis_Pytho, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initclassy_sz(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initclassy_sz(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_classy_sz(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_classy_sz(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_classy_sz(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  static PyThread_type_lock __pyx_t_8[8];
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'classy_sz' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("classy_sz", __pyx_methods, __pyx_k_module_classy_sz_synopsis_Pytho, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "classy_sz" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_classy_sz(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_classy_sz) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "classy_sz")) {
      if (unlikely((PyDict_SetItemString(modules, "classy_sz", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_version_info); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_tuple__52, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {

        /* "View.MemoryView":101
 * try:
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence             # <<<<<<<<<<<<<<
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__53, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_abc); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Sequence); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
        __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;

        /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
        goto __pyx_L8;
      }

      /* "View.MemoryView":103
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence             # <<<<<<<<<<<<<<
 * except:
 * 
 */
      /*else*/ {
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 103, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_Sequence); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 103, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
        __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
      }
      __pyx_L8:;

      /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L7_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "View.MemoryView":104
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 * except:             # <<<<<<<<<<<<<<
 * 
 *     __pyx_collections_abc_Sequence = None
 */
    /*except:*/ {
      __Pyx_AddTraceback("View.MemoryView", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(1, 104, __pyx_L4_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "View.MemoryView":106
 * except:
 * 
 *     __pyx_collections_abc_Sequence = None             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
      __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L3_exception_handled;
    }

    /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L7_try_end:;
  }

  /* "View.MemoryView":241
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "View.MemoryView":242
 * 
 *     try:
 *         count = __pyx_collections_abc_Sequence.count             # <<<<<<<<<<<<<<
 *         index = __pyx_collections_abc_Sequence.index
 *     except:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 242, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_array_type, __pyx_n_s_count, __pyx_t_7) < 0) __PYX_ERR(1, 242, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_array_type);

      /* "View.MemoryView":243
 *     try:
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index             # <<<<<<<<<<<<<<
 *     except:
 *         pass
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 243, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_array_type, __pyx_n_s_index, __pyx_t_7) < 0) __PYX_ERR(1, 243, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_array_type);

      /* "View.MemoryView":241
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":244
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 *     except:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L12_exception_handled;
    }
    __pyx_L12_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L16_try_end:;
  }

  /* "View.MemoryView":309
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(generic);
  __Pyx_DECREF_SET(generic, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":310
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__56, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(strided);
  __Pyx_DECREF_SET(strided, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":311
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(indirect);
  __Pyx_DECREF_SET(indirect, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":314
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(contiguous);
  __Pyx_DECREF_SET(contiguous, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":315
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(indirect_contiguous);
  __Pyx_DECREF_SET(indirect_contiguous, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":323
 * 
 * 
 * cdef int __pyx_memoryview_thread_locks_used = 0             # <<<<<<<<<<<<<<
 * cdef PyThread_type_lock[8] __pyx_memoryview_thread_locks = [
 *     PyThread_allocate_lock(),
 */
  __pyx_memoryview_thread_locks_used = 0;

  /* "View.MemoryView":324
 * 
 * cdef int __pyx_memoryview_thread_locks_used = 0
 * cdef PyThread_type_lock[8] __pyx_memoryview_thread_locks = [             # <<<<<<<<<<<<<<
 *     PyThread_allocate_lock(),
 *     PyThread_allocate_lock(),
 */
  __pyx_t_8[0] = PyThread_allocate_lock();
  __pyx_t_8[1] = PyThread_allocate_lock();
  __pyx_t_8[2] = PyThread_allocate_lock();
  __pyx_t_8[3] = PyThread_allocate_lock();
  __pyx_t_8[4] = PyThread_allocate_lock();
  __pyx_t_8[5] = PyThread_allocate_lock();
  __pyx_t_8[6] = PyThread_allocate_lock();
  __pyx_t_8[7] = PyThread_allocate_lock();
  memcpy(&(__pyx_memoryview_thread_locks[0]), __pyx_t_8, sizeof(__pyx_memoryview_thread_locks[0]) * (8));

  /* "View.MemoryView":982
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "View.MemoryView":983
 * 
 *     try:
 *         count = __pyx_collections_abc_Sequence.count             # <<<<<<<<<<<<<<
 *         index = __pyx_collections_abc_Sequence.index
 *     except:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 983, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_memoryviewslice_type, __pyx_n_s_count, __pyx_t_7) < 0) __PYX_ERR(1, 983, __pyx_L17_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_memoryviewslice_type);

      /* "View.MemoryView":984
 *     try:
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index             # <<<<<<<<<<<<<<
 *     except:
 *         pass
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 984, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_memoryviewslice_type, __pyx_n_s_index, __pyx_t_7) < 0) __PYX_ERR(1, 984, __pyx_L17_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_memoryviewslice_type);

      /* "View.MemoryView":982
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L22_try_end;
    __pyx_L17_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":985
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 *     except:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L18_exception_handled;
    }
    __pyx_L18_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L22_try_end:;
  }

  /* "View.MemoryView":988
 *         pass
 * 
 * try:             # <<<<<<<<<<<<<<
 *     if __pyx_collections_abc_Sequence:
 * 
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "View.MemoryView":989
 * 
 * try:
 *     if __pyx_collections_abc_Sequence:             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_collections_abc_Sequence); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 989, __pyx_L23_error)
      if (__pyx_t_6) {

        /* "View.MemoryView":993
 * 
 * 
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence.register(array)
 * except:
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_register); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 993, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)__pyx_memoryviewslice_type)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 993, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "View.MemoryView":994
 * 
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)
 *         __pyx_collections_abc_Sequence.register(array)             # <<<<<<<<<<<<<<
 * except:
 *     pass  # ignore failure, it's a minor issue
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_register); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 994, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_array_type)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 994, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "View.MemoryView":989
 * 
 * try:
 *     if __pyx_collections_abc_Sequence:             # <<<<<<<<<<<<<<
 * 
 * 
 */
      }

      /* "View.MemoryView":988
 *         pass
 * 
 * try:             # <<<<<<<<<<<<<<
 *     if __pyx_collections_abc_Sequence:
 * 
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L28_try_end;
    __pyx_L23_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":995
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)
 *         __pyx_collections_abc_Sequence.register(array)
 * except:             # <<<<<<<<<<<<<<
 *     pass  # ignore failure, it's a minor issue
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L24_exception_handled;
    }
    __pyx_L24_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L28_try_end:;
  }

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum, NULL, __pyx_n_s_View_MemoryView); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Enum, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":13
 * 
 * """
 * from math import exp,log             # <<<<<<<<<<<<<<
 * from collections import defaultdict #BB: added for class_sz
 * import numpy as np
 */
  __pyx_t_7 = PyList_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_s_exp);
  __Pyx_GIVEREF(__pyx_n_s_exp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_exp)) __PYX_ERR(0, 13, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_log);
  __Pyx_GIVEREF(__pyx_n_s_log);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 1, __pyx_n_s_log)) __PYX_ERR(0, 13, __pyx_L1_error);
  __pyx_t_4 = __Pyx_Import(__pyx_n_s_math, __pyx_t_7, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_4, __pyx_n_s_exp); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_exp, __pyx_t_7) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_4, __pyx_n_s_log); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_log, __pyx_t_7) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":14
 * """
 * from math import exp,log
 * from collections import defaultdict #BB: added for class_sz             # <<<<<<<<<<<<<<
 * import numpy as np
 * cimport numpy as np
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_n_s_defaultdict);
  __Pyx_GIVEREF(__pyx_n_s_defaultdict);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_defaultdict)) __PYX_ERR(0, 14, __pyx_L1_error);
  __pyx_t_7 = __Pyx_Import(__pyx_n_s_collections, __pyx_t_4, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s_defaultdict); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_defaultdict, __pyx_t_4) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":15
 * from math import exp,log
 * from collections import defaultdict #BB: added for class_sz
 * import numpy as np             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * from libc.stdlib cimport *
 */
  __pyx_t_7 = __Pyx_ImportDottedModule(__pyx_n_s_numpy, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_7) < 0) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":22
 * import cython
 * cimport cython
 * from scipy import interpolate             # <<<<<<<<<<<<<<
 * from scipy import integrate
 * from scipy.interpolate import InterpolatedUnivariateSpline as _spline
 */
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_s_interpolate);
  __Pyx_GIVEREF(__pyx_n_s_interpolate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_interpolate)) __PYX_ERR(0, 22, __pyx_L1_error);
  __pyx_t_4 = __Pyx_Import(__pyx_n_s_scipy, __pyx_t_7, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_4, __pyx_n_s_interpolate); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_interpolate, __pyx_t_7) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":23
 * cimport cython
 * from scipy import interpolate
 * from scipy import integrate             # <<<<<<<<<<<<<<
 * from scipy.interpolate import InterpolatedUnivariateSpline as _spline
 * from libc.math cimport pow
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_n_s_integrate);
  __Pyx_GIVEREF(__pyx_n_s_integrate);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_integrate)) __PYX_ERR(0, 23, __pyx_L1_error);
  __pyx_t_7 = __Pyx_Import(__pyx_n_s_scipy, __pyx_t_4, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s_integrate); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_integrate, __pyx_t_4) < 0) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":24
 * from scipy import interpolate
 * from scipy import integrate
 * from scipy.interpolate import InterpolatedUnivariateSpline as _spline             # <<<<<<<<<<<<<<
 * from libc.math cimport pow
 * 
 */
  __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_s_InterpolatedUnivariateSpline);
  __Pyx_GIVEREF(__pyx_n_s_InterpolatedUnivariateSpline);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_7, 0, __pyx_n_s_InterpolatedUnivariateSpline)) __PYX_ERR(0, 24, __pyx_L1_error);
  __pyx_t_4 = __Pyx_Import(__pyx_n_s_scipy_interpolate, __pyx_t_7, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_ImportFrom(__pyx_t_4, __pyx_n_s_InterpolatedUnivariateSpline); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_spline, __pyx_t_7) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":27
 * from libc.math cimport pow
 * 
 * import mcfit             # <<<<<<<<<<<<<<
 * import time
 * import re
 */
  __pyx_t_4 = __Pyx_ImportDottedModule(__pyx_n_s_mcfit, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mcfit, __pyx_t_4) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":28
 * 
 * import mcfit
 * import time             # <<<<<<<<<<<<<<
 * import re
 * 
 */
  __pyx_t_4 = __Pyx_ImportDottedModule(__pyx_n_s_time, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_4) < 0) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":29
 * import mcfit
 * import time
 * import re             # <<<<<<<<<<<<<<
 * 
 * import warnings
 */
  __pyx_t_4 = __Pyx_ImportDottedModule(__pyx_n_s_re, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_4) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":31
 * import re
 * 
 * import warnings             # <<<<<<<<<<<<<<
 * from contextlib import contextmanager
 * 
 */
  __pyx_t_4 = __Pyx_ImportDottedModule(__pyx_n_s_warnings, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_warnings, __pyx_t_4) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":32
 * 
 * import warnings
 * from contextlib import contextmanager             # <<<<<<<<<<<<<<
 * 
 * import logging
 */
  __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_n_s_contextmanager);
  __Pyx_GIVEREF(__pyx_n_s_contextmanager);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_4, 0, __pyx_n_s_contextmanager)) __PYX_ERR(0, 32, __pyx_L1_error);
  __pyx_t_7 = __Pyx_Import(__pyx_n_s_contextlib, __pyx_t_4, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s_contextmanager); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_contextmanager, __pyx_t_4) < 0) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":34
 * from contextlib import contextmanager
 * 
 * import logging             # <<<<<<<<<<<<<<
 * 
 * def configure_logging(level=logging.INFO):
 */
  __pyx_t_7 = __Pyx_ImportDottedModule(__pyx_n_s_logging, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_logging, __pyx_t_7) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":36
 * import logging
 * 
 * def configure_logging(level=logging.INFO):             # <<<<<<<<<<<<<<
 *     logging.basicConfig(
 *         format='%(levelname)s - %(message)s',
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_1configure_logging, 0, __pyx_n_s_configure_logging, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults), 1)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_logging); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_INFO); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_7)->__pyx_arg_level = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_9classy_sz_15__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_configure_logging, __pyx_t_7) < 0) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":42
 *     )
 * 
 * def set_verbosity(verbosity):             # <<<<<<<<<<<<<<
 *     levels = {
 *         'none': logging.CRITICAL,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_3set_verbosity, 0, __pyx_n_s_set_verbosity, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__65)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_set_verbosity, __pyx_t_7) < 0) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "class-sz/python/classy.pyx":52
 *     configure_logging(level)
 * 
 * @contextmanager             # <<<<<<<<<<<<<<
 * def suppress_warnings():
 *     warnings.filterwarnings("ignore")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_contextmanager); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5suppress_warnings, 0, __pyx_n_s_suppress_warnings, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__17)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_suppress_warnings, __pyx_t_4) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":60
 *         warnings.resetwarnings()
 * 
 * with suppress_warnings():             # <<<<<<<<<<<<<<
 *     import classy_szfast
 *     from classy_szfast import Class_szfast
 */
  /*with:*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_suppress_warnings); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_LookupSpecial(__pyx_t_5, __pyx_n_s_exit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_LookupSpecial(__pyx_t_5, __pyx_n_s_enter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 60, __pyx_L30_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 60, __pyx_L30_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_2);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_9);
        /*try:*/ {

          /* "class-sz/python/classy.pyx":61
 * 
 * with suppress_warnings():
 *     import classy_szfast             # <<<<<<<<<<<<<<
 *     from classy_szfast import Class_szfast
 * 
 */
          __pyx_t_5 = __Pyx_ImportDottedModule(__pyx_n_s_classy_szfast, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 61, __pyx_L34_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (PyDict_SetItem(__pyx_d, __pyx_n_s_classy_szfast, __pyx_t_5) < 0) __PYX_ERR(0, 61, __pyx_L34_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "class-sz/python/classy.pyx":62
 * with suppress_warnings():
 *     import classy_szfast
 *     from classy_szfast import Class_szfast             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 62, __pyx_L34_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_n_s_Class_szfast);
          __Pyx_GIVEREF(__pyx_n_s_Class_szfast);
          if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_n_s_Class_szfast)) __PYX_ERR(0, 62, __pyx_L34_error);
          __pyx_t_7 = __Pyx_Import(__pyx_n_s_classy_szfast, __pyx_t_5, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 62, __pyx_L34_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_7, __pyx_n_s_Class_szfast); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 62, __pyx_L34_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (PyDict_SetItem(__pyx_d, __pyx_n_s_Class_szfast, __pyx_t_5) < 0) __PYX_ERR(0, 62, __pyx_L34_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "class-sz/python/classy.pyx":60
 *         warnings.resetwarnings()
 * 
 * with suppress_warnings():             # <<<<<<<<<<<<<<
 *     import classy_szfast
 *     from classy_szfast import Class_szfast
 */
        }
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L39_try_end;
        __pyx_L34_error:;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        /*except:*/ {
          __Pyx_AddTraceback("classy_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 60, __pyx_L36_except_error)
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_4);
          __pyx_t_10 = PyTuple_Pack(3, __pyx_t_7, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 60, __pyx_L36_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 60, __pyx_L36_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (__pyx_t_6 < 0) __PYX_ERR(0, 60, __pyx_L36_except_error)
          __pyx_t_12 = (!__pyx_t_6);
          if (unlikely(__pyx_t_12)) {
            __Pyx_GIVEREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_5);
            __Pyx_XGIVEREF(__pyx_t_4);
            __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_5, __pyx_t_4);
            __pyx_t_7 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; 
            __PYX_ERR(0, 60, __pyx_L36_except_error)
          }
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L35_exception_handled;
        }
        __pyx_L36_except_error:;
        __Pyx_XGIVEREF(__pyx_t_2);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_9);
        goto __pyx_L1_error;
        __pyx_L35_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_2);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_9);
        __pyx_L39_try_end:;
      }
    }
    /*finally:*/ {
      /*normal exit:*/{
        if (__pyx_t_1) {
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__66, NULL);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 60, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        goto __pyx_L33;
      }
      __pyx_L33:;
    }
    goto __pyx_L43;
    __pyx_L30_error:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L1_error;
    __pyx_L43:;
  }

  /* "class-sz/python/classy.pyx":67
 * 
 * 
 * def class_sz_in_dict_output(d):             # <<<<<<<<<<<<<<
 *     # Define the allowed keys
 *     non_class_sz_keys = {"mPk", "tCl", "lCl", "pCl"}
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_8class_sz_in_dict_output, 0, __pyx_n_s_class_sz_in_dict_output, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__68)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_class_sz_in_dict_output, __pyx_t_4) < 0) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":89
 * 
 * 
 * def contains_specific_keys(d,specific_keys = {"tCl", "lCl", "pCl", "mPk"}):             # <<<<<<<<<<<<<<
 *     # Define the specific keys to check
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_10contains_specific_keys, 0, __pyx_n_s_contains_specific_keys, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__70)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_4, sizeof(__pyx_defaults1), 1)) __PYX_ERR(0, 89, __pyx_L1_error)
  __pyx_t_5 = PySet_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PySet_Add(__pyx_t_5, __pyx_n_u_tCl) < 0) __PYX_ERR(0, 89, __pyx_L1_error)
  if (PySet_Add(__pyx_t_5, __pyx_n_u_lCl) < 0) __PYX_ERR(0, 89, __pyx_L1_error)
  if (PySet_Add(__pyx_t_5, __pyx_n_u_pCl) < 0) __PYX_ERR(0, 89, __pyx_L1_error)
  if (PySet_Add(__pyx_t_5, __pyx_n_u_mPk) < 0) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_t_4)->__pyx_arg_specific_keys = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_4, __pyx_pf_9classy_sz_17__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_contains_specific_keys, __pyx_t_4) < 0) __PYX_ERR(0, 89, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":109
 * 
 * 
 * def contains_specific_pattern_or_keys(d):             # <<<<<<<<<<<<<<
 *     # Extract the string from dict["output"]
 *     output_string = d.get("output", "")
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_12contains_specific_pattern_or_keys, 0, __pyx_n_s_contains_specific_pattern_or_key, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__72)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_contains_specific_pattern_or_key, __pyx_t_4) < 0) __PYX_ERR(0, 109, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":156
 * 
 * # Nils : Added for python 3.x and python 2.x compatibility
 * import sys             # <<<<<<<<<<<<<<
 * def viewdictitems(d):
 *     if sys.version_info >= (3,0):
 */
  __pyx_t_4 = __Pyx_ImportDottedModule(__pyx_n_s_sys, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_4) < 0) __PYX_ERR(0, 156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":157
 * # Nils : Added for python 3.x and python 2.x compatibility
 * import sys
 * def viewdictitems(d):             # <<<<<<<<<<<<<<
 *     if sys.version_info >= (3,0):
 *         return d.items()
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_14viewdictitems, 0, __pyx_n_s_viewdictitems, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__74)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_viewdictitems, __pyx_t_4) < 0) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":171
 * DEF _MAXTITLESTRINGLENGTH_ = 8000
 * 
 * __version__ = _VERSION_.decode("utf-8")             # <<<<<<<<<<<<<<
 * 
 * # Implement a specific Exception (this might not be optimally designed, nor
 */
  __pyx_t_13 = __Pyx_ssize_strlen(_VERSION_); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 171, __pyx_L1_error)
  __pyx_t_4 = __Pyx_decode_c_string(_VERSION_, 0, __pyx_t_13, NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_version, __pyx_t_4) < 0) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":179
 * # the unused_parameters file), or a NameError in other cases. This allows
 * # MontePython to handle things differently.
 * class CosmoError(Exception):             # <<<<<<<<<<<<<<
 *     def __init__(self, message=""):
 *         self.message = message.decode() if isinstance(message,bytes) else message
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0]));
  __Pyx_GIVEREF((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0]));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])))) __PYX_ERR(0, 179, __pyx_L1_error);
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = __Pyx_Py3MetaclassPrepare(__pyx_t_7, __pyx_t_5, __pyx_n_s_CosmoError, __pyx_n_s_CosmoError, (PyObject *) NULL, __pyx_n_s_classy_sz, (PyObject *) NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__pyx_t_5 != __pyx_t_4) {
    if (unlikely((PyDict_SetItemString(__pyx_t_10, "__orig_bases__", __pyx_t_4) < 0))) __PYX_ERR(0, 179, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":180
 * # MontePython to handle things differently.
 * class CosmoError(Exception):
 *     def __init__(self, message=""):             # <<<<<<<<<<<<<<
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_10CosmoError_1__init__, 0, __pyx_n_s_CosmoError___init, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__76)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__77);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_init, __pyx_t_4) < 0) __PYX_ERR(0, 180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":183
 *         self.message = message.decode() if isinstance(message,bytes) else message
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return '\n\nError in Class: ' + self.message
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_10CosmoError_3__str__, 0, __pyx_n_s_CosmoError___str, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__79)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetNameInClass(__pyx_t_10, __pyx_n_s_str, __pyx_t_4) < 0) __PYX_ERR(0, 183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "class-sz/python/classy.pyx":179
 * # the unused_parameters file), or a NameError in other cases. This allows
 * # MontePython to handle things differently.
 * class CosmoError(Exception):             # <<<<<<<<<<<<<<
 *     def __init__(self, message=""):
 *         self.message = message.decode() if isinstance(message,bytes) else message
 */
  __pyx_t_4 = __Pyx_Py3ClassCreate(__pyx_t_7, __pyx_n_s_CosmoError, __pyx_t_5, __pyx_t_10, NULL, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CosmoError, __pyx_t_4) < 0) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":187
 * 
 * 
 * class CosmoSevereError(CosmoError):             # <<<<<<<<<<<<<<
 *     """
 *     Raised when Class failed to understand one or more input parameters.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CosmoError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(0, 187, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = __Pyx_Py3MetaclassPrepare(__pyx_t_10, __pyx_t_5, __pyx_n_s_CosmoSevereError, __pyx_n_s_CosmoSevereError, (PyObject *) NULL, __pyx_n_s_classy_sz, __pyx_kp_s_Raised_when_Class_failed_to_und); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__pyx_t_5 != __pyx_t_7) {
    if (unlikely((PyDict_SetItemString(__pyx_t_4, "__orig_bases__", __pyx_t_7) < 0))) __PYX_ERR(0, 187, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_10, __pyx_n_s_CosmoSevereError, __pyx_t_5, __pyx_t_4, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CosmoSevereError, __pyx_t_7) < 0) __PYX_ERR(0, 187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":198
 * 
 * 
 * class CosmoComputationError(CosmoError):             # <<<<<<<<<<<<<<
 *     """
 *     Raised when Class could not compute the cosmology at this point.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CosmoError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_5)) __PYX_ERR(0, 198, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PEP560_update_bases(__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_CalculateMetaclass(NULL, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_4, __pyx_t_5, __pyx_n_s_CosmoComputationError, __pyx_n_s_CosmoComputationError, (PyObject *) NULL, __pyx_n_s_classy_sz, __pyx_kp_s_Raised_when_Class_could_not_com); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__pyx_t_5 != __pyx_t_10) {
    if (unlikely((PyDict_SetItemString(__pyx_t_7, "__orig_bases__", __pyx_t_10) < 0))) __PYX_ERR(0, 198, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_Py3ClassCreate(__pyx_t_4, __pyx_n_s_CosmoComputationError, __pyx_t_5, __pyx_t_7, NULL, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CosmoComputationError, __pyx_t_10) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":276
 * 
 * # BB: modified for class_sz
 *     def set_default(self):             # <<<<<<<<<<<<<<
 *         # print('setting default')
 *         _pars = {
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_1set_default, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_set_default, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__81)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_set_default, __pyx_t_5) < 0) __PYX_ERR(0, 276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":376
 * 
 *     # Set up the dictionary
 *     def set(self,*pars,**kars):             # <<<<<<<<<<<<<<
 *         oldpars = self._pars.copy()
 *         if len(pars)==1:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_7set, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_set, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_set, __pyx_t_5) < 0) __PYX_ERR(0, 376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":390
 *         return True
 * 
 *     def empty(self):             # <<<<<<<<<<<<<<
 *         self._pars = {}
 *         self.computed = False
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_9empty, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_empty, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__84)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_empty, __pyx_t_5) < 0) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":396
 *     # Create an equivalent of the parameter file. Non specified values will be
 *     # taken at their default (in Class)
 *     def _fillparfile(self):             # <<<<<<<<<<<<<<
 *         cdef char* dumc
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_11_fillparfile, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class__fillparfile, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__86)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_fillparfile, __pyx_t_5) < 0) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":427
 * 
 *     # Called at the end of a run, to free memory
 *     def struct_cleanup(self):             # <<<<<<<<<<<<<<
 *         # print('cleaning up memoryyyy!!!')
 *         # print('level:',self.ncp)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_13struct_cleanup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_struct_cleanup, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__87)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_struct_cleanup, __pyx_t_5) < 0) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":458
 *         self.computed = False
 * 
 *     def _check_task_dependency(self, level):             # <<<<<<<<<<<<<<
 *         """
 *         Fill the level list with all the needed modules
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_15_check_task_dependency, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class__check_task_dependency, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__89)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_check_task_dependency, __pyx_t_5) < 0) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":518
 *         return level
 * 
 *     def _pars_check(self, key, value, contains=False, add=""):             # <<<<<<<<<<<<<<
 *         val = ""
 *         if key in self._pars:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_17_pars_check, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class__pars_check, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__91)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__92);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pars_check, __pyx_t_5) < 0) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":540
 *         return False
 * 
 *     def compute(self, level=["szcount"]):             # <<<<<<<<<<<<<<
 *         """
 *         #compute(level=["lensing"])
 */
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_n_u_szcount);
  __Pyx_GIVEREF(__pyx_n_u_szcount);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_n_u_szcount)) __PYX_ERR(0, 540, __pyx_L1_error);
  __pyx_k__21 = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_n_u_szcount);
  __Pyx_GIVEREF(__pyx_n_u_szcount);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_5, 0, __pyx_n_u_szcount)) __PYX_ERR(0, 540, __pyx_L1_error);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(0, 540, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_19compute, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_compute, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__94)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_compute, __pyx_t_5) < 0) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":715
 * 
 * 
 *     def calculate_pkl_fftlog_alphas(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         cnew = self.class_szfast.calculate_pkl_fftlog_alphas(zpk=zpk,**params_settings)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_21calculate_pkl_fftlog_alphas, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_calculate_pkl_fftlog_alpha, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__96)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_calculate_pkl_fftlog_alphas, __pyx_t_5) < 0) __PYX_ERR(0, 715, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":720
 *         return self.class_szfast.cp_pkl_fftlog_alphas_nus[self.class_szfast.cosmo_model]['arr_0'],cnew
 * 
 *     def get_pkl_reconstructed_from_fftlog(self,zpk):             # <<<<<<<<<<<<<<
 *         params_settings = self._pars
 *         return self.class_szfast.get_pkl_reconstructed_from_fftlog(zpk=zpk,**params_settings)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_23get_pkl_reconstructed_from_fftlog, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pkl_reconstructed_from, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__98)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pkl_reconstructed_from_fftlo, __pyx_t_5) < 0) __PYX_ERR(0, 720, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":727
 *     # @cython.wraparound(False)
 *     # the likelihood_mode parameter is used to identify whether we run within cobaya
 *     def compute_class_szfast(self,likelihood_mode=False):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_25compute_class_szfast, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_compute_class_szfast, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__100)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__101);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_compute_class_szfast, __pyx_t_5) < 0) __PYX_ERR(0, 727, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1097
 * 
 * 
 *     def compute_class_sz(self,pdict_to_update):             # <<<<<<<<<<<<<<
 *         integrate_only = False
 *         try:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_27compute_class_sz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_compute_class_sz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__103)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_compute_class_sz, __pyx_t_5) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1287
 * 
 * 
 *     def raw_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         raw_cl(lmax=-1, nofail=False)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_29raw_cl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_raw_cl, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__105)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__106);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_raw_cl, __pyx_t_5) < 0) __PYX_ERR(0, 1287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1377
 *         return cl
 * 
 *     def lensed_cl(self, lmax=-1,nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         lensed_cl(lmax=-1, nofail=False)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_31lensed_cl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_lensed_cl, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__108)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__106);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_lensed_cl, __pyx_t_5) < 0) __PYX_ERR(0, 1377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1477
 *           return cl
 * 
 *     def density_cl(self, lmax=-1, nofail=False):             # <<<<<<<<<<<<<<
 *         """
 *         density_cl(lmax=-1, nofail=False)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_33density_cl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_density_cl, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__110)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__106);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_density_cl, __pyx_t_5) < 0) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1585
 *         return cl
 * 
 *     def z_of_r (self,z_array):             # <<<<<<<<<<<<<<
 *         """
 *         returns chi [Mpc] vs dzdchi [1/Mpc]
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_35z_of_r, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_z_of_r, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__112)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_z_of_r, __pyx_t_5) < 0) __PYX_ERR(0, 1585, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1625
 *         return r[:],dzdr[:]
 * 
 *     def luminosity_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         luminosity_distance(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_37luminosity_distance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_luminosity_distance, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__114)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_luminosity_distance, __pyx_t_5) < 0) __PYX_ERR(0, 1625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1643
 *         return lum_distance
 * 
 *     def get_pkl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_39get_pkl_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pkl_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__116)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__117);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pkl_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 1643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1646
 *         return self.class_szfast.calculate_pkl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 *     def get_pknl_at_z(self, z_asked, params_values_dict=None):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.calculate_pknl_at_z(z_asked, params_values_dict = params_values_dict)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_41get_pknl_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pknl_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__118)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__117);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pknl_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 1646, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1650
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_43pk_unvectorized, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_unvectorized, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__120)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_unvectorized, __pyx_t_5) < 0) __PYX_ERR(0, 1650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1687
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_45pk, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__122)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk, __pyx_t_5) < 0) __PYX_ERR(0, 1687, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1747
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z (will be non linear if requested to Class, linear otherwise)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_47pk_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_cb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__124)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_cb, __pyx_t_5) < 0) __PYX_ERR(0, 1747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1774
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin_unvectorized(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_49pk_lin_unvectorized, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_lin_unvectorized, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__126)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_lin_unvectorized, __pyx_t_5) < 0) __PYX_ERR(0, 1774, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1810
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_lin(self, k, z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_51pk_lin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_lin, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__128)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_lin, __pyx_t_5) < 0) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1867
 * 
 *     # Gives the total matter pk for a given (k,z)
 *     def pk_nonlin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear total matter pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_53pk_nonlin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_nonlin, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__130)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1867, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_nonlin, __pyx_t_5) < 0) __PYX_ERR(0, 1867, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1888
 * 
 *     # Gives the cdm+b pk for a given (k,z)
 *     def pk_cb_lin(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives the linear cdm+b pk (in Mpc**3) for a given k (in 1/Mpc) and z
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_55pk_cb_lin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_cb_lin, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__132)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_cb_lin, __pyx_t_5) < 0) __PYX_ERR(0, 1888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1922
 *     #    return pk
 * 
 *     def get_pk_cb(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_57get_pk_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_cb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__134)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_cb, __pyx_t_5) < 0) __PYX_ERR(0, 1922, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1933
 *         return pk_cb
 * 
 *     def get_pk_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk = np.zeros((k_size,z_size,mu_size),'float64')
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_59get_pk_lin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_lin, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__136)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_lin, __pyx_t_5) < 0) __PYX_ERR(0, 1933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1944
 *         return pk
 * 
 *     def get_pk_cb_lin(self, np.ndarray[DTYPE_t,ndim=3] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, int mu_size):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the linear power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=3] pk_cb = np.zeros((k_size,z_size,mu_size),'float64')
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_61get_pk_cb_lin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_cb_lin, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__137)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_cb_lin, __pyx_t_5) < 0) __PYX_ERR(0, 1944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":1955
 *         return pk_cb
 * 
 *     def get_pk_and_k_and_z(self, nonlinear=True, only_clustering_species = False,h_units=False):             # <<<<<<<<<<<<<<
 *         """
 *         Returns a grid of matter power spectrum values and the z and k
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_63get_pk_and_k_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_and_k_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__139)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__140);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_and_k_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 1955, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2034
 * 
 *     # Gives sigma(R,z) for a given (R,z)
 *     def sigma(self,double R,double z, h_units = False):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (total matter) for a given R and z
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_65sigma, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_sigma, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__142)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__101);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_sigma, __pyx_t_5) < 0) __PYX_ERR(0, 2034, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2069
 * 
 *     # Gives sigma_cb(R,z) for a given (R,z)
 *     def sigma_cb(self,double R,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives sigma (cdm+b) for a given R and z
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_67sigma_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_sigma_cb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__144)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_sigma_cb, __pyx_t_5) < 0) __PYX_ERR(0, 2069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2098
 * 
 *     # Gives effective logarithmic slope of P_L(k,z) (total matter) for a given (k,z)
 *     def pk_tilt(self,double k,double z):             # <<<<<<<<<<<<<<
 *         """
 *         Gives effective logarithmic slope of P_L(k,z) (total matter) for a given k and z
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_69pk_tilt, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_tilt, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__146)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_tilt, __pyx_t_5) < 0) __PYX_ERR(0, 2098, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2122
 * 
 *     #calculates the hmcode window_function of the Navarrow Frenk White Profile
 *     def nonlinear_hmcode_window_nfw(self,double k,double rv,double c):             # <<<<<<<<<<<<<<
 *         """
 *         Gives window_nfw for a given wavevector k, virial radius rv and concentration c
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_71nonlinear_hmcode_window_nfw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_window_nf, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__148)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_window_nfw, __pyx_t_5) < 0) __PYX_ERR(0, 2122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2138
 *     #################################
 *     # gives an estimation of f(z)*sigma8(z) at the scale of 8 h/Mpc, computed as (d sigma8/d ln a)
 *     def effective_f_sigma8(self, z, z_step=0.1):             # <<<<<<<<<<<<<<
 *         """
 *         effective_f_sigma8(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_73effective_f_sigma8, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_effective_f_sigma8, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__150)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__151);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_effective_f_sigma8, __pyx_t_5) < 0) __PYX_ERR(0, 2138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2177
 * 
 * 
 *     def age(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.ba.age
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_75age, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_age, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__152)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_age, __pyx_t_5) < 0) __PYX_ERR(0, 2177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2184
 *           return self.ba.age
 * 
 *     def h(self):             # <<<<<<<<<<<<<<
 *         return self.ba.h
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_77h, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_h, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__153)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_h, __pyx_t_5) < 0) __PYX_ERR(0, 2184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2187
 *         return self.ba.h
 * 
 *     def n_s(self):             # <<<<<<<<<<<<<<
 *         return self.pm.n_s
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_79n_s, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_n_s, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__154)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_n_s, __pyx_t_5) < 0) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2190
 *         return self.pm.n_s
 * 
 *     def tau_reio(self):             # <<<<<<<<<<<<<<
 *         return self.th.tau_reio
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_81tau_reio, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_tau_reio, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__155)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_tau_reio, __pyx_t_5) < 0) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2193
 *         return self.th.tau_reio
 * 
 *     def Omega_m(self):             # <<<<<<<<<<<<<<
 * 
 *         if self._pars['skip_background_and_thermo']:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_83Omega_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__157)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega_m, __pyx_t_5) < 0) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2207
 *           return self.ba.Omega0_m
 * 
 *     def Omega_r(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_r
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_85Omega_r, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega_r, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__158)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega_r, __pyx_t_5) < 0) __PYX_ERR(0, 2207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2210
 *         return self.ba.Omega0_r
 * 
 *     def theta_s_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_87theta_s_100, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_theta_s_100, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__159)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_theta_s_100, __pyx_t_5) < 0) __PYX_ERR(0, 2210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2213
 *         return 100.*self.th.rs_rec/self.th.da_rec/(1.+self.th.z_rec)
 * 
 *     def theta_star_100(self):             # <<<<<<<<<<<<<<
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_89theta_star_100, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_theta_star_100, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__160)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_theta_star_100, __pyx_t_5) < 0) __PYX_ERR(0, 2213, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2216
 *         return 100.*self.th.rs_star/self.th.da_star/(1.+self.th.z_star)
 * 
 *     def Omega_Lambda(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_lambda
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_91Omega_Lambda, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega_Lambda, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__161)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega_Lambda, __pyx_t_5) < 0) __PYX_ERR(0, 2216, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2219
 *         return self.ba.Omega0_lambda
 * 
 *     def Omega_g(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_g
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_93Omega_g, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega_g, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__162)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega_g, __pyx_t_5) < 0) __PYX_ERR(0, 2219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2222
 *         return self.ba.Omega0_g
 * 
 *     def Omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_95Omega_b, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega_b, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__163)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega_b, __pyx_t_5) < 0) __PYX_ERR(0, 2222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2225
 *         return self.ba.Omega0_b
 * 
 *     def omega_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_97omega_b, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_omega_b, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__164)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_omega_b, __pyx_t_5) < 0) __PYX_ERR(0, 2225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2228
 *         return self.ba.Omega0_b * self.ba.h * self.ba.h
 * 
 *     def omega_cdm(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_99omega_cdm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_omega_cdm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__165)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_omega_cdm, __pyx_t_5) < 0) __PYX_ERR(0, 2228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2231
 *         return self.ba.Omega0_cdm * self.ba.h * self.ba.h
 * 
 *     def Neff(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.Neff_fast
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_101Neff, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Neff, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__166)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Neff, __pyx_t_5) < 0) __PYX_ERR(0, 2231, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2237
 *           return self.ba.Neff
 * 
 *     def k_eq(self):             # <<<<<<<<<<<<<<
 *         self.compute(["background"])
 *         return self.ba.a_eq*self.ba.H_eq
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_103k_eq, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_k_eq, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__167)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_k_eq, __pyx_t_5) < 0) __PYX_ERR(0, 2237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2241
 *         return self.ba.a_eq*self.ba.H_eq
 * 
 *     def sigma8(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           return self.sigma8_fast
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_105sigma8, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_sigma8, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__168)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_sigma8, __pyx_t_5) < 0) __PYX_ERR(0, 2241, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2248
 *           return self.nl.sigma8[self.nl.index_pk_m]
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_107get_sigma8_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_sigma8_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__170)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_sigma8_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 2248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2251
 *         return self.class_szfast.get_sigma8_at_z(z)
 * 
 *     def get_effective_f_sigma8(self,z):             # <<<<<<<<<<<<<<
 *         return self.class_szfast.get_effective_f_sigma8(z)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_109get_effective_f_sigma8, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_effective_f_sigma8, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__171)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_effective_f_sigma8, __pyx_t_5) < 0) __PYX_ERR(0, 2251, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2255
 * 
 * 
 *     def get_fstar_of_m_at_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_fstar_of_m_at_z(m,z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_111get_fstar_of_m_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_fstar_of_m_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__173)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_fstar_of_m_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 2255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2264
 *     #    return self.sp.neff
 * 
 *     def sigma8_cb(self):             # <<<<<<<<<<<<<<
 *         self.compute(["nonlinear"])
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_113sigma8_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_sigma8_cb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__174)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_sigma8_cb, __pyx_t_5) < 0) __PYX_ERR(0, 2264, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2268
 *         return self.nl.sigma8[self.nl.index_pk_cb]
 * 
 *     def rs_drag(self):             # <<<<<<<<<<<<<<
 *         if self.tsz.use_class_sz_fast_mode == 1:
 *           if self.tsz.skip_background_and_thermo:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_115rs_drag, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_rs_drag, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__175)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_rs_drag, __pyx_t_5) < 0) __PYX_ERR(0, 2268, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2278
 *           return self.th.rs_d
 * 
 *     def z_reio(self):             # <<<<<<<<<<<<<<
 *         self.compute(["thermodynamics"])
 *         return self.th.z_reio
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_117z_reio, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_z_reio, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__176)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_z_reio, __pyx_t_5) < 0) __PYX_ERR(0, 2278, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2282
 *         return self.th.z_reio
 * 
 *     def get_chi(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         chi(z) in h-units
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_119get_chi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_chi, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__178)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_chi, __pyx_t_5) < 0) __PYX_ERR(0, 2282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2303
 * 
 * 
 *     def angular_distance(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_121angular_distance, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_angular_distance, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__180)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_angular_distance, __pyx_t_5) < 0) __PYX_ERR(0, 2303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2341
 *         return D_A
 * 
 *     def get_radial_kernel_W_galaxy_ngal_at_z(self, z, index_g):             # <<<<<<<<<<<<<<
 *         """
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_123get_radial_kernel_W_galaxy_ngal_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_radial_kernel_W_galaxy, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__182)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_radial_kernel_W_galaxy_ngal, __pyx_t_5) < 0) __PYX_ERR(0, 2341, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2376
 * 
 * 
 *     def scale_independent_growth_factor(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_125scale_independent_growth_factor, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_scale_independent_growth_f, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__184)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_scale_independent_growth_factor, __pyx_t_5) < 0) __PYX_ERR(0, 2376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2406
 *         return D
 * 
 *     def scale_independent_growth_factor_f(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         scale_independent_growth_factor_f(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_127scale_independent_growth_factor_f, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_scale_independent_growth_f_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__186)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_scale_independent_growth_factor_2, __pyx_t_5) < 0) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2436
 *         return f
 * 
 *     def z_of_tau(self, tau):             # <<<<<<<<<<<<<<
 *         """
 *         Redshift corresponding to a given conformal time.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_129z_of_tau, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_z_of_tau, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__188)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_z_of_tau, __pyx_t_5) < 0) __PYX_ERR(0, 2436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2460
 *         return z
 * 
 *     def get_Ez(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         E(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_131get_Ez, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_Ez, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__189)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_Ez, __pyx_t_5) < 0) __PYX_ERR(0, 2460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2474
 * 
 * 
 *     def Hubble(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Hubble(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_133Hubble, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Hubble, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__191)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Hubble, __pyx_t_5) < 0) __PYX_ERR(0, 2474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2537
 *             return H_array
 * 
 *     def get_H(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         get_H(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_135get_H, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_H, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__193)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_H, __pyx_t_5) < 0) __PYX_ERR(0, 2537, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2575
 *             return H_over_c_in_h_over_Mpc_array
 * 
 *     def Om_m(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Omega_m(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_137Om_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Om_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__195)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Om_m, __pyx_t_5) < 0) __PYX_ERR(0, 2575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2606
 * 
 * 
 *     def ionization_fraction(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         ionization_fraction(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_139ionization_fraction, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_ionization_fraction, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__197)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_ionization_fraction, __pyx_t_5) < 0) __PYX_ERR(0, 2606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2641
 *         return xe
 * 
 *     def baryon_temperature(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         baryon_temperature(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_141baryon_temperature, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_baryon_temperature, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__199)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_baryon_temperature, __pyx_t_5) < 0) __PYX_ERR(0, 2641, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2676
 *         return Tb
 * 
 *     def T_cmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the CMB temperature
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_143T_cmb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_T_cmb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__200)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_T_cmb, __pyx_t_5) < 0) __PYX_ERR(0, 2676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2684
 *     # redundent with a previous Omega_m() funciton,
 *     # but we leave it not to break compatibility
 *     def Omega0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the sum of Omega0 for all non-relativistic components
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_145Omega0_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega0_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__201)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega0_m, __pyx_t_5) < 0) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2691
 * 
 * 
 *     def cl_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the 1-halo and 2-halo terms of tSZ power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_147cl_sz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_sz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__203)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_sz, __pyx_t_5) < 0) __PYX_ERR(0, 2691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2706
 * 
 * 
 *     def dl_isw_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (ISW x SZ) Return the ISW x tSZ power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_149dl_isw_sz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_dl_isw_sz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__205)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_dl_isw_sz, __pyx_t_5) < 0) __PYX_ERR(0, 2706, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2718
 *         return dl
 * 
 *     def cl_sz_at_nu_in_GHz_in_microK2(self,nu_in_GHz):             # <<<<<<<<<<<<<<
 *         frequency_in_Hz = nu_in_GHz*1e9
 *         T_cmb = self.T_cmb()
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_151cl_sz_at_nu_in_GHz_in_microK2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_sz_at_nu_in_GHz_in_micr, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__207)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_sz_at_nu_in_GHz_in_microK2, __pyx_t_5) < 0) __PYX_ERR(0, 2718, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2730
 *         return r
 * 
 *     def get_volume_dVdzdOmega_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_volume_at_z(z,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_153get_volume_dVdzdOmega_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_volume_dVdzdOmega_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__208)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_volume_dVdzdOmega_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 2730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2734
 * 
 * 
 *     def get_z_of_chi_unvectorized(self,chi):             # <<<<<<<<<<<<<<
 *         return get_z_of_chi(chi,&self.tsz,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_155get_z_of_chi_unvectorized, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_z_of_chi_unvectorized, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__210)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_z_of_chi_unvectorized, __pyx_t_5) < 0) __PYX_ERR(0, 2734, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2738
 * 
 * 
 *     def get_z_of_chi(self,chi):             # <<<<<<<<<<<<<<
 *          # Check if input is a scalar
 *         if isinstance(chi, (float, np.float64)):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_157get_z_of_chi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_z_of_chi, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__212)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_z_of_chi, __pyx_t_5) < 0) __PYX_ERR(0, 2738, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2760
 * 
 *     # Define the vectorized method
 *     def get_comoving_volume(self, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the comoving volume at given redshifts.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_159get_comoving_volume, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_comoving_volume, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__214)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_comoving_volume, __pyx_t_5) < 0) __PYX_ERR(0, 2760, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2794
 * 
 * 
 *     def get_IA_of_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_IA_of_z(z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_161get_IA_of_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_IA_of_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__215)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_IA_of_z, __pyx_t_5) < 0) __PYX_ERR(0, 2794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2798
 * 
 * 
 *     def get_f_of_sigma_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_163get_f_of_sigma_at_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_f_of_sigma_at_m_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__216)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_f_of_sigma_at_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 2798, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2801
 *         return get_f_of_sigma_at_m_and_z(m,z,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_delta_mean_from_delta_crit_at_z(self,delta_crit,z):             # <<<<<<<<<<<<<<
 *         return get_delta_mean_from_delta_crit_at_z(delta_crit,z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_165get_delta_mean_from_delta_crit_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_delta_mean_from_delta, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__218)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_delta_mean_from_delta_crit_a, __pyx_t_5) < 0) __PYX_ERR(0, 2801, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2805
 * 
 * 
 *     def get_galaxy_number_counts(self,z):             # <<<<<<<<<<<<<<
 *         return get_galaxy_number_counts(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_167get_galaxy_number_counts, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_galaxy_number_counts, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__219)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_galaxy_number_counts, __pyx_t_5) < 0) __PYX_ERR(0, 2805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2809
 * 
 * 
 *     def get_cov_N_N(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the covariance of cluster number counts
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_169get_cov_N_N, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_cov_N_N, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__221)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_cov_N_N, __pyx_t_5) < 0) __PYX_ERR(0, 2809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2834
 *         return cl
 * 
 *     def cl_kg_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x galaxy-lensing power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_171cl_kg_kg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kg_kg, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__222)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kg_kg, __pyx_t_5) < 0) __PYX_ERR(0, 2834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2848
 *         return cl
 * 
 *     def cl_kg_k(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy-lensing x cmb-lensing power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_173cl_kg_k, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kg_k, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__223)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kg_k, __pyx_t_5) < 0) __PYX_ERR(0, 2848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2862
 *         return cl
 * 
 *     def cl_yg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x g power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_175cl_yg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_yg, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__224)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2862, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_yg, __pyx_t_5) < 0) __PYX_ERR(0, 2862, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2876
 *         return cl
 * 
 *     def cl_IA_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of IA x g power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_177cl_IA_g, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_IA_g, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__225)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2876, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_IA_g, __pyx_t_5) < 0) __PYX_ERR(0, 2876, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2890
 *         return cl
 * 
 *     def cl_kg_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy lensing x lensing magnifications spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_179cl_kg_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kg_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__226)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kg_m, __pyx_t_5) < 0) __PYX_ERR(0, 2890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2904
 *         return cl
 * 
 *     def cl_ykg(self,             # <<<<<<<<<<<<<<
 *                Nmcfit = 1024,
 *                log10xmin_mcfit = -6,
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_181cl_ykg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_ykg, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__228)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__229);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_ykg, __pyx_t_5) < 0) __PYX_ERR(0, 2904, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2943
 * 
 * 
 *     def cl_kSZ_kSZ_g(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x g power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_183cl_kSZ_kSZ_g, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kSZ_kSZ_g, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__230)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kSZ_kSZ_g, __pyx_t_5) < 0) __PYX_ERR(0, 2943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2971
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kg power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_185cl_kSZ_kSZ_kg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kSZ_kSZ_kg, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__231)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kSZ_kSZ_kg, __pyx_t_5) < 0) __PYX_ERR(0, 2971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":2993
 *         return cl
 * 
 *     def cl_kSZ_kSZ_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of kSZ x kSZ x kcmb power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_187cl_kSZ_kSZ_kcmb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kSZ_kSZ_kcmb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__232)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kSZ_kSZ_kcmb, __pyx_t_5) < 0) __PYX_ERR(0, 2993, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3015
 *         return cl
 * 
 *     def cl_gal_gal_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of gal x gal x kcmb power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_189cl_gal_gal_kcmb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_gal_gal_kcmb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__233)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_gal_gal_kcmb, __pyx_t_5) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3032
 * 
 * 
 *     def cl_te_y_y(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return Te x y x y power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_191cl_te_y_y, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_te_y_y, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__234)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_te_y_y, __pyx_t_5) < 0) __PYX_ERR(0, 3032, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3044
 *         return cl
 * 
 *     def cl_ym(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x mu (lensing magnification) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_193cl_ym, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_ym, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__235)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_ym, __pyx_t_5) < 0) __PYX_ERR(0, 3044, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3059
 * 
 * 
 *     def cl_y_kcmb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of y x k (cmb lensing) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_195cl_y_kcmb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_y_kcmb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__236)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_y_kcmb, __pyx_t_5) < 0) __PYX_ERR(0, 3059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3073
 *         return cl
 * 
 *     def cl_t2t2f(self):             # <<<<<<<<<<<<<<
 *         cl = {}
 *         cl['ell'] = []
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_197cl_t2t2f, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_t2t2f, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__237)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_t2t2f, __pyx_t_5) < 0) __PYX_ERR(0, 3073, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3084
 * 
 * 
 *     def cl_gg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gxg power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_199cl_gg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_gg, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__238)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_gg, __pyx_t_5) < 0) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3101
 * 
 * 
 *     def cl_ksz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kszxksz power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_201cl_ksz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_ksz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__239)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_ksz, __pyx_t_5) < 0) __PYX_ERR(0, 3101, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3116
 * 
 * 
 *     def cl_ggamma(self,             # <<<<<<<<<<<<<<
 *                   Nmcfit = 1024,
 *                   log10xmin_mcfit = -6,
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_203cl_ggamma, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_ggamma, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__240)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__229);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_ggamma, __pyx_t_5) < 0) __PYX_ERR(0, 3116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3154
 *         return cl
 * 
 *     def gamma_ggamma(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tangential shear
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_205gamma_ggamma, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_gamma_ggamma, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__241)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_gamma_ggamma, __pyx_t_5) < 0) __PYX_ERR(0, 3154, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3168
 *         return cl
 * 
 *     def cl_ee(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x electron power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_207cl_ee, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_ee, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__242)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_ee, __pyx_t_5) < 0) __PYX_ERR(0, 3168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3185
 * 
 * 
 *     def cl_eg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of electron x galaxy power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_209cl_eg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_eg, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__243)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_eg, __pyx_t_5) < 0) __PYX_ERR(0, 3185, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3201
 *         return cl
 * 
 *     def cl_kg(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x galaxy power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_211cl_kg, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kg, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__244)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kg, __pyx_t_5) < 0) __PYX_ERR(0, 3201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3217
 *         return cl
 * 
 *     def pk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) matter power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_213pk_at_z_hm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_at_z_hm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__245)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_at_z_hm, __pyx_t_5) < 0) __PYX_ERR(0, 3217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3232
 * 
 * 
 *     def bk_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) matter bispectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_215bk_at_z_hm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_bk_at_z_hm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__246)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_bk_at_z_hm, __pyx_t_5) < 0) __PYX_ERR(0, 3232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3249
 * 
 * 
 *     def bk_ttg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of 3d B(k) ttg bispectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_217bk_ttg_at_z_hm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_bk_ttg_at_z_hm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__247)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_bk_ttg_at_z_hm, __pyx_t_5) < 0) __PYX_ERR(0, 3249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3265
 *         return cl
 * 
 *     def b_yyy(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of tsz bispectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_219b_yyy, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_b_yyy, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__248)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_b_yyy, __pyx_t_5) < 0) __PYX_ERR(0, 3265, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3281
 *         return cl
 * 
 *     def b_tty(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo, 2-halo and 3-halo terms of ksz-ksz-tsz bispectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_221b_tty, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_b_tty, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__249)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_b_tty, __pyx_t_5) < 0) __PYX_ERR(0, 3281, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3297
 *         return cl
 * 
 *     def pk_gg_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) gg power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_223pk_gg_at_z_hm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_gg_at_z_hm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__250)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_gg_at_z_hm, __pyx_t_5) < 0) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3311
 *         return cl
 * 
 *     def pk_b_at_z_2h(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_225pk_b_at_z_2h, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_b_at_z_2h, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__251)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_b_at_z_2h, __pyx_t_5) < 0) __PYX_ERR(0, 3311, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3323
 *         return cl
 * 
 *     def pk_bb_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) bb power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_227pk_bb_at_z_hm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_bb_at_z_hm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__252)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_bb_at_z_hm, __pyx_t_5) < 0) __PYX_ERR(0, 3323, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3337
 *         return cl
 * 
 *     def pk_em_at_z_hm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of 3d P(k) electron-matter power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_229pk_em_at_z_hm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_pk_em_at_z_hm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__253)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_pk_em_at_z_hm, __pyx_t_5) < 0) __PYX_ERR(0, 3337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3351
 *         return cl
 * 
 *     def cl_kk(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_231cl_kk, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kk, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__254)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kk, __pyx_t_5) < 0) __PYX_ERR(0, 3351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3367
 *         return cl
 * 
 *     def cl_c1c1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_233cl_c1c1, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_c1c1, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__255)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_c1c1, __pyx_t_5) < 0) __PYX_ERR(0, 3367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3382
 *         return cl
 * 
 *     def cl_c1_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_235cl_c1_lens, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_c1_lens, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__256)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_c1_lens, __pyx_t_5) < 0) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3397
 *         return cl
 * 
 *     def cl_c1_tSZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_237cl_c1_tSZ, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_c1_tSZ, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__257)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_c1_tSZ, __pyx_t_5) < 0) __PYX_ERR(0, 3397, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3412
 *         return cl
 * 
 *     def cl_c1_gal(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_239cl_c1_gal, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_c1_gal, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__258)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_c1_gal, __pyx_t_5) < 0) __PYX_ERR(0, 3412, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3427
 *         return cl
 * 
 *     def cl_c1_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa x kappa (lensing) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_241cl_c1_gallens, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_c1_gallens, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__259)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_c1_gallens, __pyx_t_5) < 0) __PYX_ERR(0, 3427, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3442
 *         return cl
 * 
 *     def cib_monopole(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib monopole as a function of frequency
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_243cib_monopole, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cib_monopole, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__260)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cib_monopole, __pyx_t_5) < 0) __PYX_ERR(0, 3442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3454
 *         return cl
 * 
 *     def cib_shotnoise(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cib shotnoise as a function of frequency
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_245cib_shotnoise, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cib_shotnoise, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__262)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cib_shotnoise, __pyx_t_5) < 0) __PYX_ERR(0, 3454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3467
 *         return cl
 * 
 *     def cl_cib_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of cib x cib power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_247cl_cib_cib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_cib_cib, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__264)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_cib_cib, __pyx_t_5) < 0) __PYX_ERR(0, 3467, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3489
 *         return cl_cib
 * 
 *     def cl_galn_galn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x gal power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_249cl_galn_galn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_galn_galn, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__266)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_galn_galn, __pyx_t_5) < 0) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3513
 *         return cl_gg
 * 
 *     def cl_galn_lens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_251cl_galn_lens, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_galn_lens, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__268)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_galn_lens, __pyx_t_5) < 0) __PYX_ERR(0, 3513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3534
 *         return cl_gk
 * 
 *     def cl_galn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_253cl_galn_gallens, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_galn_gallens, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__270)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_galn_gallens, __pyx_t_5) < 0) __PYX_ERR(0, 3534, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3553
 *         return cl_gkg
 * 
 *     def cl_galn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_255cl_galn_tsz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_galn_tsz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_galn_tsz, __pyx_t_5) < 0) __PYX_ERR(0, 3553, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3571
 *             cl_gy[str(int(nu1))] = cl
 *         return cl_gy
 *     def cl_galn_IA(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 2-halo terms of gal x lens power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_257cl_galn_IA, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_galn_IA, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__274)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_galn_IA, __pyx_t_5) < 0) __PYX_ERR(0, 3571, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3590
 *         return cl_gIA
 * 
 *     def cl_lensmagn_gallens(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_259cl_lensmagn_gallens, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_lensmagn_gallens, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__276)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_lensmagn_gallens, __pyx_t_5) < 0) __PYX_ERR(0, 3590, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3609
 *         return cl_mkg
 * 
 *     def cl_lensmagn_tsz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of gal x lens power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_261cl_lensmagn_tsz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_lensmagn_tsz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__278)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_lensmagn_tsz, __pyx_t_5) < 0) __PYX_ERR(0, 3609, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3628
 *         return cl_my
 * 
 *     def cl_kg_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kg x cib power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_263cl_kg_cib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_kg_cib, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__280)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_kg_cib, __pyx_t_5) < 0) __PYX_ERR(0, 3628, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3648
 * 
 * 
 *     def cl_custom1_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of custom1 x cib power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_265cl_custom1_cib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_custom1_cib, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__281)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_custom1_cib, __pyx_t_5) < 0) __PYX_ERR(0, 3648, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3667
 *         return cl_y_cib
 * 
 *     def cl_tSZ_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of tSZ x cib power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_267cl_tSZ_cib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_tSZ_cib, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_tSZ_cib, __pyx_t_5) < 0) __PYX_ERR(0, 3667, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3686
 *         return cl_y_cib
 * 
 *     def cl_gal_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x cib power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_269cl_gal_cib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_gal_cib, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__284)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_gal_cib, __pyx_t_5) < 0) __PYX_ERR(0, 3686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3705
 *         return cl_g_cib
 * 
 *     def cl_lens_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of lens x cib power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_271cl_lens_cib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_lens_cib, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__286)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_lens_cib, __pyx_t_5) < 0) __PYX_ERR(0, 3705, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3725
 * 
 * 
 *     def cl_km(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of kappa (lensing) x mu (lensing magnification) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_273cl_km, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_km, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__287)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_km, __pyx_t_5) < 0) __PYX_ERR(0, 3725, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3741
 *         return cl
 * 
 *     def cl_mm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of mu x mu (lensing magnification) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_275cl_mm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_mm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__288)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_mm, __pyx_t_5) < 0) __PYX_ERR(0, 3741, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3757
 *         return cl
 * 
 *     def cl_gm(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the 1-halo and 2-halo terms of galaxy x mu (lensing magnification) power spectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_277cl_gm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_cl_gm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__289)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cl_gm, __pyx_t_5) < 0) __PYX_ERR(0, 3757, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3774
 * 
 * 
 *     def get_scale_dependent_bias_at_z_and_k(self,z_asked,k_asked,bh):             # <<<<<<<<<<<<<<
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_279get_scale_dependent_bias_at_z_and_k, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_scale_dependent_bias_a, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__291)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_scale_dependent_bias_at_z_an, __pyx_t_5) < 0) __PYX_ERR(0, 3774, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3777
 *         return get_scale_dependent_bias_at_z_and_k(z_asked,k_asked,bh,&self.tsz)
 * 
 *     def get_szcounts_dndzdq_at_z_q(self,z_asked,qobs_asked):             # <<<<<<<<<<<<<<
 *         return get_szcounts_dndzdq_at_z_q(z_asked, qobs_asked, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_281get_szcounts_dndzdq_at_z_q, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_szcounts_dndzdq_at_z_q, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__293)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_szcounts_dndzdq_at_z_q, __pyx_t_5) < 0) __PYX_ERR(0, 3777, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3782
 * 
 * 
 *     def get_params_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the current parameters
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_283get_params_sz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_params_sz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__294)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_params_sz, __pyx_t_5) < 0) __PYX_ERR(0, 3782, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3789
 * 
 * 
 *     def tllprime_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the trispectrum
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_285tllprime_sz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_tllprime_sz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__296)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_tllprime_sz, __pyx_t_5) < 0) __PYX_ERR(0, 3789, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3804
 * 
 * 
 *     def A_rs(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_rs coefficient
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_287A_rs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_A_rs, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__297)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_A_rs, __pyx_t_5) < 0) __PYX_ERR(0, 3804, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3810
 *         return self.tsz.A_rs
 * 
 *     def B_sz(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the mass bias
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_289B_sz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_B_sz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__298)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_B_sz, __pyx_t_5) < 0) __PYX_ERR(0, 3810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3816
 *         return self.tsz.HSEbias
 * 
 *     def Rho_crit_0(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in Mpc/h, Msun/h units
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_291Rho_crit_0, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Rho_crit_0, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__299)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Rho_crit_0, __pyx_t_5) < 0) __PYX_ERR(0, 3816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3822
 *         return self.tsz.Rho_crit_0
 * 
 *     def rho0_crit(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the critical density in mpc/h, msun/h units at present time.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_293rho0_crit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_rho0_crit, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__300)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_rho0_crit, __pyx_t_5) < 0) __PYX_ERR(0, 3822, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3828
 *         return self.Rho_crit_0()
 * 
 *     def rho0_cb(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the cdm+baryon density in mpc/h, msun/h units at present time.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_295rho0_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_rho0_cb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__301)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_rho0_cb, __pyx_t_5) < 0) __PYX_ERR(0, 3828, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3834
 *         return self.rho0_crit()*(self.Omega0_b()+self.Omega0_cdm())
 * 
 *     def rho0_m(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the mean density of the sum of Omega0 for all non-relativistic components in mpc/h, msun/h units at present time.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_297rho0_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_rho0_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__302)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_rho0_m, __pyx_t_5) < 0) __PYX_ERR(0, 3834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3840
 *         return self.rho0_crit()*(self.Omega0_m())
 * 
 *     def chi_star(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the comoving distance to recombination in Mpc/h
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_299chi_star, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_chi_star, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__303)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_chi_star, __pyx_t_5) < 0) __PYX_ERR(0, 3840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3846
 *         return self.tsz.chi_star
 * 
 *     def delta_def_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the overdensity definition for custom1 profile
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_301delta_def_custom1, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_delta_def_custom1, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__304)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_delta_def_custom1, __pyx_t_5) < 0) __PYX_ERR(0, 3846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3852
 *         return self.tsz.delta_def_custom1
 * 
 *     def effective_galaxy_bias(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the effective galaxy bias
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_303effective_galaxy_bias, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_effective_galaxy_bias, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__305)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_effective_galaxy_bias, __pyx_t_5) < 0) __PYX_ERR(0, 3852, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3860
 * 
 * 
 *     def x_out_custom1(self):             # <<<<<<<<<<<<<<
 *         """
 *         (class_sz) Return the truncation for custom1 profile, r_cut = x_out*r_delta
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_305x_out_custom1, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_x_out_custom1, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__306)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_x_out_custom1, __pyx_t_5) < 0) __PYX_ERR(0, 3860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3866
 *         return self.tsz.x_out_custom1
 * 
 *     def M1SZ(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the lower mass bound
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_307M1SZ, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_M1SZ, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__307)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_M1SZ, __pyx_t_5) < 0) __PYX_ERR(0, 3866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3873
 * 
 * 
 *     def ystar(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return ystar
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_309ystar, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_ystar, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__308)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_ystar, __pyx_t_5) < 0) __PYX_ERR(0, 3873, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3880
 * 
 * 
 *     def alpha(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return alpha
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_311alpha, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_alpha, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__309)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_alpha, __pyx_t_5) < 0) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3886
 *         return self.csz.alpha
 * 
 *     def sigmaM(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return sigmaM
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_313sigmaM, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_sigmaM, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__310)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_sigmaM, __pyx_t_5) < 0) __PYX_ERR(0, 3886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3893
 * 
 * 
 *     def sigma8_Pcb(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.sigma8_Pcb
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_315sigma8_Pcb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_sigma8_Pcb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__311)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_sigma8_Pcb, __pyx_t_5) < 0) __PYX_ERR(0, 3893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3896
 *         return self.tsz.sigma8_Pcb
 * 
 *     def A_cib(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_317A_cib, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_A_cib, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__312)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_A_cib, __pyx_t_5) < 0) __PYX_ERR(0, 3896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3902
 *         return self.tsz.A_cib
 * 
 *     def A_sn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_cib coefficient
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_319A_sn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_A_sn, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__313)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_A_sn, __pyx_t_5) < 0) __PYX_ERR(0, 3902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3909
 * 
 * 
 *     def A_ir(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the foreground A_ir coefficient
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_321A_ir, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_A_ir, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__314)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_A_ir, __pyx_t_5) < 0) __PYX_ERR(0, 3909, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3916
 * 
 * 
 *     def A_cn(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the correlated noise A_cn coefficient
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_323A_cn, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_A_cn, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__315)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_A_cn, __pyx_t_5) < 0) __PYX_ERR(0, 3916, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3922
 *         return self.tsz.A_cn
 * 
 *     def get_te_of_m500c_at_z_arnaud(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_325get_te_of_m500c_at_z_arnaud, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_te_of_m500c_at_z_arnau, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__316)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_te_of_m500c_at_z_arnaud, __pyx_t_5) < 0) __PYX_ERR(0, 3922, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3925
 *         return get_te_of_m500c_at_z_arnaud(m,z,&self.ba,&self.tsz)
 * 
 *     def get_lensing_noise_at_ell(self,l):             # <<<<<<<<<<<<<<
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_327get_lensing_noise_at_ell, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_lensing_noise_at_ell, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__318)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_lensing_noise_at_ell, __pyx_t_5) < 0) __PYX_ERR(0, 3925, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3928
 *         return get_lensing_noise_at_ell(l,&self.tsz)
 * 
 *     def get_te_of_m500c_at_z_lee(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_329get_te_of_m500c_at_z_lee, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_te_of_m500c_at_z_lee, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__319)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_te_of_m500c_at_z_lee, __pyx_t_5) < 0) __PYX_ERR(0, 3928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3931
 *         return get_te_of_m500c_at_z_lee(m,z,&self.ba,&self.tsz)
 * 
 *     def get_f_tinker10_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_331get_f_tinker10_at_nu_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_f_tinker10_at_nu_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__321)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_f_tinker10_at_nu_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3934
 *         return get_f_tinker10_at_nu_and_z(nu,z,&self.tsz)
 * 
 *     def get_f_tinker08_at_nu_and_z(self,nu,z):             # <<<<<<<<<<<<<<
 *         return get_f_tinker08_at_nu_and_z(nu,z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_333get_f_tinker08_at_nu_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_f_tinker08_at_nu_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__322)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_f_tinker08_at_nu_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 3934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3938
 * 
 * 
 *     def get_T10_alpha_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_335get_T10_alpha_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_T10_alpha_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__323)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_T10_alpha_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 3938, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3941
 *         return get_T10_alpha_at_z(z,&self.tsz)
 * 
 *     def get_dndlnM_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 * 
 *         r = get_dndlnM_at_z_and_M(z,m,&self.tsz)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_337get_dndlnM_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dndlnM_at_z_and_M, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__325)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dndlnM_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":3948
 * 
 * 
 *     def get_dndlnm(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of dndlnM at given redshifts and masses.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_339get_dndlnm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dndlnm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__327)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dndlnm, __pyx_t_5) < 0) __PYX_ERR(0, 3948, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4059
 * 
 * 
 *     def get_dcib0dz_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         r = get_dcib0dz_at_z_and_nu(z,nu,&self.tsz)
 *         return r
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_341get_dcib0dz_at_z_and_nu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dcib0dz_at_z_and_nu, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__329)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dcib0dz_at_z_and_nu, __pyx_t_5) < 0) __PYX_ERR(0, 4059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4063
 *         return r
 * 
 *     def get_dydz_at_z(self,z):             # <<<<<<<<<<<<<<
 *         r = get_dydz_at_z(z,&self.tsz)
 *         return r
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_343get_dydz_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dydz_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__331)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dydz_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4063, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4067
 *         return r
 * 
 *     def get_mean_y(self):             # <<<<<<<<<<<<<<
 *         r = self.tsz.y_monopole
 *         return r
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_345get_mean_y, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_mean_y, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__333)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_mean_y, __pyx_t_5) < 0) __PYX_ERR(0, 4067, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4071
 *         return r
 * 
 *     def get_mean_galaxy_bias_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_mean_galaxy_bias_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_347get_mean_galaxy_bias_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_mean_galaxy_bias_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__334)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_mean_galaxy_bias_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4071, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4075
 * 
 * 
 *     def get_gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb):             # <<<<<<<<<<<<<<
 *         r = gnu_tsz_of_nu_in_ghz(nu_in_ghz,Tcmb)
 *         return r
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_349get_gnu_tsz_of_nu_in_ghz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_gnu_tsz_of_nu_in_ghz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__336)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_gnu_tsz_of_nu_in_ghz, __pyx_t_5) < 0) __PYX_ERR(0, 4075, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4080
 * 
 * 
 *     def get_hmf_counter_term_nmin_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_351get_hmf_counter_term_nmin_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_hmf_counter_term_nmin, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__337)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_hmf_counter_term_nmin_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4083
 *         return get_hmf_counter_term_nmin_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b1min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_353get_hmf_counter_term_b1min_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_hmf_counter_term_b1min, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__338)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_hmf_counter_term_b1min_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4083, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4086
 *         return get_hmf_counter_term_b1min_at_z(z,&self.tsz)
 * 
 *     def get_hmf_counter_term_b2min_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_355get_hmf_counter_term_b2min_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_hmf_counter_term_b2min, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__339)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_hmf_counter_term_b2min_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4089
 *         return get_hmf_counter_term_b2min_at_z(z,&self.tsz)
 * 
 *     def get_gas_density_profile_at_k_M_z(self,l_asked,m_asked,z_asked, normalize = 0):             # <<<<<<<<<<<<<<
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_357get_gas_density_profile_at_k_M_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_gas_density_profile_at, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__341)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__342);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_gas_density_profile_at_k_M_z, __pyx_t_5) < 0) __PYX_ERR(0, 4089, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4092
 *         return get_gas_density_profile_at_k_M_z(l_asked,m_asked,z_asked,normalize,&self.tsz)
 * 
 *     def get_rho_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_359get_rho_2h_at_r_and_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_rho_2h_at_r_and_m_and, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__344)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_rho_2h_at_r_and_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4092, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4096
 * 
 * 
 *     def get_P_delta_at_m_and_z_b12(self,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         # this is in ev/cm3, see https://arxiv.org/pdf/2202.02275.pdf
 *         # return get_P_delta_at_m_and_z_b12(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_361get_P_delta_at_m_and_z_b12, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_P_delta_at_m_and_z_b12, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__346)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_P_delta_at_m_and_z_b12, __pyx_t_5) < 0) __PYX_ERR(0, 4096, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4106
 * 
 * 
 *     def get_gas_pressure_2h_at_r_and_m_and_z(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_363get_gas_pressure_2h_at_r_and_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_gas_pressure_2h_at_r_a, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__347)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_gas_pressure_2h_at_r_and_m_a, __pyx_t_5) < 0) __PYX_ERR(0, 4106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4109
 *         return get_gas_pressure_2h_at_r_and_m_and_z(r_asked,m_asked,z_asked,&self.tsz,&self.ba)
 * 
 *     def get_dkappacmbdz_at_l_and_z(self,l,z,use_pklin = 0):             # <<<<<<<<<<<<<<
 *         if use_pklin == 1:
 *             return get_dkappacmbdz_pklin_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_365get_dkappacmbdz_at_l_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dkappacmbdz_at_l_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__349)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__342);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dkappacmbdz_at_l_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4109, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4115
 *             return get_dkappacmbdz_at_l_and_z(l,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_dydzdlnm_at_z_and_m(self,z,m,l=0):             # <<<<<<<<<<<<<<
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_367get_dydzdlnm_at_z_and_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dydzdlnm_at_z_and_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__351)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__342);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dydzdlnm_at_z_and_m, __pyx_t_5) < 0) __PYX_ERR(0, 4115, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4118
 *         return get_dyldzdlnm_at_l_z_and_m(l,z,m,&self.ba,&self.nl,&self.tsz)
 * 
 *     def get_c_delta_at_m_and_z(self,m,z,delta_def):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           c_delta = self.get_c200m_at_m_and_z(m,z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_369get_c_delta_at_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_c_delta_at_m_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__353)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_c_delta_at_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4129
 *         return c_delta
 * 
 *     def get_delta_from_delta_def_at_z(self,delta_def,z):             # <<<<<<<<<<<<<<
 *         if delta_def == 0:
 *           Omega_m = self.get_Omega_m_at_z(z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_371get_delta_from_delta_def_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_delta_from_delta_def_a, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__355)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_delta_from_delta_def_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4143
 *         return delta
 * 
 *     def get_r_delta_of_m_delta_at_z(self,delta,m_delta,z):             # <<<<<<<<<<<<<<
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_373get_r_delta_of_m_delta_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_r_delta_of_m_delta_at, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__357)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_r_delta_of_m_delta_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4146
 *         return (m_delta*3./4./np.pi/delta/self.get_rho_crit_at_z(z))**(1./3.)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_375get_m200m_to_m200c_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m200m_to_m200c_at_z_an, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__359)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m200m_to_m200c_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 4146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4149
 *         return get_m200m_to_m200c_at_z_and_M(z_asked,m_asked,&self.tsz)
 * 
 *     def get_normalization_gas_density_profile(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_377get_normalization_gas_density_profile, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_normalization_gas_dens, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__360)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_normalization_gas_density_pr, __pyx_t_5) < 0) __PYX_ERR(0, 4149, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4152
 *         return get_normalization_gas_density_profile(z_asked,m_asked,&self.tsz)
 * 
 *     def get_m_to_xout_at_z_and_m(self,z_asked,m_asked):             # <<<<<<<<<<<<<<
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_379get_m_to_xout_at_z_and_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m_to_xout_at_z_and_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__361)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m_to_xout_at_z_and_m, __pyx_t_5) < 0) __PYX_ERR(0, 4152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4155
 *         return get_m_to_xout_at_z_and_m(z_asked,m_asked,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_381get_c200m_at_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_c200m_at_m_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__362)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_c200m_at_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4158
 *         return get_c200m_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_383get_c200c_at_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_c200c_at_m_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__363)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_c200c_at_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4161
 *         return get_c200c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c500c_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_385get_c500c_at_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_c500c_at_m_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__364)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_c500c_at_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4161, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4164
 *         return get_c500c_at_m_and_z(m,z,&self.ba,&self.tsz)
 * 
 *     def get_c200m_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_387get_c200m_at_m_and_z_D08, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_c200m_at_m_and_z_D08, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__366)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_c200m_at_m_and_z_D08, __pyx_t_5) < 0) __PYX_ERR(0, 4164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4167
 *         return get_c200m_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_D08(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_389get_c200c_at_m_and_z_D08, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_c200c_at_m_and_z_D08, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__367)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_c200c_at_m_and_z_D08, __pyx_t_5) < 0) __PYX_ERR(0, 4167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4170
 *         return get_c200c_at_m_and_z_D08(M,z)
 * 
 *     def get_c200c_at_m_and_z_B13(self,M,z):             # <<<<<<<<<<<<<<
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_391get_c200c_at_m_and_z_B13, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_c200c_at_m_and_z_B13, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__368)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_c200c_at_m_and_z_B13, __pyx_t_5) < 0) __PYX_ERR(0, 4170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4173
 *         return get_c200c_at_m_and_z_B13(M,z,&self.ba,&self.tsz)
 * 
 *     def get_f_b(self):             # <<<<<<<<<<<<<<
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_393get_f_b, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_f_b, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__369)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_f_b, __pyx_t_5) < 0) __PYX_ERR(0, 4173, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4176
 *         return self.ba.Omega0_b/self.tsz.Omega_m_0
 * 
 *     def get_f_free(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.f_free
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_395get_f_free, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_f_free, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__370)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_f_free, __pyx_t_5) < 0) __PYX_ERR(0, 4176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4179
 *         return self.tsz.f_free
 * 
 *     def get_mu_e(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.mu_e
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_397get_mu_e, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_mu_e, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__371)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_mu_e, __pyx_t_5) < 0) __PYX_ERR(0, 4179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4182
 *         return self.tsz.mu_e
 * 
 *     def get_Omega_m_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_399get_Omega_m_0, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_Omega_m_0, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__372)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_Omega_m_0, __pyx_t_5) < 0) __PYX_ERR(0, 4182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4184
 *     def get_Omega_m_0(self):
 *         return self.tsz.Omega_m_0
 *     def get_Omega_r_0(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.Omega_r_0
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_401get_Omega_r_0, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_Omega_r_0, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__373)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_Omega_r_0, __pyx_t_5) < 0) __PYX_ERR(0, 4184, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4187
 *         return self.tsz.Omega_r_0
 * 
 *     def get_m_nfw(self,x):             # <<<<<<<<<<<<<<
 *         return m_nfw(x)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_403get_m_nfw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m_nfw, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__375)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m_nfw, __pyx_t_5) < 0) __PYX_ERR(0, 4187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4190
 *         return m_nfw(x)
 * 
 *     def get_rho_crit_at_z(self,z_asked):             # <<<<<<<<<<<<<<
 *         return get_rho_crit_at_z(z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_405get_rho_crit_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_rho_crit_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__377)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_rho_crit_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4194
 * 
 * 
 *     def get_pkl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the linear power spectrum at a given scale and redshift.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_407get_pkl_unvectorized, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pkl_unvectorized, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__379)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pkl_unvectorized, __pyx_t_5) < 0) __PYX_ERR(0, 4194, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4214
 * 
 * 
 *     def get_pknl_unvectorized(self,kh, z):             # <<<<<<<<<<<<<<
 *         """
 *         Compute the non-linear power spectrum at a given scale and redshift.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_409get_pknl_unvectorized, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pknl_unvectorized, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__380)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pknl_unvectorized, __pyx_t_5) < 0) __PYX_ERR(0, 4214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4234
 * 
 * 
 *     def get_pkl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the linear power spectrum at given wavenumbers and redshifts.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_411get_pkl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pkl, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__382)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pkl, __pyx_t_5) < 0) __PYX_ERR(0, 4234, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4279
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pknl(self, kh_input, z_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the non-linear power spectrum at given wavenumbers and redshifts.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_413get_pknl, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pknl, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__384)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pknl, __pyx_t_5) < 0) __PYX_ERR(0, 4279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4324
 *         return handle_combinations(kh_input, z_input)
 * 
 *     def get_pk(self, kh_input, z_input, type="lin"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the power spectrum at given wavenumbers and redshifts.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_415get_pk, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__386)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__387);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk, __pyx_t_5) < 0) __PYX_ERR(0, 4324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4360
 * 
 * 
 *     def get_pk_nonlin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_417get_pk_nonlin_at_k_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_nonlin_at_k_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__389)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_nonlin_at_k_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4363
 *         return get_pk_nonlin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_419get_pk_lin_at_k_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_lin_at_k_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__390)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_lin_at_k_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4366
 *         return get_pk_lin_at_k_and_z(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_nonlin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_421get_pk_nonlin_at_k_and_z_fast, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_nonlin_at_k_and_z_f, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__391)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_nonlin_at_k_and_z_fast, __pyx_t_5) < 0) __PYX_ERR(0, 4366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4369
 *         return get_pk_nonlin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_pk_lin_at_k_and_z_fast(self,k, z):             # <<<<<<<<<<<<<<
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_423get_pk_lin_at_k_and_z_fast, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_lin_at_k_and_z_fast, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__392)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_lin_at_k_and_z_fast, __pyx_t_5) < 0) __PYX_ERR(0, 4369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4372
 *         return get_pk_lin_at_k_and_z_fast(k,z,&self.ba,&self.pm,&self.nl,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_b16_200c(self,             # <<<<<<<<<<<<<<
 *                                           r_asked,
 *                                           m_asked,
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_425get_gas_profile_at_x_M_z_b16_200c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_gas_profile_at_x_M_z_b, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__394)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__395);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_gas_profile_at_x_M_z_b16_200, __pyx_t_5) < 0) __PYX_ERR(0, 4372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4421
 *                                                  &self.tsz)
 * 
 *     def get_pressure_P_over_P_delta_at_x_M_z_b12_200c(self,             # <<<<<<<<<<<<<<
 *                                                         x_asked,
 *                                                         m_asked,
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_427get_pressure_P_over_P_delta_at_x_M_z_b12_200c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pressure_P_over_P_delt, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__397)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__398);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pressure_P_over_P_delta_at_x, __pyx_t_5) < 0) __PYX_ERR(0, 4421, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4470
 * 
 * 
 *     def get_pressure_P_over_P_delta_at_x_gnfw_500c(self,             # <<<<<<<<<<<<<<
 *                                                      x_asked,
 *                                                      P0GNFW = 8.130,
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_429get_pressure_P_over_P_delta_at_x_gnfw_500c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pressure_P_over_P_delt_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__400)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pressure_P_over_P_delta_at_x_2, __pyx_t_5) < 0) __PYX_ERR(0, 4470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4485
 *                                                            &self.ba,
 *                                                            &self.tsz)
 *     def get_dA_z1z2(self,z1,z2):             # <<<<<<<<<<<<<<
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_431get_dA_z1z2, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dA_z1z2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__403)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dA_z1z2, __pyx_t_5) < 0) __PYX_ERR(0, 4485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4488
 *         return -(1./(1.+z2))*(np.vectorize(self.get_dA)(z1)*(1.+z1)-np.vectorize(self.get_dA)(z2)*(1.+z2))
 * 
 *     def get_dA(self,z):             # <<<<<<<<<<<<<<
 *         """
 *         angular_distance(z) in Mpc/h
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_433get_dA, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dA, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__404)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dA, __pyx_t_5) < 0) __PYX_ERR(0, 4488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4516
 *         return D_A*self.ba.h
 * 
 *     def get_rad_to_arcmin(self,theta_rad):             # <<<<<<<<<<<<<<
 *         return (60.*180.)/np.pi*theta_rad
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_435get_rad_to_arcmin, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_rad_to_arcmin, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__406)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_rad_to_arcmin, __pyx_t_5) < 0) __PYX_ERR(0, 4516, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4519
 *         return (60.*180.)/np.pi*theta_rad
 * 
 *     def get_truncated_nfw_profile_at_z_k_rd_cd_xout(self, double z, double k, double r_delta, double c_delta, double xout=1):             # <<<<<<<<<<<<<<
 *         return evaluate_truncated_nfw_profile(z, k, r_delta, c_delta, xout)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_437get_truncated_nfw_profile_at_z_k_rd_cd_xout, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_truncated_nfw_profile, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__408)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__409);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_truncated_nfw_profile_at_z_k, __pyx_t_5) < 0) __PYX_ERR(0, 4519, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4523
 * 
 * 
 *     def get_truncated_nfw_profile_at_z_k_m_xout(self, double z, double k, double m, double xout=1):             # <<<<<<<<<<<<<<
 *         delta_def = self.tsz.delta_def_matter_density
 *         delta = self.get_delta_from_delta_def_at_z(delta_def,z)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_439get_truncated_nfw_profile_at_z_k_m_xout, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_truncated_nfw_profile_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__411)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__409);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_truncated_nfw_profile_at_z_k_2, __pyx_t_5) < 0) __PYX_ERR(0, 4523, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4533
 * 
 *     # Define the vectorized method
 *     def get_uk_nfw(self, z_input, k_input, m_input, double xout=1):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the truncated NFW profile at given redshifts, wavenumbers, and masses.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_441get_uk_nfw, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_uk_nfw, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__413)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__409);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_uk_nfw, __pyx_t_5) < 0) __PYX_ERR(0, 4533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4592
 * 
 *     # Define the general method
 *     def get_uk(self, z_input, k_input, m_input, double xout=1, profile="nfw"):             # <<<<<<<<<<<<<<
 *         """
 *         General computation of the profile at given redshifts, wavenumbers, and masses.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_443get_uk, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_uk, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__415)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__416);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_uk, __pyx_t_5) < 0) __PYX_ERR(0, 4592, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4619
 * 
 * 
 *     def get_arcmin_to_rad(self,theta_arcmin):             # <<<<<<<<<<<<<<
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_445get_arcmin_to_rad, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_arcmin_to_rad, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__418)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_arcmin_to_rad, __pyx_t_5) < 0) __PYX_ERR(0, 4619, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4622
 *         return np.pi/(60.*180.)*theta_arcmin
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_447get_gas_profile_at_x_M_z_nfw_200m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_gas_profile_at_x_M_z_n, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__419)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_gas_profile_at_x_M_z_nfw_200, __pyx_t_5) < 0) __PYX_ERR(0, 4622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4625
 *         return get_gas_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_gas_profile_at_x_M_z_bcm_200c(self, x_asked, m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_449get_gas_profile_at_x_M_z_bcm_200c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_gas_profile_at_x_M_z_b_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__421)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_gas_profile_at_x_M_z_bcm_200, __pyx_t_5) < 0) __PYX_ERR(0, 4625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4628
 *         return get_gas_profile_at_x_M_z_bcm_200c(x_asked,m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_rvir_of_m200c_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_451get_rvir_of_m200c_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_rvir_of_m200c_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__423)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_rvir_of_m200c_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4628, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4631
 *         return get_rvir_of_m200c_at_z(m_asked,z,&self.ba,&self.tsz)
 * 
 *     def get_Delta_c_of_Omega_m(self,Omega_m):             # <<<<<<<<<<<<<<
 *         return Delta_c_of_Omega_m(Omega_m)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_453get_Delta_c_of_Omega_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_Delta_c_of_Omega_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__425)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_Delta_c_of_Omega_m, __pyx_t_5) < 0) __PYX_ERR(0, 4631, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4635
 * 
 * 
 *     def get_cvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_455get_cvir_of_mvir_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_cvir_of_mvir_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__426)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_cvir_of_mvir_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4638
 *         return evaluate_cvir_of_mvir(m_asked,z,&self.tsz,&self.ba)
 * 
 *     def get_Omega_m_at_z(self,z):             # <<<<<<<<<<<<<<
 *         cdef double tau
 *         cdef int last_index #junk
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_457get_Omega_m_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_Omega_m_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__428)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_Omega_m_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4638, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4655
 *         return omega
 * 
 *     def get_rvir_of_mvir_at_z(self,m_asked,z):             # <<<<<<<<<<<<<<
 *         omega = self.get_Omega_m_at_z(z)
 *         Delta_c = self.get_Delta_c_of_Omega_m(omega)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_459get_rvir_of_mvir_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_rvir_of_mvir_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__430)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_rvir_of_mvir_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4661
 *         return evaluate_rvir_of_mvir(m_asked,Delta_c,rhoc,&self.tsz);
 * 
 *     def get_gas_profile_at_x_M_z_nfw_200c(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_461get_gas_profile_at_x_M_z_nfw_200c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_gas_profile_at_x_M_z_n_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_gas_profile_at_x_M_z_nfw_200_2, __pyx_t_5) < 0) __PYX_ERR(0, 4661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4664
 *         return get_gas_profile_at_x_M_z_nfw_200c(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_mass_profile_at_x_M_z_nfw_200m(self,r_asked,m_asked,z_asked):             # <<<<<<<<<<<<<<
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_463get_mass_profile_at_x_M_z_nfw_200m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_mass_profile_at_x_M_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__432)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_mass_profile_at_x_M_z_nfw_20, __pyx_t_5) < 0) __PYX_ERR(0, 4664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4667
 *         return get_mass_profile_at_x_M_z_nfw_200m(r_asked,m_asked,z_asked,&self.ba,&self.tsz)
 * 
 *     def get_planck_sigma_at_theta500(self, theta500):             # <<<<<<<<<<<<<<
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_465get_planck_sigma_at_theta500, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_planck_sigma_at_theta5, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__434)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_planck_sigma_at_theta500, __pyx_t_5) < 0) __PYX_ERR(0, 4667, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4670
 *         return get_planck_sigma_at_theta500(theta500, &self.tsz)
 * 
 *     def get_szcountsz_sigma_at_theta_in_patch(self, id,theta500):             # <<<<<<<<<<<<<<
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_467get_szcountsz_sigma_at_theta_in_patch, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_szcountsz_sigma_at_the, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__436)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_szcountsz_sigma_at_theta_in, __pyx_t_5) < 0) __PYX_ERR(0, 4670, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4673
 *         return get_szcountsz_sigma_at_theta_in_patch(theta500, id, &self.tsz)
 * 
 *     def get_second_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_469get_second_order_bias_at_z_and_nu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_second_order_bias_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__438)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_second_order_bias_at_z_and_n, __pyx_t_5) < 0) __PYX_ERR(0, 4673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4676
 *         return get_second_order_bias_at_z_and_nu(z,nu,&self.tsz,&self.ba)
 * 
 *     def get_first_order_bias_at_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_471get_first_order_bias_at_z_and_nu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_first_order_bias_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__439)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_first_order_bias_at_z_and_nu, __pyx_t_5) < 0) __PYX_ERR(0, 4676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4679
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_first_order_bias_at_z_and_m_unvectorized(self,z,m):             # <<<<<<<<<<<<<<
 *         nu = self.get_nu_at_z_and_m(z,m)
 *         return get_first_order_bias_at_z_and_nu(z,nu,&self.tsz)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_473get_first_order_bias_at_z_and_m_unvectorized, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_first_order_bias_at_z_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__441)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_first_order_bias_at_z_and_m, __pyx_t_5) < 0) __PYX_ERR(0, 4679, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4685
 * 
 *    # Define the vectorized method
 *     def get_first_order_bias_at_z_and_m(self, z_input, m_input):             # <<<<<<<<<<<<<<
 *         """
 *         Vectorized computation of the first order bias at given redshifts and masses.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_475get_first_order_bias_at_z_and_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_first_order_bias_at_z_3, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__442)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_first_order_bias_at_z_and_m_2, __pyx_t_5) < 0) __PYX_ERR(0, 4685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4791
 *     #         raise TypeError("Inputs should be floats or 1D NumPy arrays of type float64, and when both are arrays, they should have the same length.")
 * 
 *     def get_cib_Snu_z_and_nu(self,z,nu):             # <<<<<<<<<<<<<<
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_477get_cib_Snu_z_and_nu, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_cib_Snu_z_and_nu, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__443)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_cib_Snu_z_and_nu, __pyx_t_5) < 0) __PYX_ERR(0, 4791, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4794
 *         return get_cib_Snu_z_and_nu(z,nu,&self.tsz)
 * 
 *     def get_sigma_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_479get_sigma_at_z_and_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_sigma_at_z_and_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__445)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4794, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_sigma_at_z_and_m, __pyx_t_5) < 0) __PYX_ERR(0, 4794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4797
 *         return get_sigma_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_dlnsigma_dlnR_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_481get_dlnsigma_dlnR_at_z_and_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_dlnsigma_dlnR_at_z_and, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__446)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_dlnsigma_dlnR_at_z_and_m, __pyx_t_5) < 0) __PYX_ERR(0, 4797, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4800
 *         return get_dlnsigma_dlnR_at_z_and_m(z,m,&self.tsz,&self.ba)
 * 
 *     def get_sigma8_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_483get_sigma8_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_sigma8_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_sigma8_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4802
 *     def get_sigma8_at_z(self,z):
 *         return get_sigma8_at_z(z,&self.tsz,&self.ba)
 *     def get_y_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_485get_y_at_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_y_at_m_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__448)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_y_at_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4805
 *         return get_y_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_theta_at_m_and_z(self,m,z):             # <<<<<<<<<<<<<<
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_487get_theta_at_m_and_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_theta_at_m_and_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__449)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_theta_at_m_and_z, __pyx_t_5) < 0) __PYX_ERR(0, 4805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4808
 *         return get_theta_at_m_and_z(m, z, &self.tsz, &self.ba)
 * 
 *     def get_m200m_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_489get_m200m_to_m500c_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m200m_to_m500c_at_z_an, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__450)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m200m_to_m500c_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 4808, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4811
 *         return get_m200m_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200c_to_m500c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m500c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_491get_m200c_to_m500c_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m200c_to_m500c_at_z_an, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__451)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m200c_to_m500c_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 4811, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4815
 * 
 * 
 *     def get_m200c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_493get_m200c_to_m200m_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m200c_to_m200m_at_z_an, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__452)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4815, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m200c_to_m200m_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 4815, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4818
 *         return get_m200c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 *     def get_m200m_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m200m_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_495get_m200m_to_m200c_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m200m_to_m200c_at_z_an, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__453)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m200m_to_m200c_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 4818, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4823
 * 
 * 
 *     def get_m500c_to_m200c_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200c_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_497get_m500c_to_m200c_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m500c_to_m200c_at_z_an, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__454)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m500c_to_m200c_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 4823, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4827
 * 
 * 
 *     def get_m500c_to_m200m_at_z_and_M(self,z,m):             # <<<<<<<<<<<<<<
 *         return get_m500c_to_m200m_at_z_and_M(z,m,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_499get_m500c_to_m200m_at_z_and_M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_m500c_to_m200m_at_z_an, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__455)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_m500c_to_m200m_at_z_and_M, __pyx_t_5) < 0) __PYX_ERR(0, 4827, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4831
 * 
 * 
 *     def calcFRel(self,z, M500, obsFreqGHz = 148.0):             # <<<<<<<<<<<<<<
 *         """Calculates relativistic correction to SZ effect at specified frequency, given z, M500 in MSun.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_501calcFRel, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_calcFRel, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__457)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__458);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_calcFRel, __pyx_t_5) < 0) __PYX_ERR(0, 4831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4893
 *         return fRel
 * 
 *     def get_radial_kernel_W_galaxy_lensing_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_503get_radial_kernel_W_galaxy_lensing_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_radial_kernel_W_galaxy_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__459)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_radial_kernel_W_galaxy_lensi, __pyx_t_5) < 0) __PYX_ERR(0, 4893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4896
 *         return radial_kernel_W_galaxy_lensing_at_z(z,&self.tsz)
 * 
 *     def get_custom1_bias_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_505get_custom1_bias_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_custom1_bias_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__460)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_custom1_bias_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4896, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4899
 *         return get_b_custom1_at_z(z,&self.tsz)
 * 
 *     def get_radial_kernel_W_custom1_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_507get_radial_kernel_W_custom1_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_radial_kernel_W_custom, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__461)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_radial_kernel_W_custom1_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4899, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4902
 *         return get_radial_kernel_W_custom1_at_z(z,&self.tsz)
 * 
 *     def get_custom1_profile_at_x_m_z(self,double x, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_509get_custom1_profile_at_x_m_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_custom1_profile_at_x_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__463)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_custom1_profile_at_x_m_z, __pyx_t_5) < 0) __PYX_ERR(0, 4902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4905
 *         return get_custom1_profile_at_x_m_z(x,m,z,&self.tsz)
 * 
 *     def get_custom1_profile_at_k_m_z(self,double k, double m, double z):             # <<<<<<<<<<<<<<
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_511get_custom1_profile_at_k_m_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_custom1_profile_at_k_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__465)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_custom1_profile_at_k_m_z, __pyx_t_5) < 0) __PYX_ERR(0, 4905, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4908
 *         return get_custom1_profile_at_k_m_z(k,m,z,&self.tsz)
 * 
 *     def get_ng_bar_at_z(self,double z):             # <<<<<<<<<<<<<<
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_513get_ng_bar_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_ng_bar_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__466)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_ng_bar_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4911
 *         return evaluate_mean_galaxy_number_density_at_z(z, &self.tsz)
 * 
 *     def get_source_galaxy_number_counts(self,double z):             # <<<<<<<<<<<<<<
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_515get_source_galaxy_number_counts, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_source_galaxy_number_c, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__467)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4911, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_source_galaxy_number_counts, __pyx_t_5) < 0) __PYX_ERR(0, 4911, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4914
 *         return get_source_galaxy_number_counts(z, &self.tsz)
 * 
 *     def get_N_satellites(self,double z,double M_halo,double Nc_mean,double M_min,double alpha_s,double M1_prime):             # <<<<<<<<<<<<<<
 *         Ns = HOD_mean_number_of_satellite_galaxies(z,M_halo,Nc_mean,M_min,alpha_s,M1_prime,&self.tsz,&self.ba)
 *         return Ns
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_517get_N_satellites, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_N_satellites, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__469)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4914, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_N_satellites, __pyx_t_5) < 0) __PYX_ERR(0, 4914, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4918
 *         return Ns
 * 
 *     def get_N_centrals(self,double z,double M_halo,double M_min,double sigma_log10M,double fc):             # <<<<<<<<<<<<<<
 *         Nc = HOD_mean_number_of_central_galaxies(z,M_halo,M_min,sigma_log10M,fc,&self.tsz,&self.ba)
 *         return Nc
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_519get_N_centrals, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_N_centrals, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__471)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_N_centrals, __pyx_t_5) < 0) __PYX_ERR(0, 4918, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4923
 * 
 * 
 *     def get_unwise_m_min_cut_at_z(self,double z,int sample_id):             # <<<<<<<<<<<<<<
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_521get_unwise_m_min_cut_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_unwise_m_min_cut_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__473)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_unwise_m_min_cut_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 4923, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4926
 *         return evaluate_unwise_m_min_cut(z,sample_id,&self.tsz)
 * 
 *     def get_yc_at_m_and_z_H13(self,m,z,A,B):             # <<<<<<<<<<<<<<
 *         Eh = self.Hubble(z)/self.Hubble(0)
 *         f_rel = self.calcFRel(z, m)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_523get_yc_at_m_and_z_H13, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_yc_at_m_and_z_H13, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__475)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_yc_at_m_and_z_H13, __pyx_t_5) < 0) __PYX_ERR(0, 4926, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4937
 *         return yp
 * 
 *     def _cumulativeNumberDensity(self, z):             # <<<<<<<<<<<<<<
 *         """
 *         Returns N > M (per cubic Mpc).
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_525_cumulativeNumberDensity, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class__cumulativeNumberDensity, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_cumulativeNumberDensity, __pyx_t_5) < 0) __PYX_ERR(0, 4937, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4961
 * 
 * 
 *     def getPLog10M(self, z):             # <<<<<<<<<<<<<<
 *         """Returns the log10(mass) probability distribution at the given z, for the logarithmic mass
 *         binning and mass definition set when the MockSurvey object was constructed.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_527getPLog10M, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_getPLog10M, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__479)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4961, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_getPLog10M, __pyx_t_5) < 0) __PYX_ERR(0, 4961, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":4980
 *         return PLog10M
 * 
 *     def getM500_from_y0_H13(self,y0,y0Err,A,B,sigma_int,z,applyMFDebiasCorrection = True):             # <<<<<<<<<<<<<<
 *         # y0 is fixed_y_c*1e-4 in the catalogue
 *         # log_y0Err is fixed_err_y_c in the catalogue
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_529getM500_from_y0_H13, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_getM500_from_y0_H13, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__481)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__482);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_getM500_from_y0_H13, __pyx_t_5) < 0) __PYX_ERR(0, 4980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5048
 * 
 * 
 *     def get_bispectrum_f2_kernel(self, double k1, double k2, double k3):             # <<<<<<<<<<<<<<
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_531get_bispectrum_f2_kernel, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_bispectrum_f2_kernel, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__484)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_bispectrum_f2_kernel, __pyx_t_5) < 0) __PYX_ERR(0, 5048, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5051
 *         return bispectrum_f2_kernel(k1, k2, k3)
 * 
 *     def get_nu_at_z_and_m(self,z,m):             # <<<<<<<<<<<<<<
 *         # (delc/sigma)**2
 *         return get_nu_at_z_and_m(z,m,&self.tsz,&self.ba)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_533get_nu_at_z_and_m, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_nu_at_z_and_m, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__485)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_nu_at_z_and_m, __pyx_t_5) < 0) __PYX_ERR(0, 5051, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5056
 * 
 * 
 *     def get_matter_bispectrum_at_z_effective_approach_smoothed(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_535get_matter_bispectrum_at_z_effective_approach_smoothed, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_matter_bispectrum_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__487)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_matter_bispectrum_at_z_effec, __pyx_t_5) < 0) __PYX_ERR(0, 5056, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5059
 *         return get_matter_bispectrum_at_z_effective_approach_smoothed(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_537get_ttg_bispectrum_at_z_effective_approach, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_ttg_bispectrum_at_z_ef, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__488)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_ttg_bispectrum_at_z_effectiv, __pyx_t_5) < 0) __PYX_ERR(0, 5059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5062
 *         return get_ttg_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_ttg_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_539get_ttg_bispectrum_at_z_tree_level_PT, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_ttg_bispectrum_at_z_tr, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__489)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_ttg_bispectrum_at_z_tree_lev, __pyx_t_5) < 0) __PYX_ERR(0, 5062, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5065
 *         return get_ttg_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_541get_matter_bispectrum_at_z_effective_approach, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_matter_bispectrum_at_z_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__490)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_matter_bispectrum_at_z_effec_2, __pyx_t_5) < 0) __PYX_ERR(0, 5065, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5067
 *     def get_matter_bispectrum_at_z_effective_approach(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_543get_matter_bispectrum_at_z_effective_approach_SC, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_matter_bispectrum_at_z_3, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__491)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_matter_bispectrum_at_z_effec_3, __pyx_t_5) < 0) __PYX_ERR(0, 5067, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5069
 *     def get_matter_bispectrum_at_z_effective_approach_SC(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):
 *         return get_matter_bispectrum_at_z_effective_approach_SC(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 *     def get_matter_bispectrum_at_z_tree_level_PT(self,k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z):             # <<<<<<<<<<<<<<
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_545get_matter_bispectrum_at_z_tree_level_PT, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_matter_bispectrum_at_z_4, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__492)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_matter_bispectrum_at_z_tree, __pyx_t_5) < 0) __PYX_ERR(0, 5069, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5072
 *         return get_matter_bispectrum_at_z_tree_level_PT(k1_in_h_over_Mpc,k2_in_h_over_Mpc,k3_in_h_over_Mpc,z,&self.tsz,&self.ba,&self.nl,&self.pm)
 * 
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_547get_nl_index_at_z_and_k, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_nl_index_at_z_and_k, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__494)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_nl_index_at_z_and_k, __pyx_t_5) < 0) __PYX_ERR(0, 5072, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5074
 *     def get_nl_index_at_z_and_k(self,z,k1_in_h_over_Mpc):
 *         return get_nl_index_at_z_and_k(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 *     def get_nl_index_at_z_and_k_no_wiggles(self,z,k1_in_h_over_Mpc):             # <<<<<<<<<<<<<<
 *         return get_nl_index_at_z_and_k_no_wiggles(z,k1_in_h_over_Mpc,&self.tsz,&self.nl)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_549get_nl_index_at_z_and_k_no_wiggles, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_nl_index_at_z_and_k_no, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__495)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_nl_index_at_z_and_k_no_wiggl, __pyx_t_5) < 0) __PYX_ERR(0, 5074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5079
 * 
 * 
 *     def get_vrms2_at_z(self,z):             # <<<<<<<<<<<<<<
 *         return get_vrms2_at_z(z,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_551get_vrms2_at_z, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_vrms2_at_z, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__496)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_vrms2_at_z, __pyx_t_5) < 0) __PYX_ERR(0, 5079, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5083
 * 
 * 
 *     def get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(self,z,m,x):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_553get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_1e6xdy_from_battaglia, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__498)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_1e6xdy_from_battaglia_pressu, __pyx_t_5) < 0) __PYX_ERR(0, 5083, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5086
 *         return get_1e6xdy_from_battaglia_pressure_at_x_z_and_m200c(z,m,x,&self.ba,&self.tsz)
 * 
 *     def get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_555get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_1e6xdy_from_gnfw_press, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__500)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_1e6xdy_from_gnfw_pressure_at, __pyx_t_5) < 0) __PYX_ERR(0, 5086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5089
 *         return get_1e6xdy_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def get_upp_from_gnfw_pressure_at_x_z_and_m500c(self,z,m,x,d):             # <<<<<<<<<<<<<<
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_557get_upp_from_gnfw_pressure_at_x_z_and_m500c, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_upp_from_gnfw_pressure, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__501)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_upp_from_gnfw_pressure_at_x, __pyx_t_5) < 0) __PYX_ERR(0, 5089, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5092
 *         return get_upp_from_gnfw_pressure_at_x_z_and_m500c(z,m,x,d,&self.ba,&self.tsz)
 * 
 *     def szunbinned_loglike(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_559szunbinned_loglike, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_szunbinned_loglike, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__502)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_szunbinned_loglike, __pyx_t_5) < 0) __PYX_ERR(0, 5092, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5094
 *     def szunbinned_loglike(self):
 *         return self.tsz.szunbinned_loglike
 *     def szcounts_ntot(self):             # <<<<<<<<<<<<<<
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_561szcounts_ntot, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_szcounts_ntot, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__503)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_szcounts_ntot, __pyx_t_5) < 0) __PYX_ERR(0, 5094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5096
 *     def szcounts_ntot(self):
 *         return self.tsz.szcounts_ntot
 *     def szcounts_ntot_rates_loglike(self, int nq = 500, double qmax = -1):             # <<<<<<<<<<<<<<
 *         # # lndndzdq =  []
 *         # # print(self.tsz.szcat_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_563szcounts_ntot_rates_loglike, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_szcounts_ntot_rates_loglik, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__505)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__506);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_szcounts_ntot_rates_loglike, __pyx_t_5) < 0) __PYX_ERR(0, 5096, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5125
 *         # return Nz
 * 
 *     def dndzdy_theoretical(self):             # <<<<<<<<<<<<<<
 *         """
 *         (SZ) Return the dndzdy theoretical
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_565dndzdy_theoretical, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_dndzdy_theoretical, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__508)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_dndzdy_theoretical, __pyx_t_5) < 0) __PYX_ERR(0, 5125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5168
 * 
 * 
 *     def get_background(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return an array of the background quantities at all times.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_567get_background, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_background, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__510)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_background, __pyx_t_5) < 0) __PYX_ERR(0, 5168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5208
 *         return background
 * 
 *     def get_thermodynamics(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the thermodynamics quantities.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_569get_thermodynamics, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_thermodynamics, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__512)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_thermodynamics, __pyx_t_5) < 0) __PYX_ERR(0, 5208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5246
 *         return thermodynamics
 * 
 *     def get_primordial(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the primordial scalar and/or tensor spectrum depending on 'modes'.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_571get_primordial, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_primordial, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__514)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_primordial, __pyx_t_5) < 0) __PYX_ERR(0, 5246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5286
 * 
 * 
 *     @cython.returns(dict)             # <<<<<<<<<<<<<<
 *     @cython.initializedcheck(False)
 *     @cython.boundscheck(False)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_573get_perturbations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_perturbations, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__515)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_perturbations, __pyx_t_5) < 0) __PYX_ERR(0, 5286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5359
 *         return perturbations
 * 
 *     def get_transfer(self, z=0., output_format='class'):             # <<<<<<<<<<<<<<
 *         """
 *         Return the density and/or velocity transfer functions for all initial
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_575get_transfer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_transfer, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__517)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__518);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_transfer, __pyx_t_5) < 0) __PYX_ERR(0, 5359, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5433
 *         return transfers
 * 
 *     def get_current_derived_parameters(self, names):             # <<<<<<<<<<<<<<
 *         """
 *         get_current_derived_parameters(names)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_577get_current_derived_parameters, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_current_derived_parame, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__520)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_current_derived_parameters, __pyx_t_5) < 0) __PYX_ERR(0, 5433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5696
 *         return derived
 * 
 *     def nonlinear_scale(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_scale(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_579nonlinear_scale, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_scale, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__522)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_scale, __pyx_t_5) < 0) __PYX_ERR(0, 5696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5721
 *         return k_nl
 * 
 *     def nonlinear_scale_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_581nonlinear_scale_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_scale_cb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__523)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_scale_cb, __pyx_t_5) < 0) __PYX_ERR(0, 5721, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5752
 *         return k_nl_cb
 * 
 *     def nonlinear_hmcode_sigma8(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_583nonlinear_hmcode_sigma8, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigma8, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__525)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigma8, __pyx_t_5) < 0) __PYX_ERR(0, 5752, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5770
 *         return sigma_8
 * 
 *     def nonlinear_hmcode_sigma8_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigma8(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_585nonlinear_hmcode_sigma8_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigma8_cb, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__526)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigma8_cb, __pyx_t_5) < 0) __PYX_ERR(0, 5770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5788
 *         return sigma_8_cb
 * 
 *     def nonlinear_hmcode_sigmadisp(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_587nonlinear_hmcode_sigmadisp, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigmadisp, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__528)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigmadisp, __pyx_t_5) < 0) __PYX_ERR(0, 5788, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5812
 *         return sigma_disp
 * 
 *     def nonlinear_hmcode_sigmadisp_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_589nonlinear_hmcode_sigmadisp_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigmadisp_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__529)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigmadisp_cb, __pyx_t_5) < 0) __PYX_ERR(0, 5812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5836
 *         return sigma_disp_cb
 * 
 *     def nonlinear_hmcode_sigmadisp100(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_591nonlinear_hmcode_sigmadisp100, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigmadisp_3, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__531)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigmadisp100, __pyx_t_5) < 0) __PYX_ERR(0, 5836, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5860
 *         return sigma_disp_100
 * 
 *     def nonlinear_hmcode_sigmadisp100_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmadisp100(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_593nonlinear_hmcode_sigmadisp100_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigmadisp_4, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__532)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigmadisp100_cb, __pyx_t_5) < 0) __PYX_ERR(0, 5860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5884
 *         return sigma_disp_100_cb
 * 
 *     def nonlinear_hmcode_sigmaprime(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_595nonlinear_hmcode_sigmaprime, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigmaprim, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__534)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigmaprime, __pyx_t_5) < 0) __PYX_ERR(0, 5884, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5908
 *         return sigma_prime
 * 
 *     def nonlinear_hmcode_sigmaprime_cb(self, np.ndarray[DTYPE_t,ndim=1] z, int z_size):             # <<<<<<<<<<<<<<
 *         """
 *         nonlinear_hmcode_sigmaprime(z, z_size)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_597nonlinear_hmcode_sigmaprime_cb, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_nonlinear_hmcode_sigmaprim_2, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__535)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_nonlinear_hmcode_sigmaprime_cb, __pyx_t_5) < 0) __PYX_ERR(0, 5908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5966
 *         ctx.add('cosmo', self)
 * 
 *     def get_pk_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_601get_pk_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_array, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__537)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_array, __pyx_t_5) < 0) __PYX_ERR(0, 5966, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5979
 *         return pk
 * 
 *     def get_pk_cb_array(self, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] z, int k_size, int z_size, nonlinear):             # <<<<<<<<<<<<<<
 *         """ Fast function to get the power spectrum on a k and z array """
 *         cdef np.ndarray[DTYPE_t, ndim=1] pk = np.zeros(k_size*z_size,'float64')
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_603get_pk_cb_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_pk_cb_array, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__538)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_pk_cb_array, __pyx_t_5) < 0) __PYX_ERR(0, 5979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5992
 *         return pk_cb
 * 
 *     def get_fftlog_ComputeXiLMsloz(self, int l, int m, int N, np.ndarray[DTYPE_t,ndim=1] k, np.ndarray[DTYPE_t,ndim=1] pk, np.ndarray[DTYPE_t,ndim=1] r, np.ndarray[DTYPE_t,ndim=1] xi):             # <<<<<<<<<<<<<<
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_605get_fftlog_ComputeXiLMsloz, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_fftlog_ComputeXiLMsloz, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__540)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_fftlog_ComputeXiLMsloz, __pyx_t_5) < 0) __PYX_ERR(0, 5992, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5995
 *         fftlog_ComputeXiLMsloz(l, m, N, <double*> k.data, <double*> pk.data, <double*> r.data, <double*> xi.data, &self.tsz)
 * 
 *     def get_n5k_z_of_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_607get_n5k_z_of_chi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_n5k_z_of_chi, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__541)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_n5k_z_of_chi, __pyx_t_5) < 0) __PYX_ERR(0, 5995, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":5998
 *         return get_n5k_z_of_chi(chi, &self.tsz)
 * 
 *     def get_n5k_pk_at_z_and_k(self, double z_asked, double k_asked):             # <<<<<<<<<<<<<<
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_609get_n5k_pk_at_z_and_k, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_n5k_pk_at_z_and_k, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__543)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 5998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_n5k_pk_at_z_and_k, __pyx_t_5) < 0) __PYX_ERR(0, 5998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":6001
 *         return get_n5k_pk_at_z_and_k(z_asked, k_asked, &self.tsz)
 * 
 *     def get_n5k_cl_K1_at_chi(self, double chi):             # <<<<<<<<<<<<<<
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_611get_n5k_cl_K1_at_chi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_get_n5k_cl_K1_at_chi, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__544)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_get_n5k_cl_K1_at_chi, __pyx_t_5) < 0) __PYX_ERR(0, 6001, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":6004
 *         return get_n5k_cl_K1_at_chi(chi, &self.tsz)
 * 
 *     def load_n5k_cl_K1(self):             # <<<<<<<<<<<<<<
 *         load_n5k_cl_K1(&self.tsz)
 *         return 1
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_613load_n5k_cl_K1, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_load_n5k_cl_K1, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__545)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_load_n5k_cl_K1, __pyx_t_5) < 0) __PYX_ERR(0, 6004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":6008
 *         return 1
 * 
 *     def load_n5k_pk_zk(self):             # <<<<<<<<<<<<<<
 *         load_n5k_pk_zk(&self.tsz)
 *         return 1
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_615load_n5k_pk_zk, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_load_n5k_pk_zk, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__546)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_load_n5k_pk_zk, __pyx_t_5) < 0) __PYX_ERR(0, 6008, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":6012
 *         return 1
 * 
 *     def load_n5k_z_of_chi(self):             # <<<<<<<<<<<<<<
 *         load_n5k_z_of_chi(&self.tsz)
 *         return 1
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_617load_n5k_z_of_chi, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_load_n5k_z_of_chi, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__547)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6012, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_load_n5k_z_of_chi, __pyx_t_5) < 0) __PYX_ERR(0, 6012, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":6017
 * 
 * 
 *     def Omega0_k(self):             # <<<<<<<<<<<<<<
 *         """ Curvature contribution """
 *         return self.ba.Omega0_k
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_619Omega0_k, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega0_k, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__548)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega0_k, __pyx_t_5) < 0) __PYX_ERR(0, 6017, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":6021
 *         return self.ba.Omega0_k
 * 
 *     def Omega0_cdm(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the cold dark matter density parameter at present time.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_621Omega0_cdm, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega0_cdm, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__549)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega0_cdm, __pyx_t_5) < 0) __PYX_ERR(0, 6021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "class-sz/python/classy.pyx":6030
 *         return self.ba.Omega0_cdm
 * 
 *     def Omega0_b(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return the baryon density parameter at present time.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_623Omega0_b, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class_Omega0_b, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__550)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 6030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_9classy_sz_Class, __pyx_n_s_Omega0_b, __pyx_t_5) < 0) __PYX_ERR(0, 6030, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_9classy_sz_Class);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_625__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class___reduce_cython, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__551)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9classy_sz_5Class_627__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Class___setstate_cython, NULL, __pyx_n_s_classy_sz, __pyx_d, ((PyObject *)__pyx_codeobj__553)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "class-sz/python/classy.pyx":1
 * """             # <<<<<<<<<<<<<<
 * .. module:: classy_sz
 *     :synopsis: Python wrapper around CLASS_SZ
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init classy_sz", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init classy_sz");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSsize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(Py_ssize_t)*3+2];
    char *dpos, *end = digits + sizeof(Py_ssize_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    Py_ssize_t remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_ssize_t neg_one = (Py_ssize_t) -1, const_zero = (Py_ssize_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (Py_ssize_t) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (Py_ssize_t) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (Py_ssize_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        Py_ssize_t kwsize;
#if CYTHON_ASSUME_SAFE_MACROS
        kwsize = PyTuple_GET_SIZE(kw);
#else
        kwsize = PyTuple_Size(kw);
        if (kwsize < 0) return 0;
#endif
        if (unlikely(kwsize == 0))
            return 1;
        if (!kw_allowed) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, 0);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < kwsize; pos++) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, pos);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* DivInt[Py_ssize_t] */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t a, Py_ssize_t b) {
    Py_ssize_t q = a / b;
    Py_ssize_t r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__3;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* PySequenceMultiply */
static PyObject* __Pyx_PySequence_Multiply_Generic(PyObject *seq, Py_ssize_t mul) {
    PyObject *result, *pymul = PyInt_FromSsize_t(mul);
    if (unlikely(!pymul))
        return NULL;
    result = PyNumber_Multiply(seq, pymul);
    Py_DECREF(pymul);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul) {
#if CYTHON_USE_TYPE_SLOTS
    PyTypeObject *type = Py_TYPE(seq);
    if (likely(type->tp_as_sequence && type->tp_as_sequence->sq_repeat)) {
        return type->tp_as_sequence->sq_repeat(seq, mul);
    } else
#endif
    {
        return __Pyx_PySequence_Multiply_Generic(seq, mul);
    }
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_ass_subscript) {
            int r;
            PyObject *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return -1;
            r = mm->mp_ass_subscript(o, key, v);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return sm->sq_ass_item(o, i, v);
        }
    }
#else
    if (is_list || !PyMapping_Check(o))
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* DivInt[long] */
static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__2);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
#if !(CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2)
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_GetMethod;
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* StringJoin */
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    (void) __Pyx_PyObject_CallMethod1;
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION < 3
    return _PyString_Join(sep, values);
#elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    return _PyBytes_Join(sep, values);
#else
    return __Pyx_PyObject_CallMethod1(sep, __pyx_n_s_join, values);
#endif
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_size_t(size_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(size_t)*3+2];
    char *dpos, *end = digits + sizeof(size_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    size_t remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (size_t) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (size_t) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (size_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* UnpackUnboundCMethod */
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!__Pyx_CyOrPyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc;
    __Pyx_PyThreadState_declare
    #ifdef __Pyx_StopAsyncIteration_USED
    int is_async_stopiteration = 0;
    #endif
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    cur_exc = PyErr_Occurred();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        #ifdef __Pyx_StopAsyncIteration_USED
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, __Pyx_PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else
        #endif
            return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(val);
    Py_XDECREF(tb);
    PyErr_SetString(PyExc_RuntimeError,
        #ifdef __Pyx_StopAsyncIteration_USED
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        #endif
        "generator raised StopIteration");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* set_iter */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    is_set = is_set || likely(PySet_CheckExact(iterable) || PyFrozenSet_CheckExact(iterable));
    *p_source_is_set = is_set;
    if (likely(is_set)) {
        *p_orig_length = PySet_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#else
    CYTHON_UNUSED_VAR(is_set);
    *p_source_is_set = 0;
#endif
    *p_orig_length = 0;
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set) {
    if (!CYTHON_COMPILING_IN_CPYTHON || PY_VERSION_HEX >= 0x030d0000 || unlikely(!source_is_set)) {
        *value = PyIter_Next(iter_obj);
        if (unlikely(!*value)) {
            return __Pyx_IterFinish();
        }
        CYTHON_UNUSED_VAR(orig_length);
        CYTHON_UNUSED_VAR(ppos);
        return 1;
    }
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    if (unlikely(PySet_GET_SIZE(iter_obj) != orig_length)) {
        PyErr_SetString(
            PyExc_RuntimeError,
            "set changed size during iteration");
        return -1;
    }
    {
        Py_hash_t hash;
        int ret = _PySet_NextEntry(iter_obj, ppos, value, &hash);
        assert (ret != -1);
        if (likely(ret)) {
            Py_INCREF(*value);
            return 1;
        }
    }
#endif
    return 0;
}

/* pyfrozenset_new */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if ((PY_VERSION_HEX >= 0x031000A1) || likely(PySet_GET_SIZE(result)))
            return result;
        Py_DECREF(result);
#endif
    }
#if CYTHON_USE_TYPE_SLOTS
    return PyFrozenSet_Type.tp_new(&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#else
    return PyObject_Call((PyObject*)&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#endif
}

/* PySetContains */
static int __Pyx_PySet_ContainsUnhashable(PyObject *set, PyObject *key) {
    int result = -1;
    if (PySet_Check(key) && PyErr_ExceptionMatches(PyExc_TypeError)) {
        PyObject *tmpkey;
        PyErr_Clear();
        tmpkey = __Pyx_PyFrozenSet_New(key);
        if (tmpkey != NULL) {
            result = PySet_Contains(set, tmpkey);
            Py_DECREF(tmpkey);
        }
    }
    return result;
}
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq) {
    int result = PySet_Contains(set, key);
    if (unlikely(result < 0)) {
        result = __Pyx_PySet_ContainsUnhashable(set, key);
    }
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
    else state = (PyGILState_STATE)0;
#endif
    CYTHON_UNUSED_VAR(clineno);
    CYTHON_UNUSED_VAR(lineno);
    CYTHON_UNUSED_VAR(filename);
    CYTHON_MAYBE_UNUSED_VAR(nogil);
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(0);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* decode_c_string */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        size_t slen = strlen(cstring);
        if (unlikely(slen > (size_t) PY_SSIZE_T_MAX)) {
            PyErr_SetString(PyExc_OverflowError,
                            "c-string too long to convert to Python");
            return NULL;
        }
        length = (Py_ssize_t) slen;
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    if (unlikely(stop <= start))
        return __Pyx_NewRef(__pyx_empty_unicode);
    length = stop - start;
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* MergeKeywords */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping) {
    PyObject *iter, *key = NULL, *value = NULL;
    int source_is_dict, result;
    Py_ssize_t orig_length, ppos = 0;
    iter = __Pyx_dict_iterator(source_mapping, 0, __pyx_n_s_items, &orig_length, &source_is_dict);
    if (unlikely(!iter)) {
        PyObject *args;
        if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError))) goto bad;
        PyErr_Clear();
        args = PyTuple_Pack(1, source_mapping);
        if (likely(args)) {
            PyObject *fallback = PyObject_Call((PyObject*)&PyDict_Type, args, NULL);
            Py_DECREF(args);
            if (likely(fallback)) {
                iter = __Pyx_dict_iterator(fallback, 1, __pyx_n_s_items, &orig_length, &source_is_dict);
                Py_DECREF(fallback);
            }
        }
        if (unlikely(!iter)) goto bad;
    }
    while (1) {
        result = __Pyx_dict_iter_next(iter, orig_length, &ppos, &key, &value, NULL, source_is_dict);
        if (unlikely(result < 0)) goto bad;
        if (!result) break;
        if (unlikely(PyDict_Contains(kwdict, key))) {
            __Pyx_RaiseDoubleKeywordsError("function", key);
            result = -1;
        } else {
            result = PyDict_SetItem(kwdict, key, value);
        }
        Py_DECREF(key);
        Py_DECREF(value);
        if (unlikely(result < 0)) goto bad;
    }
    Py_XDECREF(iter);
    return 0;
bad:
    Py_XDECREF(iter);
    return -1;
}

/* RaiseClosureNameError */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a == b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyFloatBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double b = floatval;
    double a, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op1))) {
#if CYTHON_COMPILING_IN_LIMITED_API
        a = __pyx_PyFloat_AsDouble(op1);
#else
        a = PyFloat_AS_DOUBLE(op1);
#endif
        
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        a = (double) PyInt_AS_LONG(op1);
        
    } else
    #endif
    if (likely(PyLong_CheckExact(op1))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op1)) {
            a = 0.0;
            
        } else if (__Pyx_PyLong_IsCompact(op1)) {
            a = (double) __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        a = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    a = PyLong_AsDouble(op1);
                    if (unlikely(a == -1.0 && PyErr_Occurred())) return NULL;
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
    }
        PyFPE_START_PROTECT("divide", return NULL)
        result = a / b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

/* PyFloatBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_SubtractObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double b = floatval;
    double a, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op1))) {
#if CYTHON_COMPILING_IN_LIMITED_API
        a = __pyx_PyFloat_AsDouble(op1);
#else
        a = PyFloat_AS_DOUBLE(op1);
#endif
        
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        a = (double) PyInt_AS_LONG(op1);
        
    } else
    #endif
    if (likely(PyLong_CheckExact(op1))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op1)) {
            a = 0.0;
            
        } else if (__Pyx_PyLong_IsCompact(op1)) {
            a = (double) __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        a = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    a = PyLong_AsDouble(op1);
                    if (unlikely(a == -1.0 && PyErr_Occurred())) return NULL;
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
    }
        PyFPE_START_PROTECT("subtract", return NULL)
        result = a - b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 0;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a != b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) != 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 1;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 1;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal != 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a != (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* SliceObject */
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(PyObject* obj, PyObject* value,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_ass_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_ass_slice(obj, cstart, cstop, value);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_ass_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        int result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_ass_subscript(obj, py_slice, value);
#else
        result = value ? PyObject_SetItem(obj, py_slice, value) : PyObject_DelItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object does not support slice %.10s",
        obj_type_name, value ? "assignment" : "deletion");
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return -1;
}

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
static int
__Pyx_unicode_modifiable(PyObject *unicode)
{
    if (Py_REFCNT(unicode) != 1)
        return 0;
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* PyIntFromDouble */
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE PyObject* __Pyx_PyInt_FromDouble(double value) {
    if (value >= (double)LONG_MIN && value <= (double)LONG_MAX) {
        return PyInt_FromLong((long)value);
    }
    return PyLong_FromDouble(value);
}
#endif

/* IsLittleEndian */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void)
{
  union {
    uint32_t u32;
    uint8_t u8[4];
  } S;
  S.u32 = 0x01020304;
  return S.u8[0] == 4;
}

/* BufferFormatCheck */
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t <= '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case '?': return "'bool'";
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparsable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, int is_complex) {
  CYTHON_UNUSED_VAR(is_complex);
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, int is_complex) {
  CYTHON_UNUSED_VAR(is_complex);
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case '?': case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static int
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number, ndim;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return -1;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return -1;
    ndim = ctx->head->field->type->ndim;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return -1;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i]) {
            PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
            return -1;
        }
        if (*ts != ',' && *ts != ')') {
            PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
            return -1;
        }
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim) {
        PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
        return -1;
    }
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return -1;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return 0;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
        CYTHON_FALLTHROUGH;
      case '?': case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if ((ctx->enc_type == *ts) && (got_Z == ctx->is_complex) &&
            (ctx->enc_packmode == ctx->new_packmode) && (!ctx->is_valid_array)) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
        CYTHON_FALLTHROUGH;
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (__pyx_buffmt_parse_array(ctx, &ts) < 0) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}

/* BufferGetAndValidate */
  static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (unlikely(info->buf == NULL)) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}
static void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static int __Pyx__GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  buf->buf = NULL;
  if (unlikely(__Pyx_GetBuffer(obj, buf, flags) == -1)) {
    __Pyx_ZeroBuffer(buf);
    return -1;
  }
  if (unlikely(buf->ndim != nd)) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if (unlikely((size_t)buf->itemsize != dtype->size)) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_SafeReleaseBuffer(buf);
  return -1;
}

/* BufferIndexError */
  static void __Pyx_RaiseBufferIndexError(int axis) {
  PyErr_Format(PyExc_IndexError,
     "Out of bounds on buffer access (axis %d)", axis);
}

/* PyIntBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        const long a = intval;
        long x;
        long b = PyInt_AS_LONG(op2);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        const long a = intval;
        long b, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG lla = intval;
        PY_LONG_LONG llb, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op2))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op2))) {
            b = __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        const long a = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double b = __pyx_PyFloat_AsDouble(op2);
#else
        double b = PyFloat_AS_DOUBLE(op2);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyIntBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_TrueDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        
            if (8 * sizeof(long) <= 53 || likely(labs(a) <= ((PY_LONG_LONG)1 << 53))) {
                return PyFloat_FromDouble((double)a / (double)b);
            }
            return PyInt_Type.tp_as_number->nb_true_divide(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT && 1 * PyLong_SHIFT < 53) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT && 1 * PyLong_SHIFT < 53) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT && 2 * PyLong_SHIFT < 53) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT && 2 * PyLong_SHIFT < 53) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT && 3 * PyLong_SHIFT < 53) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT && 3 * PyLong_SHIFT < 53) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_true_divide(op1, op2);
            }
        }
                if ((8 * sizeof(long) <= 53 || likely(labs(a) <= ((PY_LONG_LONG)1 << 53)))
                        || __Pyx_PyLong_DigitCount(op1) <= 52 / PyLong_SHIFT) {
                    return PyFloat_FromDouble((double)a / (double)b);
                }
                return PyLong_Type.tp_as_number->nb_true_divide(op1, op2);
            return PyLong_FromLong(x);
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("divide", return NULL)
            result = ((double)a) / (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
}
#endif

/* PyFloatBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_TrueDivideCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double a = floatval;
    double b, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op2))) {
#if CYTHON_COMPILING_IN_LIMITED_API
        b = __pyx_PyFloat_AsDouble(op2);
#else
        b = PyFloat_AS_DOUBLE(op2);
#endif
        if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        b = (double) PyInt_AS_LONG(op2);
        if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
    } else
    #endif
    if (likely(PyLong_CheckExact(op2))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op2)) {
            b = 0.0;
            if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
        } else if (__Pyx_PyLong_IsCompact(op2)) {
            b = (double) __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        b = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    b = PyLong_AsDouble(op2);
                    if (unlikely(b == -1.0 && PyErr_Occurred())) return NULL;
                    #if !CYTHON_USE_PYLONG_INTERNALS
                    if (unlikely(zerodivision_check && ((b) == 0.0))) { PyErr_SetString(PyExc_ZeroDivisionError, "float division by zero"); return NULL;}
                    #endif
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
    }
        PyFPE_START_PROTECT("divide", return NULL)
        result = a / b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

/* PyFloatBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddCObj(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double a = floatval;
    double b, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op2))) {
#if CYTHON_COMPILING_IN_LIMITED_API
        b = __pyx_PyFloat_AsDouble(op2);
#else
        b = PyFloat_AS_DOUBLE(op2);
#endif
        
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        b = (double) PyInt_AS_LONG(op2);
        
    } else
    #endif
    if (likely(PyLong_CheckExact(op2))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op2)) {
            b = 0.0;
            
        } else if (__Pyx_PyLong_IsCompact(op2)) {
            b = (double) __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        b = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        b = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (b < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                b = -b;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    b = PyLong_AsDouble(op2);
                    if (unlikely(b == -1.0 && PyErr_Occurred())) return NULL;
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
    }
        PyFPE_START_PROTECT("add", return NULL)
        result = a + b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

/* PyFloatBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyFloat_AddObjC(PyObject *op1, PyObject *op2, double floatval, int inplace, int zerodivision_check) {
    const double b = floatval;
    double a, result;
    CYTHON_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    if (likely(PyFloat_CheckExact(op1))) {
#if CYTHON_COMPILING_IN_LIMITED_API
        a = __pyx_PyFloat_AsDouble(op1);
#else
        a = PyFloat_AS_DOUBLE(op1);
#endif
        
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        a = (double) PyInt_AS_LONG(op1);
        
    } else
    #endif
    if (likely(PyLong_CheckExact(op1))) {
        #if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsZero(op1)) {
            a = 0.0;
            
        } else if (__Pyx_PyLong_IsCompact(op1)) {
            a = (double) __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                case 2:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                        a = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -2)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                case 3:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -3)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                case 4:
                    if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                        a = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (a < (double) ((PY_LONG_LONG)1 << 53))) {
                            if (size == -4)
                                a = -a;
                            break;
                        }
                    }
                    CYTHON_FALLTHROUGH;
                default:
        #endif
                    a = PyLong_AsDouble(op1);
                    if (unlikely(a == -1.0 && PyErr_Occurred())) return NULL;
        #if CYTHON_USE_PYLONG_INTERNALS
            }
        }
        #endif
    } else {
        return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
    }
        PyFPE_START_PROTECT("add", return NULL)
        result = a + b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

/* FixUpExtensionType */
  #if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* FetchSharedCythonModule */
  static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
  static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
  #if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
  #if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if PY_VERSION_HEX >= 0x030d00A4
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
  static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* PyIntBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a - (unsigned long)b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return PyLong_FromLong(-intval);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* PyIntBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        const long a = intval;
        long b = PyInt_AS_LONG(op2);
        
#ifdef HAVE_LONG_LONG
            if (sizeof(PY_LONG_LONG) > sizeof(long)) {
                PY_LONG_LONG result = (PY_LONG_LONG)a * (PY_LONG_LONG)b;
                return (result >= LONG_MIN && result <= LONG_MAX) ?
                    PyInt_FromLong((long)result) : PyLong_FromLongLong(result);
            }
#endif
#if CYTHON_USE_TYPE_SLOTS
            return PyInt_Type.tp_as_number->nb_multiply(op1, op2);
#else
            return PyNumber_Multiply(op1, op2);
#endif
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        const long a = intval;
        long b, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG lla = intval;
        PY_LONG_LONG llb, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op2))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op2))) {
            b = __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        b = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        llb = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        b = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        llb = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        b = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        llb = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
            }
        }
                CYTHON_UNUSED_VAR(a);
                CYTHON_UNUSED_VAR(b);
                #ifdef HAVE_LONG_LONG
                llb = b;
                goto long_long;
                #else
                return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
                #endif
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        const long a = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double b = __pyx_PyFloat_AsDouble(op2);
#else
        double b = PyFloat_AS_DOUBLE(op2);
#endif
            double result;
            
            PyFPE_START_PROTECT("multiply", return NULL)
            result = ((double)a) * (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#endif

/* PyObject_GenericGetAttrNoDict */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* ValidateBasesTuple */
  #if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !(CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY)
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
  static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
  static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_n_s_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_n_s_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable */
  static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_n_s_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_n_s_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
  #if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i;
    void** base_vtables;
    __Pyx_TypeName tp_base_name;
    __Pyx_TypeName base_name;
    void* unknown = (void*)-1;
    PyObject* bases = type->tp_bases;
    int base_depth = 0;
    {
        PyTypeObject* base = type->tp_base;
        while (base) {
            base_depth += 1;
            base = base->tp_base;
        }
    }
    base_vtables = (void**) malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
    for (i = 1; i < PyTuple_GET_SIZE(bases); i++) {
        void* base_vtable = __Pyx_GetVtable(((PyTypeObject*)PyTuple_GET_ITEM(bases, i)));
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = type->tp_base;
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = base->tp_base;
            }
        }
    }
    PyErr_Clear();
    free(base_vtables);
    return 0;
bad:
    tp_base_name = __Pyx_PyType_GetName(type->tp_base);
    base_name = __Pyx_PyType_GetName((PyTypeObject*)PyTuple_GET_ITEM(bases, i));
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
    free(base_vtables);
    return -1;
}
#endif

/* SetupReduce */
  #if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* TypeImport */
  #ifndef __PYX_HAVE_RT_ImportType_3_0_11
#define __PYX_HAVE_RT_ImportType_3_0_11
static PyTypeObject *__Pyx_ImportType_3_0_11(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_11 check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_0_11 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_0_11 && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* PyObjectLookupSpecial */
  #if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3UpdateBases */
  static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base, *meth, *new_base, *result, *new_bases = NULL;
    size_bases = PyTuple_GET_SIZE(bases);
    for (i = 0; i < size_bases; i++) {
        base  = PyTuple_GET_ITEM(bases, i);
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_n_s_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                base = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base);
                Py_INCREF(base);
            }
        }
        j = PyList_GET_SIZE(new_bases);
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
    return result;
error:
    Py_XDECREF(new_bases);
    return NULL;
}

/* CalculateMetaclass */
  static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_MACROS
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
  static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* CLineInTraceback */
  #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
  #if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
  #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    __Pyx_TypeName obj_type_name;
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_array_type)) return __pyx_array_getbuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_memoryview_type)) return __pyx_memoryview_getbuffer(obj, view, flags);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
                 "'" __Pyx_FMT_TYPENAME "' does not have the buffer interface",
                 obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
    if ((0)) {}
    view->obj = NULL;
    Py_DECREF(obj);
}
#endif


  /* MemviewSliceIsContig */
  static int
__pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim)
{
    int i, index, step, start;
    Py_ssize_t itemsize = mvs.memview->view.itemsize;
    if (order == 'F') {
        step = 1;
        start = 0;
    } else {
        step = -1;
        start = ndim - 1;
    }
    for (i = 0; i < ndim; i++) {
        index = start + step * i;
        if (mvs.suboffsets[index] >= 0 || mvs.strides[index] != itemsize)
            return 0;
        itemsize *= mvs.shape[index];
    }
    return 1;
}

/* OverlappingSlices */
  static void
__pyx_get_array_memory_extents(__Pyx_memviewslice *slice,
                               void **out_start, void **out_end,
                               int ndim, size_t itemsize)
{
    char *start, *end;
    int i;
    start = end = slice->data;
    for (i = 0; i < ndim; i++) {
        Py_ssize_t stride = slice->strides[i];
        Py_ssize_t extent = slice->shape[i];
        if (extent == 0) {
            *out_start = *out_end = start;
            return;
        } else {
            if (stride > 0)
                end += stride * (extent - 1);
            else
                start += stride * (extent - 1);
        }
    }
    *out_start = start;
    *out_end = end + itemsize;
}
static int
__pyx_slices_overlap(__Pyx_memviewslice *slice1,
                     __Pyx_memviewslice *slice2,
                     int ndim, size_t itemsize)
{
    void *start1, *end1, *start2, *end2;
    __pyx_get_array_memory_extents(slice1, &start1, &end1, ndim, itemsize);
    __pyx_get_array_memory_extents(slice2, &start2, &end2, ndim, itemsize);
    return (start1 < end2) && (start2 < end1);
}

/* CIntFromPyVerify */
  #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* TypeInfoCompare */
  static int
__pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b)
{
    int i;
    if (!a || !b)
        return 0;
    if (a == b)
        return 1;
    if (a->size != b->size || a->typegroup != b->typegroup ||
            a->is_unsigned != b->is_unsigned || a->ndim != b->ndim) {
        if (a->typegroup == 'H' || b->typegroup == 'H') {
            return a->size == b->size;
        } else {
            return 0;
        }
    }
    if (a->ndim) {
        for (i = 0; i < a->ndim; i++)
            if (a->arraysize[i] != b->arraysize[i])
                return 0;
    }
    if (a->typegroup == 'S') {
        if (a->flags != b->flags)
            return 0;
        if (a->fields || b->fields) {
            if (!(a->fields && b->fields))
                return 0;
            for (i = 0; a->fields[i].type && b->fields[i].type; i++) {
                __Pyx_StructField *field_a = a->fields + i;
                __Pyx_StructField *field_b = b->fields + i;
                if (field_a->offset != field_b->offset ||
                    !__pyx_typeinfo_cmp(field_a->type, field_b->type))
                    return 0;
            }
            return !a->fields[i].type && !b->fields[i].type;
        }
    }
    return 1;
}

/* MemviewSliceValidateAndInit */
  static int
__pyx_check_strides(Py_buffer *buf, int dim, int ndim, int spec)
{
    if (buf->shape[dim] <= 1)
        return 1;
    if (buf->strides) {
        if (spec & __Pyx_MEMVIEW_CONTIG) {
            if (spec & (__Pyx_MEMVIEW_PTR|__Pyx_MEMVIEW_FULL)) {
                if (unlikely(buf->strides[dim] != sizeof(void *))) {
                    PyErr_Format(PyExc_ValueError,
                                 "Buffer is not indirectly contiguous "
                                 "in dimension %d.", dim);
                    goto fail;
                }
            } else if (unlikely(buf->strides[dim] != buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
        if (spec & __Pyx_MEMVIEW_FOLLOW) {
            Py_ssize_t stride = buf->strides[dim];
            if (stride < 0)
                stride = -stride;
            if (unlikely(stride < buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
    } else {
        if (unlikely(spec & __Pyx_MEMVIEW_CONTIG && dim != ndim - 1)) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not contiguous in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(spec & (__Pyx_MEMVIEW_PTR))) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not indirect in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(buf->suboffsets)) {
            PyErr_SetString(PyExc_ValueError,
                            "Buffer exposes suboffsets but no strides");
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_check_suboffsets(Py_buffer *buf, int dim, int ndim, int spec)
{
    CYTHON_UNUSED_VAR(ndim);
    if (spec & __Pyx_MEMVIEW_DIRECT) {
        if (unlikely(buf->suboffsets && buf->suboffsets[dim] >= 0)) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer not compatible with direct access "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    if (spec & __Pyx_MEMVIEW_PTR) {
        if (unlikely(!buf->suboffsets || (buf->suboffsets[dim] < 0))) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer is not indirectly accessible "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_verify_contig(Py_buffer *buf, int ndim, int c_or_f_flag)
{
    int i;
    if (c_or_f_flag & __Pyx_IS_F_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = 0; i < ndim; i++) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not fortran contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    } else if (c_or_f_flag & __Pyx_IS_C_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = ndim - 1; i >- 1; i--) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not C contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    }
    return 1;
fail:
    return 0;
}
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj)
{
    struct __pyx_memoryview_obj *memview, *new_memview;
    __Pyx_RefNannyDeclarations
    Py_buffer *buf;
    int i, spec = 0, retval = -1;
    __Pyx_BufFmt_Context ctx;
    int from_memoryview = __pyx_memoryview_check(original_obj);
    __Pyx_RefNannySetupContext("ValidateAndInit_memviewslice", 0);
    if (from_memoryview && __pyx_typeinfo_cmp(dtype, ((struct __pyx_memoryview_obj *)
                                                            original_obj)->typeinfo)) {
        memview = (struct __pyx_memoryview_obj *) original_obj;
        new_memview = NULL;
    } else {
        memview = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                            original_obj, buf_flags, 0, dtype);
        new_memview = memview;
        if (unlikely(!memview))
            goto fail;
    }
    buf = &memview->view;
    if (unlikely(buf->ndim != ndim)) {
        PyErr_Format(PyExc_ValueError,
                "Buffer has wrong number of dimensions (expected %d, got %d)",
                ndim, buf->ndim);
        goto fail;
    }
    if (new_memview) {
        __Pyx_BufFmt_Init(&ctx, stack, dtype);
        if (unlikely(!__Pyx_BufFmt_CheckString(&ctx, buf->format))) goto fail;
    }
    if (unlikely((unsigned) buf->itemsize != dtype->size)) {
        PyErr_Format(PyExc_ValueError,
                     "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "u byte%s) "
                     "does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "u byte%s)",
                     buf->itemsize,
                     (buf->itemsize > 1) ? "s" : "",
                     dtype->name,
                     dtype->size,
                     (dtype->size > 1) ? "s" : "");
        goto fail;
    }
    if (buf->len > 0) {
        for (i = 0; i < ndim; i++) {
            spec = axes_specs[i];
            if (unlikely(!__pyx_check_strides(buf, i, ndim, spec)))
                goto fail;
            if (unlikely(!__pyx_check_suboffsets(buf, i, ndim, spec)))
                goto fail;
        }
        if (unlikely(buf->strides && !__pyx_verify_contig(buf, ndim, c_or_f_flag)))
            goto fail;
    }
    if (unlikely(__Pyx_init_memviewslice(memview, ndim, memviewslice,
                                         new_memview != NULL) == -1)) {
        goto fail;
    }
    retval = 0;
    goto no_fail;
fail:
    Py_XDECREF(new_memview);
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_d_dc_double(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_FOLLOW), (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_CONTIG) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, __Pyx_IS_C_CONTIG,
                                                 (PyBUF_C_CONTIGUOUS | PyBUF_FORMAT) | writable_flag, 2,
                                                 &__Pyx_TypeInfo_double, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_double(const char *itemp) {
    return (PyObject *) PyFloat_FromDouble(*(double *) itemp);
}
static CYTHON_INLINE int __pyx_memview_set_double(const char *itemp, PyObject *obj) {
    double value = __pyx_PyFloat_AsDouble(obj);
    if (unlikely((value == (double)-1) && PyErr_Occurred()))
        return 0;
    *(double *) itemp = value;
    return 1;
}

/* Declarations */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_long_double_complex __pyx_t_long_double_complex_from_parts(long double x, long double y) {
      return ::std::complex< long double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_long_double_complex __pyx_t_long_double_complex_from_parts(long double x, long double y) {
      return x + y*(__pyx_t_long_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_long_double_complex __pyx_t_long_double_complex_from_parts(long double x, long double y) {
      __pyx_t_long_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_long__double(__pyx_t_long_double_complex a, __pyx_t_long_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_sum_long__double(__pyx_t_long_double_complex a, __pyx_t_long_double_complex b) {
        __pyx_t_long_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_diff_long__double(__pyx_t_long_double_complex a, __pyx_t_long_double_complex b) {
        __pyx_t_long_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_prod_long__double(__pyx_t_long_double_complex a, __pyx_t_long_double_complex b) {
        __pyx_t_long_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_quot_long__double(__pyx_t_long_double_complex a, __pyx_t_long_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_long_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsl(b.real) >= fabsl(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_long_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                long double r = b.imag / b.real;
                long double s = (long double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_long_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            long double r = b.real / b.imag;
            long double s = (long double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_long_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_quot_long__double(__pyx_t_long_double_complex a, __pyx_t_long_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_long_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            long double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_long_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_neg_long__double(__pyx_t_long_double_complex a) {
        __pyx_t_long_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_long__double(__pyx_t_long_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_conj_long__double(__pyx_t_long_double_complex a) {
        __pyx_t_long_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE long double __Pyx_c_abs_long__double(__pyx_t_long_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtl(z.real*z.real + z.imag*z.imag);
          #else
            return hypotl(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_long_double_complex __Pyx_c_pow_long__double(__pyx_t_long_double_complex a, __pyx_t_long_double_complex b) {
            __pyx_t_long_double_complex z;
            long double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    long double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_long__double(a, a);
                    case 3:
                        z = __Pyx_c_prod_long__double(a, a);
                        return __Pyx_c_prod_long__double(z, a);
                    case 4:
                        z = __Pyx_c_prod_long__double(a, a);
                        return __Pyx_c_prod_long__double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = powl(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2l(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_long__double(a);
                theta = atan2l(a.imag, a.real);
            }
            lnr = logl(r);
            z_r = expl(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosl(z_theta);
            z.imag = z_r * sinl(z_theta);
            return z;
        }
    #endif
#endif

/* MemviewSliceCopyTemplate */
  static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object)
{
    __Pyx_RefNannyDeclarations
    int i;
    __Pyx_memviewslice new_mvs = { 0, 0, { 0 }, { 0 }, { 0 } };
    struct __pyx_memoryview_obj *from_memview = from_mvs->memview;
    Py_buffer *buf = &from_memview->view;
    PyObject *shape_tuple = NULL;
    PyObject *temp_int = NULL;
    struct __pyx_array_obj *array_obj = NULL;
    struct __pyx_memoryview_obj *memview_obj = NULL;
    __Pyx_RefNannySetupContext("__pyx_memoryview_copy_new_contig", 0);
    for (i = 0; i < ndim; i++) {
        if (unlikely(from_mvs->suboffsets[i] >= 0)) {
            PyErr_Format(PyExc_ValueError, "Cannot copy memoryview slice with "
                                           "indirect dimensions (axis %d)", i);
            goto fail;
        }
    }
    shape_tuple = PyTuple_New(ndim);
    if (unlikely(!shape_tuple)) {
        goto fail;
    }
    __Pyx_GOTREF(shape_tuple);
    for(i = 0; i < ndim; i++) {
        temp_int = PyInt_FromSsize_t(from_mvs->shape[i]);
        if(unlikely(!temp_int)) {
            goto fail;
        } else {
            PyTuple_SET_ITEM(shape_tuple, i, temp_int);
            temp_int = NULL;
        }
    }
    array_obj = __pyx_array_new(shape_tuple, sizeof_dtype, buf->format, (char *) mode, NULL);
    if (unlikely(!array_obj)) {
        goto fail;
    }
    __Pyx_GOTREF(array_obj);
    memview_obj = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                    (PyObject *) array_obj, contig_flag,
                                    dtype_is_object,
                                    from_mvs->memview->typeinfo);
    if (unlikely(!memview_obj))
        goto fail;
    if (unlikely(__Pyx_init_memviewslice(memview_obj, ndim, &new_mvs, 1) < 0))
        goto fail;
    if (unlikely(__pyx_memoryview_copy_contents(*from_mvs, new_mvs, ndim, ndim,
                                                dtype_is_object) < 0))
        goto fail;
    goto no_fail;
fail:
    __Pyx_XDECREF(new_mvs.memview);
    new_mvs.memview = NULL;
    new_mvs.data = NULL;
no_fail:
    __Pyx_XDECREF(shape_tuple);
    __Pyx_XDECREF(temp_int);
    __Pyx_XDECREF(array_obj);
    __Pyx_RefNannyFinishContext();
    return new_mvs;
}

/* MemviewSliceInit */
  static int
__Pyx_init_memviewslice(struct __pyx_memoryview_obj *memview,
                        int ndim,
                        __Pyx_memviewslice *memviewslice,
                        int memview_is_new_reference)
{
    __Pyx_RefNannyDeclarations
    int i, retval=-1;
    Py_buffer *buf = &memview->view;
    __Pyx_RefNannySetupContext("init_memviewslice", 0);
    if (unlikely(memviewslice->memview || memviewslice->data)) {
        PyErr_SetString(PyExc_ValueError,
            "memviewslice is already initialized!");
        goto fail;
    }
    if (buf->strides) {
        for (i = 0; i < ndim; i++) {
            memviewslice->strides[i] = buf->strides[i];
        }
    } else {
        Py_ssize_t stride = buf->itemsize;
        for (i = ndim - 1; i >= 0; i--) {
            memviewslice->strides[i] = stride;
            stride *= buf->shape[i];
        }
    }
    for (i = 0; i < ndim; i++) {
        memviewslice->shape[i]   = buf->shape[i];
        if (buf->suboffsets) {
            memviewslice->suboffsets[i] = buf->suboffsets[i];
        } else {
            memviewslice->suboffsets[i] = -1;
        }
    }
    memviewslice->memview = memview;
    memviewslice->data = (char *)buf->buf;
    if (__pyx_add_acquisition_count(memview) == 0 && !memview_is_new_reference) {
        Py_INCREF(memview);
    }
    retval = 0;
    goto no_fail;
fail:
    memviewslice->memview = 0;
    memviewslice->data = 0;
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}
#ifndef Py_NO_RETURN
#define Py_NO_RETURN
#endif
static void __pyx_fatalerror(const char *fmt, ...) Py_NO_RETURN {
    va_list vargs;
    char msg[200];
#if PY_VERSION_HEX >= 0x030A0000 || defined(HAVE_STDARG_PROTOTYPES)
    va_start(vargs, fmt);
#else
    va_start(vargs);
#endif
    vsnprintf(msg, 200, fmt, vargs);
    va_end(vargs);
    Py_FatalError(msg);
}
static CYTHON_INLINE int
__pyx_add_acquisition_count_locked(__pyx_atomic_int_type *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)++;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE int
__pyx_sub_acquisition_count_locked(__pyx_atomic_int_type *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)--;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE void
__Pyx_INC_MEMVIEW(__Pyx_memviewslice *memslice, int have_gil, int lineno)
{
    __pyx_nonatomic_int_type old_acquisition_count;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None)) {
        return;
    }
    old_acquisition_count = __pyx_add_acquisition_count(memview);
    if (unlikely(old_acquisition_count <= 0)) {
        if (likely(old_acquisition_count == 0)) {
            if (have_gil) {
                Py_INCREF((PyObject *) memview);
            } else {
                PyGILState_STATE _gilstate = PyGILState_Ensure();
                Py_INCREF((PyObject *) memview);
                PyGILState_Release(_gilstate);
            }
        } else {
            __pyx_fatalerror("Acquisition count is %d (line %d)",
                             old_acquisition_count+1, lineno);
        }
    }
}
static CYTHON_INLINE void __Pyx_XCLEAR_MEMVIEW(__Pyx_memviewslice *memslice,
                                             int have_gil, int lineno) {
    __pyx_nonatomic_int_type old_acquisition_count;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None)) {
        memslice->memview = NULL;
        return;
    }
    old_acquisition_count = __pyx_sub_acquisition_count(memview);
    memslice->data = NULL;
    if (likely(old_acquisition_count > 1)) {
        memslice->memview = NULL;
    } else if (likely(old_acquisition_count == 1)) {
        if (have_gil) {
            Py_CLEAR(memslice->memview);
        } else {
            PyGILState_STATE _gilstate = PyGILState_Ensure();
            Py_CLEAR(memslice->memview);
            PyGILState_Release(_gilstate);
        }
    } else {
        __pyx_fatalerror("Acquisition count is %d (line %d)",
                         old_acquisition_count-1, lineno);
    }
}

/* CIntFromPy */
  static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* TypeInfoToFormat */
  static struct __pyx_typeinfo_string __Pyx_TypeInfoToFormat(__Pyx_TypeInfo *type) {
    struct __pyx_typeinfo_string result = { {0} };
    char *buf = (char *) result.string;
    size_t size = type->size;
    switch (type->typegroup) {
        case 'H':
            *buf = 'c';
            break;
        case 'I':
        case 'U':
            if (size == 1)
                *buf = (type->is_unsigned) ? 'B' : 'b';
            else if (size == 2)
                *buf = (type->is_unsigned) ? 'H' : 'h';
            else if (size == 4)
                *buf = (type->is_unsigned) ? 'I' : 'i';
            else if (size == 8)
                *buf = (type->is_unsigned) ? 'Q' : 'q';
            break;
        case 'P':
            *buf = 'P';
            break;
        case 'C':
         {
            __Pyx_TypeInfo complex_type = *type;
            complex_type.typegroup = 'R';
            complex_type.size /= 2;
            *buf++ = 'Z';
            *buf = __Pyx_TypeInfoToFormat(&complex_type).string[0];
            break;
         }
        case 'R':
            if (size == 4)
                *buf = 'f';
            else if (size == 8)
                *buf = 'd';
            else
                *buf = 'g';
            break;
    }
    return result;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
  static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
  static CYTHON_INLINE npy_intp __Pyx_PyInt_As_npy_intp(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_intp neg_one = (npy_intp) -1, const_zero = (npy_intp) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_intp) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_intp, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_intp) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        npy_intp val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_intp) -1;
        val = __Pyx_PyInt_As_npy_intp(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(npy_intp, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(npy_intp) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) >= 2 * PyLong_SHIFT)) {
                            return (npy_intp) (((((npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(npy_intp) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) >= 3 * PyLong_SHIFT)) {
                            return (npy_intp) (((((((npy_intp)digits[2]) << PyLong_SHIFT) | (npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(npy_intp) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) >= 4 * PyLong_SHIFT)) {
                            return (npy_intp) (((((((((npy_intp)digits[3]) << PyLong_SHIFT) | (npy_intp)digits[2]) << PyLong_SHIFT) | (npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (npy_intp) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(npy_intp) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(npy_intp, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(npy_intp) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(npy_intp, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(npy_intp, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(npy_intp) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) - 1 > 2 * PyLong_SHIFT)) {
                            return (npy_intp) (((npy_intp)-1)*(((((npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(npy_intp) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) - 1 > 2 * PyLong_SHIFT)) {
                            return (npy_intp) ((((((npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(npy_intp) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) - 1 > 3 * PyLong_SHIFT)) {
                            return (npy_intp) (((npy_intp)-1)*(((((((npy_intp)digits[2]) << PyLong_SHIFT) | (npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(npy_intp) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) - 1 > 3 * PyLong_SHIFT)) {
                            return (npy_intp) ((((((((npy_intp)digits[2]) << PyLong_SHIFT) | (npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(npy_intp) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) - 1 > 4 * PyLong_SHIFT)) {
                            return (npy_intp) (((npy_intp)-1)*(((((((((npy_intp)digits[3]) << PyLong_SHIFT) | (npy_intp)digits[2]) << PyLong_SHIFT) | (npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(npy_intp) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(npy_intp, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(npy_intp) - 1 > 4 * PyLong_SHIFT)) {
                            return (npy_intp) ((((((((((npy_intp)digits[3]) << PyLong_SHIFT) | (npy_intp)digits[2]) << PyLong_SHIFT) | (npy_intp)digits[1]) << PyLong_SHIFT) | (npy_intp)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(npy_intp) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(npy_intp, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(npy_intp) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(npy_intp, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        npy_intp val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (npy_intp) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (npy_intp) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (npy_intp) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (npy_intp) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(npy_intp) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((npy_intp) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(npy_intp) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((npy_intp) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((npy_intp) 1) << (sizeof(npy_intp) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (npy_intp) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_intp");
    return (npy_intp) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_intp");
    return (npy_intp) -1;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_intp(npy_intp value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_intp neg_one = (npy_intp) -1, const_zero = (npy_intp) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_intp) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_intp) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_intp) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_intp) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_intp) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(npy_intp),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_intp));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
  static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(size_t) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 2 * PyLong_SHIFT)) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 3 * PyLong_SHIFT)) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 4 * PyLong_SHIFT)) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (size_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(size_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(size_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(size_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        size_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (size_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (size_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (size_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (size_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(size_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((size_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(size_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((size_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((size_t) 1) << (sizeof(size_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (size_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_short(short value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const short neg_one = (short) -1, const_zero = (short) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(short) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(short) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(short) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(short) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(short) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(short),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(short));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
  static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const char neg_one = (char) -1, const_zero = (char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(char) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(char, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (char) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        char val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (char) -1;
        val = __Pyx_PyInt_As_char(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) >= 2 * PyLong_SHIFT)) {
                            return (char) (((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) >= 3 * PyLong_SHIFT)) {
                            return (char) (((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) >= 4 * PyLong_SHIFT)) {
                            return (char) (((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (char) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(char) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(char) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(char) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                            return (char) (((char)-1)*(((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                            return (char) ((((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                            return (char) (((char)-1)*(((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                            return (char) ((((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                            return (char) (((char)-1)*(((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                            return (char) ((((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(char) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(char) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        char val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (char) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (char) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (char) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (char) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(char) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((char) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(char) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((char) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((char) 1) << (sizeof(char) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (char) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to char");
    return (char) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to char");
    return (char) -1;
}

/* FormatTypeName */
  #if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__554);
    }
    return name;
}
#endif

/* CoroutineBase */
  #include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(PyObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body(self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(PyObject* gen, PyObject *retval) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval))
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    gen->is_running = 0;
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        Py_TYPE(gen)->tp_del(self);
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (likely(--self->ob_refcnt == 0)) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context)
{
    PyObject *frame = self->gi_frame;
    CYTHON_UNUSED_VAR(context);
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
  static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
  #ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (unlikely(!module)) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
  static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) __Pyx_PyObject_GenericGetAttrNoDict},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    __pyx_GeneratorType_slots
};
#else
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if PY_VERSION_HEX >= 0x030d00A4
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_Generator_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_GeneratorType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
#endif
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
  static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* InitStrings */
  #if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
